/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(vb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function tb(ub){var r=ub.a;var s=r.buffer;r.grow=rb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=ub.abort;var M=NaN;var N=Infinity;var O=ub.b;var P=ub.c;var Q=ub.d;var R=ub.e;var S=ub.f;var T=ub.g;var U=ub.h;var V=ub.i;var W=ub.j;var X=ub.k;var Y=ub.l;var Z=ub.m;var _=ub.n;var $=ub.o;var aa=ub.p;var ba=ub.q;var ca=ub.r;var da=ub.s;var ea=ub.t;var fa=ub.u;var ga=ub.v;var ha=ub.w;var ia=ub.x;var ja=ub.y;var ka=ub.z;var la=ub.A;var ma=ub.B;var na=ub.C;var oa=ub.D;var pa=ub.E;var qa=ub.F;var ra=ub.G;var sa=ub.H;var ta=ub.I;var ua=ub.J;var va=ub.K;var wa=ub.L;var xa=ub.M;var ya=ub.N;var za=ub.O;var Aa=ub.P;var Ba=ub.Q;var Ca=ub.R;var Da=ub.S;var Ea=ub.T;var Fa=ub.U;var Ga=ub.V;var Ha=ub.W;var Ia=ub.X;var Ja=ub.Y;var Ka=ub.Z;var La=ub._;var Ma=ub.$;var Na=ub.aa;var Oa=ub.ba;var Pa=ub.ca;var Qa=ub.da;var Ra=ub.ea;var Sa=ub.fa;var Ta=ub.ga;var Ua=ub.ha;var Va=ub.ia;var Wa=ub.ja;var Xa=ub.ka;var Ya=ub.la;var Za=ub.ma;var _a=ub.na;var $a=ub.oa;var ab=ub.pa;var bb=ub.qa;var cb=ub.ra;var db=ub.sa;var eb=ub.ta;var fb=ub.ua;var gb=ub.va;var hb=5712688;var ib=0;var jb=0;var kb=0;
// EMSCRIPTEN_START_FUNCS
function bJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,V=0,W=C(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=C(0),Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=C(0),$a=0;ea=hb-32|0;hb=ea;e=ea+24|0;v[e>>2]=49792;v[e>>2]=49692;g=aJ(ea+16|0);h=aJ(ea+8|0);ga=b;ma=c;na=e;oa=v[g>>2];Fa=w[g+4|0];pa=v[h>>2];Ga=w[h+4|0];c=0;M=hb-112|0;hb=M;d=a;qa=a+24604|0;a=qa;a:{if(!v[a+16>>2]){break a}b=v[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=v[a+28>>2];if(a>>>0>4){break a}c=23>>>a&1}if(!c){c=M+96|0;vM(c,9162,13038,220,45);a=hb+-64|0;hb=a;v[a+56>>2]=0;e=wM(a+56|0);b=vc(a+24|0,17850);v[23516]=0;U(5,a+8|0,1,17513);g=v[23516];v[23516]=0;b:{c:{d:{e:{if((g|0)!=1){v[23516]=0;U(2,a+40|0,b|0,a+8|0);g=v[23516];v[23516]=0;if((g|0)==1){break e}v[23516]=0;da(863,e|0,c|0,1,13640,a+40|0);c=v[23516];v[23516]=0;if((c|0)!=1){break b}c=P()|0;O()|0;xb(a+40|0);break d}c=P()|0;O()|0;break c}c=P()|0;O()|0}xb(a+8|0)}xb(b);S(c|0);L()}xb(a+40|0);xb(a+8|0);xb(b);hb=a- -64|0}ra=d+8204|0;sa=d+397452|0;ta=d+397448|0;aa=d+393352|0;H=d+397456|0;_=d+12|0;Ha=d+1074376|0;Ia=d+1298420|0;Ja=d+1074365|0;while(1){f:{g:{a=v[d+480208>>2];if(!(!ga|a&512)){h:{if(v[d+1074380>>2]){break h}b=a|512;i:{if(a&256){break i}j=hb-48|0;hb=j;F=hb-32|0;hb=F;k=d+1074312|0;e=d+1074992|0;h=d+1298264|0;s=d+1074424|0;o=d+484360|0;n=d+1074448|0;m=d+1074376|0;b=v[d+1074392>>2];r=d+480188|0;A=d+480180|0;q=d+484376|0;p=d+484348|0;G=d+480210|0;E=d+484364|0;j:{k:{l:while(1){m:{a=b+1|0;v[d+1074392>>2]=a;if(bl(m)>>>0>a>>>0){break m}MN(F+24|0,v[A>>2],x[r>>1],m,(v[d+480208>>2]&524288)>>>19|0);n:{o:{p:{q:{r:{if(w[d+480208|0]&32){l=v[p>>2];c=v[d+484344>>2];b=x[d+1074446>>1];break r}b=65535;J=v[d+484360>>2];i=w[q|0];a=Sb(J,i);c=v[a>>2];a=Oc(c,v[a+4>>2]);f=x[d+1074448>>1];if(a>>>0>f>>>0){b=x[$b(c,f)>>1]}u[d+1074446>>1]=b;s:{t:{c=v[d+484344>>2];l=v[p>>2];a=b&65535;if(vf(c,l)>>>0<=a>>>0){break t}a=Xb(c,a);if(Nb(v[a>>2],v[a+4>>2])){break t}a=0;break s}a=1}while(1){u:{v:{if(!a){b=65534;u[d+1074446>>1]=65534;break v}w:{x:{y:{a=b&65535;if(vf(c,l)>>>0<=a>>>0){z:{A:{if((a|0)==65535){g=Sb(J,i);break A}g=Sb(J,i);if(Oc(v[g>>2],v[g+4>>2])>>>0>(f&65535)>>>0){break z}}b=x[g+28>>1];if(b){c=v[g>>2];l=Oc(c,v[g+4>>2]);break x}a=f&65535;c=v[g>>2];l=Oc(c,v[g+4>>2]);if(!a|l>>>0<a>>>0){break y}while(1){b=a;a=a-1|0;if(!a){break y}if(x[$b(c,a)>>1]!=65535){continue}break}break x}f=f+1|0;u[n>>1]=f;break w}u[d+1074450>>1]=f;break r}b=0}u[d+1074448>>1]=b;v[d+480208>>2]=v[d+480208>>2]&-524289;while(1){a=b&65535;if(a>>>0>=l>>>0){break q}if(x[$b(c,a)>>1]==65534){b=b+1|0;u[n>>1]=b;continue}break}if(!zq(g,a)){break q}f=x[d+1074448>>1];J=v[d+484360>>2];i=w[q|0];g=Sb(J,i)}b=65535;a=f&65535;if(Oc(v[g>>2],v[g+4>>2])>>>0>a>>>0){b=x[$b(v[Sb(J,i)>>2],a)>>1]}u[d+1074446>>1]=b;c=v[d+484344>>2];l=v[p>>2];a=b&65535;if(vf(c,l)>>>0<=a>>>0){break v}a=Xb(c,a);if(!Nb(v[a>>2],v[a+4>>2])){break u}}a=1;continue}a=0;continue}}a=b&65535;if(!te(c,l,a)){break k}b=v[s>>2];if(b>>>0>=y[Xb(c,a)+12>>2]){v[s>>2]=0;b=0}if(v[d+480208>>2]&32?v[d+480272>>2]!=-1:0){break n}if(!ct(h,x[n>>1],b,Qp(F+16|0,e),w[F+24|0])){break n}a=v[d+480272>>2];if(a){if((a|0)>0){v[d+480272>>2]=a-1}Rn(h,1);ct(h,x[n>>1],v[s>>2],Qp(F+16|0,e),w[F+24|0]);break n}if(!(w[G|0]&64)){break q}b=0;if(YN(h,n,s)){break o}v[d+1074448>>2]=0;v[d+1074424>>2]=0;v[d+1074428>>2]=0;c=pj(v[d+484360>>2],v[E>>2])-1|0;a=w[q|0];if((c|0)>(a|0)){break p}Dj(o,0)}Rn(h,1);break k}Dj(o,a+1&255);Rn(h,1)}while(1){if((b|0)==256){kM(d);v[d+1074416>>2]=v[d+480196>>2];v[d+1074420>>2]=v[d+480204>>2];v[d+1074456>>2]=v[d+480200>>2];a=x[d+1074448>>1];u[d+1074450>>1]=a;b=v[d+1074424>>2];v[d+1074428>>2]=b;c=Sb(v[d+484360>>2],w[q|0]);g=v[c>>2];if(Oc(g,v[c+4>>2])>>>0>a>>>0){Ya=d,Za=x[$b(g,a)>>1],u[Ya+1074446>>1]=Za}ct(h,a,b,Qp(F+16|0,e),w[F+24|0]);if(!te(v[d+484344>>2],v[p>>2],x[d+1074446>>1])){break k}}else{Vn((B(b,872)+d|0)+1074992|0,d,b&65535,134217728);b=b+1|0;continue}break}}KN(d,m,(v[d+480208>>2]&32)>>>5|0);a=Xb(v[d+484344>>2],x[d+1074446>>1]);a=ed(v[a>>2],v[v[a+48>>2]+12>>2],v[d+1074424>>2],0);g=e+B(x[r>>1],872)|0;b=e;while(1){if((b|0)==(g|0)){B:{C:{a=v[d+484344>>2];b=x[d+1074446>>1];if(Hm(a,v[d+484348>>2],b)){a=Xb(a,b);b=v[a+16>>2];a=v[a+20>>2];if(HN(b,a)){break C}}v[d+1074408>>2]=v[d+480216>>2];a=v[d+480220>>2];break B}v[d+1074408>>2]=b}v[d+1074412>>2]=a;if(!w[F+24|0]){break m}b=v[d+1074416>>2];v[d+1074392>>2]=b;continue l}Ab(F+16|0,k,82);D:{if(!zb(v[v[F+16>>2]>>2],v[F+20>>2])|w[b+805|0]!=1){break D}c=w[a+3|0];if((c|0)!=2&(c|0)!=3){break D}Ya=b,Za=_g(d,w[b+800|0],u[b+772>>1],v[b+704>>2]),v[Ya+700>>2]=Za}Ab(F+16|0,k,91);E:{if(!zb(v[v[F+16>>2]>>2],v[F+20>>2])){break E}if(Wc(w[a|0])){break E}c=w[b+788|0];if(!Wc(c)|w[b+791|0]!=19){break E}f=w[b+793|0];if((f&240)!=208|y[d+1074416>>2]>(f&15)>>>0){break E}Ya=b,Za=_g(d,c,u[b+772>>1],0),v[Ya+700>>2]=Za}Ab(F+16|0,k,92);F:{if(!zb(v[v[F+16>>2]>>2],v[F+20>>2])){break F}Ab(F+8|0,k,5);if(zb(v[v[F+8>>2]>>2],v[F+12>>2])|v[d+1074416>>2]!=1|w[b+791|0]!=17){break F}v[d+1074420>>2]=B(w[b+793|0],1e4)}c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+788|0]=c;t[b+789|0]=c>>>8;t[b+790|0]=c>>>16;t[b+791|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[b+792|0]=c;t[b+793|0]=c>>>8;c=v[b+676>>2];v[b+20>>2]=v[b+672>>2];v[b+24>>2]=c;v[b+88>>2]=v[b+88>>2]&-393217;Ab(F+16|0,k,21);if(!zb(v[v[F+16>>2]>>2],v[F+20>>2])){t[b+831|0]=0}v[b+860>>2]=0;t[b+805|0]=0;a=a+6|0;b=b+872|0;continue}}break}a=v[d+1074416>>2];if(!a){v[d+1074416>>2]=1;a=1}b=v[d+480208>>2];e=v[d+1074392>>2];G:{H:{if(e){c=b&-4097;v[d+480208>>2]=c;g=v[d+480180>>2];if(g&1048580|(b&2097152?0:(g|0)==1)){break G}if(bl(m)>>>0<=e>>>0){break G}if(!((e>>>0)%(v[d+1074400>>2]+a>>>0)|0)){break H}break G}c=b&-528385}v[d+480208>>2]=c|4096}q=0;i=hb-16|0;hb=i;u[d+1074444>>1]=65535;a=d+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;A=d+480180|0;$=d+1075809|0;o=d+1074312|0;Z=d+906300|0;G=d+480208|0;I=d+1074376|0;Y=d+480188|0;ba=d+480210|0;V=d+480190|0;Q=d+480192|0;while(1){I:{if(x[Y>>1]<=q>>>0){J:{if(!(w[G+1|0]&16)){break J}if(!zN(d,I,Sb(v[d+484360>>2],w[d+484376|0]),1)){break J}v[G>>2]=v[G>>2]|524288}hb=i+16|0;break I}p=B(q,872)+d|0;k=p+1075785|0;c=w[k|0];l=p+1075784|0;r=w[l|0];R=p+1075781|0;e=w[R|0];a=v[d+1074392>>2];b=v[d+1074400>>2];h=v[d+1074416>>2];X=p+1075782|0;f=w[X|0];s=p+1075783|0;J=w[s|0];g=mm(f,J);n=p+1075843|0;t[n|0]=v[G>>2]>>>12&1|w[n|0]&254;h=(a>>>0)%(b+h>>>0)|0;N=p+1075780|0;a=w[N|0];K:{L:{M:{if((a|0)==252){m=ek(f,r);E=ek(J,c);a=252;b=e-1|0;if((b&255)>>>0>249){break M}b=v[Id(Z,b)>>2];if(!b){break M}lb[v[v[b>>2]+44>>2]](b,m,C(C(E>>>0)/C(999)));a=w[N|0]}if((a&255)==251){break L}}if(z[p+1075852>>2]==C(0)|J){break K}}m=v[G>>2]&4096;N:{if(!m){b=w[p+1075862|0];break N}b=w[R|0];t[p+1075862|0]=b}if((b-1&255)>>>0>249){break K}E=Id(Z,(b&255)-1|0);b=v[E>>2];if(!b){break K}O:{if(!m){a=x[p+1075860>>1];break O}a=My(w[X|0],w[l|0]);u[p+1075860>>1]=a;W=C(C(My(w[s|0],w[k|0])>>>0)/C(999));z[p+1075856>>2]=W;Ya=p+1075852|0,_a=C(C(W-C(lb[v[v[b>>2]+48>>2]](b,a)))/C(bl(I)>>>0)),z[Ya>>2]=_a;b=v[E>>2]}k=a;a=(v[d+1074392>>2]+1|0)==(bl(I)|0);lb[v[v[b>>2]+(a?44:108)>>2]](b,k,z[(a?p+1075856|0:p+1075852|0)>>2]);a=w[N|0]}k=p+1074992|0;if(oN(a&255)){b=hb-16|0;hb=b;u[b+12>>1]=0;v[b+8>>2]=0;a=sg(b+8|0);c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[k+788|0]=c;t[k+789|0]=c>>>8;t[k+790|0]=c>>>16;t[k+791|0]=c>>>24;a=w[a+4|0]|w[a+5|0]<<8;t[k+792|0]=a;t[k+793|0]=a>>>8;hb=b+16|0;g=0;J=0;r=0;f=0;e=0;c=0}P:{if(!(w[G+1|0]&16)){RM(d,k);break P}if(!e){break P}v[p+1075752>>2]=0}Q:{R:{if((J|0)==33){Ab(i+8|0,o,30);a=c>>>4|0;yy(d,q&65535,a+(c&15)|0,zb(v[v[i+8>>2]>>2],v[i+12>>2]));break R}a=0;if((J-19&255)>>>0>1){break R}S:{if(!(!(v[A>>2]&16777250)|c)){c=w[p+1075825|0];break S}t[p+1075825|0]=c}b=c&240;if((b|0)==208){b=c&15;if(!b){b=v[A>>2];if(b&16777248){a=1;break R}if((b|0)==2){break Q}break R}if(b>>>0>=v[d+1074400>>2]+v[d+1074416>>2]>>>0){Ab(i+8|0,o,14);a=b;if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){break R}if(!e){break Q}t[p+1075795|0]=e;break Q}a=b;break R}if(!(w[G+1|0]&16)|(b|0)!=224){break R}b=v[A>>2];if(v[d+1074396>>2]?b&16777250:0){break R}m=b&2;b=c&15;if(b?0:m){break R}v[d+1074396>>2]=b+1}b=v[A>>2]==16&(J|0)==19&(c&240)==208;E=b?0:a;T:{if(!E|w[N|0]!=255|w[X|0]!=2){break T}Ab(i+8|0,o,74);if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){break T}t[X|0]=0}K=c&15;a=v[d+1074392>>2];Ab(i+8|0,o,72);U:{if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){s=0;if(E>>>0>=y[d+1074416>>2]){break U}}Ab(i+8|0,o,88);s=(h|0)==(E|0)|(a|0)==(E|0);if(!(!zb(v[v[i+8>>2]>>2],v[i+12>>2])|!E)){break U}s=(a|0)==(E|0)}Ab(i+8|0,o,44);b=b?K|144:c;V:{if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){a=w[n|0];break V}a=w[n|0]&-2|(h|0)==(E|0)}t[n|0]=a&253|(s?2:0);Ab(i+8|0,o,66);g=(!E|zb(v[v[i+8>>2]>>2],v[i+12>>2])^1)&g;W:{X:{if(!(v[d+1074392>>2]|(!(w[ba|0]&32)|!e))){v[p+1075652>>2]=0;if(s){break X}if(!zi(v[k+8>>2],v[k+12>>2])){break W}t[p+1075795|0]=e;if(x[V>>1]<e>>>0){break W}a=B(e,104)+d|0;v[p+1075680>>2]=x[a+484410>>1];u[p+1075764>>1]=t[a+484417|0];break W}if(!s){break W}}c=w[N|0];if(e){t[p+1075795|0]=e}Y:{Z:{if(!Wc(c)){break Z}Ab(i+8|0,o,67);if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){break Z}a=u[p+1075762>>1];_:{if(!e|g){break _}h=nq(d,c,e);if(!h){break _}a=t[Fi(d,h)+36|0]}c=(a+c|0)-132>>>0<4294967176?0:c;break Y}if(!(v[A>>2]&25165856)){break Y}l=x[Q>>1];if(!l){break Y}if(c){a=Wc(c)}else{a=1}if(!a){break Y}h=e;$:{if(!e){h=w[p+1075796|0];if(!h){break $}}if(v[((h<<2)+d|0)+900380>>2]?h>>>0<=l>>>0:0){break Y}c=0}e=0}if(!((J|0)!=25|b)){Ab(i+8|0,o,55);a=zb(v[v[i+8>>2]>>2],v[i+12>>2]);e=a?0:e;c=a?0:c}Ab(i+8|0,o,65);a=(e|0)!=0;l=zb(v[v[i+8>>2]>>2],v[i+12>>2]);ca=!c;T=1;aa:{if(v[A>>2]&16777248){break aa}Ab(i+8|0,o,107);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){break aa}Ab(i,o,85);T=0;if(!zb(v[v[i>>2]>>2],v[i+4>>2])){break aa}if(zi(v[k+8>>2],v[k+12>>2])){break aa}T=1;h=v[p+1075096>>2];if(!h){break aa}T=Vd(v[h>>2],v[h+20>>2])^1}m=a&l;a=a&ca;ba:{ca:{da:{ea:{fa:{ga:{ha:{if(!(v[A>>2]&1048580)){break ha}ia:{if((c|0)!=255){break ia}if(!(!((f|0)==1|e)&(J|0)!=13)){Ab(i+8|0,o,55);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){break ia}}h=v[p+1075648>>2];if(t[h+60|0]&1?h:0){break ia}v[p+1075680>>2]=0;a=p+1075080|0;v[a>>2]=v[a>>2]|2097152;ja:{if(!(v[G>>2]&4096)){break ja}Ab(i+8|0,o,86);if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){break ja}v[a>>2]=v[a>>2]|4096}e=0;c=0;a=0;h=0;l=1;if(m){break ca}break ba}Ab(i+8|0,o,59);if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])|v[G>>2]&4096){break ha}if(!c){c=w[p+1075789|0]-w[p+1075762|0]|0;break ga}if(c>>>0>250){T=0;m=1;c=0;break ga}if(!e){Ab(i+8|0,o,98);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){break ga}}T=1;m=1;break ga}h=0;if(!a){break ea}break fa}h=c;g=0}Ab(i+8|0,o,65);if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){break da}c=h;h=1}a=c;l=1;if(m){break ca}break ba}c=h;h=1;l=m}ka:{la:{if(!x[Q>>1]){if(x[V>>1]<e>>>0){break ka}a=(B(e,104)+d|0)+484380|0;break la}a=v[p+1075096>>2];if(!a){break ka}}ma:{if(u[a+34>>1]<0){break ma}if(v[A>>2]==2){if(!Vd(v[a>>2],v[a+20>>2])){break ma}}v[p+1075680>>2]=x[a+30>>1]}if(!l){break ka}Yp(k,x[a+28>>1],d)}a=c}Ab(i+8|0,o,71);if(!(!zb(v[v[i+8>>2]>>2],v[i+12>>2])|!e)){t[p+1075831|0]=32}na:{if(!x[Q>>1]){break na}Ab(i+8|0,o,100);if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])|!e){break na}if(Wc(a&255)){break na}c=v[G>>2];oa:{if(g){if(c&8){break oa}break na}if(!(c&4)){break na}}km(k);v[p+1075688>>2]=65536;c=p+1075080|0;v[c>>2]=v[c>>2]|2097152}if(h){Ab(i+8|0,o,11);pa:{qa:{ra:{if(!(zb(v[v[i+8>>2]>>2],v[i+12>>2])|v[A>>2]==268435456)){c=x[Q>>1];break ra}Ab(i+8|0,o,87);h=0;if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){h=zi(v[k+8>>2],v[k+12>>2])^1}c=x[Q>>1];sa:{if(c){if(c>>>0<e>>>0){break qa}if(v[p+1075648>>2]!=v[((e<<2)+d|0)+900380>>2]|h){break sa}break qa}if((h^-1)&v[p+1075096>>2]==((B(e,104)+d|0)+484380|0)){break pa}}a=w[p+1075789|0]}if(!(c&65535)){break pa}}if(!(v[A>>2]&1048588)){break pa}km(k);t[p+1075810|0]=0;v[p+1075748>>2]=0;v[p+1075688>>2]=65536;c=p+1075080|0;v[c>>2]=v[c>>2]&-2101249|2097152;Ab(i+8|0,o,86);if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){break pa}v[c>>2]=v[c>>2]&-2049}e=T?e:0}l=a&255;ta:{if(l>>>0<251){break ta}Ab(i+8|0,o,50);ua:{if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])|!e){break ua}c=nq(d,w[p+1075791|0],e);if(!c){break ua}c=B(c,104)+d|0;if(u[c+484414>>1]<0){break ua}v[p+1075680>>2]=x[c+484410>>1]}Ab(i+8|0,o,100);if(Ya=zb(v[v[i+8>>2]>>2],v[i+12>>2]),Za=0,$a=v[G>>2]&4,$a?Ya:Za){break ta}e=0}c=Wc(l);if(c){t[p+1075794|0]=a;t[p+1075791|0]=a;if(!g){SM(d,q&65535,e,l,0)}gP(k)}va:{wa:{xa:{ya:{za:{if(e){h=p+1075096|0;m=v[h>>2];Pp(d,k,e,g,1,1);a=v[h>>2];Aa:{if(!a|!(w[a+35|0]&2)){break Aa}T=v[d+1298300>>2];if(!vd(T)){break Aa}gz(T,q&65535,a+68|0)}Ba:{Ca:{if(v[A>>2]==1){if(!g){break Ca}Ab(i+8|0,o,85);if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ca}break Ba}Ab(i+8|0,o,50);if((c|zb(v[v[i+8>>2]>>2],v[i+12>>2])^1)!=1){break Ba}}t[p+1075795|0]=0}Ab(i+8|0,o,42);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!c|(m|0)==v[h>>2]){break ya}break za}if(v[A>>2]&16777248){a=0;if(c&(m|0)!=v[h>>2]){break xa}}Ab(i+8|0,o,107);Da:{if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])|(m|0)==v[h>>2]){break Da}if((c^1|g)==1){a=p+1075068|0;if(y[a>>2]>=y[k+4>>2]){break Da}v[a>>2]=0;break ya}g=0}Ab(i+8|0,o,85);if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){break ya}if(!zi(v[k+8>>2],v[k+12>>2])){break za}break ya}if(!l){a=g;break va}h=0;m=p+1075795|0;a=w[m|0];if(!(!a|c^1)){Pp(d,k,a,g,!(v[p+1075096>>2]?1:v[p+1075648>>2]),!(v[A>>2]&1048580));t[m|0]=0;h=1}a=g;break wa}v[k>>2]=0;v[k+4>>2]=0}a=g}h=0;if(!l){break va}}c=v[p+1075096>>2];Ea:{if(!c|!(w[c+35|0]&2)){break Ea}g=v[d+1298300>>2];if(!vd(g)){break Ea}if(!h){if(TM(g,q&65535)){break Ea}}gz(g,q&65535,c+68|0)}c=q&65535;$s(d,k,l,a,!(v[A>>2]&1048580),0,c);FN(v[A>>2],x[Y>>1],I,c);if(!(!a|(!(v[A>>2]&1048580)|!e))){e=p+1075080|0;v[e>>2]=v[e>>2]|2097152;km(k);t[p+1075810|0]=0;v[p+1075748>>2]=0}if(!(v[p+1075080>>2]&512)){break va}if(!vd(v[d+1298300>>2])){break va}if(l>>>0<=253){if((l|0)!=253){break va}Ab(i+8|0,o,99);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){break va}}Ab(i+8|0,o,110);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){hz(v[d+1298300>>2],c,0,1,0)}fk(v[d+1298300>>2],c)}Fa:{Ga:{switch(f-1|0){case 0:r=r>>>0<64?r:64;v[p+1075680>>2]=r<<2;c=p+1075080|0;v[c>>2]=v[c>>2]|2097152;break Fa;case 1:break Ga;default:break Fa}}lm(d,k,r,6)}if(x[Q>>1]){QM(d,q&65535)}g=a}Ab(i+8|0,o,77);if(Ya=zb(v[v[i+8>>2]>>2],v[i+12>>2]),Za=0,$a=v[((q<<5)+d|0)+480280>>2]&1024,$a?Ya:Za){break Q}a=v[d+1074392>>2];Ab(i+8|0,o,75);e=a>>>0>=E>>>0;Ha:{Ia:{Ja:{Ka:{if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])|!E){break Ka}c=v[d+1074392>>2];if(!c){break Ja}e=1;if((c|0)!=(E|0)){break Ka}e=!w[R|0]&(f|0)!=11}a=f;if(!e|a>>>0<3){break Ja}if((a|0)==11){a=i+8|0;Ry(a,d,w[N+3|0],w[N+4|0],E);a=w[Re(a)|0];xy(d,q&65535,x[i+8>>1]);if(a){break Ia}f=11;break Ja}Ab(i+8|0,o,62);La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{if(!(!zb(v[v[i+8>>2]>>2],v[i+12>>2])|r)){r=0;f=0;Sa:{switch(a-8|0){case 0:break Ra;case 1:break Sa;default:break Ja}}if(w[G+1|0]&16){break Ja}v[p+1075684>>2]=0;break Ja}Ab(i+8|0,o,41);Ta:{if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ta}if(r){t[p+1075826|0]=r;break Ta}r=w[p+1075826|0]}Ua:{switch(a-3|0){case 0:case 1:Va:{Wa:{if(r){break Wa}Ab(i+8|0,o,41);if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){break Wa}r=w[p+1075826|0];if(r){break Va}r=0;break Ja}t[p+1075826|0]=r}On(d,k,((a|0)==3?r<<4:r)&255);break Ja;case 2:if((E|0)!=v[d+1074392>>2]){Ab(i+8|0,o,41);f=5;if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ja}}Ab(i+8|0,o,41);Nn(d,k,r,zb(v[v[i+8>>2]>>2],v[i+12>>2]));f=5;break Ja;case 3:if((E|0)!=v[d+1074392>>2]){Ab(i+8|0,o,41);f=6;if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ja}}Ab(i+8|0,o,41);Mn(d,k,r,zb(v[v[i+8>>2]>>2],v[i+12>>2]));f=6;break Ja;case 11:break La;case 12:break Ma;case 10:break Na;case 9:break Oa;case 7:break Pa;case 6:break Qa;case 5:break Ra;case 4:break Ua;default:break Ja}}Ab(i+8|0,o,53);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){t[p+1075815|0]=r&15;f=7;break Ja}al(k,r<<4);f=7;break Ja}al(k,r);f=8;break Ja}Ab(i+8|0,o,62);wy(d,k,r,zb(v[v[i+8>>2]>>2],v[i+12>>2])^1);f=9;break Ja}Ab(i+8|0,o,62);wy(d,k,r<<4&240,zb(v[v[i+8>>2]>>2],v[i+12>>2])^1);f=10;break Ja}f=12;Ab(i+8|0,o,12);PM(d,q&65535,r<<2&252,zb(v[v[i+8>>2]>>2],v[i+12>>2]));break Ja}Ab(i+8|0,o,12);OM(d,q&65535,r<<2&252,zb(v[v[i+8>>2]>>2],v[i+12>>2]));f=13;break Ja}f=15;if(!s){break Ja}a=v[p+1075096>>2];if(!a|r>>>0>9){break Ja}Xa:{if(!r){e=v[p+1075656>>2];break Xa}e=v[Bb(a+68|0,r-1|0)>>2];v[p+1075656>>2]=e}Pn(d,k,e);break Ja}f=14;if(r>>>0>1){break Ja}t[n|0]=w[n|0]&247|!r<<3}e=b;Ya:{Za:{_a:{switch(J-1|0){case 12:if(!(w[G+1|0]&16)){break Ia}a=B(q,872)+d|0;v[a+1075680>>2]=b>>>0<64?b<<2:256;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ia;case 1:if(!b){e=0;if(t[A|0]&1){break Ha}}PM(d,q&65535,b,0);break Ia;case 2:if(!b){e=0;if(t[A|0]&1){break Ha}}OM(d,q&65535,b,0);break Ia;case 10:if(!b){e=0;if(v[A>>2]==1){break Ha}}On(d,k,b);break Ia;case 3:xy(d,q&65535,b);break Ia;case 5:if(!(!b&v[A>>2]==1)){On(d,k,b)}xy(d,q&65535,0);break Ia;case 4:al(k,b);break Ia;case 6:if(!(!b&v[A>>2]==1)){On(d,k,b)}al(k,0);break Ia;case 15:if(!(w[G+1|0]&16)){break Ia}break Ya;case 16:Ab(i+8|0,o,5);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!(w[G+1|0]&16)|!b){break Ia}break Ya}e=Ln(d,x[d+1074446>>1],v[d+1074424>>2],q&65535,0);$a:{if(!(v[d+480180>>2]&16777250)){break $a}if(e){t[(B(q,872)+d|0)+1075827|0]=e;break $a}e=w[(B(q,872)+d|0)+1075827|0]}v[i+8>>2]=B(e,1e4);uc(i+8|0,B(v[v[d+8>>2]+24>>2],1e4));a=hb-16|0;hb=a;c=v[i+8>>2];v[a+8>>2]=c;b=v[d+8>>2];ab:{if(c>>>0>=(v[d+480180>>2]&16393?1e4:32e4)>>>0){c=v[d+480208>>2];Ab(a,d+1074312|0,92);if((zb(v[v[a>>2]>>2],v[a+4>>2])|0)==((c&4096)>>>12|0)){break ab}v[a>>2]=B(v[b+24>>2],1e4);Ya=d+1074420|0,Za=v[Hb(a+8|0,a)>>2],v[Ya>>2]=Za;break ab}if(w[d+480209|0]&16){break ab}g=d+1074420|0;c=(c>>>0)/1e4|0;h=B(c&15,1e4);v[g>>2]=v[g>>2]+((c&240)==16?h:0-h|0);c=v[b+20>>2];b=v[b+24>>2];Ab(a,d+1074312|0,8);Ko(g,B(c,1e4),zb(v[v[a>>2]>>2],v[a+4>>2])?255e4:B(b,1e4))}hb=a+16|0;break Ha;case 9:if(!s|v[A>>2]==4&g){break Ia}EN(d,k,q&65535,v[d+1074424>>2],x[d+1074446>>1]);break Ia;case 43:if(!s){break Ia}c=rka(v[(B(q,872)+d|0)+1075068>>2],0,b,0);a=kb;f=a>>>8|0;Pn(d,k,Bc((a&255)<<24|c>>>8,f));break Ia;case 0:if(v[d+1074392>>2]){break Ia}a=B(q,872)+d|0;bb:{if(w[a+1075789|0]?v[a+1075692>>2]:0){break bb}a=v[a+1075648>>2];if(a){if(sj(w[a+31|0])){break bb}}Ab(i+8|0,o,13);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){break bb}if(v[A>>2]&16777248){break Ia}}if(!b){e=0;if(w[A|0]&5){break Ha}t[(B(q,872)+d|0)+1075797|0]=1;break Ha}a=B(q,872)+d|0;t[a+1075798|0]=b;t[a+1075797|0]=1;break Ia;case 14:if(v[A>>2]&1048580){b=b&240?b:w[(B(q,872)+d|0)+1075799|0]&240|b;if(!(b&15)){b=w[(B(q,872)+d|0)+1075799|0]&15|b}b=b|256}e=b;Ab(i+8|0,o,23);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){b=d;c=q&65535;if(e){t[(B(q,872)+d|0)+1075799|0]=e;a=e}else{a=w[(B(q,872)+d|0)+1075799|0]}vy(b,c,a&255,(f|0)==15?r+1|0:0);break Ha}cb:{if(e){t[(B(q,872)+d|0)+1075799|0]=e;break cb}e=w[(B(q,872)+d|0)+1075799|0]}vy(d,q&65535,e,(f|0)==15?r+1|0:0);break Ha;case 17:if(!(w[G+1|0]&16)){break Ia}Ab(i+8|0,o,22);db:{eb:{if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!b){b=0;break eb}if(w[G|0]&4){break eb}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;t[(B(q,872)+d|0)+1075832|0]=b;break eb}Ab(i+8|0,o,71);if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){break db}}a=(B(q,872)+d|0)+1075831|0;t[a|0]=w[a|0]|128}a=B(q,872)+d|0;t[a+1075797|0]=18;if(!b){e=0;break Ha}t[a+1075832|0]=b;break Ia;case 22:if(!(w[G+1|0]&16)){break Ia}a=v[A>>2];e=b<<!(a&59593760);if(e>>>0<=128){v[d+1074456>>2]=e<<1;break Ha}if(a&16777250){break Ha}v[d+1074456>>2]=256;break Ha;case 23:Ab(i+8|0,o,9);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){NM(d,b,(B(q,872)+d|0)+1075809|0);break Ia}NM(d,b,$);break Ia;case 8:if(!(w[G+1|0]&16)){break Ia}lm(d,k,b,8);break Ia;case 28:wy(d,k,b,1);break Ia;case 7:vN(k,b);break Ia;case 25:wN(d,k,b);break Ia;case 18:e=hb-16|0;hb=e;h=d+1074376|0;a=q&65535;g=B(a,872);c=(h+g|0)+616|0;f=b&15;fb:{gb:{switch(b>>>4|0){case 0:a=(b&1)<<14;c=x[d+480188>>1];g=0;while(1){if((c|0)==(g|0)){break fb}h=(B(g,872)+d|0)+1075080|0;v[h>>2]=(a|v[h>>2]&-16385)^16384;g=g+1|0;continue};case 1:if(!f){f=0;if(!(v[d+480180>>2]&1048580)){break fb}}Iy(d,c,f);Ab(e+8|0,d+1074312|0,117);if(zb(v[v[e+8>>2]>>2],v[e+12>>2])){break fb}Fn(d,a,b|240,1);break fb;case 2:if(!f){f=0;if(!(v[d+480180>>2]&1048580)){break fb}}Hy(d,c,f);Ab(e+8|0,d+1074312|0,117);if(zb(v[v[e+8>>2]>>2],v[e+12>>2])){break fb}Fn(d,a,0-(b|240)|0,1);break fb;case 3:a=(d+g|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((f|0)!=0)<<20;break fb;case 4:t[(d+g|0)+1075814|0]=b&7;break fb;case 5:if(!(w[d+480209|0]&16)){break fb}g=v[d+480180>>2];if(g&69206025){c=B(a,872)+d|0;u[c+1075764>>1]=f<<28>>24;g=c+1075692|0;if(!v[g>>2]){break fb}if(!Wc(w[c+1075780|0])){break fb}a=B(a,872)+d|0;Ya=g,Za=_g(d,w[a+1075789|0],f<<28>>24,v[a+1075696>>2]),v[Ya>>2]=Za;break fb}c=Wc(w[(B(a,872)+d|0)+1075780|0]);if((g|0)==16){if(!c){break fb}c=B(a,872)+d|0;g=v[c+1075096>>2];if(!g){break fb}t[g+37|0]=f;u[c+1075764>>1]=f;c=c+1075692|0;if(!v[c>>2]){break fb}a=B(a,872)+d|0;Ya=c,Za=_g(d,w[a+1075789|0],f,v[a+1075696>>2]),v[Ya>>2]=Za;break fb}if(!c){break fb}a=B(a,872)+d|0;c=(b<<4^-128)<<24>>24;u[a+1075764>>1]=c;g=a+1075692|0;if(!v[g>>2]){break fb}Ya=g,Za=_g(d,w[a+1075789|0],c,v[a+1075696>>2]),v[Ya>>2]=Za;break fb;case 6:if(!(w[d+480209|0]&16)){break fb}Qy(d,h,c,f);break fb;case 7:t[(d+g|0)+1075817|0]=b&7;break fb;case 8:if(!(w[d+480209|0]&16)){break fb}lm(d,c,f,4);break fb;case 9:vy(d,a,f,0);break fb;case 10:if(f){Nn(d,c,f,0);break fb}if(!(v[d+480180>>2]&1048580)){break fb}Nn(d,c,0,0);break fb;case 11:if(f){Mn(d,c,f,0);break fb}if(!(v[d+480180>>2]&1048580)){break fb}Mn(d,c,0,0);break fb;case 12:yy(d,a,f,0);break fb;case 15:break gb;default:break fb}}if(v[d+480180>>2]==1){t[(B(a,872)+d|0)+1075838|0]=f;if(!(w[d+480209|0]&16)){break fb}RM(d,c);break fb}t[(B(a,872)+d|0)+1075836|0]=f}hb=e+16|0;break Ia;case 19:MM(d,q&65535,b);break Ia;case 24:Ab(i+8|0,o,55);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){if(v[d+1074392>>2]!=(b|0)){break Ia}a=v[(B(q,872)+d|0)+1075648>>2];if(t[a+60|0]&1?a:0){break Za}if(!(!(w[X|0]?1:w[R|0])|b)){a=(B(q,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|4096;break Za}a=B(q,872)+d|0;v[a+1075680>>2]=0;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Za}if(!(w[G+1|0]&16)){break Ia}break Za;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break Ia}if(!(1<<a&880)){if(a){if((a|0)!=1){break Ia}Gy(d,k,K);Ab(i+8|0,o,117);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ia}Fn(d,q&65535,-224-K|0,1);break Ia}Jy(d,k,K);Ab(i+8|0,o,117);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ia}Fn(d,q&65535,K|224,1);break Ia}Ab(i+8|0,o,58);if(zb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ia}MM(d,q&65535,b);break Ia;case 34:case 35:if(!(w[G+1|0]&16)&(J|0)!=36){break Ia}c=q&65535;AN(d,c,I,(J|0)==36);a=Kp(d,v[k+88>>2],v[k+656>>2]);if(!a){break Ia}lb[v[v[a>>2]+80>>2]](a,(x[k+774>>1]&65532)>>>2^8192,c);break Ia;case 20:if(!(w[G+1|0]&16)|b>>>0>64){break Ia}a=B(q,872)+d|0;v[a+1075740>>2]=b;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ia;case 21:f=v[A>>2];e=v[G>>2];a=b;hb:{if(a){t[k+816|0]=a;break hb}a=w[k+816|0]}g=a&255;h=a&240;c=a&15;ib:{jb:{if(!(!h|(c|0)!=15)){if(!(e&4096)){break ib}a=g>>>4|0;break jb}e=e&4096;if(!(!c|(h|0)!=240)){if(!e){break ib}a=0-c|0;break jb}if(e){break ib}if(c){a=0-c|0;if(!(f&25690144)|!h){break jb}break ib}if((a&255)>>>0<16){break ib}a=g>>>4|0}Ya=k,Za=Wb(a+v[k+748>>2]|0,0,64),v[Ya+748>>2]=Za}break Ia;case 26:uN(k,b);break Ia;case 29:if(!(w[G+1|0]&16)){break Ia}a=B(q,872)+d|0;v[a+1075716>>2]=b;Ab(i+8|0,o,60);if(Ya=0,Za=zb(v[v[i+8>>2]>>2],v[i+12>>2]),$a=w[a+1075722|0]&4,$a?Ya:Za){break Ia}a=B(q,872)+d|0;v[a+1075732>>2]=b;v[a+1075724>>2]=b;break Ia;case 11:yN(d,I,q&65535);break Ia;case 13:a=xN(d,I,q&65535,b);if((a|0)==-1){break Ia}v[d+1074436>>2]=a;if(!(w[d+480208|0]&32)){break Ia}u[d+1074444>>1]=x[d+1074448>>1];break Ia;case 37:case 38:case 39:case 40:lN(d,k,b,(J|0)==38|(J|0)==40,(J&254)==40);break Ia;case 41:DN(k,b);break Ia;case 42:if(v[d+1074392>>2]|K>>>0>1|b>>>0>47){break Ia}a=(b&240)==16;g=a?x[d+480188>>1]-1|0:q;e=a?0:q;a=((K|0)==1)<<26;while(1){c=e&65535;if(c>>>0>(g&65535)>>>0){break Ia}h=((c<<5)+d|0)+480280|0;v[h>>2]=a|v[h>>2]&-67108865;c=(B(c,872)+d|0)+1075080|0;v[c>>2]=a|v[c>>2]&-67108865;e=e+1|0;continue};case 44:break _a;default:break Ha}}BN(k,b);break Ia}Kn(d,k);break Ia}IN(d,I,b)}e=b}Ab(i+8|0,o,78);if(!(!zb(v[v[i+8>>2]>>2],v[i+12>>2])|!e)){rN(k,e&255)}a=w[R|0];if(!a){break Q}t[p+1075796|0]=a}q=q+1|0;continue}break}a=1;break j}a=0}hb=F+32|0;N=!v[d+1074420>>2]|a^1;kb:{if(N){break kb}a=GN(d,d+1074376|0);v[d+1074380>>2]=a;v[d+1074404>>2]=a;b=Bd(x[d+480188>>1],1,31);lb:{if(Sd(w[d+1074366|0])){a=v[d+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}s=((B(v[d+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+32336|0]|0;break lb}s=v[d+480228>>2]}u[d+480212>>1]=0;o=d+1074312|0;T=d+1074365|0;F=d+480180|0;I=d+480210|0;K=d+480209|0;R=d+1074366|0;X=d+1074364|0;Z=d+1074360|0;q=0;while(1){if((q|0)==256){b=v[d+24608>>2];g=x[d+480212>>1];if(b>>>0>g>>>0){break kb}e=hb-16|0;hb=e;v[e+8>>2]=d;a=d+1074478|0;c=a;g=a+(g<<1)|0;mb:{a=a+(b<<1)|0;b=a-c|0;if((b|0)<3){break mb}h=b>>1;b=(h-2|0)/2|0;while(1){if((b|0)<0){break mb}cy(c,v[e+8>>2],h,c+(b<<1)|0);b=b-1|0;continue}}h=a-c>>1;b=a;while(1){if((b|0)!=(g|0)){if(Fp(v[e+8>>2],x[b>>1],x[c>>1])){dy(b,c);cy(c,v[e+8>>2],h,c)}b=b+2|0;continue}break}b=a-c>>1;while(1){if((b|0)>1){a=a-2|0;dy(c,a);b=b-1|0;cy(c,v[e+8>>2],b,c);continue}break}hb=e+16|0}else{m=B(q,872)+d|0;p=m+1075080|0;nb:{if(!(v[p>>2]&4096)|(v[m+1075016>>2]|(v[m+1075012>>2]|v[m+1075688>>2]))){break nb}Ab(j+16|0,o,64);if(zb(v[v[j+16>>2]>>2],v[j+20>>2])){break nb}v[m+1075068>>2]=0;a=m+1075084|0;v[a>>2]=0;v[a+4>>2]=0}a=x[d+480188>>1];b=v[p>>2];ob:{if(v[m+1075068>>2]|a>>>0>q>>>0?b&1024:1){if(a>>>0>q>>>0){aM(d,q&65535)}u[m+1075834>>1]=0;break ob}c=0;Q=m+1075712|0;v[Q>>2]=0;G=m+1075672|0;v[G>>2]=0;A=m+1075e3|0;e=A;v[e>>2]=0;v[e+4>>2]=0;v[m+1075092>>2]=0;v[j+44>>2]=1065353216;u[j+42>>1]=0;J=m+1075648|0;E=v[J>>2];v[j+36>>2]=0;f=0;l=m+1075692|0;f=v[l>>2]?v[m+1075068>>2]!=0:f;g=m+1074992|0;pb:{qb:{rb:{if(a>>>0<=q>>>0){break rb}if(w[((q<<5)+d|0)+480288|0]){break qb}if(!E){break rb}c=w[E+34|0]!=0}if((c|f)!=1){break pb}}v[j+8>>2]=v[m+1075680>>2];v[j+32>>2]=v[m+1075744>>2];Ab(j+16|0,o,28);b=j+8|0;a=zb(v[v[j+16>>2]>>2],v[j+20>>2])?j+32|0:b;c=hb-16|0;hb=c;e=d+1074312|0;Ab(c+8|0,e,28);sb:{if(zb(v[v[c+8>>2]>>2],v[c+12>>2])){v[a>>2]=v[a>>2]+u[g+776>>1];me(a,0,64);break sb}Ab(c+8|0,e,1);e=u[g+776>>1];if(zb(v[v[c+8>>2]>>2],v[c+12>>2])){v[a>>2]=e+v[a>>2];me(a,0,256);break sb}v[g+688>>2]=e+v[g+688>>2];me(g+688|0,0,256);v[a>>2]=v[g+688>>2];u[g+776>>1]=0}hb=c+16|0;a=hb-16|0;hb=a;c=d+1074312|0;Ab(a+8|0,c,28);tb:{ub:{if(!zb(v[v[a+8>>2]>>2],v[a+12>>2])){Ab(a,c,1);if(!zb(v[v[a>>2]>>2],v[a+4>>2])){break ub}}v[g+684>>2]=v[g+692>>2]+u[g+778>>1];me(g+684|0,0,256);break tb}v[g+692>>2]=v[g+692>>2]+u[g+778>>1];me(g+692|0,0,256);u[g+778>>1]=0;v[g+684>>2]=v[g+692>>2]}hb=a+16|0;e=hb-16|0;hb=e;vb:{if(!(w[g+90|0]&4)|(v[d+480208>>2]&2101248)==2101248){break vb}wb:{if(v[b>>2]<=0){Ab(e+8|0,d+1074312|0,21);if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])){break wb}}c=5;if(!(v[d+480180>>2]&5)){Ab(e+8|0,d+1074312|0,21);c=zb(v[v[e+8>>2]>>2],v[e+12>>2])?5:6}a=gy(d,w[g+825|0],w[g+820|0]);xb:{if((w[g+825|0]&3)!=1){break xb}Ab(e+8|0,d+1074312|0,89);if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])){break xb}a=w[g+819|0];k=w[g+820|0];h=k<<2&124;a=(!(w[g+90|0]&2)|w[d+480209|0]&16?a:w[g+823|0]+a|0)&32?h^127:h;a=k&32?0-a|0:a}if(v[d+480180>>2]!=131072){a=v[b>>2]+((B(w[g+827|0],a)|0)/(1<<c)|0)|0}else{c=64-a|0;a=v[b>>2];a=((B(w[g+827|0],B(c,a))|0)/-8192|0)+a|0}v[b>>2]=a}a=v[d+480208>>2];if(!(v[d+480180>>2]&16777248)|a&4?a&4096:0){break vb}Ab(e+8|0,d+1074312|0,21);a=w[g+826|0];c=w[g+820|0];h=zb(v[v[e+8>>2]>>2],v[e+12>>2]);t[g+820|0]=(h?a<<2:c)+(h?c:a)}hb=e+16|0;e=q&65535;h=hb-16|0;hb=h;a=d+1074312|0;Ab(h+8|0,a,71);yb:{if(zb(v[v[h+8>>2]>>2],v[h+12>>2])){a=(B(e,872)+d|0)+1075831|0;c=t[a|0];if((c|0)>=0){break yb}if(!(w[d+480209|0]&16|w[(B(e,872)+d|0)+1075797|0]!=18)){k=c&-33;t[a|0]=k;zb:{Ab:{if((k|0)!=-64){c=c&223;if((c|0)!=128){break Ab}c=w[(B(e,872)+d|0)+1075832|0]>>>4|-64;break zb}c=w[(B(e,872)+d|0)+1075832|0]&15|-128;break zb}c=c-1|0}t[a|0]=c;a=(B(e,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|2097152}if((c&224)!=128){break yb}v[b>>2]=0;break yb}if(w[(B(e,872)+d|0)+1075797|0]!=18){break yb}Ab(h+8|0,a,22);Bb:{if(zb(v[v[h+8>>2]>>2],v[h+12>>2])){n=B(e,872)+d|0;a=n+1075831|0;k=w[a|0];c=k<<24>>24;if(!((c|0)>=0|!v[n+1075068>>2])){Cb:{Db:{if((k|0)!=192){if((k|0)!=128){break Db}c=w[(B(e,872)+d|0)+1075832|0]>>>4|-64;break Cb}c=w[(B(e,872)+d|0)+1075832|0]&15|-128;break Cb}c=c-1|0}t[a|0]=c}if((c&192)!=128){break Bb}v[b>>2]=0;break Bb}a=w[(B(e,872)+d|0)+1075832|0];r=a>>>4|0;i=r+(a&15)|0;k=v[d+480180>>2];if(!(w[d+480208|0]&4?0:k&16777248)){r=r+1|0;i=i+2|0}a=(B(e,872)+d|0)+1075831|0;c=w[a|0];if(!(k&4)){c=(c&255)>>>0<i>>>0?c:0;if((c&255)>>>0>=r>>>0){v[b>>2]=0}t[a|0]=c+1;break Bb}Eb:{if(w[d+480209|0]&16){c=c&255?c-1|0:0;break Eb}t[a|0]=c+1}if(((c&255)>>>0)%(i>>>0)>>>0<r>>>0){break Bb}v[b>>2]=0}a=(B(e,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|2097152}a=B(e,872)+d|0;Fb:{if(w[a+1075797|0]!=18){break Fb}c=v[a+1075648>>2];if(!c){break Fb}a=w[c+34|0];if(!a|w[c+15|0]&2){break Fb}k=B(e,872)+d|0;if(v[k+1075080>>2]&134218752){break Fb}k=k+1075791|0;n=w[k|0];if(!Wc(n)){break Fb}a=v[Id(d+906300|0,a-1|0)>>2];if(!a){break Fb}n=lb[v[v[a>>2]+104>>2]](a,n,e)|0;i=v[b>>2];if(!(!n|i)){lb[v[v[a>>2]+96>>2]](a,c,w[k|0]|256,0,e);break Fb}if(n|!i){break Fb}lb[v[v[a>>2]+96>>2]](a,c,w[k|0],x[(B(e,872)+d|0)+1075680>>1],e)}hb=h+16|0;me(b,0,256);v[j+8>>2]=v[j+8>>2]<<6;Gb:{if(E){Ab(j+16|0,o,31);if(zb(v[v[j+16>>2]>>2],v[j+20>>2])){Xs(d,g)}c=j+8|0;a=hb-16|0;hb=a;Hb:{if(!ey(d,g,0)){break Hb}h=v[g+656>>2];k=d+1074312|0;Ab(a+8|0,k,31);Ib:{if(zb(v[v[a+8>>2]>>2],v[a+12>>2])){b=v[g+724>>2];if(b){break Ib}break Hb}b=v[g+724>>2]}Ab(a+8|0,k,31);i=b-zb(v[v[a+8>>2]>>2],v[a+12>>2])|0;b=Xp(h+48|0,i,256,64);r=w[h+65|0];Jb:{if((r|0)==255){break Jb}n=u[g+728>>1];if((n|0)==-1){break Jb}r=Bb(v[h+48>>2],r);h=w[r+2|0];r=x[r>>1];Ab(a+8|0,k,94);k=h<<2;b=(i|0)==(r|0)?k:b;if(zb(v[v[a+8>>2]>>2],v[a+12>>2])){b=n+(b-k<<1)|0;break Jb}if(!h){b=0;break Jb}b=(B(b,n)|0)/(k|0)|0}Ya=c,Za=(B(Wb(b,0,512),v[c>>2])|0)/256|0,v[Ya>>2]=Za}hb=a+16|0;jN(g,c);a=hb-16|0;hb=a;Kb:{if(!ey(d,g,1)){break Kb}c=v[g+656>>2];h=d+1074312|0;Ab(a+8|0,h,31);Lb:{if(zb(v[v[a+8>>2]>>2],v[a+12>>2])){b=v[g+732>>2];if(b){break Lb}break Kb}b=v[g+732>>2]}Ab(a+8|0,h,31);c=Xp(c+68|0,b-zb(v[v[a+8>>2]>>2],v[a+12>>2])|0,64,64)-32|0;b=v[g+684>>2];Ya=g,Za=Wb(((B(c,(b|0)>127?256-b|0:b)|0)/32|0)+b|0,0,256),v[Ya+684>>2]=Za}hb=a+16|0;Ab(j+16|0,o,115);if(zb(v[v[j+16>>2]>>2],v[j+20>>2])){break Gb}b=w[m+1075789|0];if(!b){break Gb}a=v[J>>2];if(!a|!w[a+26|0]){break Gb}mN(m+1075676|0,b,w[a+26|0],w[a+27|0]);break Gb}if(!(w[p+1|0]&16)){break Gb}v[m+1075688>>2]=0;v[j+8>>2]=0}Mb:{if(w[m+1075843|0]&8){c=0;v[j+8>>2]=0;break Mb}c=v[j+8>>2];if(!c){c=0;break Mb}if(w[p+3|0]&8){v[G>>2]=0;break Mb}if(Sd(w[T|0])){a=B(v[j+32>>2],v[m+1075740>>2]);b=a;h=a>>31;a=c<<8;Ya=G,Za=Dc(ska(rka(b,h,a,a>>31),kb,1048576,0),kb),v[Ya>>2]=Za;break Mb}a=B(v[j+32>>2],v[m+1075740>>2]);b=a;h=a>>31;a=B(v[d+1074456>>2],c);Ya=G,Za=Dc(ska(rka(b,h,a,a>>31),kb,1048576,0),kb),v[Ya>>2]=Za}v[Q>>2]=c;Nb:{Ob:{c=v[l>>2];if(!(v[F>>2]==2|(c|0)>=v[d+480260>>2])){if(!jj(d)){break Ob}c=v[l>>2]}if((c|0)<v[d+480264>>2]){break Nb}Ab(j+16|0,o,113);if(!zb(v[v[j+16>>2]>>2],v[j+20>>2])){break Nb}if(jj(d)){break Nb}v[l>>2]=v[d+480264>>2];break Nb}v[l>>2]=v[d+480260>>2]}Ab(j+16|0,o,73);a=v[l>>2];v[j+36>>2]=a;Pb:{if((v[p>>2]&1572864)!=1572864){break Pb}b=v[d+480208>>2];if(b&2097152){if(!mm(w[m+1075782|0],w[m+1075783|0])|b&4096){break Pb}}b=m+1075704|0;Qb:{if((a|0)==v[b>>2]){c=v[m+1075708>>2];break Qb}v[b>>2]=a;c=a;a=m+1075764|0;b=m+1075696|0;c=_g(d,Us(d,c,u[a>>1],v[b>>2]),u[a>>1],v[b>>2]);v[m+1075708>>2]=c}v[j+36>>2]=c}k=hb-16|0;hb=k;i=B(e,872)+d|0;r=i+1075648|0;a=v[r>>2];Rb:{if(!a){break Rb}b=w[a+34|0];if(v[(B(e,872)+d|0)+1075080>>2]&134218752|(!b|w[a+15|0]&2)){break Rb}if(!v[Id(d+906300|0,b-1|0)>>2]){break Rb}b=B(e,872)+d|0;h=b+1075780|0;a=w[b+1075793|0];Y=b+1075783|0;n=w[Y|0];Sb:{Tb:{if((n|0)==1){b=a;Ub:{Vb:{switch(((y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 0:b=a+(w[(B(e,872)+d|0)+1075798|0]>>>4|0)|0;break Ub;case 1:break Vb;default:break Ub}}b=a+(w[(B(e,872)+d|0)+1075798|0]&15)|0}c=B(e,872)+d|0;if(w[c+1075792|0]==(b&255)){break Sb}if(!(t[c+1075843|0]&1)){break Tb}if(!Wc(w[h|0])){break Tb}if(mm(w[h+2|0],1)){break Tb}break Sb}if(w[h|0]){b=a;if(!mm(w[h+2|0],n)){break Sb}}b=a;if(!w[(B(e,872)+d|0)+1075792|0]){break Sb}}jm(d,e,b&255|512,x[(B(e,872)+d|0)+1075680>>1])}V=(B(e,872)+d|0)+1075792|0;c=w[V|0];Wb:{Xb:{if(c){if((n|0)!=1|(b&255)!=(c|0)){break Xb}break Wb}if(!(t[(B(e,872)+d|0)+1075843|0]&1)|(n|0)!=1){break Wb}if(Wc(w[h|0])){break Wb}c=a;if(!Wc(a)){break Wb}}jm(d,e,c&255|256,0)}t[V|0]=w[Y|0]==1?b:0}Yb:{if(w[i+1075797|0]!=1){break Yb}if(uj(v[r>>2])){b=0;Zb:{_b:{$b:{switch(y[d+1074392>>2]%3|0){case 1:b=w[(B(e,872)+d|0)+1075798|0]>>>4|0;break _b;case 0:break _b;case 2:break $b;default:break Zb}}b=w[(B(e,872)+d|0)+1075798|0]&15}u[j+42>>1]=b}a=(B(e,872)+d|0)+1075843|0;t[a|0]=w[a|0]|96;break Yb}if(!(!(w[d+480209|0]&16)|v[d+480180>>2]!=1048576)){a=B(e,872)+d|0;b=_g(d,w[a+1075789|0],u[a+1075764>>1],v[a+1075696>>2]);v[j+36>>2]=b;v[a+1075692>>2]=b}b=d+1074312|0;Ab(k+8|0,b,13);if(zb(v[v[k+8>>2]>>2],v[k+12>>2])){b=w[(B(e,872)+d|0)+1075798|0];if(!b){break Yb}a=65536;ac:{switch(((y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:b=b<<4;case 0:a=v[((b&240)<<2)+37312>>2];break;default:break ac}}e=jj(d);b=v[j+36>>2];c=b;b=b>>31;if(e){a=rka(c,b,a,a>>31)+32768|0;h=kb;a=ska(a,a>>>0<32768?h+1|0:h,65536,0)}else{e=(a|0)/2|0;h=e>>31;n=b<<16|c>>>16;c=c<<16;b=c+e|0;n=h+n|0;a=ska(b,b>>>0<c>>>0?n+1|0:n,a,a>>31)}b=kb;Ya=j,Za=Dc(a,b),v[Ya+36>>2]=Za;break Yb}Ab(k+8|0,b,51);if(zb(v[v[k+8>>2]>>2],v[k+12>>2])){if(w[d+480209|0]&16){break Yb}bc:{cc:{a=v[d+1074416>>2];b=a-(y[d+1074392>>2]%(a>>>0)|0)|0;if((b|0)>16){break cc}if((b|0)==16){break Yb}a=0;dc:{switch((b|0)%3|0){case 0:break Yb;case 2:break cc;case 1:break dc;default:break bc}}a=w[(B(e,872)+d|0)+1075798|0]>>>4|0;break bc}a=w[(B(e,872)+d|0)+1075798|0]&15}c=a;a=B(e,872)+d|0;b=a+1075764|0;a=a+1075696|0;c=c+Us(d,v[j+36>>2],u[b>>1],v[a>>2])|0;b=_g(d,c,u[b>>1],v[a>>2]);v[j+36>>2]=b;if(c>>>0<109){break Yb}v[k+8>>2]=b;Ya=k,Za=_g(d,109,0,v[a>>2]),v[Ya+4>>2]=Za;Ya=j,Za=v[Vc(k+8|0,k+4|0)>>2],v[Ya+36>>2]=Za;break Yb}h=v[d+1074392>>2];n=d+480180|0;c=v[n>>2];ec:{if((c|0)!=1){a=w[(B(e,872)+d|0)+1075789|0];break ec}a=B(e,872)+d|0;a=Us(d,v[j+36>>2],u[a+1075764>>1],v[a+1075696>>2]);c=v[n>>2]}fc:{gc:{switch((((c&67633152?h+2|0:h)>>>0)%3|0)-1|0){case 0:a=(w[(B(e,872)+d|0)+1075798|0]>>>4|0)+a|0;break fc;case 1:break gc;default:break fc}}a=(w[(B(e,872)+d|0)+1075798|0]&15)+a|0}if(!(c&67633408|w[(B(e,872)+d|0)+1075789|0]!=(a&255))){Ab(k+8|0,b,82);if(!zb(v[v[k+8>>2]>>2],v[k+12>>2])){break Yb}}if(w[d+480210|0]&32){c=a&255;if((c|0)==85){v[j+36>>2]=2147483647;break Yb}a=c>>>0>85?a-37|0:a}c=B(e,872)+d|0;h=_g(d,a&255,u[c+1075764>>1],v[c+1075696>>2]);v[j+36>>2]=h;if(v[d+480180>>2]&71860480){v[c+1075692>>2]=h;break Yb}Ab(k+8|0,b,82);if(!zb(v[v[k+8>>2]>>2],v[k+12>>2])){break Yb}t[(B(e,872)+d|0)+1075792|0]=a}hb=k+16|0;if(!(!(w[I|0]&33)|v[j+36>>2]==2147483647)){hc:{if(v[F>>2]==2){c=452;a=3424;break hc}a=B(x[m+1075764>>1]>>>4&15,24);b=x[a+33046>>1]>>>1|0;c=b>>>0>452?b:452;a=x[a+33024>>1]<<1}me(j+36|0,c,a);me(l,c,a)}sN(d,g);b=v[p>>2]}ic:{if(!(b&256)|w[K|0]&64){break ic}Ab(j+16|0,o,37);if(!zb(v[v[j+16>>2]>>2],v[j+20>>2])){break ic}v[m+1075676>>2]=128}l=q&65535;aM(d,l);jc:{if(!f){break jc}a=kN(d,g,j+36|0);if((a|0)<0|!(w[p+1|0]&2)){break jc}b=v[d+1298300>>2];if(!vd(b)){break jc}Vp(b,l,a>>>2&255,1)}kc:{if(w[m+1075782|0]!=8){break kc}lc:{mc:{a=w[m+1075783|0];switch(a-5|0){case 1:break kc;case 0:case 2:break lc;default:break mc}}if((a|0)!=26){break kc}}a=v[F>>2];if((a|0)==4){if(w[K|0]&16){break kc}a=m+1075811|0;t[a|0]=w[a|0]+w[m+1075815|0];break kc}if(!(a&16777248)){break kc}al(g,w[m+1075784|0]);$L(d,l,j+36|0,j+44|0)}$L(d,l,j+36|0,j+44|0);nc:{if(!f){break nc}v[j+32>>2]=0;b=j+36|0;n=hb-16|0;hb=n;e=v[g+104>>2];oc:{if(!e|!w[e+40|0]){break oc}i=uj(v[g+656>>2]);f=jj(d);Ab(n+8|0,d+1074312|0,21);a=f?38336:37312;k=f?37312:38336;if(!(i|!zb(v[v[n+8>>2]>>2],v[n+12>>2])|v[d+480180>>2]==1048576)){i=w[e+41|0];if(!i){break oc}c=w[g+818|0];v[n+4>>2]=v[g+756>>2]+w[e+39|0];bi(n+4|0,w[e+40|0]<<8);h=v[n+4>>2];t[g+818|0]=c+i;v[g+756>>2]=h;h=(h|0)/256|0;pc:{qc:{switch(w[e+38|0]-1|0){case 3:c=ZL(Jn(d))+-64|0;break pc;case 2:c=64-(c+1>>>1|0)|0;break pc;case 1:c=(c+1>>>1|0)+-64|0;break pc;case 0:c=(c>>>1^-1)&64;break pc;default:break qc}}c=t[c+33616|0]}bi(b,8388607);e=v[b>>2]<<8;v[b>>2]=e;h=B(c,h);i=(h|0)/64|0;c=i>>31;i=(c^i)-c|0;r=i>>>2|0;c=e;rc:{sc:{if((h|0)<=-64){h=e>>31;a=v[(r<<2)+a>>2];a=Dc(ska(rka(e,h,a,a>>31),kb,65536,0),kb)-e|0;k=i&3;if(!k){break rc}f=(k<<2)+(f?37248:37184)|0;break sc}h=e>>31;a=v[k+(r<<2)>>2];a=Dc(ska(rka(e,h,a,a>>31),kb,65536,0),kb)-e|0;k=i&3;if(!k){break rc}f=(k<<2)+(f?37184:37248)|0}k=a;a=v[f>>2];a=(k+Dc(ska(rka(a,a>>31,e,h),kb,65536,0),kb)|0)-e|0}v[b>>2]=(a+c|0)/256;v[j+32>>2]=a&255;break oc}h=v[d+480180>>2]&16777248;c=w[e+39|0];tc:{if(!(h|c)){v[g+756>>2]=w[e+40|0]<<8;break tc}uc:{vc:{if(h){r=c<<1;f=v[g+756>>2];c=g+756|0;break vc}if(w[g+89|0]&8){break uc}f=((w[e+40|0]<<8&65280)>>>0)/(c>>>0)|0;r=v[g+756>>2];c=g+756|0}v[c>>2]=f+r}bi(g+756|0,w[e+40|0]<<8)}c=w[g+818|0]+w[e+41|0]|0;t[g+818|0]=c;c=c<<24>>24;wc:{xc:{switch(w[e+38|0]-1|0){case 3:t[g+818|0]=c+1;h=t[(c&63)+33552|0];break wc;case 2:h=(64-(c>>>1|0)&127)+-64|0;break wc;case 1:h=((c>>>1|0)- -64&127)+-64|0;break wc;case 0:h=(c|0)>=0?-64:64;break wc;default:break xc}}h=0-t[(c&255)+33616|0]|0;if(v[d+480180>>2]!=1048576){break wc}h=(64-t[(c+-64&255)+33616|0]|0)/2<<16>>16}c=h;h=B(c,v[g+756>>2]);f=(h|0)/256|0;if(i){z[j+44>>2]=z[j+44>>2]+C(C(C(C(w[e+40|0])*C(.05000000074505806))*C(c|0))*C(.000244140625));t[g+851|0]=w[g+851|0]|64;break oc}if(v[d+480180>>2]!=4){yc:{if((h|0)<=-256){f=0-f|0;c=0-h>>>16|0;e=(c<<2)+a|0;break yc}a=k;c=(h|0)/65536|0;e=a+(c<<2)|0}h=v[b>>2];c=v[((c<<2)+a|0)+4>>2];a=v[e>>2];a=((B(c-a|0,(f|0)/4&63)|0)/64|0)+a|0;a=Dc(ska(rka(h,h>>31,a,a>>31),kb,256,0),kb);v[b>>2]=a;v[j+32>>2]=a&255;v[b>>2]=v[b>>2]/256;break oc}v[b>>2]=v[b>>2]+((h|0)/16384|0)}hb=n+16|0;f=v[j+36>>2];if((f|0)<=v[d+480260>>2]){Ab(j+16|0,o,81);if(zb(v[v[j+16>>2]>>2],v[j+20>>2])){v[m+1075068>>2]=0}f=v[d+480260>>2];v[j+36>>2]=f}zc:{if(!uj(v[g+656>>2])){break zc}a=m+1075843|0;b=w[a|0];if(!(v[d+1074392>>2]|!(b&32)?b&64:1)){break zc}fP(g,z[j+44>>2],u[j+42>>1],d);b=a;a=w[a|0];t[b|0]=(a&64?-65:-33)&a}a=j+16|0;Sy(a,d,g,f,v[j+32>>2]);b=Db(a);a=rka(v[j+16>>2],v[j+20>>2],v[d+480240>>2],0);f=kb;c=ska(a,f,65536,0);e=kb;a=a+65535|0;f=a>>>0<65535?f+1|0:f;a=!f&a>>>0<131071;c=a?1:c;v[j+16>>2]=c;a=a?0:e;v[j+20>>2]=a;v[A>>2]=c;v[A+4>>2]=a;if((v[p>>2]&134219264)!=512){break nc}if(!vd(v[d+1298300>>2])){break nc}Ab(j+8|0,o,99);Ac:{Bc:{if(Ya=zb(v[v[j+8>>2]>>2],v[j+12>>2]),Za=1,$a=w[p+1|0]&16,$a?Ya:Za){a=v[F>>2];break Bc}a=v[F>>2];if((a|0)!=2){break Ac}}c=v[p>>2];e=c&2048;Cc:{if(e?(a|0)==2:0){break Cc}a=rka(v[b>>2],0,261625,0)+66904|0;b=kb;b=Bc(uka(a,a>>>0<66904?b+1|0:b,133808,0),kb);a=1;Dc:{if(e){break Dc}a=0;if(!(c&4096)){break Dc}a=!v[m+1075688>>2]}Ab(j+8|0,o,110);if(Ya=zb(v[v[j+8>>2]>>2],v[j+12>>2]),Za=0,$a=a,$a?Ya:Za){break Cc}c=v[d+1298300>>2];Ab(j+8|0,o,95);hz(c,l,b,a,zb(v[v[j+8>>2]>>2],v[j+12>>2]))}b=v[d+1298300>>2];a=rka(B(v[m+1075744>>2],B(v[m+1075740>>2],v[Q>>2])),0,63,0)+33554432|0;f=kb;f=a>>>0<33554432?f+1|0:f;Vp(b,l,Bc((f&67108863)<<6|a>>>26,f>>>26|0)&255,0);a=m+1075676|0;h=a;b=v[a>>2];c=0;a=v[d+1298300>>2];e=gl(a,l);Ec:{if((e|0)==255){break Ec}f=v[a>>2];if(gk(f)){break Ec}c=Ib(Jd(a+318|0,e),10);n=v[a+4>>2];e=jt(e)|192;a=w[c|0]&-49;a=(b|0)<171?a|16:a;a=((b|0)>84?a|32:a)&255;ah(f,n,l,e,a);c=(a>>>5&1)+(a<<27>>31)|0}v[h>>2]=(c<<7)+128}Fc:{a=v[J>>2];if(!a|(w[a+60|0]&7)!=1){break Fc}b=v[a+48>>2];a=v[a+52>>2];if(nc(b,a)){break Fc}b=v[_L(g,0)>>2];a=yj(a);if(b>>>0<x[a>>1]|w[a+2|0]){break Fc}nj(v[d+1298300>>2],l,1);Ab(j+8|0,o,109);a=v[p>>2];Ya=p,Za=(zb(v[v[j+8>>2]>>2],v[j+12>>2])?a:a&-4609)|4096,v[Ya>>2]=Za;v[m+1075688>>2]=0;break nc}Ab(j+8|0,o,99);if(!zb(v[v[j+8>>2]>>2],v[j+12>>2])|!(w[p+1|0]&16)|v[m+1075688>>2]){break nc}nj(v[d+1298300>>2],l,1);v[p>>2]=v[p>>2]&-513}Gc:{if(!E){break Gc}Ab(j+16|0,o,31);if(zb(v[v[j+16>>2]>>2],v[j+20>>2])){break Gc}Xs(d,g)}b=v[p>>2];a=b&-65537;n=m+1075012|0;k=v[G>>2];i=m+1075016|0;c=v[n>>2]|(k|v[i>>2])?(a|b<<7&65536)^65536:a;v[p>>2]=c;r=m+1075664|0;a=r;v[a>>2]=0;v[a+4>>2]=0;h=m+1075834|0;a=w[h|0];b=a-4|0;b=a>>>0<b>>>0?0:b;t[h|0]=b;l=m+1075835|0;a=w[l|0];e=a-4|0;a=a>>>0<e>>>0?0:e;t[l|0]=a;Hc:{Ic:{Jc:{Kc:{Lc:{Mc:{Nc:{Oc:{Pc:{e=v[m+1075096>>2];Qc:{if(!e){break Qc}f=v[e+20>>2];if(!Vd(v[e>>2],f)|!v[m+1075068>>2]){break Qc}if(zi(v[g+8>>2],v[g+12>>2])){break Pc}}v[m+1075008>>2]=0;break Oc}v[m+1075008>>2]=f;if(f){break Nc}}if(!lj(v[g+656>>2])){break Mc}f=0;if(c&6144){break Mc}}G=v[m+1075676>>2];e=(B(k,256-G|0)|0)/16384|0;e=e>>>0<127?e:127;if(b<<24>>24<0){t[h|0]=e;V=e}else{V=b}b=e>>>1|0;if((V&255)>>>0<b>>>0){t[h|0]=b}b=(B(k,G)|0)/16384|0;b=b>>>0<127?b:127;if(a<<24>>24<0){t[l|0]=b;a=b}b=b>>>1|0;if(b>>>0>(a&255)>>>0){break Lc}break Kc}if((b&255)>>>0>=129){t[h|0]=0}f=0;b=0;if((a&255)>>>0<129){break Jc}}t[l|0]=b}if(!f){break Jc}f=128;h=v[d+24624>>2];if(h>>>0>=2){f=Wb(v[m+1075676>>2],0,256)}v[j+16>>2]=f;b=B(k,s)>>>(Sd(w[R|0])?7:8)|0;Rc:{Sc:{Tc:{switch(w[X|0]){case 0:if(!(w[d+24616|0]&16)){break Sc}case 1:if((f|0)<=127){a=b>>>1|0;b=(B(b,f)|0)/256|0;break Rc}a=(B(b,256-f|0)|0)/256|0;b=b>>>1|0;break Rc;case 3:break Tc;default:break Sc}}bi(j+16|0,255);e=v[j+16>>2];if((e|0)<=0){a=65536}else{a=x[(0-e<<1)+39872>>1]}a=B(a,b)>>>16|0;b=B(b,x[(e<<1)+39360>>1])>>>16|0;break Rc}a=(B(b,256-f|0)|0)/256|0;b=(B(b,f)|0)/256|0}e=v[J>>2];Uc:{if(e){f=w[e+14|0];if(Co(f)){break Uc}}f=w[d+480268|0];if(Co(f)){break Uc}e=w[d+24648|0];f=w[I|0]&128?v[d+24668>>2]?-1:e:e}k=m+1075668|0;l=m+1075786|0;t[l|0]=f;e=v[A>>2];n=v[A+4>>2];if(!(c&131072|((e|0)!=0|(n|0)!=1)|(v[m+1075748>>2]|(f&255)==255))){t[l|0]=0}f=a;a=1<<v[Z>>2];v[r>>2]=(f|0)/(a|0);a=(b|0)/(a|0)|0;v[k>>2]=(c&256)>>>8|0?(h|0)==2?0-a|0:a:a;if(c&128){v[A>>2]=0-e;v[A+4>>2]=0-(((e|0)!=0)+n|0)}f=0;k=hb-16|0;hb=k;v[g+28>>2]=0;v[g+32>>2]=0;bi(g+672|0,524287);bi(g+676|0,524287);Vc:{Wc:{e=v[g+88>>2];if(!(e&65536)){b=v[g+676>>2];a=v[g+672>>2];break Wc}a=v[g+20>>2];h=v[g+672>>2];Xc:{if((a|0)!=(h|0)){b=v[g+24>>2];c=v[g+676>>2];break Xc}b=v[g+24>>2];c=v[g+676>>2];if((b|0)==(c|0)){break Wc}}e=v[d+24620>>2];c=(a|0)<(h|0)|(b|0)<(c|0);Yc:{if(c){a=mt(e,v[d+24636>>2]);break Yc}a=mt(e,v[d+24640>>2])}Ab(k,d+1074312|0,4);if(!(!zb(v[v[k>>2]>>2],v[k+4>>2])|!(v[d+480180>>2]&4))){a=v[d+24620>>2];a=rka(a,a>>31,5,0)+500|0;h=kb;a=Dc(ska(a,a>>>0<500?h+1|0:h,1e3,0),kb)}e=v[g+656>>2];Zc:{if(!e){b=a;break Zc}b=a;if(!c){break Zc}c=x[e+12>>1];if(c){b=(B(c,v[d+24620>>2])>>>0)/1e5|0}f=(c|0)!=0}l=b?b:1;e=v[g+672>>2];n=v[g+20>>2];i=e-n<<12;r=g;c=v[g+676>>2];b=v[g+24>>2];h=c-b<<12;if(!(w[g+90|0]&32|(!(c|e)|(!(b|n)|f)))){v[k+12>>2]=v[d+1074380>>2];me(k+12|0,a,2048);l=v[k+12>>2]}h=(h|0)/(l|0)|0;v[r+32>>2]=h;f=(i|0)/(l|0)|0;v[g+28>>2]=f;b=c+((B(h,l)|0)/-4096|0)|0;v[g+24>>2]=b;a=e+((B(f,l)|0)/-4096|0)|0;v[g+20>>2]=a;if(f|h){v[g+100>>2]=l;c=v[g+88>>2];break Vc}v[g+24>>2]=c;v[g+20>>2]=e;b=c;a=e;c=v[g+88>>2]&-65537;break Vc}v[g+24>>2]=b;v[g+20>>2]=a;c=e&-65537}v[g+88>>2]=c&-2097153;v[g+40>>2]=b<<12;v[g+36>>2]=a<<12;hb=k+16|0;c=v[p>>2];if(!(c&512)){break Ic}break Hc}v[n>>2]=0;v[i>>2]=0;v[m+1075068>>2]=0;if(v[m+1075088>>2]){break Ic}if(!v[m+1075084>>2]){break Hc}}a=x[d+480212>>1];u[d+480212>>1]=a+1;u[((a<<1)+d|0)+1074478>>1]=q}v[m+1075660>>2]=c}q=q+1|0;continue}break}}hb=j+48|0;if(N^1){a=v[d+480208>>2];break h}if(Sd(w[Ia|0])){b=v[d+480208>>2]|512;break i}l=0;_c:{a=v[d+24620>>2]/10|0;c=Dc(a,a>>31);if(!c){break _c}b=c>>>0<1048576?c:1048576;v[d+1074380>>2]=b;g=x[d+480212>>1];e=d+1074376|0;while(1){if((g|0)==(l|0)){break _c}a=e+B(x[(e+(l<<1)|0)+102>>1],872)|0;h=a+1288|0;v[h>>2]=0;v[h+4>>2]=0;v[a+716>>2]=b;h=v[a+640>>2]<<12;v[a+656>>2]=h;f=v[a+636>>2]<<12;v[a+652>>2]=f;v[a+704>>2]=v[a+704>>2]|65536;v[a+644>>2]=(0-f|0)/(b|0);v[a+648>>2]=(0-h|0)/(b|0);l=l+1|0;continue}}a=v[d+480208>>2];b=a|256;if(c){break i}b=a|512}a=b;v[d+480208>>2]=a}if(!(a&512)){break g}Ya=d+1074392|0,Za=bl(Ha),v[Ya>>2]=Za}hb=M+112|0;break f}v[M+96>>2]=512;a=v[d+1074380>>2];v[M+104>>2]=ga;v[M+100>>2]=a;k=zB(M+96|0);if(v[d+24632>>2]){a=0;b=hb-48|0;hb=b;c=k<<2;while(1){if((a|0)==4){$c:{a=0;while(1){if((a|0)==4){break $c}v[(b+32|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}}}else{v[b+32>>2]=0;e=((a<<11)+d|0)+16396|0;Uz(e,c+e|0,b+32|0);a=a+1|0;continue}break}a=v[d+24632>>2];v[b+24>>2]=k;v[b+20>>2]=a;v[b+16>>2]=b+32;a=v[v[na>>2]+8>>2];v[b+8>>2]=k;c=v[b+20>>2];v[b>>2]=v[b+16>>2];v[b+4>>2]=c;lb[a|0](na,b);hb=b+48|0}if(Sd(Ga)){a=0;while(1){if((a|0)==4){a=v[d+24632>>2];v[M+88>>2]=k;v[M+84>>2]=a;v[M+80>>2]=M+96;a=v[v[pa>>2]+8>>2];v[M+40>>2]=k;b=v[M+84>>2];v[M+32>>2]=v[M+80>>2];v[M+36>>2]=b;lb[a|0](pa,M+32|0)}else{v[(M+96|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}break}}$=0;ha=0;E=hb-48|0;hb=E;if(k){o=d+12|0;r=d+24592|0;A=d+24588|0;Rm(o,k,r,A);if(y[d+24624>>2]>=3){Rm(d+8204|0,k,d+24600|0,d+24596|0)}u[E+42>>1]=0;ua=d+1074312|0;Ka=d+24648|0;va=d+906300|0;La=d+24596|0;Ma=d+24600|0;Na=d+8204|0;F=d+397452|0;G=d+397448|0;p=d+393352|0;wa=d+397456|0;ja=d+1074376|0;Oa=d+480190|0;while(1){if(x[d+480212>>1]<=$>>>0){Ya=d,Za=x[ie(d+480214|0,E+42|0)>>1],u[Ya+480214>>1]=Za}else{l=ja+($<<1)|0;h=x[l+102>>1];a=B(h,872);Q=a+ja|0;ad:{bd:{if(v[Q+632>>2]){break bd}b=a+d|0;if(v[b+1075088>>2]){break bd}if(!v[b+1075084>>2]){break ad}}j=a+d|0;a=w[j+1075786|0]+1|0;if((a&255)>>>0<=5){f=v[(a<<24>>24<<2)+27952>>2]}else{f=0}I=j+1075080|0;g=v[I>>2];cd:{if(!(!(g&16777216)&w[d+24612|0]>>>5)){a=r;b=A;c=g;e=o;if(!(c&8388608)){break cd}}a=G;b=F;if(!w[wa+12|0]){Rm(p,k,a,b)}t[wa+12|0]=1;h=x[l+102>>1];c=v[I>>2];e=p}n=b;b=c>>>8&y[d+24624>>2]>2;T=b?La:n;J=b?Ma:a;c=b?Na:e;ka=Fl(d,ja,h,2,1)-1|0;xa=(ka&255)>>>0>249;dd:{if(xa){break dd}b=v[Id(va,ka)>>2];if(!b){break dd}a=v[b+24>>2];if(!a){break dd}T=b+36|0;J=b+40|0;if(!(t[b+28|0]&1)){Rm(a,k,J,T);v[b+28>>2]=v[b+28>>2]|1}c=a}l=Q+616|0;if(w[j+1075843|0]&8){$C(l,c,k);a=j+1075084|0;v[J>>2]=v[J>>2]+v[a>>2];v[T>>2]=v[T>>2]+v[j+1075088>>2];v[a>>2]=0;v[a+4>>2]=0;break ad}ba=0;e=hb-16|0;hb=e;a=E+16|0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;b=e+8|0;h=d+1074312|0;Ab(b,h,33);Ya=a,Za=zb(v[v[e+8>>2]>>2],v[e+12>>2]),t[Ya+16|0]=Za;Ab(b,h,116);Ya=a,Za=zb(v[v[e+8>>2]>>2],v[e+12>>2])^1,t[Ya+17|0]=Za;if(v[l+16>>2]){ZC(a,l);s=v[l+8>>2];n=v[l+12>>2];b=n>>31;n=(b^n)-((b>>>0>(b^s)>>>0)+b|0)|0;b=n;v[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}Pa=g>>>12&8|(g>>>5&2|(f|g&1));Qa=ha&65535;Ra=j+1075795|0;Sa=j+1075778|0;Ta=j+1075688|0;Ua=j+1075024|0;Va=j+1075020|0;Wa=j+1075668|0;Xa=j+1075664|0;R=j+1075088|0;X=j+1075084|0;ya=j+1075016|0;za=j+1075012|0;ca=j+1075096|0;Z=j+1075076|0;N=j+1075068|0;K=j+1075e3|0;ia=j+1075072|0;Y=j+1075092|0;hb=e+16|0;q=a;a=k;while(1){ed:{b=v[Y>>2];fa=b?a>>>0>b>>>0?b:a:a;v[E+8>>2]=fa;fd:{gd:{if(!fa){break gd}j=v[K>>2];g=v[K+4>>2];if(!(j|g)){break gd}f=v[N>>2];if(!f){break gd}e=v[q>>2];if(!e){break gd}b=v[I>>2];n=v[ia>>2];v[Q+632>>2]=e;e=v[l>>2];hd:{id:{s=n&b<<30>>31;h=v[l+4>>2];m=h;if((s|0)>(h|0)){if((g|0)<0){e=Pg(0,s<<1,e,h);v[l>>2]=e;h=kb;v[l+4>>2]=h;if(!((h|0)>=(s|0)&h>>>0<f+s>>>1>>>0)){e=0;v[l>>2]=e;h=s;v[l+4>>2]=h}jd:{if(b&4){b=b&-129;v[I>>2]=b;g=0-(((j|0)!=0)+g|0)|0;j=0-j|0;v[K>>2]=j;v[K+4>>2]=g;break jd}v[l>>2]=e;h=f-1|0;v[l+4>>2]=h}if(!(b&2)){break gd}if(f>>>0>h>>>0){break hd}break gd}if((h|0)>0|(h|0)>=0){break hd}h=0;break id}if(f>>>0>m>>>0){break hd}if(!(b&2)){break gd}if(b&4){if(!!j&(g|0)>=0|(g|0)>0){g=0-(((j|0)!=0)+g|0)|0;j=0-j|0;v[K>>2]=j;v[K+4>>2]=g}b=b|128;v[I>>2]=b;if(w[E+33|0]){m=w[E+32|0];i=v[Z>>2]-(m+n|0)|0;e=Pg(e,h,0,f);h=kb;if(h>>>0<i>>>0){e=Pg(0,f-m|0,e,h);h=kb;break id}h=n;e=0;break id}h=1-((e|0)!=0)|0;e=0-e|0;i=(f<<1)-(h+m|0)|0;m=e;v[l>>2]=e;V=0;h=V|i;v[l+4>>2]=h;if(i>>>0>n>>>0&f>>>0>i>>>0){break hd}v[E+44>>2]=w[E+32|0]+1;e=m;h=V|f-v[Hb(N,E+44|0)>>2];break id}if((g|0)<0){g=0-(((j|0)!=0)+g|0)|0;j=0-j|0;v[K>>2]=j;v[K+4>>2]=g}Pb(l,0,s-f|0);b=v[I>>2]|8192;v[I>>2]=b;e=v[l>>2];h=v[l+4>>2];break hd}v[l>>2]=e;v[l+4>>2]=h}V=h;kd:{if((h|0)<(s|0)){if((g|h)<0){break gd}v[E+44>>2]=fa;f=j;n=g;break kd}f=v[N>>2];if(f>>>0<V>>>0|(!!j&(g|0)>=0|(g|0)>0)&(f|0)==(V|0)){break gd}v[E+44>>2]=fa;f=g>>31;i=f^j;m=f;f=i-f|0;n=(g^m)-((i>>>0<m>>>0)+m|0)|0}m=f;i=n;uc(E+8|0,v[E+28>>2]);f=v[ia>>2];Aa=f+16|0;Ba=v[E+8>>2];Of(e,h,mf(j,g,Ba-1|0),kb);n=kb;Ca=f>>>0>V>>>0;if(!(!Ca&V>>>0<Aa>>>0)){b=b&-8193;v[I>>2]=b}ld:{md:{la=v[E+20>>2];nd:{if(la){f=v[E+24>>2];if(f>>>0<=V>>>0){od:{if((g|0)<0){j=0;g=f;break od}j=e;g=h;e=0;h=v[Z>>2]}Ya=E,Za=Lo(Pg(Pg(e,h,j,g),kb,1,0),kb,m,i)+1|0,v[Ya+44>>2]=Za;v[Q+632>>2]=la;break ld}if(!(!(b&8192)|Ca|V>>>0>=Aa>>>0)){Ya=E,Za=Lo(Pg(Pg(0,s+16|0,e,h),kb,1,0),kb,m,i)+1|0,v[Ya+44>>2]=Za;Ya=Q,Za=B(v[Z>>2]-s|0,yk(x[v[ca>>2]+34>>1]))+la|0,v[Ya+632>>2]=Za;break ld}if(!j&(g|0)<=0|(g|0)<0){break nd}if(fa>>>0<2|f>>>0>n>>>0){break md}Ya=E,Za=Lo(Pg(Pg(0,f,e,h),kb,1,0),kb,m,i)+1|0,v[Ya+44>>2]=Za;break ld}if((g|0)>0|(g|0)>=0){break md}}if((n|0)>=(s|0)){break ld}Ya=E,Za=Lo(Pg(Pg(e,h,0,s),kb,1,0),kb,m,i)+1|0,v[Ya+44>>2]=Za;break ld}b=v[N>>2];if((b|0)>(n|0)){break ld}Ya=E,Za=Lo(Pg(Pg(0,b,e,h),kb,1,0),kb,m,i)+1|0,v[Ya+44>>2]=Za}Ko(E+44|0,1,Ba);g=v[E+44>>2];if((g|0)>0){break fd}}v[Q+632>>2]=0;v[N>>2]=0;v[l>>2]=0;v[l+4>>2]=0;v[Y>>2]=0;$C(l,c,a);v[J>>2]=v[J>>2]+v[X>>2];v[T>>2]=v[T>>2]+v[R>>2];v[R>>2]=0;v[X>>2]=0;v[I>>2]=v[I>>2]&-129;break ed}pd:{qd:{if(y[d+24608>>2]>Qa>>>0){b=4;if(v[Y>>2]){break qd}b=0;if(v[ya>>2]|v[za>>2]){break qd}}Pb(l,rka(v[K>>2],v[K+4>>2],g,g>>31),kb);ba=0;v[R>>2]=0;v[X>>2]=0;c=(g<<3)+c|0;break pd}e=(g<<3)+c|0;h=e-8|0;v[X>>2]=0-v[h>>2];f=e-4|0;v[R>>2]=0-v[f>>2];lb[v[((b|Pa)<<2)+27568>>2]](l,Ka,c,g);v[X>>2]=v[X>>2]+v[h>>2];v[R>>2]=v[R>>2]+v[f>>2];ba=1;c=e}b=v[Y>>2];rd:{if(!b){break rd}if(b>>>0<=g>>>0){v[Y>>2]=0;v[za>>2]=v[Xa>>2];v[ya>>2]=v[Wa>>2];v[Va>>2]=0;v[Ua>>2]=0;if(v[Ta>>2]|!(w[I+1|0]&16)){break rd}v[N>>2]=0;v[Q+632>>2]=0;break rd}v[Y>>2]=b-g}e=0;h=0;b=v[l+4>>2];h=b>>>0>=y[Z>>2]?(w[I|0]&2)>>>1|0:h;f=b;b=v[N>>2];e=f>>>0<b>>>0|(!b|w[I|0]&2)?e:!x[Sa>>1];a=a-g|0;Ab(E+8|0,ua,85);sd:{td:{ud:{vd:{if(!zb(v[v[E+8>>2]>>2],v[E+12>>2])){break vd}b=w[Ra|0];if(!b|b>>>0>x[Oa>>1]){break vd}b=B(b,104)+d|0;g=b+484380|0;f=v[ca>>2];if((g|0)==(f|0)|(e|h)!=1){break ud}v[ca>>2]=g;v[Q+632>>2]=v[b+484400>>2];e=x[b+484414>>1];v[I>>2]=e|v[I>>2]&-768;h=e<<30>>31;e=v[b+484388>>2];v[N>>2]=h&e;b=v[b+484384>>2];v[ia>>2]=b;v[Z>>2]=e;v[l+4>>2]=b;ZC(q,l);if(!v[Q+632>>2]){break ed}if((a|0)>0){continue}break ed}if(h){break td}break sd}if(!h|(g|0)!=(f|0)){break sd}}Ab(E+8|0,ua,83);if(!zb(v[v[E+8>>2]>>2],v[E+12>>2])|v[ia>>2]){break sd}v[l>>2]=v[l>>2];v[l+4>>2]=0;b=v[v[ca>>2]+8>>2];v[N>>2]=b;v[Z>>2]=b}if((a|0)>0){continue}}break}v[Q+632>>2]=v[q>>2];ha=ba+ha|0;u[E+42>>1]=ha;if(!ba|xa){break ad}a=v[Id(va,ka)>>2];if(!a){break ad}lb[v[v[a>>2]+152>>2]](a)}$=$+1|0;continue}break}}hb=E+48|0;i=v[d+1298300>>2];if(vd(i)){a=_;b=k;c=(B(v[d+480232>>2],v[d+480236>>2])>>>0)/48|0;l=hb-16|0;hb=l;wd:{if(!w[i+534|0]){break wd}e=rka(c,0,6169,0);c=kb;f=c>>>16|0;p=Bc((c&65535)<<16|e>>>16,f);while(1){if(!b){break wd}f=v[i>>2];h=v[f>>2];c=v[f+4>>2];while(1){if((c|0)>=(h|0)){v[f+8>>2]=v[f+12>>2];h=0;j=0;q=0;c=hb-16|0;hb=c;while(1){if((q|0)==18){e=(h|0)<32767?h:32767;u[f+12>>1]=(e|0)>-32768?e:-32768;e=(j|0)<32767?j:32767;u[f+14>>1]=(e|0)>-32768?e:-32768;u[f+3832>>1]=x[f+3832>>1]+1;e=(x[f+3834>>1]+1>>>0)%13440|0;u[f+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;u[f+3836>>1]=(e&65280)>>>8;if(!w[f+3843|0]){u[f+3836>>1]=(e&64512)>>>10}e=x[f+3838>>1]+1|0;u[f+3838>>1]=e;if((e&65535)>>>0>=1024){u[f+3838>>1]=0;u[f+3840>>1]=x[f+3840>>1]+1&7}hb=c+16|0}else{g=f+B(q,44)|0;xd:{if(!w[g+56|0]){u[c+12>>1]=0;u[c+14>>1]=0;break xd}n=v[g+32>>2];e=x[n+3840>>1];if(e&3){n=(x[g+36>>1]>>>7&7)>>>(w[n+3844|0]^1)>>>(e&1)<<x[g+38>>1];e=e&4?0-n|0:n}else{e=0}n=v[g+52>>2];yd:{if(n){r=x[n+32>>1];o=x[g+48>>1];n=hg(v[g+16>>2],v[g+40>>2],e<<16>>16,0,u[g+46>>1]);s=v[g+40>>2];m=v[g+20>>2];if(!r){if(!o){e=e<<16>>16;n=hg(m,s,e,n,0);n=hg(v[g+24>>2],v[g+40>>2],e,n,0);e=hg(v[g+28>>2],v[g+40>>2],e,n,0);break yd}e=e<<16>>16;s=hg(m,s,e,0,0);s=hg(v[g+24>>2],v[g+40>>2],e,s,0);e=hg(v[g+28>>2],v[g+40>>2],e,s,0)+n|0;break yd}if(!o){e=e<<16>>16;n=hg(m,s,e,n,0);s=hg(v[g+24>>2],v[g+40>>2],e,0,0);e=hg(v[g+28>>2],v[g+40>>2],e,s,0)+n|0;break yd}e=e<<16>>16;s=hg(m,s,e,0,0);e=(hg(v[g+24>>2],v[g+40>>2],e,s,0)+n|0)+hg(v[g+28>>2],v[g+40>>2],e,0,0)|0;break yd}o=x[g+48>>1];e=e<<16>>16;n=hg(v[g+16>>2],v[g+40>>2],e,0,u[g+46>>1]);s=v[g+40>>2];m=v[g+20>>2];if(!o){e=hg(m,s,e,n,0);break yd}e=hg(m,s,e,0,0)+n|0}u[c+14>>1]=w[g+57|0]?e:0;u[c+12>>1]=w[g+58|0]?e:0}q=q+1|0;j=u[c+12>>1]+j|0;h=u[c+14>>1]+h|0;continue}break}h=v[f>>2];c=v[f+4>>2]-h|0;v[f+4>>2]=c;continue}break}e=h-c|0;u[l+14>>1]=(B(u[f+12>>1],c)+B(e,u[f+8>>1])|0)/(h|0);u[l+12>>1]=(B(u[f+14>>1],c)+B(e,u[f+10>>1])|0)/(h|0);v[f+4>>2]=c+49716;v[a>>2]=v[a>>2]+B(p,u[l+14>>1]);v[a+4>>2]=v[a+4>>2]+B(p,u[l+12>>1]);a=a+8|0;b=b-1|0;continue}}hb=l+16|0}a=w[H+12|0];if(v[H+16>>2]?1:a){if(!a){Rm(aa,k,ta,sa)}a=v[H>>2];b=v[H+80>>2];c=B(a,b)>>>4|0;c=c>>>0<32767?c:32767;u[H+98>>1]=c;u[H+96>>1]=c;c=v[H+49948>>2];e=B(c,a)>>>4|0;e=e>>>0<65536?e:65536;g=e+127>>>3|0;u[H+49946>>1]=g;e=e+255>>>4|0;u[H+49944>>1]=e;u[H+49942>>1]=e;u[H+49940>>1]=g;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0>8?a:8)|0;a=16-(B((b|0)<32768?b:32768,a>>>0>16?0:a)>>15)|0;q=0;while(1){if((k|0)!=(q|0)){b=q<<3;c=b+_|0;v[c>>2]=v[c>>2]+B(a,v[b+aa>>2]>>4);b=b|4;c=b+_|0;v[c>>2]=v[c>>2]+B(a,v[b+aa>>2]>>4);q=q+1|0;continue}break}n=H+68|0;l=0;b=u[H+84>>1];c=v[H+40>>2];h=v[H+36>>2];while(1){if((k|0)==(l|0)){v[H+40>>2]=c;v[H+36>>2]=h;g=k}else{a=(l<<3)+aa|0;e=v[a>>2]>>12;h=(B(b,e-h|0)>>15)+e|0;v[a>>2]=h;e=a;a=v[a+4>>2]>>12;c=(B(b,a-c|0)>>15)+a|0;v[e+4>>2]=c;l=l+1|0;continue}break}if(g){b=aa;a=g;r=v[n>>2]-1|0;i=x[n+22>>1];e=u[n+26>>1];s=u[n+18>>1];c=x[n+20>>1];h=u[n+24>>1];m=u[n+16>>1];q=v[n+4>>2];f=n+32928|0;while(1){if(a){j=fd(v[b>>2]);l=fd(v[b+4>>2]);c=fd((c<<16>>16)-j|0);i=fd((i<<16>>16)-l|0);c=$c(fd((B(c,m)|0)/65536<<1)+j|0);i=$c(fd((B(i,s)|0)/65536<<1)+l|0);l=f+(q<<2)|0;p=u[l>>1];j=$c(((B(p,h)|0)/-65536|0)+c|0);q=q+1&127;o=f+(q<<2)|0;l=u[l+2>>1];A=$c(((B(l,e)|0)/-65536|0)+i|0);u[o+2>>1]=A;u[o>>1]=j;r=r+1&8191;o=n+(r<<2)|0;Ya=o,Za=$c(p+((B(h,j)|0)/65536|0)|0),u[Ya+160>>1]=Za;Ya=o,Za=$c(l+((B(e,A)|0)/65536|0)|0),u[Ya+162>>1]=Za;b=b+8|0;a=a-1|0;continue}break}u[n+22>>1]=i;u[n+20>>1]=c;v[n+4>>2]=q}j=H+49892|0;G=H+33508|0;b=g;a=aa;while(1){if(b){e=v[H+76>>2];h=e&4095;i=G+(h<<2)|0;c=a;h=4096-h|0;A=e-v[H+49892>>2]&4095;e=4096-A|0;e=e>>>0>h>>>0?h:e;e=b>>>0<e>>>0?b:e;h=e>>>0<64?e:64;q=h;e=0;s=hb-32|0;hb=s;f=v[n>>2];while(1){if((e|0)==7){zd:{p=u[n+28>>1]/8<<16>>16;Ad:while(1){if(!q){break zd}q=q-1|0;e=0;l=0;f=0;while(1)if((e|0)==4){e=4;r=0;o=$c((f|0)/32768|0);F=$c((l|0)/32768|0);l=0;while(1)if((e|0)==7){e=$c(o+((l|0)/32768|0)|0);u[i>>1]=e;v[c>>2]=B(e,p);e=$c(F+((r|0)/32768|0)|0);u[i+2>>1]=e;v[c+4>>2]=B(e,p);c=c+8|0;i=i+4|0;continue Ad}else{f=s+(e<<2)|0;m=v[f>>2]+1&8191;v[f>>2]=m;m=n+(m<<2)|0;E=u[m+160>>1];f=n+(e<<4)|0;m=u[m+162>>1];r=(B(E,u[f+44>>1])+r|0)+B(m,u[f+46>>1])|0;l=(B(E,u[f+40>>1])+l|0)+B(m,u[f+42>>1])|0;e=e+1|0;continue}}else{m=s+(e<<2)|0;o=v[m>>2]+1&8191;v[m>>2]=o;V=l;l=n+(o<<2)|0;o=u[l+160>>1];m=n+(e<<4)|0;r=u[l+162>>1];l=(V+B(o,u[m+44>>1])|0)+B(r,u[m+46>>1])|0;f=(B(o,u[m+40>>1])+f|0)+B(r,u[m+42>>1])|0;e=e+1|0;continue}}}}else{v[s+(e<<2)>>2]=f+(v[(n+(e<<4)|0)+32>>2]^-1);e=e+1|0;continue}break}hb=s+32|0;q=G+(A<<2)|0;e=a;c=h;f=v[j+4>>2];l=j+8256|0;s=j- -64|0;m=j+24640|0;i=j+16448|0;while(1){p=f&2047;if(c){E=u[l+((f+1206&2047)<<2)>>1];J=u[(l+((f+754&2047)<<2)|0)+2>>1];F=u[(s+((f+1602&2047)<<2)|0)+2>>1];I=u[s+((f+1750&2047)<<2)>>1];o=u[q>>1];r=u[q+2>>1];A=m+((f+502&2047)<<2)|0;K=u[A>>1];Q=fd(u[j+32>>1]-K|0);A=u[A+2>>1];N=fd(u[j+34>>1]-A|0);T=u[j+26>>1];R=m+((f+22&2047)<<2)|0;X=u[R>>1];Z=fd(u[j+36>>1]-X|0);Y=u[j+28>>1];R=u[R+2>>1];V=fd(u[j+38>>1]-R|0);$=u[j+30>>1];K=$c(fd((B(Q,u[j+24>>1])|0)/65536<<1)+K|0);u[j+32>>1]=K;Ya=j,Za=$c(fd((B(N,T)|0)/65536<<1)+A|0),u[Ya+34>>1]=Za;Ya=j,Za=$c(fd((B(Z,Y)|0)/65536<<1)+X|0),u[Ya+36>>1]=Za;A=$c(fd((B(V,$)|0)/65536<<1)+R|0);u[j+38>>1]=A;K=fd((B(K,u[j+16>>1])|0)/32768|0);A=fd((B(A,u[j+22>>1])|0)/32768|0);K=fd(K+((o|0)/4<<16>>16)|0);Q=fd(A+((r|0)/4<<16>>16)|0);o=u[j+8>>1];N=fd(K+((B(o,I)|0)/-65536|0)|0);r=p<<2;T=r+s|0;A=u[j+10>>1];R=fd(Q+((B(A,F)|0)/-65536|0)|0);u[T+2>>1]=R;u[T>>1]=N;I=fd(I+((B(o,N)|0)/65536|0)|0);N=i+r|0;F=fd(F+((B(A,R)|0)/65536|0)|0);u[N+2>>1]=F;u[N>>1]=I;I=fd(I+K|0);K=fd(F+Q|0);F=i+((f+682&2047)<<2)|0;Q=u[F+2>>1];N=u[F>>1];F=fd((B(Q,u[j+42>>1])+B(N,u[j+40>>1])|0)/32768|0);f=i+((f+426&2047)<<2)|0;T=u[f+2>>1];R=u[f>>1];f=fd((B(T,u[j+46>>1])+B(R,u[j+44>>1])|0)/32768|0);N=fd(fd(I+N|0)-F|0);Q=fd(fd(K+Q|0)-f|0);I=fd(fd(I+R|0)-F|0);K=fd(fd(K+T|0)-f|0);F=fd(F+((B(o,E)|0)/-65536|0)|0);T=l+r|0;R=fd(f+((B(A,J)|0)/-65536|0)|0);u[T+2>>1]=R;u[T>>1]=F;o=(B(o,F)|0)/65536|0;f=fd(o+E|0);r=m+r|0;A=(B(A,R)|0)/65536|0;F=fd(A+J|0);u[r+2>>1]=F;u[r>>1]=f;Ya=e,Za=(v[e>>2]+B(fd(f+N|0),u[j+48>>1])|0)+B(fd(F+Q|0),u[j+50>>1])|0,v[Ya>>2]=Za;Ya=e,Za=(v[e+4>>2]+B(fd(fd(o)+I|0),u[j+52>>1])|0)+B(fd(fd(A)+K|0),u[j+54>>1])|0,v[Ya+4>>2]=Za;e=e+8|0;f=p+1|0;q=q+4|0;c=c-1|0;continue}break}v[j+4>>2]=p;v[H+76>>2]=h+v[H+76>>2]&4095;v[H+68>>2]=h+v[H+68>>2]&8191;b=b-h|0;a=(h<<3)+a|0;continue}break}v[H+68>>2]=v[H+68>>2]&8191;l=aa;e=_;c=g;h=0;f=0;j=v[H+56>>2];b=v[H- -64>>2];q=v[H+52>>2];a=v[H+60>>2];while(1){if(c){h=v[l>>2];f=v[l+4>>2];b=b-f|0;b=(((b|0)/1024|0)-b|0)+j|0;v[e+4>>2]=b+v[e+4>>2];a=a-h|0;a=(((a|0)/1024|0)-a|0)+q|0;v[e>>2]=a+v[e>>2];j=b+((b|0)/-512|0)|0;q=a+((a|0)/-512|0)|0;e=e+8|0;l=l+8|0;c=c-1|0;a=h;b=f;continue}break}v[H+64>>2]=f;v[H+60>>2]=h;v[H+56>>2]=j;v[H+52>>2]=q;a=v[H+20>>2];Bd:{if(w[H+12|0]){break Bd}a=v[H+16>>2];if(a>>>0>g>>>0){a=a-g|0;break Bd}hK(H,ta,sa);a=0}t[H+12|0]=0;v[H+16>>2]=a}if(v[d+946300>>2]){Cd:{f=0;e=0;g=k<<2;q=d+906300|0;i=x[d+480214>>1]!=0;Da=z[d+1074336>>2];W=z[d+1074332>>2];while(1)if((f|0)==250){h=d+12|0;n=d+12300|0;s=d+14348|0;iv(h,n,s,k,W);a=d+1074476|0;A=w[a|0];t[a|0]=0;a=s;c=n;while(1){Dd:{Ed:{Fd:{if((e|0)!=250){m=Id(q,e);l=v[m>>2];if(!l|!v[l+24>>2]){break Dd}if(!ai(l+44|0)){break Dd}j=l;Gd:{if(hv(w[m+24|0])){break Gd}b=lb[v[v[l>>2]+148>>2]](l)|0;j=v[m>>2];if(b){break Gd}f=0;if(w[j+28|0]&2){break Gd}while(1){if((e|0)==(f|0)){break Dd}b=Id(q,f);f=f+1|0;if((Pm(v[b+28>>2])|0)!=(e|0)){continue}break}}b=v[l+44>>2];p=Ec(b,0);r=Ec(b,1);o=(c|0)==(p|0);c=o?n:c;b=c;a=o?s:a;f=v[m+28>>2];g=a;Hd:{if(!f){break Hd}b=c;f=Pm(f);g=a;if(f>>>0<=e>>>0){break Hd}g=a;if(f>>>0>249){break Hd}f=v[Id(q,f)>>2];g=a;if(!f){break Hd}if(!(w[j+28|0]&4)){lb[v[v[f>>2]+152>>2]](f)}g=a;if(!ai(f+44|0)){break Hd}g=v[f+44>>2];b=Ec(g,0);g=Ec(g,1)}if(!hv(w[m+24|0])){break Ed}f=0;Id:{if(o){break Id}while(1){if((f|0)==(k|0)){break Id}o=f<<2;F=o+p|0;G=c+o|0;z[F>>2]=z[G>>2]+z[F>>2];F=o+r|0;o=a+o|0;z[F>>2]=z[o>>2]+z[F>>2];v[G>>2]=0;v[o>>2]=0;f=f+1|0;continue}}a=g;c=b;if(!(i&1)){break Ed}a=v[m>>2];if(a){lb[v[v[a>>2]+152>>2]](a)}f=Pm(v[m+28>>2]);a=e;while(1){c=f;f=c&255;if(f>>>0>249|f>>>0<=(a&255)>>>0){break Fd}o=Id(q,f);f=Pm(v[o+28>>2]);a=c;c=v[o>>2];if(!c){continue}lb[v[v[c>>2]+152>>2]](c);continue}}b=0;while(1){if((b|0)!=(k|0)){W=C(z[c>>2]*Da);Jd:{if(C(D(W))<C(2147483648)){e=~~W;break Jd}e=-2147483648}v[h>>2]=e;W=C(z[a>>2]*Da);Kd:{if(C(D(W))<C(2147483648)){e=~~W;break Kd}e=-2147483648}v[h+4>>2]=e;b=b+1|0;h=h+8|0;a=a+4|0;c=c+4|0;continue}break}break Cd}a=g;c=b}f=0;Ld:{Md:{o=w[m+24|0];if(!((o&2)>>>1|0)){if(!XC(o)|!(w[j+28|0]&4)){break Md}}while(1){if((f|0)==(k|0)){break Ld}l=f<<2;m=l+b|0;z[m>>2]=z[l+p>>2]+z[m>>2];m=g+l|0;z[m>>2]=z[l+r>>2]+z[m>>2];f=f+1|0;continue}}if(A){lb[v[v[l>>2]+132>>2]](l)}lb[v[v[l>>2]+60>>2]](l,b,g,k);v[j+32>>2]=k+v[j+32>>2];if(!XC(w[m+24|0])){break Ld}if((lb[v[v[l>>2]+160>>2]](l)|0)<=0|y[j+32>>2]<v[d+24620>>2]<<2>>>0){break Ld}Nd:{while(1){if((f|0)==(k|0)){break Nd}l=f<<2;W=z[l+b>>2];Od:{if(W>=C(1.1920928955078125e-7)|W<=C(-1.1920928955078125e-7)){break Od}W=z[g+l>>2];if(W>=C(1.1920928955078125e-7)){break Od}f=f+1|0;if(!(W<=C(-1.1920928955078125e-7))){continue}}break}v[j+32>>2]=0;break Ld}v[j+28>>2]=v[j+28>>2]|4}v[j+28>>2]=v[j+28>>2]&-3}e=e+1|0;continue}}else{h=Id(q,f);a=v[h>>2];Pd:{if(!a|!v[a+24>>2]){break Pd}if(!ai(a+44|0)){break Pd}if(!(lb[v[v[a>>2]+116>>2]](a)|0)){lb[v[v[a>>2]+112>>2]](a,1);lb[v[v[a>>2]+124>>2]](a)}c=v[a+44>>2];b=Ec(c,0);c=Ec(c,1);Qd:{if(t[a+28|0]&1){iv(v[a+24>>2],b,c,k,W);break Qd}j=a+40|0;if(v[a+36>>2]?1:v[j>>2]){Rm(v[a+24>>2],k,j,a+36|0);iv(v[a+24>>2],b,c,k,W);break Qd}Rb(b,0,g);Rb(c,0,g)}b=a;a=v[a+28>>2];v[b+28>>2]=a&-2;if(hv(w[h+24|0])){break Pd}i=!(a&4)|i}f=f+1|0;continue}}}if(v[d+24624>>2]==1){b=0;while(1){if((b|0)!=(k|0)){a=(b<<3)+_|0;v[(b<<2)+_>>2]=(v[a+4>>2]+v[a>>2]|0)/2;b=b+1|0;continue}break}}if(Sd(w[Ja|0])){c=0;g=hb-16|0;hb=g;Rd:{if(!v[d+1074376>>2]){l=d+1074460|0;a=l;v[a>>2]=0;v[a+4>>2]=0;a=v[d+1074456>>2];v[d+1074468>>2]=a;break Rd}a=v[d+1074456>>2];b=v[d+1074468>>2];Sd:{if((a|0)==(b|0)){e=v[d+1074460>>2];break Sd}v[d+1074468>>2]=a;e=v[d+24620>>2];h=d+1074460|0;Td:{if((a|0)>(b|0)){e=mt(e,v[d+24636>>2]);break Td}e=mt(e,v[d+24640>>2])}v[h>>2]=e;v[d+1074464>>2]=e;b=a}l=d+1074460|0;if((e|0)<=0){break Rd}b=(b<<12)-v[d+1074472>>2]|0;c=(b|0)/(e|0)|0;if(w[d+1074368|0]!=2){break Rd}v[g+12>>2]=50;h=v[d+1074464>>2];v[g+8>>2]=1e4/(h+1|0);f=v[Ne(g+12|0,g+8|0)>>2];while(1){j=c>>31;if((f|0)>=((j^c)-j|0)){break Rd}e=e+h|0;v[l>>2]=e;c=(b|0)/(e|0)|0;continue}}Ud:{Vd:{switch(v[d+24624>>2]-1|0){case 0:b=0;f=(k|0)>0?k:0;j=a<<12;e=d+12|0;n=a>>31;while(1){if((b|0)==(f|0)){break Ud}Wd:{if(v[l>>2]>0){h=v[d+1074472>>2]+c|0;v[d+1074472>>2]=h;s=v[e>>2];Ya=e,Za=Dc(ska(rka(s,s>>31,h,h>>31),kb,1048576,0),kb),v[Ya>>2]=Za;v[d+1074460>>2]=v[d+1074460>>2]-1;break Wd}h=v[e>>2];Ya=e,Za=Dc(ska(rka(h,h>>31,a,n),kb,256,0),kb),v[Ya>>2]=Za;v[d+1074472>>2]=j}b=b+1|0;e=e+4|0;continue};case 1:b=0;j=(k|0)>0?k:0;n=a<<12;e=d+12|0;h=a>>31;while(1){if((b|0)==(j|0)){break Ud}Xd:{if(v[l>>2]>0){f=v[d+1074472>>2]+c|0;v[d+1074472>>2]=f;s=v[e>>2];Ya=e,Za=Dc(ska(rka(s,s>>31,f,f>>31),kb,1048576,0),kb),v[Ya>>2]=Za;f=v[d+1074472>>2];m=f;s=f>>31;f=v[e+4>>2];Ya=e,Za=Dc(ska(rka(m,s,f,f>>31),kb,1048576,0),kb),v[Ya+4>>2]=Za;v[d+1074460>>2]=v[d+1074460>>2]-1;break Xd}f=v[e>>2];Ya=e,Za=Dc(ska(rka(f,f>>31,a,h),kb,256,0),kb),v[Ya>>2]=Za;f=v[e+4>>2];Ya=e,Za=Dc(ska(rka(f,f>>31,a,h),kb,256,0),kb),v[Ya+4>>2]=Za;v[d+1074472>>2]=n}b=b+1|0;e=e+8|0;continue};case 3:break Vd;default:break Ud}}f=0;n=(k|0)>0?k:0;s=a<<12;e=d+8204|0;b=d+12|0;h=a>>31;while(1){if((f|0)==(n|0)){break Ud}Yd:{if(v[l>>2]>0){j=v[d+1074472>>2]+c|0;v[d+1074472>>2]=j;m=v[b>>2];Ya=b,Za=Dc(ska(rka(m,m>>31,j,j>>31),kb,1048576,0),kb),v[Ya>>2]=Za;j=v[d+1074472>>2];m=j;i=j>>31;j=v[b+4>>2];Ya=b,Za=Dc(ska(rka(m,i,j,j>>31),kb,1048576,0),kb),v[Ya+4>>2]=Za;j=v[d+1074472>>2];m=j;i=j>>31;j=v[e>>2];Ya=e,Za=Dc(ska(rka(m,i,j,j>>31),kb,1048576,0),kb),v[Ya>>2]=Za;j=v[d+1074472>>2];m=j;i=j>>31;j=v[e+4>>2];Ya=e,Za=Dc(ska(rka(m,i,j,j>>31),kb,1048576,0),kb),v[Ya+4>>2]=Za;v[d+1074460>>2]=v[d+1074460>>2]-1;break Yd}j=v[b>>2];Ya=b,Za=Dc(ska(rka(j,j>>31,a,h),kb,256,0),kb),v[Ya>>2]=Za;j=v[b+4>>2];Ya=b,Za=Dc(ska(rka(j,j>>31,a,h),kb,256,0),kb),v[Ya+4>>2]=Za;j=v[e>>2];Ya=e,Za=Dc(ska(rka(j,j>>31,a,h),kb,256,0),kb),v[Ya>>2]=Za;j=v[e+4>>2];Ya=e,Za=Dc(ska(rka(j,j>>31,a,h),kb,256,0),kb),v[Ya+4>>2]=Za;v[d+1074472>>2]=s}f=f+1|0;e=e+8|0;b=b+8|0;continue}}hb=g+16|0}if(v[qa>>2]!=128){b=d+12|0;c=d+8204|0;a=v[d+24604>>2];e=v[d+24624>>2];Zd:{if((a|0)==128|e>>>0<2){break Zd}XL(b,k,a);if(e>>>0<4){break Zd}XL(c,k,a)}}if(v[d+24624>>2]==4){a=k;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+_|0;c=a<<3;e=c|4;v[b+12>>2]=v[e+ra>>2];v[b+8>>2]=v[c+ra>>2];v[b+4>>2]=v[e+_>>2];v[b>>2]=v[c+_>>2];continue}break}}if(Sd(Fa)){a=v[d+24624>>2];v[M+72>>2]=k;v[M+68>>2]=a;v[M+64>>2]=_;a=v[v[oa>>2]+8>>2];v[M+24>>2]=k;b=v[M+68>>2];v[M+16>>2]=v[M+64>>2];v[M+20>>2]=b;lb[a|0](oa,M+16|0)}a=v[d+24624>>2];v[M+56>>2]=k;v[M+52>>2]=a;v[M+48>>2]=_;a=v[v[ma>>2]+8>>2];v[M+8>>2]=k;b=v[M+52>>2];v[M>>2]=v[M+48>>2];v[M+4>>2]=b;lb[a|0](ma,M);v[d+1074380>>2]=v[d+1074380>>2]-k;v[d+1074376>>2]=k+v[d+1074376>>2];ga=ga-k|0;Ea=k+Ea|0;continue}break}hb=ea+32|0;return Ea}function ug(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),m=0,o=0,p=0,r=0,s=0,E=C(0),F=C(0),G=0,H=0,I=0,J=0,K=0,M=0,N=0;h=hb-2704|0;hb=h;a:{b:{c:{d:{e:{f:{if(kv(v[c>>2])){uc(b,268435456);J=v[c+8>>2];H=h+2680|0;e=H;v[e>>2]=0;v[e+4>>2]=0;Lb(e+8|0);v[h+2676>>2]=0;g:{h:{i:{j:{k:{l:{e=w[a+3|0];m:{n:{if((e-4&255)>>>0<=4){v[23516]=0;d=T(200,c|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break l}v[h+2676>>2]=d;break n}if(e>>>0>17){break m}o:{g=1<<e;if(!(g&63503)){if(!(g&198144)){break m}break o}if(w[a|0]){break o}break n}e=0;f=IA(a,v[b>>2]);v[23516]=0;U(201,h+512|0,c|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break k}d=h+512|0;f=v[d+4>>2];v[H>>2]=v[d>>2];v[H+4>>2]=f;Bm(H+8|0,d+8|0);Qc(d);f=Ee(H);d=v[H>>2];v[h+2676>>2]=d;if(!f){break g}}e=w[a+3|0]}i=1;p:{q:{switch(e&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:i=!w[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}i=0}g=v[b>>2];if(!(g>>>0<262145|i)){e=e&255;v[h+512>>2]=((e|0)==10)<<4;i=d-v[Hb(h+512|0,h+2676|0)>>2]|0;if(e>>>0>15){break j}r:{if(!(1<<e&63503)){if((e|0)==10){break r}break j}if(!(w[a|0]&7)){break j}}e=(i|0)>=0?i<<1:-1;break i}e=e&255;if(e>>>0>8){break h}if(!(1<<e&432)){if((e|0)!=6){break h}e=0;if(d>>>0<10){break g}v[23516]=0;Q(186,c|0,4)|0;d=v[23516];v[23516]=0;if((d|0)==1){break l}v[23516]=0;e=T(155,c|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){v[h+512>>2]=e;v[h+488>>2]=v[h+2676>>2];d=v[Hb(h+512|0,h+488|0)>>2];wg(c,8);e=((d>>>0>50529027?-1:B(d,85))>>>0)/(w[a|0]>>>3>>>0)|0;break i}a=P()|0;O()|0;break a}e=8/(iq(w[a+1|0])>>>0)|0;rka(e,0,d,0);e=kb?-1:B(e,d);break i}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}g=0;d=iq(w[a+1|0]);s:{t:{switch(e|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:g=w[a|0];break s;case 9:g=16;break s;case 10:g=4;break s;case 16:case 17:break t;default:break s}}g=8}e=B(d,g&255)>>>3|0;d=(e+i|0)-1|0;e=((d>>>0<i>>>0?-1:d)>>>0)/(e>>>0)|0}uc(b,e);g=v[b>>2]}if(!g){e=0;break g}u[b+34>>1]=x[b+34>>1]&65470|w[a|0]>15|(w[a+1|0]!=1)<<6;if(!Jg(b)){e=0;v[b>>2]=0;break g}u:{if(le(a,Uc(h+512|0,8,1,0,10))){v[23516]=0;d=Q(202,c|0,h+512|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){e=0;if(!d){break u}a=v[b>>2];d=0;v[23516]=0;v[h+488>>2]=a+1>>>1;e=T(200,c|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break b}uc(h+488|0,e);a=f+16|0;b=v[b+20>>2];i=v[h+488>>2];e=i;while(1)if(e){g=h+512|0;f=d+w[g|w[a|0]&15]|0;t[b|0]=f;d=w[g|w[a|0]>>>4]+(f&255)|0;t[b+1|0]=d;e=e-1|0;a=a+1|0;b=b+2|0;continue}else{e=i+16|0;break u}}a=P()|0;O()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{g=w[a+3|0];switch(g-4|0){case 3:break D;case 4:break E;case 5:break F;case 2:break G;case 0:case 1:break H;default:break B}}v[23516]=0;b=fa(203,h+1584|0,c|0,b|0,(g|0)==5|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break f}yb(b);e=v[c+8>>2]-J|0;break u}if(w[a+1|0]!=1){break C}v[23516]=0;Q(186,c|0,4)|0;a=v[23516];v[23516]=0;if((a|0)==1){break f}v[23516]=0;f=T(155,c|0)|0;a=v[23516];v[23516]=0;I:{J:{K:{if((a|0)!=1){v[23516]=0;v[h+488>>2]=f;i=T(204,c|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break K}v[23516]=0;U(205,h+512|0,c|0,f|0);a=v[23516];v[23516]=0;if((a|0)==1){break J}uc(h+488|0,v[h+512>>2]);g=v[h+488>>2];e=Ee(h+512|0);d=x[b+34>>1];f=v[b+20>>2];b=v[b>>2];a=v[h+512>>2];v[23516]=0;da(206,e|0,a|0,f|0,Fj(b,d)|0,i<<24>>24);a=v[23516];v[23516]=0;if((a|0)==1){break I}e=g+9|0;Qc(h+512|0);break u}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Qc(h+512|0);break a}if(w[a+1|0]!=1|w[a|0]!=16){break C}e=v[h+2676>>2];d=uk(h+1576|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];i=hb-16|0;hb=i;v[i+12>>2]=e>>>1;v[i+8>>2]=a;d=v[Hb(i+12|0,i+8|0)>>2];e=d;while(1){if(e){a=w[f|0]+g|0;g=a+w[f+1|0]|0;u[b>>1]=g<<8|a&255;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}hb=i+16|0;e=d<<1;break u}if(w[a+1|0]!=1|w[a|0]>16){break C}d=v[c+8>>2];f=v[c>>2];e=0;v[23516]=0;d=W(154,f|0,d|0,8)|0;f=v[23516];v[23516]=0;if((f|0)==1){break f}if(!d){break u}v[23516]=0;d=T(155,c|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break f}v[h+2676>>2]=d;if(d>>>0<4){break u}v[23516]=0;U(188,h+488|0,c|0,d|0);f=v[23516];v[23516]=0;if((f|0)==1){break c}f=h+488|0;s=gr(h+512|0,f);yb(f);f=v[s>>2];v[23516]=0;d=T(207,f|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}e=d+4|0;p=w[a|0];m=(p|0)!=16;g=0;i=0;while(1){if(y[b>>2]<=i>>>0){break w}L:{if(m){break L}v[23516]=0;r=Q(162,s|0,8)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break L}a=V(30656)|0;break x}v[23516]=0;j=Q(162,s|0,1)|0;a=v[23516];v[23516]=0;if((a|0)==1){break y}v[23516]=0;f=Q(162,s|0,1)|0;a=v[23516];v[23516]=0;if((a|0)==1){break y}M:{N:{O:{if(!f){f=8;while(1){v[23516]=0;d=Q(162,s|0,1)|0;a=v[23516];v[23516]=0;if((a|0)==1){break M}if(d){break O}f=f+16|0;continue}}v[23516]=0;a=Q(162,s|0,3)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break N}break y}v[23516]=0;d=Q(162,s|0,4)|0;a=v[23516];v[23516]=0;if((a|0)==1){break y}a=f+d|0}g=(g&255)+(((j?-1:0)^a)&255)|0;P:{if((p|0)!=16){t[v[b+20>>2]+i|0]=g;break P}u[v[b+20>>2]+(i<<1)>>1]=r&255|g<<8}i=i+1|0;continue}break}a=V(30656)|0;break x}if(w[a+1|0]!=1){break B}break A}if((g|0)!=7){break B}if(w[a+1|0]==1){break A}}e=w[a|0];break z}e=w[a|0];if(e>>>0>16){break z}e=0;if(y[h+2676>>2]<5){break u}d=x[b+34>>1];f=v[b+20>>2];a=v[b>>2];v[23516]=0;e=W(208,c|0,f|0,Fj(a,d)|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break u}break f}Q:{if((g&254)!=16|(e&255)!=16){break Q}d=w[a+1|0];if((d-1&255)>>>0>1){break Q}K=h,M=B(v[b>>2],iq(d)),v[K+512>>2]=M;uc(h+512|0,v[h+2676>>2]);a=v[b+20>>2];e=v[h+512>>2];if((g|0)==16){b=e;while(1){if(!b){break u}K=a,M=x[$b(30688,w[f|0])>>1],u[K>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}b=e;while(1){if(!b){break u}K=a,M=x[$b(31200,w[f|0])>>1],u[K>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}d=(e&255)!=8;if(!(d|w[a+1|0]!=1)){R:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=hb-16|0;hb=d;v[d+12>>2]=v[h+2676>>2];v[d+8>>2]=a;a=v[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0];b=b+1|0;f=f+1|0;e=e-1|0;continue}break};hb=d+16|0;e=a;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=hb-16|0;hb=d;v[d+12>>2]=v[h+2676>>2];v[d+8>>2]=a;a=v[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0]^128;b=b+1|0;f=f+1|0;e=e-1|0;continue}break};hb=d+16|0;e=a;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break R}}e=v[h+2676>>2];d=rr(h+480|0);a=v[b>>2];b=v[b+20>>2];g=w[d|0];d=hb-16|0;hb=d;v[d+12>>2]=e;v[d+8>>2]=a;a=v[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=w[f|0]+g|0;t[b|0]=g;b=b+1|0;f=f+1|0;e=e-1|0;continue}break}hb=d+16|0;e=a;break u}if(!(w[a+1|0]!=3|d)){S:{switch(g|0){case 0:j=hb-16|0;hb=j;e=v[h+2676>>2];v[j+12>>2]=e;d=v[b>>2];v[j+8>>2]=d;a=j+8|0;g=v[Hb(a,j+12|0)>>2];v[j+8>>2]=d;v[j+4>>2]=e-g;e=v[Hb(a,j+4|0)>>2];i=v[b+20>>2];a=g;d=f;while(1){if(a){t[i|0]=w[d|0];i=i+2|0;d=d+1|0;a=a-1|0;continue}break};i=v[b+20>>2]+1|0;d=v[b>>2]+f|0;a=e;while(1){if(a){t[i|0]=w[d|0];i=i+2|0;d=d+1|0;a=a-1|0;continue}break};hb=j+16|0;e=e+g|0;break u;case 1:j=hb-16|0;hb=j;e=v[h+2676>>2];v[j+12>>2]=e;d=v[b>>2];v[j+8>>2]=d;a=j+8|0;g=v[Hb(a,j+12|0)>>2];v[j+8>>2]=d;v[j+4>>2]=e-g;e=v[Hb(a,j+4|0)>>2];i=v[b+20>>2];a=g;d=f;while(1){if(a){t[i|0]=w[d|0]^128;i=i+2|0;d=d+1|0;a=a-1|0;continue}break};i=v[b+20>>2]+1|0;d=v[b>>2]+f|0;a=e;while(1){if(a){t[i|0]=w[d|0]^128;i=i+2|0;d=d+1|0;a=a-1|0;continue}break};hb=j+16|0;e=e+g|0;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break S}}i=v[h+2676>>2];e=w[rr(h+472|0)|0];p=hb-16|0;hb=p;v[p+12>>2]=i;g=v[b>>2];v[p+8>>2]=g;d=p+8|0;j=v[Hb(d,p+12|0)>>2];v[p+8>>2]=g;v[p+4>>2]=i-j;i=v[Hb(d,p+4|0)>>2];m=b;r=v[b+20>>2];d=e;b=j;g=f;while(1){if(b){d=w[g|0]+d|0;t[r|0]=d;r=r+2|0;g=g+1|0;b=b-1|0;continue}break}r=v[m+20>>2]+1|0;g=v[m>>2]+f|0;b=i;while(1){if(b){e=w[g|0]+e|0;t[r|0]=e;r=r+2|0;g=g+1|0;b=b-1|0;continue}break}hb=p+16|0;e=i+j|0;if(w[a+3|0]!=11){break u}a=v[m+20>>2];b=a+(v[m>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;continue}}d=e&255;if(!((d|0)!=8|w[a+1|0]!=2)){e=0;T:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=hb-16|0;hb=d;v[d+12>>2]=v[h+2676>>2]>>>1;v[d+8>>2]=a;a=v[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0];t[b+1|0]=w[f+1|0];b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=hb-16|0;hb=d;v[d+12>>2]=v[h+2676>>2]>>>1;v[d+8>>2]=a;a=v[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0]^128;t[b+1|0]=w[f+1|0]^128;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<1;break u;case 2:break T;default:break u}}e=v[h+2676>>2];a=rr(h+464|0);d=v[b>>2];g=v[b+20>>2];a=w[a|0];i=hb-16|0;hb=i;v[i+12>>2]=e>>>1;v[i+8>>2]=d;b=a;e=v[Hb(i+12|0,i+8|0)>>2];d=e;while(1){if(d){a=w[f|0]+a|0;t[g|0]=a;b=w[f+1|0]+b|0;t[g+1|0]=b;g=g+2|0;f=f+2|0;d=d-1|0;continue}break}hb=i+16|0;e=e<<1;break u}if(!(w[a+2|0]|((d|0)!=16|w[a+1|0]!=1))){U:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=hb-16|0;hb=d;v[d+12>>2]=v[h+2676>>2]>>>1;v[d+8>>2]=a;a=v[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[f|0]|w[f+1|0]<<8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=hb-16|0;hb=d;v[d+12>>2]=v[h+2676>>2]>>>1;v[d+8>>2]=a;a=v[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[f|0]|w[f+1|0]<<8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break U}}e=v[h+2676>>2];d=uk(h+456|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];d=hb-16|0;hb=d;v[d+12>>2]=e>>>1;v[d+8>>2]=a;a=v[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(w[f|0]+g|0)+(w[f+1|0]<<8)|0;u[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}hb=d+16|0;e=a<<1;break u}d=e&255;if(!((d|0)!=16|w[a+1|0]!=1|w[a+2|0]!=1)){e=0;V:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];g=hb-16|0;hb=g;v[g+12>>2]=v[h+2676>>2]>>>1;v[g+8>>2]=a;d=v[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=a<<8|a>>>8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=g+16|0;e=d<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];g=hb-16|0;hb=g;v[g+12>>2]=v[h+2676>>2]>>>1;v[g+8>>2]=a;d=v[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=g+16|0;e=d<<1;break u;case 2:break V;default:break u}}e=v[h+2676>>2];d=uk(h+448|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];d=hb-16|0;hb=d;v[d+12>>2]=e>>>1;v[d+8>>2]=a;a=v[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(w[f+1|0]+g|0)+(w[f|0]<<8)|0;u[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}hb=d+16|0;e=a<<1;break u}i=a;if(!(w[a+2|0]|((d|0)!=16|w[a+1|0]!=3))){W:{switch(g|0){case 0:m=hb-16|0;hb=m;d=v[h+2676>>2];v[m+12>>2]=d;j=v[b>>2]<<1;v[m+8>>2]=j;a=m+8|0;g=v[Hb(a,m+12|0)>>2];v[m+8>>2]=j;v[m+4>>2]=d-g;a=v[Hb(a,m+4|0)>>2];e=v[b+20>>2];i=g>>>1|0;g=i;d=f;while(1){if(g){u[e>>1]=w[d|0]|w[d+1|0]<<8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+j|0;d=v[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){u[d>>1]=w[e|0]|w[e+1|0]<<8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};hb=m+16|0;e=a+i<<1;break u;case 1:m=hb-16|0;hb=m;d=v[h+2676>>2];v[m+12>>2]=d;j=v[b>>2]<<1;v[m+8>>2]=j;a=m+8|0;g=v[Hb(a,m+12|0)>>2];v[m+8>>2]=j;v[m+4>>2]=d-g;a=v[Hb(a,m+4|0)>>2];e=v[b+20>>2];i=g>>>1|0;g=i;d=f;while(1){if(g){u[e>>1]=(w[d|0]|w[d+1|0]<<8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+j|0;d=v[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){u[d>>1]=(w[e|0]|w[e+1|0]<<8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};hb=m+16|0;e=a+i<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break W}}g=v[h+2676>>2];a=x[uk(h+440|0)>>1];s=hb-16|0;hb=s;v[s+12>>2]=g;p=v[b>>2]<<1;v[s+8>>2]=p;d=s+8|0;e=v[Hb(d,s+12|0)>>2];v[s+8>>2]=p;v[s+4>>2]=g-e;m=v[Hb(d,s+4|0)>>2];g=b;d=v[g+20>>2];b=a;j=e>>>1|0;r=j;e=f;while(1){if(r){b=(w[e|0]+b|0)+(w[e+1|0]<<8)|0;u[d>>1]=b;d=d+4|0;e=e+2|0;r=r-1|0;continue}break}e=f+p|0;d=v[g+20>>2]+2|0;b=m>>>1|0;r=b;while(1){if(r){a=(w[e|0]+a|0)+(w[e+1|0]<<8)|0;u[d>>1]=a;d=d+4|0;e=e+2|0;r=r-1|0;continue}break}hb=s+16|0;e=b+j<<1;if(w[i+3|0]!=11){break u}a=v[g+20>>2];b=a+(v[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;continue}}a=e&255;if(!((a|0)!=16|w[i+1|0]!=3|w[i+2|0]!=1)){e=0;X:{switch(g|0){case 0:p=hb-16|0;hb=p;d=v[h+2676>>2];v[p+12>>2]=d;m=v[b>>2]<<1;v[p+8>>2]=m;a=p+8|0;g=v[Hb(a,p+12|0)>>2];v[p+8>>2]=m;v[p+4>>2]=d-g;j=v[Hb(a,p+4|0)>>2];e=v[b+20>>2];i=g>>>1|0;g=i;d=f;while(1){if(g){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=a<<8|a>>>8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=v[b+20>>2]+2|0;b=j>>>1|0;g=b;while(1){if(g){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=a<<8|a>>>8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};hb=p+16|0;e=b+i<<1;break u;case 1:p=hb-16|0;hb=p;d=v[h+2676>>2];v[p+12>>2]=d;m=v[b>>2]<<1;v[p+8>>2]=m;a=p+8|0;g=v[Hb(a,p+12|0)>>2];v[p+8>>2]=m;v[p+4>>2]=d-g;j=v[Hb(a,p+4|0)>>2];e=v[b+20>>2];i=g>>>1|0;g=i;d=f;while(1){if(g){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=(a<<8|a>>>8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=v[b+20>>2]+2|0;b=j>>>1|0;g=b;while(1){if(g){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};hb=p+16|0;e=b+i<<1;break u;case 2:break X;default:break u}}e=v[h+2676>>2];a=x[uk(h+432|0)>>1];r=hb-16|0;hb=r;v[r+12>>2]=e;p=v[b>>2]<<1;v[r+8>>2]=p;d=r+8|0;g=v[Hb(d,r+12|0)>>2];v[r+8>>2]=p;v[r+4>>2]=e-g;m=v[Hb(d,r+4|0)>>2];e=b;i=v[b+20>>2];b=a;j=g>>>1|0;d=j;g=f;while(1){if(d){b=(w[g+1|0]+b|0)+(w[g|0]<<8)|0;u[i>>1]=b;i=i+4|0;g=g+2|0;d=d-1|0;continue}break}g=f+p|0;i=v[e+20>>2]+2|0;b=m>>>1|0;d=b;while(1){if(d){a=(w[g+1|0]+a|0)+(w[g|0]<<8)|0;u[i>>1]=a;i=i+4|0;g=g+2|0;d=d-1|0;continue}break}hb=r+16|0;e=b+j<<1;break u}if(!(w[i+2|0]|((a|0)!=16|w[i+1|0]!=2))){e=0;Y:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=hb-16|0;hb=d;v[d+12>>2]=v[h+2676>>2]>>>2;v[d+8>>2]=a;a=v[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[f|0]|w[f+1|0]<<8;u[b+2>>1]=w[f+2|0]|w[f+3|0]<<8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<2;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=hb-16|0;hb=d;v[d+12>>2]=v[h+2676>>2]>>>2;v[d+8>>2]=a;a=v[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[f|0]|w[f+1|0]<<8)^32768;u[b+2>>1]=(w[f+2|0]|w[f+3|0]<<8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<2;break u;case 2:break Y;default:break u}}e=v[h+2676>>2];a=uk(h+424|0);d=v[b>>2];g=v[b+20>>2];a=x[a>>1];i=hb-16|0;hb=i;v[i+12>>2]=e>>>2;v[i+8>>2]=d;b=a;e=v[Hb(i+12|0,i+8|0)>>2];d=e;while(1){if(d){a=(w[f|0]+a|0)+(w[f+1|0]<<8)|0;u[g>>1]=a;b=(w[f+2|0]+b|0)+(w[f+3|0]<<8)|0;u[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}hb=i+16|0;e=e<<2;break u}a=e&255;if(!((a|0)!=16|w[i+1|0]!=2|w[i+2|0]!=1)){e=0;Z:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];g=hb-16|0;hb=g;v[g+12>>2]=v[h+2676>>2]>>>2;v[g+8>>2]=a;d=v[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=a<<8|a>>>8;a=w[f+2|0]|w[f+3|0]<<8;u[b+2>>1]=a<<8|a>>>8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};hb=g+16|0;e=d<<2;break u;case 1:a=v[b>>2];b=v[b+20>>2];g=hb-16|0;hb=g;v[g+12>>2]=v[h+2676>>2]>>>2;v[g+8>>2]=a;d=v[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;a=w[f+2|0]|w[f+3|0]<<8;u[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};hb=g+16|0;e=d<<2;break u;case 2:break Z;default:break u}}e=v[h+2676>>2];a=uk(h+416|0);d=v[b>>2];g=v[b+20>>2];a=x[a>>1];i=hb-16|0;hb=i;v[i+12>>2]=e>>>2;v[i+8>>2]=d;b=a;e=v[Hb(i+12|0,i+8|0)>>2];d=e;while(1){if(d){a=(w[f+1|0]+a|0)+(w[f|0]<<8)|0;u[g>>1]=a;b=(w[f+3|0]+b|0)+(w[f+2|0]<<8)|0;u[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}hb=i+16|0;e=e<<2;break u}if(!(g|w[i+1|0]!=1|(a|0)!=24)){a=v[b+20>>2];d=v[b>>2];b=v[h+2676>>2];if(!w[i+2|0]){g=hb-16|0;hb=g;v[g+12>>2]=(b>>>0)/3;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=hd(w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24,16),u[K>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}hb=g+16|0;e=B(b,3);break u}g=hb-16|0;hb=g;v[g+12>>2]=(b>>>0)/3;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=hd(w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24,16),u[K>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}hb=g+16|0;e=B(b,3);break u}a=e&255;if(!(g|w[i+1|0]!=2|(a|0)!=24)){a=v[b+20>>2];d=v[b>>2];b=v[h+2676>>2];if(!w[i+2|0]){g=hb-16|0;hb=g;v[g+12>>2]=(b>>>0)/6;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=hd(w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24,16),u[K>>1]=M;K=a,M=hd(w[f+4|0]<<16|w[f+3|0]<<8|w[f+5|0]<<24,16),u[K+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}hb=g+16|0;e=B(b,6);break u}g=hb-16|0;hb=g;v[g+12>>2]=(b>>>0)/6;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=hd(w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24,16),u[K>>1]=M;K=a,M=hd(w[f+4|0]<<16|w[f+5|0]<<8|w[f+3|0]<<24,16),u[K+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}hb=g+16|0;e=B(b,6);break u}if(!(g|w[i+1|0]!=1|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[h+2676>>2];if(!w[i+2|0]){g=hb-16|0;hb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=hd(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),16),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<2;break u}g=hb-16|0;hb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);K=a,M=hd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<2;break u}a=e&255;if(!(g|w[i+1|0]!=2|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[h+2676>>2];if(!w[i+2|0]){g=hb-16|0;hb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=hd(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),16),u[K>>1]=M;K=a,M=hd(w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),16),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}g=hb-16|0;hb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);K=a,M=hd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);K=a,M=hd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}if(!(g|w[i+1|0]!=1|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[h+2676>>2];if(!w[i+2|0]){g=hb-16|0;hb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=Tc(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),48),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}m=hb-16|0;hb=m;v[m+12>>2]=b>>>3;v[m+8>>2]=d;i=v[Hb(m+12|0,m+8|0)>>2];e=i;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;j=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);d=r|j<<24;b=b>>>24|0;K=a,M=Tc((r|(j&255)<<24)&-16777216|(b|(j&16777215)<<8)&16711680|(j>>>8&65280|j>>>24),g|(d&65280|(b|j<<8)&255),48),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}hb=m+16|0;e=i<<3;break u}a=e&255;if(!(g|w[i+1|0]!=2|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[h+2676>>2];if(!w[i+2|0]){g=hb-16|0;hb=g;v[g+12>>2]=b>>>4;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=Tc(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),48),u[K>>1]=M;K=a,M=Tc(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24),w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24),48),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<4;break u}m=hb-16|0;hb=m;v[m+12>>2]=b>>>4;v[m+8>>2]=d;i=v[Hb(m+12|0,m+8|0)>>2];e=i;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;j=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);d=r|j<<24;b=b>>>24|0;K=a,M=Tc((r|(j&255)<<24)&-16777216|(b|(j&16777215)<<8)&16711680|(j>>>8&65280|j>>>24),g|(d&65280|(b|j<<8)&255),48),u[K>>1]=M;j=w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24);d=j<<24|j<<8&16711680;g=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);b=g<<24|j>>>8;K=a,M=Tc(((g&255)<<24|j>>>8)&-16777216|((g&16777215)<<8|j>>>24)&16711680|(g>>>8&65280|g>>>24),d|(b&65280|(g<<8|j>>>24)&255),48),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}hb=m+16|0;e=i<<4;break u}if(!(w[i+1|0]!=1|(g|0)!=3|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[h+2676>>2];if(!w[i+2|0]){g=hb-16|0;hb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){k=Gf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));k=Wh(C(Td(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));_:{if(C(D(k))<C(2147483648)){d=~~k;break _}d=-2147483648}K=a,M=$c(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<2;break u}g=hb-16|0;hb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);k=Gf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Wh(C(Td(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));$:{if(C(D(k))<C(2147483648)){d=~~k;break $}d=-2147483648}K=a,M=$c(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<2;break u}a=e&255;if(!(w[i+1|0]!=2|(g|0)!=3|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[h+2676>>2];if(!w[i+2|0]){g=hb-16|0;hb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){k=Gf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));k=Wh(C(Td(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));aa:{if(C(D(k))<C(2147483648)){d=~~k;break aa}d=-2147483648}K=a,M=$c(d),u[K>>1]=M;k=Gf((l(2,w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24)),q()));k=Wh(C(Td(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ba:{if(C(D(k))<C(2147483648)){d=~~k;break ba}d=-2147483648}K=a,M=$c(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}g=hb-16|0;hb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);k=Gf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Wh(C(Td(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ca:{if(C(D(k))<C(2147483648)){d=~~k;break ca}d=-2147483648}K=a,M=$c(d),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);k=Gf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Wh(C(Td(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));da:{if(C(D(k))<C(2147483648)){d=~~k;break da}d=-2147483648}K=a,M=$c(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}if(!(w[i+1|0]!=1|(g|0)!=3|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[h+2676>>2];if(!w[i+2|0]){g=hb-32|0;hb=g;v[g+24>>2]=b>>>3;v[g+16>>2]=d;d=v[Hb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,b|0);o=mg(+n());K=g,N=gf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=se(A[Eg(g+24|0,g+16|0,g+8|0)>>3]*32768);ea:{if(D(o)<2147483648){b=~~o;break ea}b=-2147483648}K=a,M=$c(b),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}hb=g+32|0;e=d<<3;break u}m=hb-32|0;hb=m;v[m+24>>2]=b>>>3;v[m+16>>2]=d;g=v[Hb(m+24|0,m+16|0)>>2];e=g;while(1){if(e){j=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);d=j<<24|j<<8&16711680;r=j>>>8|0;i=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);b=r|i<<24;j=j>>>24|0;l(0,(r|(i&255)<<24)&-16777216|(j|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,d|(b&65280|(j|i<<8)&255));o=mg(+n());K=m,N=gf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=se(A[Eg(m+24|0,m+16|0,m+8|0)>>3]*32768);fa:{if(D(o)<2147483648){b=~~o;break fa}b=-2147483648}K=a,M=$c(b),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}hb=m+32|0;e=g<<3;break u}a=e&255;if(!(w[i+1|0]!=2|(g|0)!=3|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[h+2676>>2];if(!w[i+2|0]){g=hb-32|0;hb=g;v[g+24>>2]=b>>>4;v[g+16>>2]=d;d=v[Hb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,b|0);o=mg(+n());K=g,N=gf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=se(A[Eg(g+24|0,g+16|0,g+8|0)>>3]*32768);ga:{if(D(o)<2147483648){b=~~o;break ga}b=-2147483648}K=a,M=$c(b),u[K>>1]=M;b=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);l(0,w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24));l(1,b|0);o=mg(+n());K=g,N=gf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=se(A[Eg(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(D(o)<2147483648){b=~~o;break ha}b=-2147483648}K=a,M=$c(b),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}hb=g+32|0;e=d<<4;break u}m=hb-32|0;hb=m;v[m+24>>2]=b>>>4;v[m+16>>2]=d;i=v[Hb(m+24|0,m+16|0)>>2];e=i;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;j=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);d=r|j<<24;b=b>>>24|0;l(0,(r|(j&255)<<24)&-16777216|(b|(j&16777215)<<8)&16711680|(j>>>8&65280|j>>>24));l(1,g|(d&65280|(b|j<<8)&255));o=mg(+n());K=m,N=gf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=se(A[Eg(m+24|0,m+16|0,m+8|0)>>3]*32768);ia:{if(D(o)<2147483648){b=~~o;break ia}b=-2147483648}K=a,M=$c(b),u[K>>1]=M;j=w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24);d=j<<24|j<<8&16711680;r=j>>>8|0;g=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);b=r|g<<24;j=j>>>24|0;l(0,(r|(g&255)<<24)&-16777216|(j|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24));l(1,d|(b&65280|(j|g<<8)&255));o=mg(+n());K=m,N=gf(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=se(A[Eg(m+24|0,m+16|0,m+8|0)>>3]*32768);ja:{if(D(o)<2147483648){b=~~o;break ja}b=-2147483648}K=a,M=$c(b),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}hb=m+32|0;e=i<<4;break u}if(!((g|0)!=15|(w[i+1|0]-1&255)>>>0>1|(a|0)!=24)){v[h+512>>2]=-2147483648;d=v[h+2676>>2];ka:{if(!w[i+2|0]){v[h+8>>2]=v[h+408>>2];v[h+404>>2]=0;a=v[h+404>>2];v[h>>2]=v[h+400>>2];v[h+4>>2]=a;r=h+512|0;s=hb-16|0;hb=s;K=s,M=B(v[b>>2],Hd(x[b+34>>1])),v[K+12>>2]=M;uc(s+12|0,(d>>>0)/3|0);e=v[h+4>>2];a=f;g=v[s+12>>2];i=g;while(1){if(i){j=w[a+1|0]<<16|w[a|0]<<8|w[a+2|0]<<24;la:{ma:{na:{if((j|0)>=0){d=j;break na}d=-2147483648;if((j|0)==-2147483648){break ma}d=0-j|0}if(d>>>0<=e>>>0){break la}}e=d}i=i-1|0;a=a+3|0;continue}else{oa:{if(!e){break oa}p=e-1|0;m=e>>>1|0;i=v[b+20>>2];a=g;while(1){if(!a){break oa}d=w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24;j=d>>31<<31|d>>>1;d=m|d<<31;pa:{if((j|0)>0|(j|0)>=0){d=uka(d,j,e,0);j=kb;break pa}j=uka(p-d|0,0-((d>>>0>p>>>0)+j|0)|0,e,0);d=0-j|0;j=0-(kb+((j|0)!=0)|0)|0}K=i,M=hd(Dc(d,j),16),u[K>>1]=M;a=a-1|0;f=f+3|0;i=i+2|0;continue}}}break}if(r){v[r>>2]=e}hb=s+16|0;e=B(g,3);break ka}v[h+24>>2]=v[h+392>>2];v[h+388>>2]=0;a=v[h+388>>2];v[h+16>>2]=v[h+384>>2];v[h+20>>2]=a;r=h+512|0;s=hb-16|0;hb=s;K=s,M=B(v[b>>2],Hd(x[b+34>>1])),v[K+12>>2]=M;uc(s+12|0,(d>>>0)/3|0);e=v[h+20>>2];a=f;g=v[s+12>>2];i=g;while(1){if(i){j=w[a+1|0]<<16|w[a+2|0]<<8|w[a|0]<<24;qa:{ra:{sa:{if((j|0)>=0){d=j;break sa}d=-2147483648;if((j|0)==-2147483648){break ra}d=0-j|0}if(d>>>0<=e>>>0){break qa}}e=d}i=i-1|0;a=a+3|0;continue}else{ta:{if(!e){break ta}p=e-1|0;m=e>>>1|0;i=v[b+20>>2];a=g;while(1){if(!a){break ta}d=w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24;j=d>>31<<31|d>>>1;d=m|d<<31;ua:{if((j|0)>0|(j|0)>=0){d=uka(d,j,e,0);j=kb;break ua}j=uka(p-d|0,0-((d>>>0>p>>>0)+j|0)|0,e,0);d=0-j|0;j=0-(kb+((j|0)!=0)|0)|0}K=i,M=hd(Dc(d,j),16),u[K>>1]=M;a=a-1|0;f=f+3|0;i=i+2|0;continue}}}break}if(r){v[r>>2]=e}hb=s+16|0;e=B(g,3)}if(!e){break u}a=v[h+512>>2];if((a|0)==-2147483648){break u}f=rka(x[b+32>>1],0,a,0)+1073741824|0;a=kb;a=f>>>0<1073741824?a+1|0:a;K=b,M=Bd(Bc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}va:{a=e&255;if((a|0)!=32){break va}if(!((g|0)!=15|(w[i+1|0]-1&255)>>>0>1)){v[h+512>>2]=-2147483648;d=v[h+2676>>2];wa:{if(!w[i+2|0]){v[h+40>>2]=v[h+376>>2];v[h+372>>2]=0;a=v[h+372>>2];v[h+32>>2]=v[h+368>>2];v[h+36>>2]=a;r=h+512|0;s=hb-16|0;hb=s;K=s,M=B(v[b>>2],Hd(x[b+34>>1])),v[K+12>>2]=M;uc(s+12|0,d>>>2|0);a=v[h+36>>2];e=f;i=f;g=v[s+12>>2];f=g;while(1){if(f){j=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);xa:{ya:{za:{if((j|0)>=0){d=j;break za}d=-2147483648;if((j|0)==-2147483648){break ya}d=0-j|0}if(d>>>0<=a>>>0){break xa}}a=d}f=f-1|0;i=i+4|0;continue}else{Aa:{if(!a){break Aa}p=a-1|0;m=a>>>1|0;i=v[b+20>>2];f=g;while(1){if(!f){break Aa}d=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);j=d>>31<<31|d>>>1;d=m|d<<31;Ba:{if((j|0)>0|(j|0)>=0){d=uka(d,j,a,0);j=kb;break Ba}j=uka(p-d|0,0-((d>>>0>p>>>0)+j|0)|0,a,0);d=0-j|0;j=0-(kb+((j|0)!=0)|0)|0}K=i,M=hd(Dc(d,j),16),u[K>>1]=M;f=f-1|0;e=e+4|0;i=i+2|0;continue}}}break}if(r){v[r>>2]=a}hb=s+16|0;e=g<<2;break wa}v[h+56>>2]=v[h+360>>2];v[h+356>>2]=0;a=v[h+356>>2];v[h+48>>2]=v[h+352>>2];v[h+52>>2]=a;r=h+512|0;s=hb-16|0;hb=s;K=s,M=B(v[b>>2],Hd(x[b+34>>1])),v[K+12>>2]=M;uc(s+12|0,d>>>2|0);a=v[h+52>>2];e=f;i=f;g=v[s+12>>2];f=g;while(1){if(f){d=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);j=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);Ca:{Da:{Ea:{if((j|0)>=0){d=j;break Ea}d=-2147483648;if((j|0)==-2147483648){break Da}d=0-j|0}if(a>>>0>=d>>>0){break Ca}}a=d}f=f-1|0;i=i+4|0;continue}else{Fa:{if(!a){break Fa}p=a-1|0;m=a>>>1|0;i=v[b+20>>2];f=g;while(1){if(!f){break Fa}d=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);j=d>>31<<31|d>>>1;d=m|d<<31;Ga:{if((j|0)>0|(j|0)>=0){d=uka(d,j,a,0);j=kb;break Ga}j=uka(p-d|0,0-((d>>>0>p>>>0)+j|0)|0,a,0);d=0-j|0;j=0-(kb+((j|0)!=0)|0)|0}K=i,M=hd(Dc(d,j),16),u[K>>1]=M;f=f-1|0;e=e+4|0;i=i+2|0;continue}}}break}if(r){v[r>>2]=a}hb=s+16|0;e=g<<2}if(!e){break u}a=v[h+512>>2];if((a|0)==-2147483648){break u}f=rka(x[b+32>>1],0,a,0)+1073741824|0;a=kb;a=f>>>0<1073741824?a+1|0:a;K=b,M=Bd(Bc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}if((g|0)!=14|(w[i+1|0]-1&255)>>>0>1){break va}v[h+512>>2]=1065353216;d=v[h+2676>>2];Ha:{if(!w[i+2|0]){v[h+340>>2]=0;v[h+344>>2]=1065353216;a=v[h+348>>2];v[h+72>>2]=v[h+344>>2];v[h+76>>2]=a;a=v[h+340>>2];v[h+64>>2]=v[h+336>>2];v[h+68>>2]=a;e=h+512|0;i=hb-16|0;hb=i;K=i,M=B(v[b>>2],Hd(x[b+34>>1])),v[K+12>>2]=M;uc(i+12|0,d>>>2|0);E=z[(h- -64|0)+4>>2];g=f;d=v[i+12>>2];a=d;while(1){if(a){k=Gf((l(2,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),q()));k=C(D(ng(k)?k>=C(0)?C(1):C(-1):k));E=k>E?k:E;a=a-1|0;g=g+4|0;continue}else{Ia:{a=E==C(0);if(a){break Ia}F=a?C(1):C(C(1)/E);g=v[b+20>>2];a=d;while(1){if(!a){break Ia}k=Gf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));k=Wh(C(Td(C(F*(ng(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));Ja:{if(C(D(k))<C(2147483648)){j=~~k;break Ja}j=-2147483648}K=g,M=$c(j),u[K>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){z[e>>2]=E}hb=i+16|0;e=d<<2}break}break Ha}v[h+324>>2]=0;v[h+328>>2]=1065353216;a=v[h+332>>2];v[h+88>>2]=v[h+328>>2];v[h+92>>2]=a;a=v[h+324>>2];v[h+80>>2]=v[h+320>>2];v[h+84>>2]=a;e=h+512|0;j=hb-16|0;hb=j;K=j,M=B(v[b>>2],Hd(x[b+34>>1])),v[K+12>>2]=M;uc(j+12|0,d>>>2|0);E=z[h+84>>2];g=f;d=v[j+12>>2];a=d;while(1){if(a){i=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);k=Gf((l(2,i<<24|i<<8&16711680|(i>>>8&65280|i>>>24)),q()));k=C(D(ng(k)?k>=C(0)?C(1):C(-1):k));E=k>E?k:E;a=a-1|0;g=g+4|0;continue}else{Ka:{a=E==C(0);if(a){break Ka}F=a?C(1):C(C(1)/E);g=v[b+20>>2];a=d;while(1){if(!a){break Ka}i=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);k=Gf((l(2,i<<24|i<<8&16711680|(i>>>8&65280|i>>>24)),q()));k=Wh(C(Td(C(F*(ng(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));La:{if(C(D(k))<C(2147483648)){i=~~k;break La}i=-2147483648}K=g,M=$c(i),u[K>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){z[e>>2]=E}hb=j+16|0;e=d<<2}break}}if(!e){break u}k=z[h+512>>2];if(k==C(1)){break u}k=Wh(Uy(C(k*C(x[b+32>>1])),C(1),C(64)));a=65535;Ma:{if(k>=C(65535)){break Ma}a=0;if(k<=C(0)){break Ma}a=~~k>>>0;if(k<C(4294967296)&k>=C(0)){break Ma}a=0}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break u}if(!((g|0)!=14|(w[i+1|0]-1&255)>>>0>1|(a|0)!=64)){v[h+512>>2]=0;v[h+516>>2]=1072693248;d=v[h+2676>>2];Na:{if(!w[i+2|0]){v[h+304>>2]=0;v[h+308>>2]=1072693248;v[h+296>>2]=0;v[h+300>>2]=0;v[h+104>>2]=0;v[h+108>>2]=0;v[h+112>>2]=0;v[h+116>>2]=1072693248;a=v[h+316>>2];v[h+120>>2]=v[h+312>>2];v[h+124>>2]=a;a=v[h+292>>2];v[h+96>>2]=v[h+288>>2];v[h+100>>2]=a;i=h+512|0;j=hb-32|0;hb=j;K=j,M=B(v[b>>2],Hd(x[b+34>>1])),v[K+4>>2]=M;uc(j+4|0,d>>>3|0);G=A[h+104>>3];d=f;e=v[j+4>>2];a=e;while(1){if(a){g=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);l(0,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));l(1,g|0);o=mg(+n());o=D(gf(o)?o>=0?1:-1:o);G=o>G?o:G;a=a-1|0;d=d+8|0;continue}else{Oa:{a=G==0;if(a){break Oa}I=a?1:1/G;d=v[b+20>>2];a=e;while(1){if(!a){break Oa}g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,g|0);o=mg(+n());K=j,N=I*(gf(o)?o>=0?1:-1:o),A[K+24>>3]=N;v[j+16>>2]=0;v[j+20>>2]=-1074790400;v[j+8>>2]=0;v[j+12>>2]=1072693248;o=se(A[Eg(j+24|0,j+16|0,j+8|0)>>3]*32768);Pa:{if(D(o)<2147483648){g=~~o;break Pa}g=-2147483648}K=d,M=$c(g),u[K>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(i){A[i>>3]=G}hb=j+32|0;e=e<<3}break}break Na}v[h+272>>2]=0;v[h+276>>2]=1072693248;v[h+264>>2]=0;v[h+268>>2]=0;v[h+136>>2]=0;v[h+140>>2]=0;v[h+144>>2]=0;v[h+148>>2]=1072693248;a=v[h+284>>2];v[h+152>>2]=v[h+280>>2];v[h+156>>2]=a;a=v[h+260>>2];v[h+128>>2]=v[h+256>>2];v[h+132>>2]=a;j=h+512|0;p=hb-32|0;hb=p;K=p,M=B(v[b>>2],Hd(x[b+34>>1])),v[K+4>>2]=M;uc(p+4|0,d>>>3|0);G=A[h+136>>3];d=f;g=v[p+4>>2];a=g;while(1){if(a){e=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);i=e<<24|e<<8&16711680;r=e>>>8|0;m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);e=e>>>24|0;i=i|((r|m<<24)&65280|(e|m<<8)&255);l(0,(r|(m&255)<<24)&-16777216|(e|(m&16777215)<<8)&16711680|(m>>>8&65280|m>>>24));l(1,i|0);o=mg(+n());o=D(gf(o)?o>=0?1:-1:o);G=o>G?o:G;a=a-1|0;d=d+8|0;continue}else{Qa:{a=G==0;if(a){break Qa}I=a?1:1/G;d=v[b+20>>2];a=g;while(1){if(!a){break Qa}m=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);e=m<<24|m<<8&16711680;r=m>>>8|0;i=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);m=m>>>24|0;e=e|((r|i<<24)&65280|(m|i<<8)&255);l(0,(r|(i&255)<<24)&-16777216|(m|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,e|0);o=mg(+n());K=p,N=I*(gf(o)?o>=0?1:-1:o),A[K+24>>3]=N;v[p+16>>2]=0;v[p+20>>2]=-1074790400;v[p+8>>2]=0;v[p+12>>2]=1072693248;o=se(A[Eg(p+24|0,p+16|0,p+8|0)>>3]*32768);Ra:{if(D(o)<2147483648){e=~~o;break Ra}e=-2147483648}K=d,M=$c(e),u[K>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(j){A[j>>3]=G}hb=p+32|0;e=g<<3}break}}if(!e){break u}o=A[h+512>>3];if(o==1){break u}K=b,M=QT(du(o*+x[b+32>>1],1,64)),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}Sa:{Ta:{Ua:{Va:{Wa:{Xa:{a=(e&255)!=32;Ya:{if(!(a|(w[i+1|0]!=1|(g|0)!=12))){e=v[h+2676>>2];if(!w[i+2|0]){v[h+248>>2]=939524096;g=h+248|0;break Ya}v[h+240>>2]=939524096;g=h+240|0;break Wa}if(!(w[i+1|0]!=2|(g|0)!=12|a)){e=v[h+2676>>2];if(!w[i+2|0]){v[h+232>>2]=939524096;g=h+232|0;break Ua}v[h+224>>2]=939524096;g=h+224|0;break Sa}a=(e&255)!=32;if(a|(w[i+1|0]!=1|(g|0)!=13)){break Va}e=v[h+2676>>2];if(w[i+2|0]){break Xa}v[h+216>>2]=872415232;g=h+216|0}a=v[b+20>>2];d=v[b>>2];b=v[g+4>>2];v[h+160>>2]=v[g>>2];v[h+164>>2]=b;g=hb-16|0;hb=g;v[g+12>>2]=e>>>2;v[g+8>>2]=d;F=z[h+160>>2];b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){k=Gf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));k=Wh(C(Td(C(F*(ng(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));Za:{if(C(D(k))<C(2147483648)){d=~~k;break Za}d=-2147483648}K=a,M=$c(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<2;break u}v[h+208>>2]=872415232;g=h+208|0}a=v[b+20>>2];d=v[b>>2];b=v[g+4>>2];v[h+168>>2]=v[g>>2];v[h+172>>2]=b;g=hb-16|0;hb=g;v[g+12>>2]=e>>>2;v[g+8>>2]=d;F=z[h+168>>2];b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);k=Gf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Wh(C(Td(C(F*(ng(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));_a:{if(C(D(k))<C(2147483648)){d=~~k;break _a}d=-2147483648}K=a,M=$c(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<2;break u}e=0;if(w[i+1|0]!=2|(g|0)!=13|a){break u}e=v[h+2676>>2];if(w[i+2|0]){break Ta}v[h+200>>2]=872415232;g=h+200|0}a=v[b+20>>2];d=v[b>>2];b=v[g+4>>2];v[h+176>>2]=v[g>>2];v[h+180>>2]=b;g=hb-16|0;hb=g;v[g+12>>2]=e>>>3;v[g+8>>2]=d;F=z[h+176>>2];b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){k=Gf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));k=Wh(C(Td(C(F*(ng(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));$a:{if(C(D(k))<C(2147483648)){d=~~k;break $a}d=-2147483648}K=a,M=$c(d),u[K>>1]=M;k=Gf((l(2,w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24)),q()));k=Wh(C(Td(C(F*(ng(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));ab:{if(C(D(k))<C(2147483648)){d=~~k;break ab}d=-2147483648}K=a,M=$c(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}v[h+192>>2]=872415232;g=h+192|0}a=v[b+20>>2];d=v[b>>2];b=v[g+4>>2];v[h+184>>2]=v[g>>2];v[h+188>>2]=b;g=hb-16|0;hb=g;v[g+12>>2]=e>>>3;v[g+8>>2]=d;F=z[h+184>>2];b=v[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);k=Gf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Wh(C(Td(C(F*(ng(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));bb:{if(C(D(k))<C(2147483648)){d=~~k;break bb}d=-2147483648}K=a,M=$c(d),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);k=Gf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Wh(C(Td(C(F*(ng(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));cb:{if(C(D(k))<C(2147483648)){d=~~k;break cb}d=-2147483648}K=a,M=$c(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}a=V(30656)|0}if((O()|0)!=(ea(30656)|0)){break d}_(a|0)|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)==1){break v}}yb(s);break u}a=P()|0;O()|0;break d}v[23516]=0;Q(153,c|0,e+J|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break f}}Qc(H)}hb=h+2704|0;return e|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}yb(s);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Qc(H);S(a|0);L()}function pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=hb-640|0;hb=d;xc(b);f=hb-16|0;hb=f;j=d+448|0;Dq(f+8|0,j);g=b;i=v[b+8>>2];b=v[f+12>>2];jc(f,v[g>>2],i,v[f+8>>2],b);h=v[f+4>>2];if((h|0)==(b|0)){Yb(g,v[f+12>>2])}hb=f+16|0;b=(b|0)==(h|0);if(!b){lT(j)}a:{b:{c:{if(!b){break c}if(!nT(d+448|0)){break c}if(!Ob(v[g>>2],v[g+8>>2],Bc(mT(d+448|0),kb))){break c}if(!c){e=1;break c}zd(a,32);t[d+447|0]=0;j=Kb(d+432|0);d:{e:{f:{g:{h:{i:{j:{k:{if(!Qb(d+448|0,16377,4)){v[23516]=0;R(414,a|0,16777216);b=v[23516];v[23516]=0;if((b|0)==1){break b}b=v[g>>2];v[23516]=0;b=T(158,b|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}v[23516]=0;Q(153,g|0,b-4|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break b}v[23516]=0;A=T(155,g|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break k}break b}l:{m:{n:{o:{p:{q:{if((x[d+488>>1]-2185&65535)>>>0>1910){break q}b=v[g>>2];v[23516]=0;b=T(158,b|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}v[23516]=0;Q(153,g|0,b-4|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break b}v[23516]=0;A=T(155,g|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break b}if(A>>>0<256){break q}b=v[g>>2];v[23516]=0;b=T(158,b|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}if(b>>>0<=A>>>0){break q}v[23516]=0;b=Q(153,g|0,A|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}if(!b){break q}v[23516]=0;b=T(415,g|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}if(!b){break q}v[23516]=0;R(414,a|0,16777216);b=v[23516];v[23516]=0;if((b|0)==1){break b}b=x[d+488>>1];if(b>>>0>=4096){v[23516]=0;c=Q(1,d+168|0,16592)|0;b=v[23516];v[23516]=0;if((b|0)==1){break j}a=v[a+1298464>>2];v[23516]=0;U(384,a|0,1,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(c);e=0;break d}b=P()|0;O()|0;xb(c);break a}if(b>>>0<2194){break q}v[23516]=0;e=Q(1,d+416|0,16116)|0;b=v[23516];v[23516]=0;if((b|0)==1){break p}b=v[a+1298464>>2];v[23516]=0;U(384,b|0,4,e|0);b=v[23516];v[23516]=0;if((b|0)==1){break o}xb(e)}if(v[a+480180>>2]!=32){break k}b=x[d+488>>1];if((b&61440)!=20480){break l}b=b&4095;e=b<<16;if(Qb(d+508|0,13700,4)){break n}t[d+447|0]=1;break m}b=P()|0;O()|0;break a}b=P()|0;O()|0;xb(e);break a}if(b>>>0<297){break m}e=x[d+508>>1]|e}v[a+1074308>>2]=e;break k}e=x[d+490>>1];if(!((e|0)!=2184&(b|0)!=2184)){t[d+447|0]=1;v[a+1074308>>2]=18284544;break k}r:{switch(b-532|0){default:if(v[d+508>>2]|((b|0)!=768|(e|0)!=768)|(x[d+480>>1]!=256|w[d+500|0]!=128)){break k}if(w[d+501|0]){break k}v[a+1074308>>2]=18285088;t[d+447|0]=1;break k;case 3:if(v[d+508>>2]|(e|0)!=512){break k}s:{if(MA(d+512|0,255,64)){v[a+1074308>>2]=18219008;v[23516]=0;b=Q(1,d+400|0,14917)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break s}b=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[23516]=0;b=Q(1,d+400|0,16966)|0;e=v[23516];v[23516]=0;if((e|0)==1){break i}}Gb(j,b);xb(b);t[d+447|0]=1;break k;case 1:case 2:break k;case 0:break r}}if(v[d+508>>2]|(e|0)!=514){break k}v[a+1074308>>2]=17367040;v[23516]=0;b=Q(1,d+400|0,14803)|0;e=v[23516];v[23516]=0;if((e|0)==1){break f}Gb(j,b);xb(b);t[d+447|0]=1}b=x[d+492>>1];e=b>>>2|0;v[a+480208>>2]=b<<3&32768|(e&8|(e&4|(v[a+480208>>2]&-32797|b<<1&16)));b=d+280|0;Uq(b,d+448|4);v[23516]=0;R(221,d+168|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break h}b=d+168|0;yc(a+1298308|0,b);wb(b);if(!(!(w[d+494|0]&4)|v[a+1074308>>2]-18285314>>>0>4276681982)){v[a+480216>>2]=w[d+478|0];v[a+480220>>2]=w[d+479|0]}b=w[d+496|0];v[a+480200>>2]=b>>>0>128?256:b<<1;b=w[d+498|0];if(b){v[a+480196>>2]=b}t[d+168|0]=31;t[d+280|0]=w[d+499|0];b=d+168|0;e=d+280|0;I=a,J=B(w[ef(b,e)|0],1e4),v[I+480204>>2]=J;t[d+168|0]=w[d+497|0];t[d+280|0]=128;I=a,J=w[Vb(b,e)|0],v[I+480228>>2]=J;e=0;while(1){if((e|0)==64){t:{v[23516]=0;Q(153,g|0,192)|0;b=v[23516];v[23516]=0;if((b|0)==1){break b}if(v[a+480180>>2]==16777216&(x[d+488>>1]-2187&65535)>>>0<=2){break t}b=w[a+484376|0];e=v[a+484360>>2];v[23516]=0;da(347,Sb(e,b)|0,g|0,x[d+480>>1],255,254);b=v[23516];v[23516]=0;if((b|0)==1){break b}break e}}else{h=(d+448|0)+e|0;i=h- -64|0;u:{if(w[i|0]==255){break u}f=(e<<5)+a|0;b=f+480280|0;af(b);I=f+480286|0,J=Bd(w[h+128|0],0,64),u[I>>1]=J;h=t[i|0];if((h|0)<0){v[b>>2]=v[b>>2]|1024}h=h&127;if(h>>>0<=64){u[f+480284>>1]=h<<2;break u}if((h|0)!=100){break u}v[b>>2]=v[b>>2]|256}e=e+1|0;continue}break}e=0;v[23516]=0;b=T(192,g|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break g}if(b){break d}v[23516]=0;b=T(155,g|0)|0;f=v[23516];v[23516]=0;v:{if((f|0)==1){break v}if(b>>>0>4e3){break d}f=w[a+484376|0];h=v[a+484360>>2];v[23516]=0;b=W(416,Sb(h,f)|0,g|0,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break v}if(!b){break d}break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}s=Lb(d+384|0);p=Lb(d+368|0);e=0;n=Lb(d+352|0);v[23516]=0;b=W(417,g|0,s|0,x[d+482>>1])|0;f=v[23516];v[23516]=0;w:{x:{y:{if((f|0)==1){break y}if(!b){break w}v[23516]=0;b=W(417,g|0,p|0,x[d+484>>1])|0;f=v[23516];v[23516]=0;if((f|0)==1){break y}if(!b){break w}v[23516]=0;b=W(417,g|0,n|0,x[d+486>>1])|0;f=v[23516];v[23516]=0;if((f|0)==1){break y}if(!b){break w}v[d+348>>2]=-1;I=d,J=Cb(v[s>>2]),v[I+168>>2]=J;e=Cb(v[s+4>>2]);while(1){b=v[d+168>>2];if(Nb(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Ie(d+168|0);continue}else{I=d,J=Cb(v[p>>2]),v[I+168>>2]=J;e=Cb(v[p+4>>2]);while(1){b=v[d+168>>2];if(Nb(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Ie(d+168|0);continue}else{I=d,J=Cb(v[n>>2]),v[I+168>>2]=J;e=Cb(v[n+4>>2]);z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{while(1){b=v[d+168>>2];if(Nb(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Ie(d+168|0);continue}else{if(t[d+494|0]&1){v[d+168>>2]=v[d+504>>2];I=d,J=v[Hb(d+348|0,d+168|0)>>2],v[I+348>>2]=J}e=0;if(x[d+490>>1]!=532){break H}b=x[d+488>>1];if(w[d+479|0]|(b?(b|0)!=532:0)|(w[d+478|0]|w[d+501|0])){break H}if(v[d+508>>2]|w[d+492|0]&192){break H}if(x[d+482>>1]){break I}f=x[d+484>>1];if(!f){break I}if((v[g+8>>2]+(sc(v[p>>2],v[p+4>>2])<<2)|0)+2>>>0>y[d+348>>2]){break I}}break}while(1){if((e&65535)>>>0<(f&65535)>>>0){v[23516]=0;b=T(155,g|0)|0;f=v[23516];v[23516]=0;J:{if((f|0)!=1){if(!b){break J}wg(g,((e&65535)<<2)+4|0);break I}b=P()|0;O()|0;break x}e=e+1|0;f=x[d+484>>1];continue}break}v[23516]=0;b=Q(1,d+336|0,15068)|0;e=v[23516];v[23516]=0;if((e|0)==1){break G}Gb(j,b);xb(b)}e=1;if(x[d+488>>1]){break H}v[23516]=0;b=Q(1,d+320|0,15525)|0;f=v[23516];v[23516]=0;if((f|0)==1){break F}Gb(j,b);xb(b)}b=x[d+494>>1];K:{if(b&2){v[23516]=0;f=T(192,g|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break A}b=v[g+8>>2];h=v[g>>2];v[23516]=0;i=b;b=f<<3;h=W(154,h|0,i|0,b|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break A}if(!(!h|y[d+348>>2]<b+v[g+8>>2]>>>0)){v[23516]=0;b=a+1298408|0;R(418,b|0,f|0);h=v[23516];v[23516]=0;if((h|0)==1){break A}I=d,J=Cb(v[b>>2]),v[I+280>>2]=J;h=Cb(v[a+1298412>>2]);L:{M:{while(1){b=v[d+280>>2];if(!Nb(b,h)){if(!(!f&e)){break K}if(!(w[d+494|0]&4)){break L}v[23516]=0;b=Q(1,d+304|0,15558)|0;e=v[23516];v[23516]=0;if((e|0)==1){break M}Gb(j,b);xb(b);break K}v[23516]=0;R(419,g|0,d+168|0);i=v[23516];v[23516]=0;if((i|0)!=1){Rb(b,0,44);i=w[d+168|0]|w[d+169|0]<<8;if(i|(w[d+170|0]|w[d+171|0]<<8)){v[b+20>>2]=((i&65024)>>>9|0)+80;I=b,J=Wb((w[d+168|0]|w[d+169|0]<<8)>>>5&15,1,12)-1|0,v[I+16>>2]=J;I=b,J=Wb((w[d+168|0]|w[d+169|0]<<8)&31,1,31),v[I+12>>2]=J;I=b,J=Wb((w[d+170|0]|w[d+171|0]<<8)>>>11|0,0,23),v[I+8>>2]=J;I=b,J=Wb((w[d+170|0]|w[d+171|0]<<8)>>>5&63,0,59),v[I+4>>2]=J;I=b,J=Wb((w[d+170|0]|w[d+171|0]<<8)<<1&62,0,59),v[I>>2]=J}v[b+44>>2]=w[d+172|0]|w[d+173|0]<<8|(w[d+174|0]<<16|w[d+175|0]<<24);v[d+280>>2]=v[d+280>>2]+48;continue}break}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}v[23516]=0;b=Q(1,d+304|0,15108)|0;e=v[23516];v[23516]=0;if((e|0)!=1){Gb(j,b);xb(b);break K}b=P()|0;O()|0;break x}wg(g,2);break K}if(!(b>>>0<2&e)){break K}v[23516]=0;b=T(192,g|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break z}if(!b){v[23516]=0;b=Q(1,d+304|0,15068)|0;e=v[23516];v[23516]=0;if((e|0)!=1){Gb(j,b);xb(b);break K}b=P()|0;O()|0;break x}wg(g,2)}N:{if(!(w[d+494|0]&8?1:w[d+492|0]&128)){break N}v[23516]=0;b=a+901404|0;e=Q(420,g|0,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break E}if(!e){break N}LA(b)}if(x[d+488>>1]<=531){jq(a+901404|0)}v[23516]=0;C=T(172,d+280|0)|0;b=v[23516];v[23516]=0;O:{P:{Q:{if((b|0)!=1){v[23516]=0;b=Q(410,g|0,13937)|0;e=v[23516];v[23516]=0;if((e|0)==1){break Q}if(b){v[23516]=0;b=T(155,g|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break P}v[23516]=0;U(188,d+256|0,g|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break P}b=d+256|0;e=hc(d+168|0,b);cd(C,e);yb(e);yb(b)}u[a+480188>>1]=1;v[23516]=0;b=Q(410,g|0,13942)|0;e=v[23516];v[23516]=0;if((e|0)==1){break Q}if(!b){break C}v[23516]=0;b=T(155,g|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){v[23516]=0;U(188,d+256|0,g|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break O}}b=P()|0;O()|0;break B}b=P()|0;O()|0;break x}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=d+256|0;f=hc(d+168|0,b);yb(b);b=v[f>>2];v[23516]=0;b=T(158,b|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break D}u[d+256>>1]=(b>>>0)/20;b=x[Rc(26820,d+256|0)>>1];u[a+480188>>1]=b;e=0;while(1){if((b|0)==(e|0)){yb(f);break C}v[23516]=0;U(421,f|0,((e<<5)+a|0)+480289|0,20);h=v[23516];v[23516]=0;if((h|0)!=1){e=e+1|0;continue}break}break D}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;yb(f);break B}R:{b=v[d+348>>2];e=v[g+8>>2];S:{if(b>>>0>=e>>>0){e=b-e|0;break S}v[23516]=0;e=T(200,g|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break R}}v[23516]=0;U(188,d+168|0,g|0,e|0);b=v[23516];v[23516]=0;if((b|0)==1){break R}b=d+168|0;D=hc(d+256|0,b);yb(b);v[23516]=0;E=Q(422,a|0,D|0)|0;b=v[23516];v[23516]=0;T:{U:{V:{if((b|0)==1){break V}if(!(t[d+494|0]&1)|!x[d+502>>1]){break U}v[23516]=0;b=Q(153,g|0,v[d+504>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break V}if(!b){break U}v[23516]=0;X(336,a+1298332|0,g|0,x[d+502>>1],4);b=v[23516];v[23516]=0;if((b|0)!=1){break U}}b=P()|0;O()|0;break T}h=a+480192|0;u[h>>1]=0;f=0;if(w[d+492|0]&4){u[d+168>>1]=x[d+482>>1];u[d+96>>1]=255;f=x[Rc(d+168|0,d+96|0)>>1];u[h>>1]=f}e=0;W:{while(1){if((f&65535)>>>0<=e>>>0){v[d+252>>2]=0;e=x[d+484>>1];if(e){b=Bb(v[p>>2],e-1|0);v[d+252>>2]=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+80}u[d+168>>1]=e;u[d+96>>1]=3999;q=a+480190|0;f=x[Rc(d+168|0,d+96|0)>>1];u[q>>1]=f;m=c&2;o=d+188|0;z=a+1298464|0;e=0;b=0;while(1){X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((f&65535)>>>0>e>>>0){f=Bb(v[p>>2],e);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if(!f){break Y}v[23516]=0;f=Q(153,g|0,f|0)|0;h=v[23516];v[23516]=0;da:{ea:{fa:{ga:{ha:{if((h|0)==1){break ha}if(!f){break Y}v[23516]=0;f=Q(423,g|0,d+168|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break ha}if(!f){break Y}v[23516]=0;i=e+1|0;f=B(i,104)+a|0;h=f+484380|0;k=Q(424,d+168|0,h|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break ga}l=d+152|0;Uq(l,o);v[23516]=0;R(221,d+96|0,l|0);l=v[23516];v[23516]=0;if((l|0)==1){break fa}l=d+96|0;Ac(((i<<5)+a|0)+946304|0,l);wb(l);v[23516]=0;k=Q(153,g|0,k|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break ga}if(!k){break Y}f=x[f+484414>>1];if(!(f&512)){break ea}v[23516]=0;f=Q(425,g|0,d+96|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break ca}if(!f){break da}v[d+8>>2]=v[d+104>>2];f=v[d+100>>2];v[d>>2]=v[d+96>>2];v[d+4>>2]=f;vl(h,1,d);break da}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if(!(f&16384)){r=x[d+488>>1];k=w[d+186|0];l=k&2;f=w[d+214|0];i=Uc(d+96|0,l?16:8,1,0,(f^-1)&1);if(!(!(k&4)|r>>>0<532)){Eo(i,3)}ia:{ja:{if(k&8){k=f&4?5:4;break ja}if(!l){k=10;if((f|0)==255){break ja}}if(f&2){t[i+2|0]=1}if(f&4){cg(i,2)}if(!(f&8)){break ia}k=9;if(!l){break ia}}cg(i,k)}if(m){f=0;v[23516]=0;W(218,d+96|0,h|0,g|0)|0;i=v[23516];v[23516]=0;if((i|0)!=1){break _}break X}f=1;i=w[d+99|0];if(i>>>0>17){break Z}i=1<<i;if(!(i&63503)){if(!(i&198144)){break Z}break $}if(w[d+96|0]){break $}break _}v[23516]=0;R(426,g|0,d+80|0);f=v[23516];v[23516]=0;if((f|0)==1){break aa}h=v[d+80>>2];if(!(!m|!h)){f=Kb(d+96|0);v[23516]=0;U(271,g|0,f|0,h|0);h=v[23516];v[23516]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{if((h|0)!=1){v[23516]=0;R(382,d+136|0,16514);h=v[23516];v[23516]=0;if((h|0)==1){break qa}v[d+64>>2]=i;v[23516]=0;U(11,d+120|0,0,f|0);h=v[23516];v[23516]=0;if((h|0)==1){break pa}v[23516]=0;X(427,d+152|0,d+136|0,d- -64|0,d+120|0);h=v[23516];v[23516]=0;if((h|0)==1){break oa}h=v[z>>2];v[23516]=0;U(384,h|0,2,d+152|0);h=v[23516];v[23516]=0;if((h|0)==1){break na}xb(d+152|0);xb(d+120|0);ac(d+136|0);wb(f);break da}b=P()|0;O()|0;break ka}b=P()|0;O()|0;break ka}b=P()|0;O()|0;break la}b=P()|0;O()|0;break ma}b=P()|0;O()|0;xb(d+152|0)}xb(d+120|0)}ac(d+136|0)}wb(f);break T}v[23516]=0;Q(186,g|0,h|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break aa}}f=0;break Z}u[d+168>>1]=1;u[d+96>>1]=f;I=a+480190|0,J=x[ie(d+168|0,d+96|0)>>1],u[I>>1]=J;if(!(x[d+488>>1]==516&b)|x[d+490>>1]!=512|(x[d+494>>1]|v[d+508>>2])){break ba}if((x[d+492>>1]&65527)!=21|w[d+496|0]!=128|(w[d+497|0]!=48|w[d+500|0]!=128)){break ba}if(w[d+501|0]|x[d+502>>1]){break ba}f=d+576|0;b=d+512|0;e=1;while(1)if((b|0)==(f|0)){b=d+640|0;while(1)if((b|0)==(f|0)){f=20;while(1){if((f|0)==26){ra:{if(!(e&1)){break ba}v[23516]=0;b=Q(1,d+152|0,9898)|0;e=v[23516];v[23516]=0;if((e|0)==1){break ra}Gb(j,b);xb(b);break ba}}else{e=!w[(d+f|0)+452|0]&e;f=f+1|0;continue}break}b=P()|0;O()|0;break T}else{e=w[f|0]==64&e;f=f+1|0;continue}}else{e=(w[b|0]&127)==32&e;b=b+1|0;continue}}b=P()|0;O()|0;break T}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;b=sc(v[n>>2],v[n+4>>2]);u[d+168>>1]=b;q=x[Rc(d+168|0,v[a+8>>2]+10|0)>>1];u[d+118>>1]=q;sa:{ta:{ua:{va:{if((b|0)!=(q|0)){v[23516]=0;Y(428,d+96|0);b=v[23516];v[23516]=0;if((b|0)==1){break sa}b=v[n+4>>2];e=v[n>>2];v[23516]=0;I=d,J=sc(e,b),v[I+136>>2]=J;X(429,d+168|0,d+96|0,d+136|0,d+118|0);b=v[23516];v[23516]=0;if((b|0)==1){break ua}b=v[a+1298464>>2];v[23516]=0;U(384,b|0,2,d+168|0);b=v[23516];v[23516]=0;if((b|0)==1){break va}xb(d+168|0);ac(d+96|0)}if(!(c&1)){u[d+118>>1]=0;q=0}m=a+480188|0;h=0;wa:{xa:{ya:{za:{Aa:{Ba:{while(1){Ca:{if((h|0)==(q|0)){Da:{Ea:{b=v[d+252>>2];if(!b){break Ea}v[23516]=0;Q(153,g|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Da}if(!(r&1)){break Ea}while(1){Fa:{b=v[g+8>>2];c=v[g>>2];v[23516]=0;b=W(154,c|0,b|0,4)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Fa}if(!b){break Ea}v[23516]=0;b=Q(410,g|0,13911)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Fa}Ga:{if(!b){v[23516]=0;b=Q(410,g|0,13916)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Fa}if(!b){break Ga}}v[23516]=0;b=T(155,g|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){wg(g,8);if(!(b&1616928864)|b&-2139062144){break Ga}break Ea}b=P()|0;O()|0;break T}v[23516]=0;b=T(192,g|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Fa}v[23516]=0;Q(186,g|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){continue}}break}b=P()|0;O()|0;break T}v[23516]=0;b=Q(430,a|0,g|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Da}b=b|w[d+447|0];t[d+447|0]=b;if(!(!b|E)){Zt(a+1074312|0);t[a+1074368|0]=0}v[23516]=0;X(431,a|0,g|0,0,d+447|0);b=v[23516];v[23516]=0;if((b|0)==1){break Da}v[23516]=0;o=a+484344|0;R(224,o|0,q|0);b=v[23516];v[23516]=0;if((b|0)==1){break Da}z=a+480188|0;H=a+480183|0;h=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{while(1){Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((h|0)!=(q|0)){b=Bb(v[n>>2],h);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b){v[23516]=0;b=Q(153,g|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break ab}if(b){break $a}}v[23516]=0;b=W(225,o|0,h&65535,64)|0;c=v[23516];v[23516]=0;if((c|0)==1){break ab}if(b){break bb}u[d+48>>1]=h;v[23516]=0;Y(432,d+96|0);b=v[23516];v[23516]=0;if((b|0)==1){break fb}v[23516]=0;U(433,d+168|0,d+96|0,d+48|0);b=v[23516];v[23516]=0;if((b|0)==1){break eb}b=v[a+1298464>>2];v[23516]=0;U(384,b|0,2,d+168|0);b=v[23516];v[23516]=0;if((b|0)==1){break db}xb(d+168|0);ac(d+96|0)}if(!v[a+1074308>>2]){e=x[d+488>>1];if((e|0)!=2184){break Za}v[a+1074308>>2]=18284544}if(!oh(v[j+4>>2],w[j+11|0])){break _a}v[23516]=0;c=Q(1,d+96|0,17711)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Ra}b=v[a+1074308>>2];v[23516]=0;R(138,d- -64|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break Ta}v[23516]=0;U(2,d+168|0,c|0,d- -64|0);b=v[23516];v[23516]=0;if((b|0)==1){break Ua}e=d+168|0;b=Gb(j,e);xb(e);xb(d- -64|0);xb(c);if(!Qb(d+508|0,13700,4)|(x[d+488>>1]&61440)!=20480){break Ya}v[23516]=0;c=Q(1,d+168|0,16978)|0;e=v[23516];v[23516]=0;if((e|0)==1){break Va}v[23516]=0;Q(96,b|0,c|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Wa}xb(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break cb}b=P()|0;O()|0;xb(d+168|0)}ac(d+96|0);break T}b=v[o>>2];v[23516]=0;R(434,Xb(b,h)|0,C|0);b=v[23516];v[23516]=0;if((b|0)!=1){break Pa}}b=P()|0;O()|0;break T}v[23516]=0;b=T(192,g|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Ha}v[23516]=0;F=T(192,g|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Ia}v[23516]=0;c=Q(186,g|0,4)|0;e=v[23516];v[23516]=0;if((e|0)==1){break Ia}if(!c){break Pa}v[23516]=0;c=W(225,o|0,h&65535,F|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break Ia}if(!c){break Pa}v[23516]=0;U(188,d+96|0,g|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break Ja}b=d+96|0;m=hc(d+168|0,b);yb(b);b=v[o>>2];v[23516]=0;R(434,Xb(b,h)|0,C|0);b=v[23516];v[23516]=0;if((b|0)==1){break La}b=x[z>>1];v[23516]=0;l=Q(435,d+120|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Ma}b=x[z>>1];c=d+96|0;Cj(c);v[23516]=0;k=W(436,d+80|0,b|0,c|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Oa}I=d,J=Cb(v[Xb(v[o>>2],h)>>2]),v[I+64>>2]=J;r=0;while(1){gb:{hb:{ib:{jb:{if(r>>>0>=F>>>0){break jb}b=v[m>>2];v[23516]=0;b=W(154,b|0,v[d+176>>2],1)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Qa}if(!b){break jb}v[23516]=0;b=T(204,m|0)|0;c=v[23516];v[23516]=0;kb:{if((c|0)!=1){b=b<<24>>24;if(b){break kb}_T(d- -64|0,x[z>>1]);r=r+1|0;continue}break Qa}lb:{c=b&127;i=c?c-1&65535:0;if(ad(v[l>>2],v[d+124>>2])>>>0>i>>>0){break lb}v[23516]=0;t[d+96|0]=0;c=i+1|0;U(437,l|0,c|0,d+96|0);e=v[23516];v[23516]=0;if((e|0)==1){break Qa}e=d+96|0;Cj(e);v[23516]=0;U(438,k|0,c|0,e|0);c=v[23516];v[23516]=0;if((c|0)!=1){break lb}break Qa}if((b|0)<0){v[23516]=0;b=T(204,m|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Qa}I=Ib(v[l>>2],i),J=b,t[I|0]=J}f=d+96|0;Cj(f);if(i>>>0<x[z>>1]){f=Ed(v[d+64>>2],i)}b=Ib(v[l>>2],i);e=w[b|0];if(e&16){I=f,J=w[Ed(v[k>>2],i)|0],t[I|0]=J;e=w[b|0]}if(e&32){I=f,J=w[Ed(v[k>>2],i)+1|0],t[I+1|0]=J;e=w[b|0]}if(e&64){c=Ed(v[k>>2],i);t[f+2|0]=w[c+2|0];t[f+4|0]=w[c+4|0];e=w[b|0]}if(e<<24>>24<0){c=Ed(v[k>>2],i);t[f+3|0]=w[c+3|0];t[f+5|0]=w[c+5|0];e=w[b|0]}if(e&1){v[23516]=0;b=T(204,m|0)|0;c=v[23516];v[23516]=0;mb:{nb:{if((c|0)!=1){b=b+(((b^-1)&128)>>>7|0)|0;if(!(t[H|0]&1)){break nb}c=b;break mb}break Qa}c=253;if((b-121&255)>>>0<132){break mb}c=(b&255)==253?0:b}t[f|0]=c;I=Ed(v[k>>2],i),J=c,t[I|0]=J;b=Ib(v[l>>2],i)}if(w[b|0]&2){v[23516]=0;b=T(204,m|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Qa}t[f+1|0]=b;I=Ed(v[k>>2],i),J=b,t[I+1|0]=J;b=Ib(v[l>>2],i)}if(!(w[b|0]&4)){break gb}v[23516]=0;b=T(204,m|0)|0;c=v[23516];v[23516]=0;ob:{pb:{if((c|0)!=1){if(b>>>0>64){break pb}t[f+4|0]=b;e=1;break ob}break Qa}if(b<<24>>24<=-64){e=2;t[f+2|0]=2;b=b^-128;t[f+4|0]=b;break hb}if(b>>>0<=74){e=5;t[f+2|0]=5;b=b-65|0;t[f+4|0]=b;break hb}if(b>>>0<=84){e=6;t[f+2|0]=6;b=b-75|0;t[f+4|0]=b;break hb}if(b>>>0<=94){e=3;t[f+2|0]=3;b=b-85|0;t[f+4|0]=b;break hb}if(b>>>0<=104){e=4;t[f+2|0]=4;b=b-95|0;t[f+4|0]=b;break hb}if(b>>>0<=114){e=13;t[f+2|0]=13;b=b-105|0;t[f+4|0]=b;break hb}if(b>>>0<=124){e=12;t[f+2|0]=12;b=b-115|0;t[f+4|0]=b;break hb}c=b+63|0;if((c&255)>>>0<=9){t[f+4|0]=c;e=11;t[f+2|0]=11;b=c;break hb}c=b+53|0;G=c&255;if(G>>>0<=9){t[f+4|0]=c;e=8;t[f+2|0]=8;if(!G){b=0;break hb}if(v[a+1074308>>2]-1>>>0>18285139){break ib}e=7;t[f+2|0]=7;break ib}b=b+33|0;if((b&255)>>>0>=10){b=w[f+4|0];e=w[f+2|0];break hb}t[f+4|0]=b;e=15}t[f+2|0]=e;break hb}Ah(k);dc(l);yb(m);break Pa}b=c}c=Ed(v[k>>2],i);t[c+4|0]=b;t[c+2|0]=e;b=Ib(v[l>>2],i)}if(!(w[b|0]&8)){continue}v[23516]=0;R(263,d+32|0,m|0);b=v[23516];v[23516]=0;if((b|0)!=1){JA(f,w[d+32|0],w[Kc(d+32|0)|0],1);b=Ed(v[k>>2],i);t[b+3|0]=w[f+3|0];t[b+5|0]=w[f+5|0];continue}break}break Qa}e=x[d+488>>1]}qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{b=e&65535;switch(b>>>12|0){case 13:break rb;case 7:break sb;case 6:break tb;case 4:break ub;case 1:break wb;case 0:break xb;default:break Xa}}if(E){v[23516]=0;b=Q(1,d+168|0,8369)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;O()|0;break T}yb:{zb:{Ab:{Bb:{Cb:{Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{if((e&65535)==532){f=x[d+490>>1];if((f|0)!=532){if((f|0)!=512){e=532;break Kb}Mb:{if(x[d+494>>1]|x[d+492>>1]!=9|(w[d+479|0]|w[d+478|0])){break Mb}if(x[d+482>>1]|x[d+480>>1]!=(x[d+486>>1]+1|0)|(w[d+496|0]!=128|w[d+497|0]!=100)){break Mb}if(w[d+498|0]!=1|w[d+500|0]!=128|(w[d+501|0]|x[d+502>>1])){break Mb}if(v[d+504>>2]|v[d+508>>2]){break Mb}v[23516]=0;b=Q(1,d+168|0,9879)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;O()|0;break T}e=532;if(v[d+508>>2]|(w[d+479|0]|w[d+478|0])){break Jb}v[a+1074308>>2]=16777381;v[23516]=0;b=Q(1,d+168|0,15005)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Gb(j,b);xb(b);t[d+447|0]=1;break Xa}b=P()|0;O()|0;break T}if(!Qb(d+508|0,14180,4)){v[23516]=0;b=Q(1,d+168|0,8407)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Gb(j,b);xb(b);e=a+1074312|0;f=38;break vb}b=P()|0;O()|0;break T}e=532;if(w[d+501|0]|x[d+494>>1]>1|(v[d+508>>2]|(x[d+492>>1]&4294)!=4)){break Lb}if(!x[a+480190>>1]){break Lb}v[23516]=0;e=Q(53,d+96|0,13513)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Hb}b=hb-16|0;hb=b;c=hb-16|0;hb=c;cv(c+8|0,a+484527|0);WS(b+8|0,v[c+8>>2],v[c+12>>2]);hb=c+16|0;Be(b,e);c=Mc(v[b+8>>2],v[b+12>>2],v[b>>2],v[b+4>>2]);hb=b+16|0;wb(e);if(c){break Ib}e=x[d+488>>1]}if(e&65535){break Lb}if(oh(v[j+4>>2],w[j+11|0])){break Fb}}f=x[d+490>>1]}if((f&65535)>>>0>767){break Xa}}if(!oh(v[j+4>>2],w[j+11|0])){break Xa}if((f&65535)>>>0<533){break Db}v[23516]=0;b=Q(1,d- -64|0,15038)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Eb}Gb(j,b);xb(b);break Cb}v[23516]=0;b=Q(1,d+168|0,8433)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Gb}Gb(j,b);xb(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}v[23516]=0;b=Q(1,d+168|0,9769)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if((e&65535)>>>0>=533){v[23516]=0;R(439,d- -64|0,4018);b=v[23516];v[23516]=0;Nb:{if((b|0)!=1){v[23516]=0;v[d+48>>2]=x[d+488>>1]-532;U(440,d+168|0,d- -64|0,d+48|0);b=v[23516];v[23516]=0;if((b|0)==1){break Nb}b=d+168|0;Gb(j,b);xb(b);ac(d- -64|0);break Cb}b=P()|0;O()|0;break T}b=P()|0;O()|0;ac(d- -64|0);break T}v[23516]=0;R(269,d- -64|0,4317);b=v[23516];v[23516]=0;if((b|0)==1){break Bb}b=x[d+488>>1];v[d+32>>2]=b>>>8&15;v[23516]=0;v[d+16>>2]=b&255;R(441,d+48|0,d+16|0);b=v[23516];v[23516]=0;if((b|0)==1){break Ab}v[23516]=0;X(427,d+168|0,d- -64|0,d+32|0,d+48|0);b=v[23516];v[23516]=0;if((b|0)==1){break zb}b=d+168|0;Gb(j,b);xb(b);xb(d+48|0);ac(d- -64|0)}b=a+1298408|0;if(!nc(v[b>>2],v[a+1298412>>2])){break Xa}c=v[d+508>>2];if(!c){break Xa}c=NC(x[d+488>>1],c);e=po(d+168|0);v[e+44>>2]=c;v[23516]=0;R(442,b|0,e|0);b=v[23516];v[23516]=0;if((b|0)!=1){break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break yb}b=P()|0;O()|0;xb(d+48|0)}ac(d- -64|0);break T}c=v[d+508>>2];v[23516]=0;U(443,d+168|0,b|0,v[d+508>>2]);e=v[23516];v[23516]=0;Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{if((e|0)!=1){e=d+168|0;Gb(j,e);xb(e);b=(b|0)==8191?c:b-4176|0;if((b|0)>1915){break Vb}f=v[a+480208>>2];if(!(f&16)){break Ub}v[23516]=0;Q(268,a+1074312|0,7)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break Tb}break qb}b=P()|0;O()|0;break T}if(b>>>0>4200){break Rb}f=v[a+480208>>2]}if(!(f&16)){v[23516]=0;Q(268,a+1074312|0,7)|0;c=v[23516];v[23516]=0;if((c|0)==1){break qb}}if((b|0)>2385){break Sb}}v[23516]=0;Q(268,a+1074312|0,38)|0;b=v[23516];v[23516]=0;if((b|0)==1){break qb}}v[23516]=0;b=Q(268,a+1074312|0,102)|0;c=v[23516];v[23516]=0;if((c|0)==1){break qb}v[23516]=0;Q(268,b|0,48)|0;b=v[23516];v[23516]=0;if((b|0)==1){break qb}break Qb}if(b>>>0>4383){break Pb}}v[23516]=0;b=W(267,a+1074312|0,116,1)|0;c=v[23516];v[23516]=0;if((c|0)==1){break qb}v[23516]=0;Q(268,b|0,115)|0;b=v[23516];v[23516]=0;if((b|0)==1){break qb}break Ob}if(b>>>0>4563){break Xa}}v[23516]=0;b=Q(268,a+1074312|0,43)|0;c=v[23516];v[23516]=0;if((c|0)==1){break qb}v[23516]=0;e=Q(268,b|0,42)|0;b=v[23516];v[23516]=0;f=87;if((b|0)==1){break qb}}v[23516]=0;Q(268,e|0,f|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break qb}break Xa}v[23516]=0;Y(444,d+96|0);b=v[23516];v[23516]=0;Wb:{Xb:{Yb:{if((b|0)!=1){b=x[d+488>>1];v[d+48>>2]=b>>>8&15;v[23516]=0;v[d+32>>2]=b&255;R(441,d- -64|0,d+32|0);b=v[23516];v[23516]=0;if((b|0)==1){break Yb}v[23516]=0;X(427,d+168|0,d+96|0,d+48|0,d- -64|0);b=v[23516];v[23516]=0;if((b|0)==1){break Xb}b=d+168|0;Gb(j,b);xb(b);xb(d- -64|0);ac(d+96|0);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break Wb}b=P()|0;O()|0;xb(d- -64|0)}ac(d+96|0);break T}v[23516]=0;b=Q(1,d+168|0,8369)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;O()|0;break T}if(!((b|0)!=32767|x[d+490>>1]!=533)){v[23516]=0;b=Q(1,d+168|0,5045)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;O()|0;break T}v[23516]=0;R(135,d+96|0,4153);b=v[23516];v[23516]=0;Zb:{if((b|0)!=1){b=x[d+488>>1];v[d+64>>2]=b>>>8&15;v[d+48>>2]=b>>>4&15;v[23516]=0;v[d+32>>2]=b&15;da(136,d+168|0,d+96|0,d- -64|0,d+48|0,d+32|0);b=v[23516];v[23516]=0;if((b|0)==1){break Zb}b=d+168|0;Gb(j,b);xb(b);ac(d+96|0);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;ac(d+96|0);break T}v[23516]=0;b=Q(1,d+168|0,6126)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Gb(j,b);xb(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if(!VD(v[a+1074308>>2])){break Xa}v[23516]=0;c=Q(1,d+168|0,17214)|0;e=v[23516];v[23516]=0;_b:{if((e|0)!=1){v[23516]=0;Q(96,b|0,c|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break _b}xb(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;xb(c);break T}$b:{ac:{bc:{cc:{dc:{ec:{e=v[a+480180>>2];if(!((e|0)!=16777216|x[d+488>>1]<2186)){v[23516]=0;b=Q(153,g|0,A|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Da}if(b){v[23516]=0;U(445,a|0,g|0,x[d+488>>1]);b=v[23516];v[23516]=0;if((b|0)==1){break Da}}e=v[a+480180>>2]}fc:{if((e|0)==16777216){v[23516]=0;b=Q(1,d+48|0,13884)|0;c=v[23516];v[23516]=0;if((c|0)==1){break ec}Gb(a+1298344|0,b);xb(b);break fc}v[23516]=0;R(269,d+32|0,4317);b=v[23516];v[23516]=0;if((b|0)==1){break dc}b=x[d+490>>1];v[d+28>>2]=b>>>8;v[23516]=0;v[d+12>>2]=b&255;R(441,d+16|0,d+12|0);b=v[23516];v[23516]=0;if((b|0)==1){break cc}v[23516]=0;X(427,d+48|0,d+32|0,d+28|0,d+16|0);b=v[23516];v[23516]=0;if((b|0)==1){break bc}b=d+48|0;Gb(a+1298344|0,b);xb(b);xb(d+16|0);ac(d+32|0)}b=v[a+480180>>2];v[23516]=0;b=Q(1,d+48|0,((b|0)==16777216?10143:6130)|0)|0;c=v[23516];v[23516]=0;e=1;if((c|0)==1){break $b}Gb(a+1298356|0,b);xb(b);Gb(a+1298368|0,j);v[a+1298404>>2]=v[a+1074308>>2]?8:5;yb(D);yb(C);break w}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break ac}b=P()|0;O()|0;xb(d+16|0)}ac(d+32|0);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;xb(c);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;xb(d- -64|0);break Sa}b=P()|0;O()|0}xb(c);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;u[d+48>>1]=h;Ah(k);break Na}h=h+1|0;continue}break}b=P()|0;O()|0;u[d+48>>1]=h}dc(l);break Ka}b=P()|0;O()|0;u[d+48>>1]=h;break Ka}b=P()|0;O()|0;u[d+48>>1]=h}yb(m);break T}b=P()|0;O()|0;u[d+48>>1]=h;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}gc:{b=Bb(v[n>>2],h);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);hc:{if(!b){break hc}v[23516]=0;b=Q(153,g|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Ba}if(!b){break hc}v[23516]=0;b=T(192,g|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break wa}v[23516]=0;l=T(192,g|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break xa}if((l-1025&65535)>>>0<64512){break hc}v[23516]=0;c=Q(186,g|0,4)|0;e=v[23516];v[23516]=0;if((e|0)==1){break xa}if(!c){break hc}v[23516]=0;U(188,d+96|0,g|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break ya}b=d+96|0;f=hc(d+168|0,b);yb(b);c=x[m>>1];b=0;v[23516]=0;i=Q(435,d+136|0,c|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Aa}ic:{while(1){if(b>>>0>=l>>>0){break ic}c=v[f>>2];v[23516]=0;c=W(154,c|0,v[d+176>>2],1)|0;e=v[23516];v[23516]=0;if((e|0)==1){break gc}if(!c){break ic}v[23516]=0;c=T(204,f|0)|0;e=v[23516];v[23516]=0;jc:{if((e|0)!=1){c=c<<24>>24;if(c){break jc}b=b+1|0;continue}break Ca}kc:{e=c&127;o=e?e-1|0:0;k=o&65535;if(ad(v[i>>2],v[d+140>>2])>>>0>k>>>0){break kc}v[23516]=0;t[d+96|0]=0;U(437,i|0,k+1|0,d+96|0);e=v[23516];v[23516]=0;if((e|0)!=1){break kc}break Ca}lc:{if((c|0)<0){v[23516]=0;c=T(204,f|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break lc}I=Ib(v[i>>2],k),J=c,t[I|0]=J}e=Ib(v[i>>2],k);c=w[e|0];if(!(!(c&15)|k>>>0<x[m>>1])){u[m>>1]=o+1;c=w[e|0]}if(c&1){v[23516]=0;Q(186,f|0,1)|0;c=v[23516];v[23516]=0;if((c|0)==1){break lc}e=Ib(v[i>>2],k)}if(w[e|0]&2){v[23516]=0;Q(186,f|0,1)|0;c=v[23516];v[23516]=0;if((c|0)==1){break lc}e=Ib(v[i>>2],k)}if(w[e|0]&4){v[23516]=0;Q(186,f|0,1)|0;c=v[23516];v[23516]=0;if((c|0)==1){break lc}e=Ib(v[i>>2],k)}if(!(w[e|0]&8)){continue}v[23516]=0;Q(186,f|0,2)|0;c=v[23516];v[23516]=0;if((c|0)!=1){continue}}break}break Ca}v[d+96>>2]=v[g+8>>2];I=d,J=v[Vc(d+252|0,d+96|0)>>2],v[I+252>>2]=J;dc(i);yb(f)}h=h+1|0;continue}}break}b=P()|0;O()|0;dc(i);break za}b=P()|0;O()|0;break T}b=P()|0;O()|0}yb(f);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;xb(d+168|0);break ta}b=P()|0;O()|0}ac(d+96|0);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}f=0;i=IA(d+96|0,v[h>>2]);v[23516]=0;Q(186,g|0,i|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break X}}if(w[d+99|0]!=1){break Z}b=v[h>>2]!=0|b}v[d+96>>2]=v[g+8>>2];I=d,J=v[Vc(d+252|0,d+96|0)>>2],v[I+252>>2]=J;r=(f|0)!=0}e=e+1|0;f=x[q>>1];continue}break}b=P()|0;O()|0;break T}mc:{b=Bb(v[s>>2],e);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);nc:{if(!b){break nc}v[23516]=0;b=Q(153,g|0,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break mc}if(!b){break nc}b=v[g+8>>2];f=v[g>>2];v[23516]=0;b=W(154,f|0,b|0,554)|0;f=v[23516];v[23516]=0;if((f|0)==1){break mc}if(!b){break nc}v[23516]=0;b=W(253,a|0,e+1&65535,0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break W}if(!b){break nc}v[23516]=0;X(446,a|0,g|0,b|0,x[d+490>>1]);f=v[23516];v[23516]=0;if((f|0)==1){break W}t[b+33|0]=w[d+501|0]}e=e+1|0;f=x[h>>1];continue}break}b=P()|0;O()|0;break T}b=P()|0;O()|0}yb(D);break B}b=P()|0;O()|0}yb(C);break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}}}}}b=P()|0;O()|0}lc(n);lc(p);lc(s);break a}lc(n);lc(p);lc(s)}xb(j)}hb=d+640|0;return e|0}b=P()|0;O()|0}xb(j);S(b|0);L()}function Oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0;e=hb-1744|0;hb=e;xc(b);a:{if(!di(b,e+1736|0)){break a}if(!iS(e+1736|0)){break a}if(!c){g=1;break a}p=w[e+1739|0];t[e+1735|0]=p;v[e+1728>>2]=-1;v[e+1724>>2]=1048576;if(p>>>0>=5){d=zg(b);v[e+1728>>2]=d;if(!Ob(v[b>>2],v[b+8>>2],d)){break a}v[e+304>>2]=134217727;N=e,V=v[Hb(e+304|0,e+1728|0)>>2]<<5,v[N+1724>>2]=V}C=Lb(e+1712|0);v[e+304>>2]=v[e+1740>>2];d=v[Hb(e+1724|0,e+304|0)>>2];v[23516]=0;R(547,C|0,d|0);d=v[23516];v[23516]=0;b:{c:{d:{e:{f:{if((d|0)!=1){v[23516]=0;d=W(548,b|0,C|0,v[e+1740>>2])|0;f=v[23516];v[23516]=0;g:{if((f|0)==1){break g}if(!d){break b}if(p>>>0>=5){v[23516]=0;Q(153,b|0,v[e+1728>>2]+12|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break g}}v[23516]=0;R(248,a|0,0);d=v[23516];v[23516]=0;if((d|0)==1){break g}$f(a);oe(e+1680|0,v[C>>2],v[C+4>>2]);d=ce(e+1672|0);f=v[d+4>>2];d=v[d>>2];v[23516]=0;m=ga(549,e+1688|0,v[e+1680>>2],v[e+1684>>2],d|0,f|0)|0;d=v[23516];v[23516]=0;h:{i:{j:{if((d|0)!=1){v[23516]=0;U(357,m|0,a+1298308|0,-1);d=v[23516];v[23516]=0;if((d|0)==1){break j}v[23516]=0;U(357,m|0,a+1298332|0,-1);d=v[23516];v[23516]=0;if((d|0)==1){break j}v[23516]=0;d=Q(550,m|0,e+1248|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break f}if(!d){break c}d=t[e+1248|0];if((d|0)<=0|(w[e+1257|0]|w[e+1258|0]<<8)>>>0>255|(w[e+1259|0]|w[e+1260|0]<<8)>>>0>3999){break c}D=a+480188|0;u[D>>1]=d&255;Te(Sb(v[a+484360>>2],w[a+484376|0]),w[e+1251|0]|w[e+1252|0]<<8);u[a+480192>>1]=w[e+1257|0]|w[e+1258|0]<<8;u[a+480190>>1]=w[e+1259|0]|w[e+1260|0]<<8;d=w[e+1261|0];v[a+480196>>2]=d?d:6;d=w[e+1262|0];v[a+480204>>2]=B(d?d:125,1e4);f=w[e+1263|0]|w[e+1264|0]<<8|(w[e+1265|0]<<16|w[e+1266|0]<<24);d=32;k:{if(f&256){break k}d=2;if(f&2){break k}d=1;if(f&128){break k}d=f&8?16:4}v[23516]=0;R(414,a|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break f}h=v[a+480208>>2];f=h|16777216;v[a+480208>>2]=f;d=w[e+1263|0]|w[e+1264|0]<<8|(w[e+1265|0]<<16|w[e+1266|0]<<24);if(d&1){f=h|16777232;v[a+480208>>2]=f}h=v[a+480180>>2];i=(h|0)==32;g=i&!(d&1024);j=(h|0)==2;n=j&d>>>2;j=j&d>>>4;i=i&!(d&2048);r=d&2097152;if(r?1:n|j|(i|g)){f=j?f|65536:f;f=n?f|2:f;f=i?f|4:f;v[a+480208>>2]=r>>>6|(g?f|8:f)}if(d&524288){v[23516]=0;W(267,a+1074312|0,5,1)|0;d=v[23516];v[23516]=0;if((d|0)==1){break f}h=v[a+480180>>2]}if((h|0)==2){break i}if((h|0)!=32){break h}t[e+304|0]=w[e+1267|0];t[e+224|0]=128;N=a,V=w[Vb(e+304|0,e+224|0)|0]<<1,v[N+480200>>2]=V;break h}d=P()|0;O()|0;break d}d=P()|0;O()|0;break e}t[e+304|0]=w[e+1267|0];t[e+224|0]=64;N=a,V=w[Vb(e+304|0,e+224|0)|0]<<2,v[N+480200>>2]=V}d=t[e+1269|0];l:{if((d|0)<0){d=d+52|0;break l}F=ux(+(d|0)*3.1/20);m:{if(F<4294967296&F>=0){d=~~F>>>0;break m}d=0}d=d+51|0}v[a+480228>>2]=d;u[e+304>>1]=64;i=x[Rc(D,e+304|0)>>1];f=0;j=(h|0)!=32;n=(h|0)==4;g=0;while(1)if((g|0)==(i|0)){g=0;i=0;while(1){if((f|0)!=16){i=w[(e+f|0)+1398|0]!=0|i;f=f+1|0;continue}break}while(1){if((g|0)!=128){i=w[((g<<1)+e|0)+1415|0]!=0|i;g=g+1|0;continue}break}n:{if(!(i&1)){break n}d=a+901692|0;g=0;while(1){if((g|0)==16){d=a+902204|0;g=0;while(1){if((g|0)!=128){f=(e+1248|0)+(g<<1)|0;o:{if(w[f+167|0]){v[23516]=0;Y(551,e+224|0);h=v[23516];v[23516]=0;p:{q:{r:{s:{t:{if((h|0)!=1){h=w[f+167|0];v[23516]=0;v[e+248>>2]=h-1;R(552,e+1192|0,e+248|0);h=v[23516];v[23516]=0;if((h|0)==1){break t}f=w[f+166|0];v[23516]=0;t[e+192|0]=f;R(553,e+1168|0,e+192|0);f=v[23516];v[23516]=0;if((f|0)==1){break s}v[23516]=0;X(554,e+304|0,e+224|0,e+1192|0,e+1168|0);f=v[23516];v[23516]=0;if((f|0)==1){break r}f=e+304|0;Be(e+1224|0,f);cf(ue(d,g),v[e+1224>>2],v[e+1228>>2]);wb(f);wb(e+1168|0);wb(e+1192|0);Ub(e+224|0);break o}d=P()|0;O()|0;break e}d=P()|0;O()|0;break p}d=P()|0;O()|0;break q}d=P()|0;O()|0;wb(e+1168|0)}wb(e+1192|0)}Ub(e+224|0);break e}f=qc(e+1216|0,21751);cf(ue(d,g),v[f>>2],v[e+1220>>2])}g=g+1|0;continue}break}h=v[a+480180>>2];break n}f=(e+g|0)+1398|0;u:{if(w[f|0]){v[23516]=0;Y(555,e+224|0);h=v[23516];v[23516]=0;v:{w:{x:{if((h|0)!=1){f=w[f|0];v[23516]=0;v[e+1168>>2]=f-1;R(552,e+1192|0,e+1168|0);f=v[23516];v[23516]=0;if((f|0)==1){break x}v[23516]=0;U(291,e+304|0,e+224|0,e+1192|0);f=v[23516];v[23516]=0;if((f|0)==1){break w}f=e+304|0;Be(e+1240|0,f);cf(ue(d,g),v[e+1240>>2],v[e+1244>>2]);wb(f);wb(e+1192|0);Ub(e+224|0);break u}d=P()|0;O()|0;break e}d=P()|0;O()|0;break v}d=P()|0;O()|0;wb(e+1192|0)}Ub(e+224|0);break e}f=qc(e+1232|0,21751);cf(ue(d,g),v[f>>2],v[e+1236>>2])}g=g+1|0;continue}}d=w[a+484376|0];f=v[a+484360>>2];v[23516]=0;f=Sb(f,d);d=h&5;da(347,f|0,m|0,w[e+1249|0]|w[e+1250|0]<<8,(d?65535:255)|0,(d?65535:254)|0);d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;U(188,e+304|0,m|0,B(w[e+1248|0],w[e+1253|0]|w[e+1254|0]<<8)<<1);d=v[23516];v[23516]=0;if((d|0)!=1){d=e+304|0;G=hc(e+1192|0,d);yb(d);v[23516]=0;U(188,d|0,m|0,(w[e+1253|0]|w[e+1254|0]<<8)<<1);d=v[23516];v[23516]=0;y:{if((d|0)!=1){d=e+304|0;H=hc(e+1168|0,d);yb(d);v[23516]=0;r=Q(217,e+1152|0,w[e+1255|0]|w[e+1256|0]<<8)|0;d=v[23516];v[23516]=0;z:{if((d|0)!=1){N=e,V=Cb(v[r>>2]),v[N+248>>2]=V;d=Cb(v[r+4>>2]);A:{B:{C:{while(1){f=v[e+248>>2];if(!Nb(f,d)){j=a+480180|0;d=v[j>>2];A=c&1;if(!A){break B}v[23516]=0;R(224,a+484344|0,w[e+1253|0]|w[e+1254|0]<<8);f=v[23516];v[23516]=0;if((f|0)!=1){break B}d=P()|0;O()|0;break A}v[23516]=0;h=T(155,m|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){v[23516]=0;U(188,e+224|0,m|0,h|0);h=v[23516];v[23516]=0;if((h|0)==1){break C}g=f;f=e+224|0;h=hc(e+304|0,f);cd(g,h);yb(h);yb(f);Jf(e+248|0);continue}break}d=P()|0;O()|0;break A}d=P()|0;O()|0;break A}s=(d|0)==16?14:(d|0)==32?1:13;I=a+484344|0;n=1;while(1){D:{E:{F:{G:{H:{I:{if((w[e+1253|0]|w[e+1254|0]<<8)>>>0<=q>>>0){switch(v[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}v[23516]=0;d=T(192,H|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break H}v[e+224>>2]=d;if(!A){break D}v[23516]=0;d=W(225,I|0,q&65535,d|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break H}l=0;if(!d){break D}while(1){h=l&65535;if(h>>>0>=w[e+1248|0]){break D}v[23516]=0;d=T(192,G|0)|0;f=v[23516];v[23516]=0;J:{if((f|0)!=1){f=v[r>>2];if(wf(f,v[r+4>>2])>>>0<=d>>>0){break J}k=Kg(f,d);xc(k);f=0;d=Xb(v[I>>2],q);g=ed(v[d>>2],v[v[d+48>>2]+12>>2],0,h);K:while(1){if(y[e+224>>2]<=f>>>0){break J}v[23516]=0;d=T(204,k|0)|0;h=v[23516];v[23516]=0;if((h|0)!=1){if(!d){break J}z=d>>>4|0;J=d&15;i=0;h=sg(e+304|0);while(1){L:{M:{N:{if(J>>>0>(i&255)>>>0){v[23516]=0;R(263,e+248|0,k|0);d=v[23516];v[23516]=0;if((d|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{d=w[Ib(e+248|0,0)|0];switch(d-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(d-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}d=w[Ib(e+248|0,1)|0];fa:{if(d>>>0<=119){d=d+s|0;break fa}ga:{switch(d-254|0){case 1:d=255;break fa;case 0:d=254;break fa;default:break ga}}d=253}t[h|0]=d;n=YA(d)&n;break L}N=e,V=w[Ib(e+248|0,1)|0]+1|0,t[N+305|0]=V;break L}ha:{if(w[e+306|0]){break ha}d=v[j>>2];if((d|0)!=32){if((d|0)!=4){break ha}d=w[Ib(e+248|0,1)|0];if(d&15){break ha}t[e+306|0]=11;t[e+308|0]=d>>>4;break L}o=w[Ib(e+248|0,1)|0];d=0;while(1){if((d|0)==10){break ha}if((o|0)==w[d+43920|0]){t[e+308|0]=d;t[e+306|0]=11;break L}else{d=d+1|0;continue}}}N=e,V=w[Ib(e+248|0,1)|0],t[N+309|0]=V;t[e+307|0]=4;break L}d=Ib(e+248|0,1);ia:{if(w[e+306|0]){break ia}o=w[d|0];if(v[j>>2]!=32|o>>>0>9){break ia}t[e+308|0]=o;t[e+306|0]=8;break L}t[e+309|0]=w[d|0];t[e+307|0]=5;break L}ja:{if(w[e+306|0]){break ja}ka:{d=v[j>>2];if((d|0)!=4){if((d|0)!=32){break ja}d=Ib(e+248|0,1);o=w[d|0];if((o|0)!=255){break ka}t[e+308|0]=64;t[e+306|0]=2;break L}d=Ib(e+248|0,1);if(w[d|0]&15){break ja}break M}if(!(o&3)){break M}}N=e,V=w[Ib(e+248|0,1)|0],t[N+309|0]=V;t[e+307|0]=9;break L}o=w[e+306|0];d=Ib(e+248|0,1);la:{if(o|v[j>>2]==1){break la}o=w[d|0];if(o>>>0>64){break la}t[e+308|0]=o;t[e+306|0]=1;break L}t[e+309|0]=w[d|0];t[e+307|0]=13;break L}d=w[Ib(e+248|0,1)|0];t[e+309|0]=d;t[e+307|0]=14;if(v[j>>2]==32){break L}t[e+309|0]=B((d&240)>>>4|0,10)+(d&15);break L}d=w[Ib(e+248|0,1)|0];t[e+309|0]=d;t[e+307|0]=d>>>0<32?16:17;break L}o=w[Ib(e+248|0,1)|0];if(o>>>0>=16){t[e+308|0]=o>>>4;t[e+306|0]=(d|0)==20?3:5;break L}t[e+308|0]=o&15;t[e+306|0]=(d|0)==20?4:6;break L}d=w[Ib(e+248|0,1)|0];if(d>>>0>=16){t[e+306|0]=10;t[e+308|0]=d>>>4;break L}t[e+306|0]=9;t[e+308|0]=d&15;break L}d=w[Ib(e+248|0,1)|0];t[e+307|0]=28;t[e+309|0]=d|16;break L}d=w[Ib(e+248|0,1)|0];t[e+307|0]=28;t[e+309|0]=d|32;break L}N=e,V=w[Ib(e+248|0,1)|0],t[N+308|0]=V;t[e+306|0]=(d|0)==31?7:8;break L}d=w[e+307|0];t[e+307|0]=(d|0)==4?6:(d|0)==5?7:11;N=e,V=w[Ib(e+248|0,1)|0],t[N+309|0]=V;break L}d=Ib(e+248|0,1);t[e+308|0]=w[d|0]%10;d=w[d|0];if(d>>>0<=9){t[e+306|0]=5;break L}if(d>>>0<=19){t[e+306|0]=6;break L}if(d>>>0<=29){t[e+306|0]=3;break L}if(d>>>0>39){break L}t[e+306|0]=4;break L}N=e,V=w[Ib(e+248|0,1)|0],t[N+308|0]=V;t[e+306|0]=(d|0)==49?13:12;break L}d=w[Ib(e+248|0,1)|0]+33|0;if((d&255)>>>0>9){break L}t[e+306|0]=15;t[e+308|0]=d;break L}if(d>>>0>57){break L}N=e,V=w[Ib(e+248|0,1)|0],t[N+309|0]=V;t[e+307|0]=w[d+26992|0];break L}v[e+248>>2]=f+z;d=v[Hb(e+248|0,e+224|0)>>2];d=d>>>0<f>>>0?f:d;while(1){if((d|0)!=(f|0)){i=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[g|0]=i;t[g+1|0]=i>>>8;t[g+2|0]=i>>>16;t[g+3|0]=i>>>24;i=w[h+4|0]|w[h+5|0]<<8;t[g+4|0]=i;t[g+5|0]=i>>>8;f=f+1|0;g=B(w[e+1248|0],6)+g|0;continue}break}f=d;continue K}d=P()|0;O()|0;break A}d=w[d|0];t[e+306|0]=2;t[e+308|0]=d>>>2}i=i+1|0;continue}}break}d=P()|0;O()|0;break A}d=P()|0;O()|0;break A}l=l+1|0;continue}}g=x[a+480192>>1];d=0;break E}d=P()|0;O()|0;break A}if((n^1)&1|x[D>>1]!=4){break F}v[a+480208>>2]=v[a+480208>>2]|8454144}g=0;d=!((w[e+1263|0]|w[e+1264|0]<<8|(w[e+1265|0]<<16|w[e+1266|0]<<24))&512)}v[23516]=0;o=Q(556,e+1136|0,g|0)|0;f=v[23516];v[23516]=0;ma:{na:{oa:{pa:{qa:{if((f|0)!=1){q=a+480192|0;j=p>>>0<5;n=a+480180|0;i=1;ra:{while(1){g=i&65535;if(g>>>0>x[q>>1]){break ra}sa:{ta:{ua:{va:{if(!d){v[23516]=0;h=W(253,a|0,g|0,0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break va}if(h){break ua}}while(1){v[23516]=0;f=T(204,m|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break na}if(f){continue}break}if(!j){while(1){v[23516]=0;f=T(204,m|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){d=P()|0;O()|0;break ma}if(f){continue}break}}v[23516]=0;Q(186,m|0,826)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break ta}}d=P()|0;O()|0;break ma}f=Kb(e+224|0);v[23516]=0;U(357,m|0,f|0,-1);l=v[23516];v[23516]=0;if((l|0)==1){break sa}Ac(h+492|0,f);if(!j){v[23516]=0;U(357,m|0,f|0,-1);l=v[23516];v[23516]=0;if((l|0)==1){break sa}Ac(h+524|0,f)}v[23516]=0;l=Q(557,m|0,e+304|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break oa}if(!l){break qa}l=v[n>>2];v[23516]=0;U(558,e+304|0,h|0,l|0);h=v[23516];v[23516]=0;if((h|0)==1){break oa}if(v[n>>2]==4){h=Bb(v[o>>2],g-1|0);g=x[e+1106>>1]|x[e+1108>>1]<<16;t[h|0]=g;t[h+1|0]=g>>>8;t[h+2|0]=g>>>16;t[h+3|0]=g>>>24}wb(f)}i=i+1|0;continue}break}break oa}if(!d){break pa}u[a+480192>>1]=0;break pa}d=P()|0;O()|0;break A}wb(f)}d=x[a+480190>>1];v[23516]=0;q=Q(559,e+288|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){J=!(t[e+1263|0]&1)|p>>>0>4;A=c&2;M=a+480180|0;i=1;d=0;while(1){c=d;wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{n=i&65535;if(n>>>0<=x[a+480190>>1]){g=Kb(e+272|0);v[23516]=0;U(357,m|0,g|0,-1);d=v[23516];v[23516]=0;if((d|0)==1){break Ra}j=B(n,104)+a|0;Ac(((n<<5)+a|0)+946304|0,g);d=p>>>0<5;if(!d){v[23516]=0;U(357,m|0,g|0,-1);f=v[23516];v[23516]=0;if((f|0)==1){break Ra}xe(j+484423|0,g)}v[23516]=0;f=Q(560,m|0,e+304|0)|0;h=v[23516];v[23516]=0;Sa:{Ta:{if((h|0)==1){break Ta}if(!f){break Sa}h=v[M>>2];v[23516]=0;f=j+484380|0;X(561,e+304|0,f|0,h|0,J|0);h=v[23516];v[23516]=0;if((h|0)==1){break Ta}s=0;Ua:{if((x[e+324>>1]&61440)!=28672|d){break Ua}v[23516]=0;s=T(562,m|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break Ua}d=P()|0;O()|0;break za}if(!A){break xa}h=w[e+339|0]|w[e+340|0]<<8|(w[e+341|0]<<16|w[e+342|0]<<24);d=x[e+324>>1];l=d&61440;if(!(h|l)){d=Uc(e+224|0,d&1?16:8,d&1024?3:1,0,0);v[23516]=0;W(218,d|0,f|0,b|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break xa}d=P()|0;O()|0;break za}if((h|0)<0){d=h+n|0;if((d|0)<=0){break xa}gS(f,(B(d,104)+a|0)+484380|0);break xa}if((h|0)<=0){break xa}if(d&1){k=j+484414|0;u[k>>1]=x[k>>1]|1}if(d&1024){k=j+484414|0;u[k>>1]=x[k>>1]|64}v[23516]=0;U(188,e+224|0,b|0,h|0);h=v[23516];v[23516]=0;Va:{Wa:{Xa:{Ya:{Za:{_a:{if((h|0)!=1){k=e+224|0;h=hc(e+248|0,k);yb(k);k=Hd(x[f+34>>1]);K=(l|0)==16384;if(!K&(l|0)!=8192){break Ya}z=v[h>>2];v[23516]=0;z=T(158,z|0)|0;E=v[23516];v[23516]=0;if((E|0)==1){break Va}E=4/(k>>>0)|0;rka(E,0,z,0);uc(f,kb?-1:B(E,z));if((l|0)==8192){break _a}if(!K){break Ya}if(!Jg(f)){break Xa}d=v[j+484400>>2];f=v[f>>2];if(!(t[e+324|0]&1)){break Za}v[23516]=0;X(563,h|0,d|0,f|0,k|0);f=v[23516];v[23516]=0;d=c;if((f|0)==1){break Ba}break Wa}d=P()|0;O()|0;break za}if(!Jg(f)){break Xa}d=v[j+484400>>2];f=v[f>>2];if(t[e+324|0]&1){v[23516]=0;X(564,h|0,d|0,f|0,k|0);f=v[23516];v[23516]=0;d=c;if((f|0)!=1){break Wa}break Ba}v[23516]=0;X(565,h|0,d|0,f|0,k|0);f=v[23516];v[23516]=0;d=c;if((f|0)==1){break Ba}break Wa}v[23516]=0;X(566,h|0,d|0,f|0,k|0);f=v[23516];v[23516]=0;d=c;if((f|0)==1){break Ba}break Wa}if((d&45056)==12288){d=fS(e+224|0,h,w[e+343|0]|w[e+344|0]<<8,s);N=cd(ff(v[q>>2],n-1|0),d),V=v[d+20>>2],v[N+20>>2]=V;yb(d);break Xa}if((l|0)!=32768){d=1;if((l|0)!=4096){break Wa}l=he(e+224|0,h);v[23516]=0;d=Q(567,e+216|0,h|0)|0;k=v[23516];v[23516]=0;if((k|0)!=1){$a:{ab:{if(!w[e+221|0]){break ab}s=w[e+343|0]|w[e+344|0]<<8;k=x[e+218>>1]<<1;if(s>>>0<(k&65535)>>>0){break ab}k=s-k|0;t[e+343|0]=k;t[e+344|0]=k>>>8;d=x[d>>1];v[23516]=0;Q(153,h|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break $a}v[23516]=0;d=T(200,h|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break $a}v[23516]=0;U(188,e+168|0,h|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break $a}d=e+168|0;k=hc(e+192|0,d);cd(l,k);yb(k);yb(d)}v[23516]=0;n=W(568,a|0,n|0,l|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break $a}d=1;if(n){d=w[e+343|0]|w[e+344|0]<<8;bb:{if(!d){break bb}n=x[f+34>>1];k=Fj(v[f>>2],n);if(k>>>0<=d>>>0){break bb}n=yk(n);j=v[j+484400>>2];dj(j,d+j|0,k-d|0);v[f>>2]=v[f>>2]-((d>>>0)/(n>>>0)|0)}uc(f,v[e+312>>2]);d=c}yb(l);break Wa}}d=P()|0;O()|0;yb(l);break Aa}v[23516]=0;d=Q(425,h|0,e+224|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break Qa}if(!d){break Xa}v[e+80>>2]=v[e+232>>2];d=v[e+228>>2];v[e+72>>2]=v[e+224>>2];v[e+76>>2]=d;vl(f,1,e+72|0)}d=c}yb(h);break wa}d=P()|0;O()|0;break Aa}d=P()|0;O()|0;break za}wb(g)}cb:{if(!A){break cb}n=1;while(1){g=n&65535;if(g>>>0>x[a+480190>>1]){break cb}b=ff(v[q>>2],g-1|0);d=v[b>>2];v[23516]=0;d=T(176,d|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break Pa}db:{eb:{if(!d){break eb}f=x[b+22>>1];d=f+n&65535;i=x[b+20>>1];j=(f|0)!=0&(d|0)!=0&d>>>0<=x[a+480190>>1]&(i|0)!=0;fb:{if(j){f=ff(v[q>>2],d-1|0);break fb}d=v[b>>2];v[23516]=0;i=T(158,d|0)|0;d=v[23516];v[23516]=0;f=b;if((d|0)==1){break Oa}}xc(f);gb:{if(j){d=v[f+8>>2];h=v[f>>2];p=x[b+20>>1];v[23516]=0;d=W(154,h|0,d|0,p|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break Oa}if(!d){break eb}v[e+224>>2]=0;v[e+248>>2]=0;v[23516]=0;U(201,e+304|0,f|0,i|0);d=v[23516];v[23516]=0;hb:{if((d|0)!=1){h=iA(Ee(e+304|0),Di(v[e+304>>2]),e+224|0,e+248|0);v[23516]=0;Q(186,f|0,v[e+224>>2])|0;d=v[23516];v[23516]=0;if((d|0)==1){break hb}Qc(e+304|0);break gb}d=P()|0;O()|0;break ya}d=P()|0;O()|0;Qc(e+304|0);break ya}h=0;v[e+224>>2]=0;v[e+248>>2]=0}v[23516]=0;R(569,e+304|0,b|0);d=v[23516];v[23516]=0;ib:{jb:{if((d|0)!=1){d=Ee(e+304|0);i=v[e+304>>2];if(!j){h=iA(d,Di(i),e+224|0,e+248|0);v[23516]=0;f=v[e+224>>2];Q(186,b|0,f|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break db}i=i-f|0;d=d+f|0}if(h){break jb}c=1;break ib}d=P()|0;O()|0;break ya}f=B(g,104)+a|0;p=f+484380|0;Jg(p);s=f+484400|0;f=0;g=v[e+248>>2];while(1){kb:{if(!i|(g|0)!=1?g:0){break kb}g=v[p>>2];if(g>>>0<=f>>>0){break kb}if(!Vd(g,v[p+20>>2])){break kb}v[e+192>>2]=0;v[e+168>>2]=0;l=eS(h,d,Di(i),e+192|0,e+272|0,e+168|0);v[23516]=0;v[e+224>>2]=l;Q(186,b|0,l|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Ca}bi(e+168|0,Di(v[p>>2]-f|0));j=v[e+168>>2];lb:{if((j|0)<=0){break lb}g=v[e+192>>2];z=x[p+34>>1];if((Hd(z)|0)!=(g|0)){break lb}k=B(f,g);A=v[s>>2];if(z&1){v[e+160>>2]=j;v[e+144>>2]=j;v[e- -64>>2]=j;v[e+48>>2]=j;v[e+140>>2]=g;v[e+136>>2]=v[e+272>>2];v[e+156>>2]=g;v[e+152>>2]=A+(k<<1);v[23516]=0;g=v[e+140>>2];v[e+40>>2]=v[e+136>>2];v[e+44>>2]=g;g=v[e+156>>2];v[e+56>>2]=v[e+152>>2];v[e+60>>2]=g;R(570,e+56|0,e+40|0);g=v[23516];v[23516]=0;if((g|0)!=1){break lb}break Ca}v[e+128>>2]=j;v[e+112>>2]=j;v[e+32>>2]=j;v[e+16>>2]=j;v[e+108>>2]=g;v[e+104>>2]=v[e+272>>2];v[e+124>>2]=g;v[e+120>>2]=k+A;v[23516]=0;g=v[e+108>>2];v[e+8>>2]=v[e+104>>2];v[e+12>>2]=g;g=v[e+124>>2];v[e+24>>2]=v[e+120>>2];v[e+28>>2]=g;R(571,e+24|0,e+8|0);g=v[23516];v[23516]=0;if((g|0)==1){break Ca}}i=i-l|0;d=d+l|0;g=dS(h);v[e+248>>2]=g;f=f+j|0;continue}break}cS(h)}Qc(e+304|0)}n=n+1|0;continue}break}break Ca}mb:{if(v[a+480180>>2]!=4){break mb}g=0;d=a+480192|0;while(1){if(x[d>>1]<=g>>>0){break mb}b=Bb(v[o>>2],g);f=w[b+3|0];h=w[b+2|0];i=w[b+1|0];b=w[b|0];v[23516]=0;g=g+1|0;la(399,a|0,g&65535,b|0,i|0,h|0,f|0);b=v[23516];v[23516]=0;if((b|0)!=1){continue}break}d=P()|0;O()|0;break ya}if(!(w[e+1265|0]&16)){break Ka}b=v[m+8>>2];d=v[m>>2];v[23516]=0;b=W(154,d|0,b|0,1)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Ma}if(!b){break Ka}g=0;v[23516]=0;b=T(204,m|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Na}if(!(b&1)){break La}while(1){if(x[D>>1]<=g>>>0){break La}v[23516]=0;b=T(155,m|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){t[((g<<5)+a|0)+480288|0]=b;g=g+1|0;continue}break}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break za}d=P()|0;O()|0;break Aa}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=a+906300|0;while(1){b=v[m+8>>2];f=v[m>>2];v[23516]=0;b=W(154,f|0,b|0,1)|0;f=v[23516];v[23516]=0;if((f|0)==1){break Da}if(!b){break Ka}v[23516]=0;b=T(204,m|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break Ia}if(!b){break Ka}v[23516]=0;f=T(155,m|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break Ja}v[23516]=0;U(188,e+224|0,m|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break Ja}h=e+224|0;f=hc(e+304|0,h);yb(h);nb:{if(b>>>0<=250){v[23516]=0;R(447,f|0,Id(d,b-1|0)|0);b=v[23516];v[23516]=0;if((b|0)==1){break nb}}yb(f);continue}break}d=P()|0;O()|0;yb(f);break ya}j=a+901404|0;i=Kb(e+192|0);n=a+480180|0;p=a+484348|0;d=0;h=0;while(1){b=v[m+8>>2];f=v[m>>2];v[23516]=0;b=W(154,f|0,b|0,8)|0;f=v[23516];v[23516]=0;ob:{pb:{qb:{rb:{sb:{if((f|0)!=1){if(b){v[23516]=0;f=T(155,m|0)|0;b=v[23516];v[23516]=0;tb:{ub:{vb:{wb:{xb:{yb:{zb:{Ab:{if((b|0)!=1){v[23516]=0;b=T(155,m|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Ab}v[23516]=0;U(188,e+304|0,m|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break zb}g=e+304|0;b=hc(e+224|0,g);yb(g);if((f|0)==1229211981){break wb}if((f|0)==1229476432){break xb}if((f|0)==1397900630){break yb}if((f|0)!=1414548815){break ob}v[23516]=0;f=Q(410,b|0,13937)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Ha}if(!f){break pb}v[23516]=0;f=T(155,b|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){v[23516]=0;U(188,e+304|0,b|0,f|0);f=v[23516];v[23516]=0;if((f|0)!=1){break vb}}d=P()|0;O()|0;break Ga}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}Bb:{Cb:{Db:{f=v[n>>2];switch(f-2|0){case 1:break ob;case 0:break ub;case 2:break Cb;default:break Db}}if((f|0)==16){break Bb}if((f|0)!=32){break ob}v[23516]=0;d=T(192,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break Ha}v[23516]=0;h=T(192,b|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break ob}break Ha}v[e+304>>2]=32;f=v[b>>2];v[23516]=0;f=T(158,f|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){v[e+248>>2]=f;f=v[Hb(e+304|0,e+248|0)>>2];v[23516]=0;U(572,b|0,i|0,f|0);f=v[23516];v[23516]=0;if((f|0)!=1){break ob}}d=P()|0;O()|0;break Ga}v[23516]=0;f=T(204,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break tb}v[23516]=0;R(573,e+248|0,4214);g=v[23516];v[23516]=0;Eb:{if((g|0)!=1){v[e+272>>2]=f>>>4;v[23516]=0;v[e+88>>2]=f&15;X(305,e+304|0,e+248|0,e+272|0,e+88|0);f=v[23516];v[23516]=0;if((f|0)==1){break Eb}f=e+304|0;Gb(i,f);xb(f);ac(e+248|0);break ob}d=P()|0;O()|0;break Ga}d=P()|0;O()|0;ac(e+248|0);break Ga}v[23516]=0;f=T(204,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Ha}v[a+480216>>2]=f;v[23516]=0;f=T(204,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Ha}v[a+480220>>2]=f;break ob}v[23516]=0;Q(420,b|0,j|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break Ha}LA(j);break ob}g=e+304|0;f=hc(e+248|0,g);yb(g);g=v[f>>2];v[23516]=0;g=T(158,g|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break qb}u[e+304>>1]=g>>>5;N=e,V=vf(v[a+484344>>2],v[p>>2]),u[N+272>>1]=V;l=x[Rc(e+304|0,e+272|0)>>1];g=0;while(1){if((g|0)==(l|0)){yb(f);break pb}v[23516]=0;R(574,f|0,e+304|0);k=v[23516];v[23516]=0;Fb:{if((k|0)==1){break Fb}k=v[I>>2];v[23516]=0;R(575,Xb(k,g)|0,e+304|0);k=v[23516];v[23516]=0;if((k|0)==1){break Fb}g=g+1|0;continue}break}break qb}v[23516]=0;d=T(192,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break Ha}break ob}d=P()|0;O()|0;break Ga}b=v[a+480180>>2];Gb:{Hb:{Ib:{if((b|0)!=32){break Ib}f=d&65535;if(f>>>0<256){break Ib}if(f>>>0<532){break Hb}}b=(b|0)!=2;Jb:{if(b){break Jb}f=d&65535;if(f>>>0<12544){break Jb}if(f>>>0<12820){break Hb}}if(b){break Gb}b=d&65535;if(b>>>0<4864|b>>>0>4895){break Gb}}jq(j)}g=1;Kb:{if(!(t[e+1265|0]&1)){break Kb}f=v[a+1074308>>2];if(!f){d=a+480192|0;f=a+480180|0;while(1){b=g&65535;if(b>>>0<=x[d>>1]){b=v[((b<<2)+a|0)+900380>>2];if(b){j=v[f>>2];v[23516]=0;R(576,Gh(b,2)|0,j|0);j=v[23516];v[23516]=0;if((j|0)==1){break sb}t[b+19|0]=w[b+19|0]+3>>>2}g=g+1|0;continue}break}f=v[a+1074308>>2]}if(f>>>0<=18350079){v[23516]=0;b=Q(268,a+1074312|0,27)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Fa}v[23516]=0;Q(268,b|0,57)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Fa}f=v[a+1074308>>2]}if(f>>>0<=19070975){v[23516]=0;Q(268,a+1074312|0,73)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Fa}f=v[a+1074308>>2]}if(f>>>0>19267583){break Kb}v[23516]=0;Q(268,a+1074312|0,50)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Fa}}Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{if(oh(v[i+4>>2],w[i+11|0])){v[23516]=0;Y(577,e+224|0);b=v[23516];v[23516]=0;Zb:{if((b|0)!=1){v[23516]=0;U(545,e+304|0,e+224|0,e+1735|0);b=v[23516];v[23516]=0;if((b|0)==1){break Zb}break Yb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;ac(e+224|0);break Ea}v[23516]=0;Y(578,e+224|0);b=v[23516];v[23516]=0;if((b|0)==1){break Xb}v[23516]=0;X(579,e+304|0,e+224|0,e+1735|0,i|0);b=v[23516];v[23516]=0;if((b|0)==1){break Wb}}b=e+304|0;Gb(i,b);xb(b);b=e+224|0;ac(b);v[23516]=0;R(544,b|0,3980);b=v[23516];v[23516]=0;if((b|0)==1){break Ub}v[23516]=0;U(545,e+304|0,e+224|0,e+1735|0);b=v[23516];v[23516]=0;if((b|0)==1){break Tb}b=e+304|0;Gb(a+1298344|0,b);xb(b);ac(e+224|0);v[23516]=0;b=Q(1,b|0,15086)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Sb}Gb(a+1298356|0,b);xb(b);b=v[a+480180>>2];switch(b-1|0){case 2:break rb;case 1:break Ob;case 3:break Pb;case 0:break Qb;default:break Vb}}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;ac(e+224|0);break Ea}if((b|0)==16){break Rb}if((b|0)==32){break Nb}if((b|0)!=16777216){break rb}v[23516]=0;b=Q(1,e+224|0,10143)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Mb}Gb(a+1298392|0,b);xb(b);v[23516]=0;b=Q(1,e+248|0,13884)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Lb}Gb(a+1298380|0,b);xb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;ac(e+224|0);break Ea}d=P()|0;O()|0;break Ea}v[23516]=0;b=Q(1,e+224|0,10148)|0;d=v[23516];v[23516]=0;_b:{if((d|0)!=1){Gb(a+1298392|0,b);xb(b);v[23516]=0;b=Q(1,e+248|0,8394)|0;d=v[23516];v[23516]=0;if((d|0)==1){break _b}Gb(a+1298380|0,b);xb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23516]=0;b=Q(1,e+224|0,12354)|0;d=v[23516];v[23516]=0;$b:{if((d|0)!=1){Gb(a+1298392|0,b);xb(b);v[23516]=0;b=Q(1,e+248|0,14351)|0;d=v[23516];v[23516]=0;if((d|0)==1){break $b}Gb(a+1298380|0,b);xb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23516]=0;b=Q(1,e+224|0,10121)|0;d=v[23516];v[23516]=0;ac:{if((d|0)!=1){Gb(a+1298392|0,b);xb(b);v[23516]=0;b=Q(1,e+248|0,15389)|0;d=v[23516];v[23516]=0;if((d|0)==1){break ac}Gb(a+1298380|0,b);xb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23516]=0;b=Q(1,e+224|0,10493)|0;d=v[23516];v[23516]=0;bc:{if((d|0)!=1){Gb(a+1298392|0,b);xb(b);v[23516]=0;b=Q(1,e+248|0,15139)|0;d=v[23516];v[23516]=0;if((d|0)==1){break bc}Gb(a+1298380|0,b);xb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}v[23516]=0;b=Q(1,e+224|0,6130)|0;d=v[23516];v[23516]=0;cc:{dc:{ec:{fc:{gc:{if((d|0)!=1){Gb(a+1298392|0,b);xb(b);if(!(h&65535)){break cc}v[23516]=0;R(269,e+272|0,4317);b=v[23516];v[23516]=0;if((b|0)==1){break gc}v[e+100>>2]=(h&65280)>>>8;v[23516]=0;v[e+84>>2]=h&255;R(441,e+88|0,e+84|0);b=v[23516];v[23516]=0;if((b|0)==1){break fc}v[23516]=0;X(427,e+248|0,e+272|0,e+100|0,e+88|0);b=v[23516];v[23516]=0;if((b|0)==1){break ec}b=e+248|0;Gb(a+1298380|0,b);xb(b);xb(e+88|0);ac(e+272|0);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break dc}d=P()|0;O()|0;xb(e+88|0)}ac(e+272|0);break Ea}v[23516]=0;b=Q(1,e+248|0,8586)|0;d=v[23516];v[23516]=0;if((d|0)!=1){Gb(a+1298380|0,b);xb(b);break rb}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;break Ea}Gb(a+1298368|0,i);hc:{if(v[a+1074308>>2]){v[a+1298404>>2]=8;break hc}if(v[a+480180>>2]==1){v[a+1298404>>2]=14;break hc}v[a+1298404>>2]=5}g=1;ic:{jc:{if(c&1){v[23516]=0;b=Q(1,e+272|0,16726)|0;c=v[23516];v[23516]=0;if((c|0)==1){break jc}a=v[a+1298464>>2];v[23516]=0;U(384,a|0,2,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break ic}xb(b)}xb(i);gA(q);lc(o);Nc(r);yb(H);yb(G);break c}d=P()|0;O()|0;break Ea}d=P()|0;O()|0;xb(b);break Ea}d=P()|0;O()|0;yb(f);break Ga}v[23516]=0;f=Q(410,b|0,13942)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Ha}kc:{if(!f){break kc}v[23516]=0;f=T(155,b|0)|0;g=v[23516];v[23516]=0;lc:{if((g|0)!=1){v[23516]=0;U(188,e+248|0,b|0,f|0);f=v[23516];v[23516]=0;if((f|0)!=1){break lc}}d=P()|0;O()|0;break Ga}g=e+248|0;f=hc(e+304|0,g);yb(g);g=v[f>>2];v[23516]=0;g=T(158,g|0)|0;l=v[23516];v[23516]=0;if((l|0)!=1){u[e+248>>1]=(g>>>0)/20;u[e+272>>1]=x[D>>1];l=x[Rc(e+248|0,e+272|0)>>1];g=0;while(1){if((g|0)==(l|0)){yb(f);break kc}v[23516]=0;U(421,f|0,((g<<5)+a|0)+480289|0,20);k=v[23516];v[23516]=0;if((k|0)!=1){g=g+1|0;continue}break}}d=P()|0;O()|0;yb(f);break Ga}v[23516]=0;Q(430,a|0,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break Ha}v[23516]=0;X(431,a|0,b|0,1,0);f=v[23516];v[23516]=0;if((f|0)==1){break Ha}if((d-2186&65535)>>>0<=117){v[n>>2]=16777216;v[23516]=0;U(445,a|0,b|0,d&65535);f=v[23516];v[23516]=0;if((f|0)==1){break Ha}}if(!v[a+1074308>>2]){break ob}v[23516]=0;f=Q(1,e+168|0,17711)|0;g=v[23516];v[23516]=0;mc:{nc:{oc:{if((g|0)!=1){g=v[a+1074308>>2];v[23516]=0;R(138,e+248|0,g|0);g=v[23516];v[23516]=0;if((g|0)==1){break oc}v[23516]=0;U(2,e+304|0,f|0,e+248|0);g=v[23516];v[23516]=0;if((g|0)==1){break nc}g=e+304|0;Gb(i,g);xb(g);xb(e+248|0);xb(f);break ob}d=P()|0;O()|0;break Ga}d=P()|0;O()|0;break mc}d=P()|0;O()|0;xb(e+248|0)}xb(f);break Ga}yb(b);continue}}d=P()|0;O()|0;break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0}yb(b);break Ea}d=P()|0;O()|0}xb(i);break ya}d=P()|0;O()|0;break ya}d=P()|0;O()|0;Qc(e+304|0);break ya}d=P()|0;O()|0}yb(h)}wb(g)}gA(q);break ma}d=c}wb(g);i=i+1|0;continue}}d=P()|0;O()|0;break ma}d=P()|0;O()|0;wb(f);break ma}d=P()|0;O()|0}lc(o);break A}q=q+1|0;continue}}Nc(r);break z}d=P()|0;O()|0}yb(H);break y}d=P()|0;O()|0}yb(G);break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}else{pc:{qc:{if(!j){t[e+304|0]=w[(e+g|0)+1270|0];t[e+224|0]=64;N=((g<<5)+a|0)+480286|0,V=w[Vb(e+304|0,e+224|0)|0],u[N>>1]=V;break qc}if(n){break pc}}rc:{d=w[(e+g|0)+1334|0];if((d|0)!=255){if((d|0)!=127){break rc}v[((g<<5)+a|0)+480280>>2]=256;break pc}u[((g<<5)+a|0)+480284>>1]=256;break pc}u[((g<<5)+a|0)+480284>>1]=d}g=g+1|0;continue}}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0}yb(m)}dc(C);S(d|0);L()}yb(m)}dc(C)}hb=e+1744|0;return g|0}function Zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;e=hb-976|0;hb=e;xc(b);a:{if(!qS(b,e+920|0)){break a}if(!uS(e+920|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(tS(e+920|0),kb))){break a}if(!c){d=1;break a}zd(a,8);$f(a);aa=w[e+923|0];K=aa-48|0;t[e+919|0]=K;Zc(b,_b(v[e+928>>2]));f=e+608|0;Wd(f,b,504);_=hc(e+896|0,f);yb(f);v[23516]=0;R(518,b|0,f|0);f=v[23516];v[23516]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(w[e+891|0]>63){break b}if(Eb(x[e+608>>1])<<16>>16<0){break b}Rb(e+528|0,0,80);h:{d=_b(v[e+952>>2]);if(!d){break h}v[23516]=0;f=Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){if(!f){break h}v[23516]=0;R(519,b|0,e+528|0);d=v[23516];v[23516]=0;if((d|0)!=1){break h}}i=P()|0;O()|0;break e}v[23516]=0;U(520,e+520|0,b|0,K&255);d=v[23516];v[23516]=0;if((d|0)!=1){ba=Re(e+520|0);d=0;f=x[e+520>>1];if((f-128&65535)>>>0<65409){break b}u[a+480188>>1]=f;M=Lb(e+504|0);d=_b(v[e+944>>2]);i:{if(d){v[23516]=0;Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break g}v[23516]=0;U(521,b|0,M|0,w[e+891|0]);d=v[23516];v[23516]=0;if((d|0)==1){break g}j=w[e+891|0];break i}j=w[e+891|0];d=0;if(j){break c}}j=j&255;u[a+480192>>1]=j;u[a+480190>>1]=j;ca=(K&255)>>>0<2|t[e+872|0]>=0;r=!ca;p=c&2;s=1;C=1;while(1){j:{k:{l:{m:{n:{o:{g=C&65535;if(g>>>0<=(j&65535)>>>0){v[23516]=0;y=s&65535;f=W(253,a|0,g|0,y|0)|0;d=v[23516];v[23516]=0;p:{if((d|0)!=1){if(f){break p}break d}i=P()|0;O()|0;break f}z=v[((g<<2)+a|0)+900380>>2];u[e+84>>1]=0;v[e+80>>2]=0;v[23516]=0;D=T(172,e+480|0)|0;d=v[23516];v[23516]=0;q:{if((d|0)!=1){d=Bb(v[M>>2],g-1|0);d=_b(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));r:{if(!d){break r}v[23516]=0;f=Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break k}if(!f){break r}v[23516]=0;R(522,b|0,e+80|0);d=v[23516];v[23516]=0;if((d|0)==1){break k}f=v[e+80>>2];d=u[e+84>>1];v[23516]=0;f=_b(f);d=ne(d);U(188,e+120|0,b|0,f<<(d>>>5&1&(d|0)>0));d=v[23516];v[23516]=0;if((d|0)==1){break k}f=e+120|0;d=hc(e+192|0,f);cd(D,d);yb(d);yb(f)}q=ne(u[e+84>>1]);d=q&15;if((q|0)>=0){break q}Pt(z,0);ea=1;break o}i=P()|0;O()|0;break f}if(d>>>0>6){break o}A=w[d+26870|0];if(!d){break m}u[a+480190>>1]=(x[a+480190>>1]+A|0)-1;l=z+108|0;m=z+236|0;n=A-2|0;j=4;s:while(1){g=1;if((j|0)==10){break n}k=B(j,12);d=(n<<3)+j|0;h=w[d+26876|0]+s|0;g=w[d+26924|0];d=0;while(1)if((d|0)==12){j=j+1|0;continue s}else{f=d+k|0;fa=$b(m,f),ga=h,u[fa>>1]=ga;f=Ib(l,f);t[f|0]=g+w[f|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=_b(v[e+532>>2]);if(!d){break D}if(!Eb(x[e+536>>1])){break D}v[23516]=0;f=Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break C}if(!f){break D}fa=e,ga=Eb(x[e+536>>1]),u[fa+192>>1]=ga;u[e+120>>1]=w[e+891|0];f=e+120|0;p=x[Rc(e+192|0,f)>>1];d=e+128|0;l=f|4;y=Eb(x[e+538>>1]);m=y>>>0<19;n=y>>>0<21;k=y>>>0<15;h=y>>>0<6;j=0;while(1){if((j|0)==(p|0)){break D}v[23516]=0;U(523,b|0,e+192|0,y|0);f=v[23516];v[23516]=0;E:{F:{G:{if((f|0)!=1){j=j+1|0;q=v[((j<<2)+a|0)+900380>>2];r=w[e+192|0];if(r){g=ql(e+120|0,0,64);ql(l,r-1&65535,64);f=w[e+193|0];if(f){f=64/(f>>>0)|0}else{f=0}ql(d,f+r|0,0);v[23516]=0;r=q+48|0;U(524,r|0,g|0,3);f=v[23516];v[23516]=0;if((f|0)==1){break G}if(w[e+192|0]==1){g=v[cc(e+472|0,Cb(v[r>>2]))>>2];f=Cb(v[r>>2]);f=v[r>>2]+(Nt(g,f)<<2)|0;Ld(r,Mi(f+4|0,v[r+4>>2],f));Cb(f)}f=w[e+193|0];v[q>>2]=f?f<<9:32767;t[q+60|0]=w[q+60|0]|1;F=1}H:{if(m){break H}v[q+4>>2]=w[e+210|0]+1>>>1;if(n){break H}u[q+28>>1]=x[e+212>>1]}g=B(x[$b(q+236|0,61)>>1],104)+a|0;t[g+484417|0]=w[e+195|0]<<4;if(k){break F}f=_b(x[e+202>>1]|x[e+204>>1]<<16);v[g+484384>>2]=f;fa=g+484388|0,ga=_b(x[e+206>>1]|x[e+208>>1]<<16)+f|0,v[fa>>2]=ga;break E}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}if(h){continue}}f=g+484414|0;i=f;o=x[f>>1]&65529;f=w[e+197|0];u[i>>1]=o|f<<1&2|f>>>1&4;if(!(f&4)){continue}u[g+484412>>1]=0;continue}}I:{d=_b(v[e+548>>2]);if(!d){break I}if(!Eb(x[e+552>>1])){break I}v[23516]=0;f=Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break C}if(!f){break I}fa=e,ga=Eb(x[e+552>>1]),u[fa+192>>1]=ga;u[e+120>>1]=w[e+891|0];n=x[Rc(e+192|0,e+120|0)>>1];k=Eb(x[e+554>>1]);d=0;J:while(1){if((d|0)==(n|0)){break I}v[23516]=0;U(525,b|0,e+192|0,k|0);f=v[23516];v[23516]=0;if((f|0)==1){break t}f=e+80|0;fU(f,e+192|0);v[23516]=0;R(221,e+120|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break u}d=d+1|0;m=((d<<2)+a|0)+900380|0;g=e+120|0;Ac(v[m>>2]+492|0,g);wb(g);f=v[m>>2];v[23516]=0;R(388,g|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break v}fa=e,ga=Ei(v[e+120>>2]),v[fa+80>>2]=ga;h=tf(e+120|0);while(1){f=v[e+80>>2];if(Nb(f,h)){l=(x[go(f)>>1]<<5)+a|0;g=l+946328|0;p=v[m>>2];f=v[p+520>>2];v[g>>2]=v[p+516>>2];v[g+4>>2]=f;f=v[p+512>>2];g=l+946320|0;v[g>>2]=v[p+508>>2];v[g+4>>2]=f;f=v[p+504>>2];g=l+946312|0;v[g>>2]=v[p+500>>2];v[g+4>>2]=f;f=v[p+496>>2];g=l+946304|0;v[g>>2]=v[p+492>>2];v[g+4>>2]=f;Ig(e+80|0);continue}else{bu(e+120|0);continue J}}}}jq(a+901404|0);d=qc(e+464|0,4943);cf(ue(a+901692|0,0),v[d>>2],v[d+4>>2]);xc(b);D=c&1;G=a+484344|0;H=a+1298332|0;da=a+1298308|0;$=a+484360|0;c=0;while(1){K:{f=c&255;if(f>>>0<w[ba|0]){v[23516]=0;X(526,b|0,e+920|0,e+528|0,e+608|0);d=v[23516];v[23516]=0;L:{M:{N:{O:{P:{if((d|0)==1){break P}Q:{if(!f){d=0;break Q}v[23516]=0;f=T(275,$|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break P}d=c;if((f|0)==255){break d}}o=wj(v[$>>2],d&255);E=Xf(e+448|0);Gc(o);I=K&255;if(I>>>0>1){break N}i=0;f=Eb(x[e+610>>1]);if(f>>>0>256|x[a+480188>>1]>16){break L}d=e+192|0;oS(d,e+608|0);v[23516]=0;U(527,o|0,d|0,f|0);d=v[23516];v[23516]=0;if((d|0)==1){break O}fa=e,ga=Cb(v[o>>2]),v[fa+192>>2]=ga;d=Cb(v[o+4>>2]);while(1){f=v[e+192>>2];if(Nb(f,d)){u[f>>1]=x[f>>1]+J;Qe(e+192|0);continue}else{jh(a,1);f=x[a+480188>>1];d=0;while(1)if((d|0)==(f|0)){d=32;break M}else{t[e+192|0]=w[(d+e|0)+874|0];t[e+120|0]=64;fa=((d<<5)+a|0)+480286|0,ga=w[Vb(e+192|0,e+120|0)|0],u[fa>>1]=ga;d=d+1|0;continue}}}}i=P()|0;O()|0;break f}i=P()|0;O()|0;break w}oS(e+192|0,e+608|0);R:{S:{T:{U:{d=Eb(x[e+204>>1]);if(!(!d|d>>>0>64|x[a+480188>>1]>64)){l=_b(v[e+212>>2]);d=Eb(x[e+216>>1]);if(d){u[e+120>>1]=d;u[e+80>>1]=800;f=Bc(((x[Rc(e+120|0,e+80|0)>>1]<<5)+50>>>0)/100|0,0)}else{f=32}d=v[e+200>>2];v[23516]=0;g=Q(153,b|0,_b(d)|0)|0;d=v[23516];v[23516]=0;V:{if((d|0)==1){break V}d=0;W:{if(!g){break W}while(1){if(x[a+480188>>1]<=d>>>0){break W}v[23516]=0;h=T(204,b|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){t[e+120|0]=h;t[e+80|0]=64;fa=((d<<5)+a|0)+480286|0,ga=w[Vb(e+120|0,e+80|0)|0],u[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;O()|0;break w}X:{Y:{d=_b(v[e+208>>2]);if(!d){break Y}v[23516]=0;g=Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break V}d=0;if(!g){break Y}while(1){if(x[a+480188>>1]<=d>>>0){break X}v[23516]=0;h=T(528,b|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){fa=((d<<5)+a|0)+480284|0,ga=(Wb(h,-16,16)<<3)+128|0,u[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;O()|0;break w}jh(a,1)}p=Lb(e+176|0);d=v[e+196>>2];v[23516]=0;g=Q(153,b|0,_b(d)|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break U}i=1;d=0;if(!g){break R}k=x[e+610>>1];h=v[b+8>>2];g=v[b>>2];v[23516]=0;h=W(154,g|0,h|0,Eb(k)<<1)|0;g=v[23516];v[23516]=0;if((g|0)==1){break U}if(!h){break R}g=x[e+610>>1];v[23516]=0;h=W(529,b|0,p|0,Eb(g)|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break U}if(!h){break R}fa=e,ga=Cb(v[p>>2]),v[fa+168>>2]=ga;m=Cb(v[e+180>>2]);while(1){d=v[e+168>>2];if(!Nb(d,m)){i=0;d=1;break R}g=Eb(w[d|0]|w[d+1|0]<<8);Z:{if(Eb(x[e+206>>1])>>>0<g>>>0){break Z}d=v[e+192>>2];v[23516]=0;Q(153,b|0,_b(d)+(g<<2)|0)|0;d=v[23516];v[23516]=0;_:{$:{aa:{ba:{ca:{if((d|0)==1){break ca}v[23516]=0;g=T(282,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break ca}v[23516]=0;g=Q(153,b|0,g|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break ca}if(!g){break Z}g=v[b+8>>2];d=v[b>>2];v[23516]=0;g=W(154,d|0,g|0,42)|0;d=v[23516];v[23516]=0;if((d|0)==1){break ca}if(!g){break Z}v[23516]=0;R(530,b|0,e+120|0);d=v[23516];v[23516]=0;da:{if((d|0)!=1){if(nc(v[o>>2],v[o+4>>2])){break da}v[23516]=0;R(531,o|0,65534);d=v[23516];v[23516]=0;if((d|0)!=1){break da}}i=P()|0;O()|0;break S}h=Eb(x[e+160>>1]);v[e+116>>2]=h;g=v[b+8>>2];d=v[b>>2];v[23516]=0;g=W(154,d|0,g|0,h|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break ba}if(!g){v[23516]=0;g=T(200,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break ba}uc(e+116|0,g)}uc(e+116|0,65534);h=v[o+4>>2];g=v[o>>2];d=0;v[23516]=0;n=v[e+116>>2];k=Oc(g,h);R(532,o|0,n+k|0);g=v[23516];v[23516]=0;if((g|0)==1){break $}while(1){ea:{if((d|0)==(n|0)){if(w[e+120|0]){break ea}break aa}v[23516]=0;h=T(274,b|0)|0;g=v[23516];v[23516]=0;fa:{if((g|0)!=1){g=h<<16>>16;if((g|0)<0){break fa}v[23516]=0;R(531,o|0,g+J&65535);g=v[23516];v[23516]=0;if((g|0)!=1){break fa}}i=P()|0;O()|0;break S}d=d+1|0;continue}break}Mm(e+104|0,e+120|0);v[23516]=0;U(533,e+56|0,v[e+104>>2],v[e+108>>2]);d=v[23516];v[23516]=0;ga:{ha:{ia:{if((d|0)!=1){v[23516]=0;U(11,e+80|0,14,e+56|0);d=v[23516];v[23516]=0;if((d|0)==1){break ia}v[23516]=0;R(276,o|0,e+80|0);d=v[23516];v[23516]=0;if((d|0)==1){break ha}xb(e+80|0);wb(e+56|0);break aa}i=P()|0;O()|0;break S}i=P()|0;O()|0;break ga}i=P()|0;O()|0;xb(e+80|0)}wb(e+56|0);break S}i=P()|0;O()|0;break S}i=P()|0;O()|0;break S}d=_b(v[e+152>>2]);if(!d){break Z}v[23516]=0;g=Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break _}}i=P()|0;O()|0;break S}if(!g){break Z}while(1){ja:{v[23516]=0;g=Q(534,b|0,e+104|0)|0;d=v[23516];v[23516]=0;ka:{la:{ma:{if((d|0)!=1){if(!g){break Z}v[23516]=0;U(188,e+56|0,b|0,w[e+107|0]);d=v[23516];v[23516]=0;if((d|0)==1){break ma}d=e+56|0;n=hc(e+80|0,d);yb(d);d=Eb(x[e+104>>1]);g=tl(d+k|0);u[e+56>>1]=g;if((d|0)==65535){break ja}d=v[o>>2];if(Oc(d,v[o+4>>2])>>>0<=g>>>0){break ja}na:{switch(w[e+106|0]-1|0){case 1:break ka;case 0:break la;default:break na}}yb(n);continue}i=P()|0;O()|0;break S}i=P()|0;O()|0;break S}fa=$b(d,g),ga=65535,u[fa>>1]=ga;yb(n);continue}v[23516]=0;h=T(274,n|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break T}v[23516]=0;g=Q(535,E|0,e+56|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break T}u[g>>1]=h;fa=$b(v[o>>2],x[e+56>>1]),ga=65534,u[fa>>1]=ga;yb(n);continue}break}yb(n)}Qe(e+168|0);continue}}i=P()|0;O()|0;break w}i=0;break L}i=P()|0;O()|0;break S}i=P()|0;O()|0;yb(n)}gd(p);break w}gd(p);if(d){d=f>>>(l>>>1&1)|0;break M}Mt(E);if(!i){break d}break K}g=Eb(x[e+868>>1]);h=w[e+871|0];q=h&64;f=w[e+872|0];z=f&32;N=(f&31)+1|0;fa=a,ga=lS(g,q>>>6|0,z>>>5|0,N),v[fa+480204>>2]=ga;fa=a,ga=Bd(w[e+873|0],1,32),v[fa+480196>>2]=ga;if(z){v[a+480216>>2]=N;v[a+480220>>2]=N<<2}f=w[e+890|0];if(f){t[e+192|0]=f;t[e+120|0]=64;fa=a,ga=w[Vb(e+192|0,e+120|0)|0]<<2,v[fa+480200>>2]=ga}v[a+480228>>2]=d;v[a+480232>>2]=d;v[a+480208>>2]=v[a+480208>>2]&-3|(h>>>4^-1)&2;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{d=_b(v[e+572>>2]);if(!d){break ya}v[23516]=0;f=Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break xa}if(!f){break ya}d=v[e+576>>2];v[23516]=0;U(271,b|0,da|0,_b(d)|0);d=v[23516];v[23516]=0;if((d|0)==1){break xa}if(w[ba|0]<2){break ya}v[23516]=0;U(11,e+192|0,14,da|0);d=v[23516];v[23516]=0;za:{if((d|0)!=1){v[23516]=0;R(276,o|0,e+192|0);d=v[23516];v[23516]=0;if((d|0)==1){break za}xb(e+192|0);break ya}i=P()|0;O()|0;break w}i=P()|0;O()|0;xb(e+192|0);break w}Aa:{if(_b(v[e+544>>2])>>>0<2){break Aa}d=v[e+540>>2];v[23516]=0;f=Q(153,b|0,_b(d)|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break xa}if(!f){break Aa}d=v[e+544>>2];v[23516]=0;X(336,H|0,b|0,_b(d)-1|0,4);d=v[23516];v[23516]=0;if((d|0)==1){break xa}}d=_b(v[e+584>>2]);if(!d){break oa}v[23516]=0;f=Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break xa}if(!f){break oa}f=v[b+8>>2];d=v[b>>2];v[23516]=0;f=W(154,d|0,f|0,12)|0;d=v[23516];v[23516]=0;if((d|0)==1){break xa}if(!f){break oa}v[23516]=0;Q(186,b|0,6)|0;d=v[23516];v[23516]=0;if((d|0)==1){break xa}v[23516]=0;f=T(274,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break xa}if((f|0)!=1){break oa}v[23516]=0;g=T(282,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break va}if(!g){break oa}f=v[b+8>>2];d=v[b>>2];v[23516]=0;f=W(154,d|0,f|0,g|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break va}if(f){break wa}break oa}i=P()|0;O()|0;break w}k=XD(e+192|0,H);v[23516]=0;X(336,H|0,b|0,g|0,4);d=v[23516];v[23516]=0;if((d|0)==1){break qa}if(!Pe(k)){v[23516]=0;f=W(536,e+24|0,2,13)|0;d=v[23516];v[23516]=0;if((d|0)==1){break ua}v[23516]=0;U(537,e+120|0,k|0,f|0);d=v[23516];v[23516]=0;if((d|0)==1){break ta}v[23516]=0;U(538,e+40|0,e+120|0,H|0);d=v[23516];v[23516]=0;if((d|0)==1){break sa}d=e+40|0;yc(H,d);wb(d);wb(e+120|0);wb(f)}wb(k);break oa}i=P()|0;O()|0;break w}i=P()|0;O()|0;break pa}i=P()|0;O()|0;break ra}i=P()|0;O()|0;wb(e+120|0)}wb(f);break pa}i=P()|0;O()|0}wb(k);break w}Ba:{if(I>>>0<2){break Ba}i=0;if(!_b(v[e+596>>2])){break Ba}while(1){if(x[a+480188>>1]<=i>>>0){break Ba}d=v[e+596>>2];v[23516]=0;f=Q(153,b|0,_b(d)+(i<<2)|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break x}Ca:{if(!f){break Ca}v[23516]=0;f=T(282,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break x}v[23516]=0;f=Q(153,b|0,f|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break x}m=0;d=0;if(!f){break Ca}while(1){Da:{g=v[b+8>>2];f=v[b>>2];v[23516]=0;g=W(154,f|0,g|0,8)|0;f=v[23516];v[23516]=0;Ea:{Fa:{Ga:{if((f|0)!=1){if(!g){break Da}v[23516]=0;R(539,b|0,e+192|0);f=v[23516];v[23516]=0;if((f|0)==1){break Ga}f=_b(v[e+192>>2]);if(!f){break Da}switch((f&536870911)-1|0){case 1:break Ea;case 0:break Fa;default:continue}}i=P()|0;O()|0;break w}i=P()|0;O()|0;break w}m=_b(v[e+196>>2]);continue}d=_b(v[e+196>>2]);continue}break}if(!m|!d){break Ca}v[23516]=0;g=Q(153,b|0,m|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break y}if(!g){break Ca}v[23516]=0;U(421,b|0,((i<<5)+a|0)+480289|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break y}}i=i+1|0;continue}}d=x[e+608>>1];v[23516]=0;s=Eb(d);R(224,G|0,J+s&65535);d=v[23516];v[23516]=0;if((d|0)==1){break z}y=h&16;r=J&65535;g=0;Ha:{Ia:{while(1){if((g|0)==(s|0)){fa=e,ga=Ei(v[E>>2]),v[fa+120>>2]=ga;g=tf(E);while(1){d=v[e+120>>2];if(!Fg(d,g)){i=1;d=_b(v[e+528>>2]);if(!d){break L}v[23516]=0;f=Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break z}if(!f){break L}J=s+J|0;Mt(E);break K}k=go(d);h=Re(k);Ja:{Ka:{La:{Ma:{d=x[k>>1];if(!d){j=0;break Ma}v[23516]=0;f=Q(314,o|0,d-1&65535)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Ja}j=x[k>>1];if(!f){break Ma}v[23516]=0;j=Q(367,o|0,j-1&65535)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Ja}break La}if(x[h>>1]==((j&65535)+1|0)){break Ka}v[23516]=0;j=Q(366,G|0,1)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Ja}if((j|0)==65535){break Ka}fa=$b(v[o>>2],x[k>>1]),ga=j,u[fa>>1]=ga}d=Xb(v[G>>2],j);ve(d,Dm(Se(Le(e+192|0,12,ju(x[h>>1])),v[d+12>>2]-1|0)));s=(s&65535)>>>0>j>>>0?s:j+1|0}Ig(e+120|0);continue}break}i=P()|0;O()|0;break w}Na:{Oa:{if(!D){break Oa}d=v[e+936>>2];v[23516]=0;f=Q(153,b|0,_b(d)+(g<<2)|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Ia}if(!f){break Oa}v[23516]=0;f=T(282,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Ia}v[23516]=0;f=Q(153,b|0,f|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Ia}if(!f){break Oa}V=Kb(e+56|0);v[23516]=0;Y=T(172,e|0)|0;d=v[23516];v[23516]=0;Pa:{Qa:{if((d|0)!=1){if(I){break Qa}v[23516]=0;R(540,b|0,e+192|0);d=v[23516];v[23516]=0;if((d|0)==1){break Na}u[e+104>>1]=w[e+192|0];Z=w[e+193|0]+1|0;f=48;break Pa}i=P()|0;O()|0;break A}v[23516]=0;n=t[e+870|0];R(541,b|0,e+176|0);d=v[23516];v[23516]=0;Ra:{Sa:{if((d|0)!=1){k=Eb(x[e+176>>1]);u[e+104>>1]=k;Z=Eb(x[e+178>>1])+1|0;d=_b(v[e+180>>2]);if(!d){break Ra}h=v[b+8>>2];v[23516]=0;Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break B}v[23516]=0;R(542,b|0,e+192|0);d=v[23516];v[23516]=0;if((d|0)==1){break B}d=v[e+196>>2];v[23516]=0;f=Q(153,b|0,_b(d)|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break B}if(!f){break Sa}d=v[e+200>>2];v[23516]=0;U(271,b|0,V|0,_b(d)|0);d=v[23516];v[23516]=0;if((d|0)!=1){break Sa}break B}break B}d=_b(v[e+208>>2]);Ta:{if(!d){break Ta}v[23516]=0;f=Q(153,b|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break B}if(!f){break Ta}v[23516]=0;f=T(282,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break B}v[23516]=0;f=Q(153,b|0,f|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break B}if(!f){break Ta}v[23516]=0;U(188,e+80|0,b|0,B(k,Z)|0);d=v[23516];v[23516]=0;if((d|0)==1){break B}f=e+80|0;d=hc(e+120|0,f);cd(Y,d);yb(d);yb(f)}v[23516]=0;Q(153,b|0,h|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break B}}f=n+(I>>>0<3?48:24)|0}v[23516]=0;k=g+r|0;h=W(225,G|0,k&65535,Z|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break B}Ua:{if(!h){break Ua}d=v[G>>2];v[23516]=0;A=Xb(d,k);R(284,A|0,V|0);d=v[23516];v[23516]=0;if((d|0)==1){break Ha}Bf(e+104|0,x[a+480188>>1]);C=0;p=x[e+104>>1];Va:while(1){if((C|0)==(Z|0)){break Ua}i=0;d=ed(v[A>>2],v[v[A+48>>2]+12>>2],C,0);while(1){if((i&65535)>>>0>=p>>>0){C=C+1|0;continue Va}Wa:{if(!I){v[23516]=0;R(543,e+192|0,b|0);h=v[23516];v[23516]=0;if((h|0)!=1){m=w[e+192|0];n=e+192|0;h=Kc(n);t[d+1|0]=m>>>3&16|w[h|0]>>>4|m>>>1&32;k=w[h|0];fa=d,ga=w[Re(n)|0],t[fa+5|0]=ga;h=m&63;j=h?h+f|0:0;m=k&15;break Wa}break B}v[23516]=0;R(356,e+192|0,b|0);h=v[23516];v[23516]=0;Xa:{Ya:{if((h|0)!=1){h=e+192|0;l=Kc(h);m=Re(h);n=Ji(h);v[23516]=0;k=T(204,Y|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break B}t[d+4|0]=k;k=w[e+192|0];h=k&127;if(!h){break Ya}j=f+h|0;break Xa}break B}j=0;if((k|0)!=128){break Xa}t[d|0]=254}t[d+1|0]=w[l|0]&63;m=w[m|0];t[d+5|0]=w[n|0]}if(j-1>>>0<=119){t[d|0]=j}F=(j|0)>84&ca|F;n=(q|0)!=0;k=(z|0)!=0;h=(y|0)!=0;l=hb-16|0;hb=l;t[d+3|0]=0;Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{m=m&255;switch(m-4|0){case 4:case 10:break Za;case 42:break $a;case 37:break ab;case 28:break bb;case 27:break cb;case 26:break db;case 25:break eb;case 24:break fb;case 23:break gb;case 22:break hb;case 21:break ib;case 20:break jb;case 18:break kb;case 17:break lb;case 16:break mb;case 14:break nb;case 13:break ob;case 12:break pb;case 11:break qb;case 9:break rb;case 8:break sb;case 5:break tb;case 0:break ub;default:break _a}}t[d+3|0]=5;k=w[d+5|0];t[l+15|0]=k>>>3;t[l+14|0]=15;h=w[Vb(l+15|0,l+14|0)|0];t[l+13|0]=k<<1&30;t[l+12|0]=15;fa=d,ga=w[Vb(l+13|0,l+12|0)|0]|h<<4,t[fa+5|0]=ga;break Za}if((w[d+5|0]-1&255)>>>0>19){break Za}t[d+3|0]=16;break Za}t[d+3|0]=13;k=w[d+5|0];vb:{if(!h){if(k>>>0>152){break vb}t[d+5|0]=B((k&240)>>>4|0,10)+(k&15);break Za}t[d+5|0]=(k&127)+1>>>1;break Za}t[d+3|0]=0;break Za}t[d+3|0]=11;break Za}h=w[d+5|0];if(!h){t[d+3|0]=14;break Za}if(h>>>0>240){break Za}t[d+3|0]=17;if(h>>>0<=2){t[d+5|0]=112;break Za}fa=d,ga=nk(+(lS(h,n,k,N)>>>0)/1e4),t[fa+5|0]=ga;break Za}t[d+3|0]=31;t[d+5|0]=w[d+5|0]|128;break Za}t[d+3|0]=19;t[l+11|0]=15;fa=d,ga=w[Vb(d+5|0,l+11|0)|0]|16,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+10|0]=15;fa=d,ga=w[Vb(d+5|0,l+10|0)|0]|32,t[fa+5|0]=ga;break Za}t[d+3|0]=5;h=w[d+5|0];t[l+9|0]=(h>>>4|0)+1;t[l+8|0]=15;fa=d,ga=h&15|w[Vb(l+9|0,l+8|0)|0]<<4,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[d+5|0]=w[d+5|0]&15|80;break Za}t[d+3|0]=19;t[l+7|0]=15;fa=d,ga=w[Vb(d+5|0,l+7|0)|0]|96,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+6|0]=15;fa=d,ga=w[Vb(d+5|0,l+6|0)|0]|192,t[fa+5|0]=ga;break Za}t[d+3|0]=10;break Za}t[d+3|0]=19;t[l+5|0]=15;fa=d,ga=w[Vb(d+5|0,l+5|0)|0]|160,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+4|0]=15;fa=d,ga=w[Vb(d+5|0,l+4|0)|0]|176,t[fa+5|0]=ga;break Za}h=(w[d+5|0]<<24)-16777216>>24;if((h|0)<0){break Za}t[d+5|0]=h;t[d+3|0]=31;break Za}t[d+3|0]=14;break Za}t[d+3|0]=19;t[l+3|0]=15;fa=d,ga=w[Vb(d+5|0,l+3|0)|0]|224,t[fa+5|0]=ga;break Za}h=w[d+5|0];if(h&240){t[d+3|0]=19;t[d+5|0]=h>>>4|208;break Za}if(!(h&15)){break Za}t[d+3|0]=19;t[d+5|0]=h|144;break Za}if(w[d+5|0]|w[d+4|0]){break Za}if(!Wc(w[d|0])){break Za}t[d+5|0]=159;t[d+3|0]=20;break Za}h=w[d+4|0];if(!h){break Za}t[d+3|0]=44;fa=d,ga=Bl(Bc(((w[d+5|0]<<8&65280)>>>0)/(h>>>0)|0,0)),t[fa+5|0]=ga;break Za}h=w[d+5|0];if((h+16&255)>>>0>32){break Za}t[d+3|0]=9;fa=d,ga=rg(((h^128)<<3)-896|0),t[fa+5|0]=ga;break Za}if(m>>>0>15){break Za}Nf(d,m,w[d+5|0])}hb=l+16|0;d=d+6|0;i=i+1|0;continue}}}yb(Y);wb(V)}g=g+1|0;continue}break}break B}i=P()|0;O()|0;break w}break B}Mt(E);d=0;if(!i){break c}}Dj($,0);d=1;wb:{if(F&1){break wb}while(1){b=d&65535;if(b>>>0>x[a+480192>>1]){u[a+480192>>1]=0;break wb}c=((b<<2)+a|0)+900380|0;b=v[c>>2];if(b){Jb(Ot(b))}v[c>>2]=0;d=d+1|0;continue}}xb:{if(!ea){break xb}v[23516]=0;c=Q(1,e+192|0,16467)|0;b=v[23516];v[23516]=0;yb:{if((b|0)!=1){b=v[a+1298464>>2];v[23516]=0;U(384,b|0,2,c|0);b=v[23516];v[23516]=0;if((b|0)==1){break yb}xb(c);break xb}i=P()|0;O()|0;break f}i=P()|0;O()|0;xb(c);break f}j=21751;zb:{Ab:{switch(aa-48|0){case 0:j=x[a+480188>>1]>4?17362:17348;break zb;case 1:j=17330;break zb;case 2:j=17312;break zb;case 3:break Ab;default:break zb}}j=17285}v[23516]=0;R(544,e+80|0,16900);b=v[23516];v[23516]=0;Bb:{Cb:{Db:{if((b|0)!=1){v[23516]=0;U(545,e+120|0,e+80|0,e+919|0);b=v[23516];v[23516]=0;if((b|0)==1){break Db}b=e+120|0;Gb(a+1298344|0,b);xb(b);ac(e+80|0);v[23516]=0;c=Q(1,b|0,12674)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Cb}Gb(a+1298356|0,c);xb(c);v[23516]=0;Q(134,a+1298368|0,j|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Bb}v[a+1298404>>2]=14;d=1;break c}i=P()|0;O()|0;break f}i=P()|0;O()|0;ac(e+80|0);break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}c=c+1|0;continue}}i=P()|0;O()|0;break f}i=P()|0;O()|0;yb(Y)}wb(V);break w}i=P()|0;O()|0;break w}i=P()|0;O()|0;break w}i=P()|0;O()|0}Mt(E);break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}A=1;if((d|0)!=7){break m}d=z+108|0;f=Yz(d);while(1){if((d|0)!=(f|0)){fa=d,ga=Cm(w[d|0]-24|0),t[fa|0]=ga;d=d+1|0;continue}break}g=0}F=1;break l}g=0;Eb:{if(r|(q|0)<0){break Eb}n=z+108|0;j=7;Fb:while(1){if((j|0)==10){break Eb}k=B(j,12);h=B(j,-12)+72|0;d=0;while(1)if((d|0)==12){j=j+1|0;continue Fb}else{f=Ib(n,d+k|0);t[f|0]=h+w[f|0];d=d+1|0;continue}}}}v[23516]=0;R(546,_|0,e+192|0);d=v[23516];v[23516]=0;if((d|0)!=1){Gb:{d=w[e+196|0];if((d-1&255)>>>0<=15){t[z+31|0]=d;F=1}d=w[e+197|0];if((d<<24)-16777216>>24>=0){t[z+30|0]=d}d=0;Hb:{while(1){if((d|0)==(A|0)){if(!p){break j}if((q|0)>=0){break Hb}break j}v[23516]=0;h=B(d+y|0,104)+a|0;R(280,h+484380|0,8);f=v[23516];v[23516]=0;if((f|0)!=1){t[e+120|0]=w[e+198|0];t[e+56|0]=64;fa=h+484410|0,ga=w[Vb(e+120|0,e+56|0)|0]<<2,u[fa>>1]=ga;t[h+484416|0]=w[e+199|0];d=d+1|0;continue}break}break k}k=Uc(e+120|0,8,1,1,0);h=Eb(x[e+194>>1]);i=Eb(x[e+192>>1]);d=v[D>>2];v[23516]=0;j=T(158,d|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){d=ne(u[e+84>>1]);if(d&16){nd(k,16);j=j>>>1|0}if(d&32){Eo(k,3);j=j>>>1|0}if(d&64){cg(k,2)}j=g?(j>>>0)/((-1<<A^-1)>>>0)|0:j;m=h+i|0;d=0;while(1){if((d|0)==(A|0)){break j}g=B(d+y|0,104)+a|0;f=g+484380|0;v[f>>2]=j;v[23516]=0;W(218,k|0,f|0,D|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break Gb}i=i<<1;m=m<<1;if(h>>>0>=2){v[g+484388>>2]=m;v[g+484384>>2]=i;f=g+484414|0;u[f>>1]=x[f>>1]|2}d=d+1|0;j=j<<1;continue}}}}}i=P()|0;O()|0;yb(D);break f}yb(D);C=C+1|0;s=s+A|0;j=x[a+480192>>1];continue}}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}i=P()|0;O()|0}lc(M)}yb(_);S(i|0);L()}d=0}lc(M)}yb(_)}hb=e+976|0;return d|0}function Fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=C(0),ha=0,ia=0,ja=0,ka=0,la=0,ma=0;e=hb-672|0;hb=e;xc(b);a:{b:{c:{if(!di(b,e+664|0)){break c}if(!lQ(e+664|0)){break c}if((uo(b)|0)>=0){break c}if(!c){d=1;break c}zd(a,16777216);d=a+480208|0;v[d>>2]=v[d>>2]|1681e4;oq(e+272|0,32);h=v[e+284>>2];d=a+1074320|0;v[d>>2]=v[e+280>>2];v[d+4>>2]=h;d=v[e+276>>2];v[a+1074312>>2]=v[e+272>>2];v[a+1074316>>2]=d;Lf(a+1074312|0,38);p=Lb(e+648|0);q=Lb(e+632|0);A=Lb(e+616|0);l=Lb(e+600|0);wg(b,4);i=a+480190|0;J=c&1;I=a+1298332|0;r=2500;H=!(c&2);F=a+1298464|0;d:{e:{f:{while(1){c=v[b+8>>2];d=v[b>>2];v[23516]=0;c=W(154,d|0,c|0,4)|0;d=v[23516];v[23516]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){v[23516]=0;c=T(697,b|0)|0;d=v[23516];v[23516]=0;o:{if((d|0)==1){break o}n=4;d=0;p:{q:{r:{switch(c+21|0){case 20:v[23516]=0;c=T(282,b|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){d=c&65535;if(x[a+480188>>1]|d-1>>>0>126){continue}u[a+480188>>1]=c;la=a,ma=Wb(512/(d>>>0)|0,16,128),v[la+480228>>2]=ma;continue}c=P()|0;O()|0;break a;case 19:v[23516]=0;M=T(282,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break o}if(M>>>0<=1024){continue}break m;case 16:v[23516]=0;c=T(282,b|0)|0;h=v[23516];v[23516]=0;if((h|0)!=1){if((c&65535)==4){continue}break m}c=P()|0;O()|0;break a;case 15:v[23516]=0;c=T(282,b|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){v[e+272>>2]=c;v[e+168>>2]=800;la=a,ma=Oe(+y[Hb(e+272|0,e+168|0)>>2]*1.24*1e4),v[la+480204>>2]=ma;continue}c=P()|0;O()|0;break a;case 31:v[23516]=0;c=T(282,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break o}_=1;r=Bd(c,0,1e4);continue;case 32:case 33:v[23516]=0;c=T(282,b|0)|0;d=v[23516];v[23516]=0;s:{t:{if((d|0)!=1){_=1;if(!c){continue}v[23516]=0;d=Q(1,e+584|0,12583)|0;c=v[23516];v[23516]=0;if((c|0)==1){break t}c=v[F>>2];v[23516]=0;U(384,c|0,2,d|0);c=v[23516];v[23516]=0;if((c|0)==1){break s}xb(d);continue}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;xb(d);break a;case 14:v[23516]=0;Q(186,b|0,4)|0;c=v[23516];v[23516]=0;if((c|0)==1){break o}g=!x[i>>1]|g;continue;case 11:if(!J){break q}if(!nc(v[p>>2],v[p+4>>2])){break q}v[23516]=0;R(698,e+272|0,b|0);c=v[23516];v[23516]=0;if((c|0)!=1){if(v[p>>2]){Gc(p);c=v[p>>2];$n(p);Jb(c);la=Db(p),ma=0,v[la>>2]=ma;v[p>>2]=0;v[p+4>>2]=0}c=e+272|0;v[p>>2]=v[c>>2];v[p+4>>2]=v[c+4>>2];d=Db(c);la=Db(p),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Ci(c);continue}c=P()|0;O()|0;break a;case 3:case 4:case 10:h=xh(v[l>>2],v[l+4>>2]);d=x[i>>1];if(h>>>0<=d>>>0){continue}if((g|H)&1){break q}if(!Yh(d)){break q}d=d+1|0;u[i>>1]=d;s=Lb(e+568|0);v[23516]=0;n=T(172,e+544|0)|0;g=v[23516];v[23516]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}v[23516]=0;c=T(282,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break u}v[23516]=0;U(188,e+168|0,b|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break u}c=e+168|0;g=hc(e+272|0,c);cd(n,g);yb(g);break g}c=P()|0;O()|0;break d}v[23516]=0;R(699,e+272|0,b|0);c=v[23516];v[23516]=0;x:{if((c|0)!=1){c=e+272|0;g=Bm(s,c);dc(c);oe(e+512|0,v[g>>2],v[e+572>>2]);c=v[ce(e+504|0)>>2];v[23516]=0;c=ga(333,e+520|0,v[e+512>>2],v[e+516>>2],c|0,v[e+508>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break x}cd(n,c);break g}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}v[23516]=0;R(700,e+272|0,b|0);c=v[23516];v[23516]=0;y:{if((c|0)!=1){c=e+272|0;g=Bm(s,c);dc(c);oe(e+472|0,v[g>>2],v[e+572>>2]);c=v[ce(e+464|0)>>2];v[23516]=0;c=ga(333,e+480|0,v[e+472>>2],v[e+476>>2],c|0,v[e+468>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break y}cd(n,c);break g}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e;case 9:c=x[i>>1];if(!Yh(c)){continue}u[i>>1]=c+1;continue;case 8:if(!J){break q}if(!nc(v[A>>2],v[A+4>>2])){break q}v[23516]=0;R(701,e+272|0,b|0);c=v[23516];v[23516]=0;if((c|0)!=1){c=e+272|0;kQ(A,c);lc(c);continue}c=P()|0;O()|0;break a;case 7:if(!nc(v[l>>2],v[l+4>>2])){break q}v[23516]=0;R(702,e+272|0,b|0);c=v[23516];v[23516]=0;if((c|0)!=1){if(v[l>>2]){Gc(l);c=v[l>>2];Cz(l);Jb(c);la=Db(l),ma=0,v[la>>2]=ma;v[l>>2]=0;v[l+4>>2]=0}c=e+272|0;v[l>>2]=v[c>>2];v[l+4>>2]=v[c+4>>2];d=Db(c);la=Db(l),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;yt(c);continue}c=P()|0;O()|0;break a;case 6:if(!J){break q}if(!nc(v[q>>2],v[q+4>>2])){break q}v[23516]=0;R(703,e+272|0,b|0);c=v[23516];v[23516]=0;if((c|0)!=1){if(v[q>>2]){Gc(q);c=v[q>>2];rt(q);Jb(c);la=Db(q),ma=0,v[la>>2]=ma;v[q>>2]=0;v[q+4>>2]=0}c=e+272|0;v[q>>2]=v[c>>2];v[q+4>>2]=v[c+4>>2];d=Db(c);la=Db(q),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;kl(c);continue}c=P()|0;O()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}v[23516]=0;R(704,e+272|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break n}z:{c=v[e+272>>2];d=v[e+276>>2];if(nc(c,d)){break z}v[23516]=0;X(342,I|0,c|0,ad(c,d)|0,1);c=v[23516];v[23516]=0;if((c|0)!=1){break z}c=P()|0;O()|0;dc(e+272|0);break a}dc(e+272|0);continue}v[23516]=0;n=T(282,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break o}}v[23516]=0;Q(186,b|0,n|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){continue}}c=P()|0;O()|0;break a}d=0;if(!x[a+480188>>1]|!M){break m}b=v[l>>2];c=v[l+4>>2];if(nc(b,c)){break m}if(J){if(nc(v[p>>2],v[p+4>>2])){break m}if(nc(v[A>>2],v[A+4>>2])){break m}if(nc(v[q>>2],v[q+4>>2])){break m}}b=xh(b,c);if(b>>>0>=256){v[23516]=0;R(705,l|0,255);b=v[23516];v[23516]=0;if((b|0)==1){break b}b=xh(v[l>>2],v[l+4>>2])}u[a+480192>>1]=b;m=a+480190|0;n=a+480192|0;la=m,ma=x[ie(i,n)>>1],u[la>>1]=ma;if(g&1){v[23516]=0;b=Q(1,e+568|0,16556)|0;c=v[23516];v[23516]=0;if((c|0)==1){break h}c=v[a+1298464>>2];v[23516]=0;U(384,c|0,2,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break i}xb(b)}g=0;A:while(1){if((g|0)!=2){d=1;while(1){f=d&65535;if(f>>>0>x[n>>1]){g=g+1|0;continue A}B:{h=rm(v[l>>2],f-1|0);if(!w[h|0]|t[h+128|0]<0){break B}if((wt(h)|0)==((g|0)!=1|0)){break B}C:{D:{E:{c=0;F:{if(!wt(h)){break F}if(Eb(w[h+6|0]|w[h+7|0]<<8)){break F}if(Eb(w[h+14|0]|w[h+15|0]<<8)>>>0>20){break F}c=(Eb(w[h+18|0]|w[h+19|0]<<8)|0)==4}G:{H:{if(c){c=w[h+23|0];b=w[h+140|0];v[23516]=0;b=ga(706,h|0,a|0,(b&2)>>>1|0,(B(f,104)+a|0)+484380|0,r&65535)|0;k=v[23516];v[23516]=0;I:{J:{if((k|0)!=1){if(!b){break I}v[23516]=0;b=Q(53,e+400|0,10745)|0;k=v[23516];v[23516]=0;if((k|0)==1){break J}Ac(((f<<5)+a|0)+946304|0,b);wb(b);k=v[l>>2];b=d;if(xh(k,v[l+4>>2])>>>0<=c>>>0){break G}la=h,ma=w[h+143|0]+w[rm(k,c)+143|0]|0,t[la+143|0]=ma;break H}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}b=c+1|0;break G}c=0;K:{if(!wt(h)){break K}if((Eb(w[h+6|0]|w[h+7|0]<<8)|0)!=1){break K}if((Eb(w[h+14|0]|w[h+15|0]<<8)|0)!=2){break K}c=(Eb(w[h+18|0]|w[h+19|0]<<8)|0)==10}b=d;if(!c){break G}pc(e+272|0,h,128);b=Eb(x[e+292>>1]);if(b>>>0>=x[i>>1]){break H}v[23516]=0;c=T(695,e+168|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break E}k=x[e+308>>1];o=x[m>>1];v[23516]=0;s=B(b,104);b=a+484380|0;k=Eb(k);b=fa(707,e+272|0,(s+b|0)+104|0,(k>>>0<o>>>0?(b+B(k,104)|0)+104|0:c)|0,b+B(f,104)|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break D}if(!b){break H}v[23516]=0;b=Q(53,e+152|0,11289)|0;c=v[23516];v[23516]=0;if((c|0)==1){break C}Ac(((f<<5)+a|0)+946304|0,b);wb(b);t[h+139|0]=w[h+139|0]+12}b=d}v[23516]=0;b=b&65535;c=W(253,a|0,f|0,b|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){if(!c|b>>>0>x[i>>1]){break B}v[23516]=0;X(708,h|0,c|0,(B(b,104)+a|0)+484380|0,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){break B}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}d=d+1|0;continue}}break}I=Xf(e+136|0);s=Xf(e+120|0);b=sc(v[A>>2],v[A+4>>2]);$=B(x[a+480188>>1],M);aa=tl((b>>>0)/($>>>0)|0);v[23516]=0;V=a+484344|0;R(224,V|0,aa|0);b=v[23516];v[23516]=0;if((b|0)==1){break k}ba=a+484376|0;Gc(Sb(v[a+484360>>2],w[ba|0]));b=x[a+480188>>1];v[23516]=0;F=Q(709,e+104|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break l}la=e,ma=Cb(v[q>>2]),v[la+48>>2]=ma;ha=a+902204|0;ia=Cb(v[q+4>>2]);ja=a+480208|0;while(1){L:{M:{N:{k=v[e+48>>2];if(!Nb(k,ia)){break N}b=ne((w[k+6|0]|w[k+7|0]<<8)<<16>>16);if((b|0)==1){break L}if((b&65535)==65535){break N}g=Eb(w[k|0]|w[k+1|0]<<8);b=v[p>>2];h=v[p+4>>2];c=Uf(b,h);if(g>>>0>=c>>>0){break L}d=Eb(w[k+2|0]|w[k+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(Uf(b,h)<<5)|0;v[e+272>>2]=b;la=e,ma=Uf(b,c),v[la+276>>2]=ma;b=v[e+272>>2];fc(e+80|0,b+(Eb(w[k|0]|w[k+1|0]<<8)<<5)|0,Eb(w[k+2|0]|w[k+3|0]<<8));O:{H=Sb(v[a+484360>>2],w[ba|0]);if(nc(v[H>>2],v[H+4>>2])){break O}v[23516]=0;R(531,H|0,65534);b=v[23516];v[23516]=0;if((b|0)!=1){break O}break M}b=v[e+80>>2];ka=ue(b,v[e+84>>2]);while(1){if((b|0)==(ka|0)){break L}c=ne(ne((w[k+8|0]|w[k+9|0]<<8)<<16>>16)+ne((w[b+16|0]|w[b+17|0]<<8)<<16>>16)<<16>>16);t[b+16|0]=c;t[b+17|0]=c>>>8;h=b;b=Pd(I);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!tt(h,d)){c=1;if(!tt(d,h)){break P}b=b+4|0}b=v[b>>2];continue}break}Q:{R:{S:{if(c){v[23516]=0;b=Q(710,I|0,h|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break M}E=x[b>>1];break S}E=0;if(!J){break S}b=w[h+12|0]|w[h+13|0]<<8;v[23516]=0;E=Q(366,V|0,Eb(b)|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break M}if((E|0)==65535){break L}v[23516]=0;b=Q(710,I|0,h|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break M}u[b>>1]=E;if(Eb(w[h+8|0]|w[h+9|0]<<8)>>>0>=aa>>>0){break R}if(Eb(w[h+10|0]|w[h+11|0]<<8)>>>0>=M>>>0){break R}m=Eb(w[h+14|0]|w[h+15|0]<<8);c=qm(Cb(v[A>>2]),B(Eb(w[h+8|0]|w[h+9|0]<<8),$));b=x[a+480188>>1];la=e,ma=qm(c,B(b,Eb(w[h+10|0]|w[h+11|0]<<8))),v[la+32>>2]=ma;N=0;v[e+16>>2]=0;o=sg(e- -64|0);T:while(1){U:{d=Eb(w[h+12|0]|w[h+13|0]<<8);c=Xb(v[V>>2],E);if(d>>>0<=N>>>0){break U}n=0;Z=ed(v[c>>2],v[v[c+48>>2]+12>>2],N,0);c=0;while(1){if((b&65535)>>>0<=n>>>0){N=N+1|0;continue T}b=Cb(v[A+4>>2]);d=v[e+32>>2];i=Nb(d,b)?d:e+16|0;b=Cb(v[A+4>>2]);if(Nb(v[e+32>>2],b)){iQ(e+32|0)}d=B(n,6)+Z|0;g=w[i+1|0];b=(g>>>0<85?g+25|0:-1)<<24>>24;r=0;f=v[l>>2];K=xh(f,v[l+4>>2]);G=w[i+3|0];V:{if(K>>>0<=G>>>0){break V}r=G+1|0;if(t[rm(f,G)+142|0]&1|(b|0)<0){break V}b=ne((w[h+16|0]|w[h+17|0]<<8)<<16>>16)+b<<24>>24;b=(b|0)<120?b:120;b=((b|0)>1?b:1)&255}W:{if(!w[d|0]|!(w[i+2|0]?1:G|(w[i|0]|(g|0)!=255))){break W}g=w[d+1|0];if(!g|g>>>0>K>>>0){break W}if(w[rm(f,g-1|0)+132|0]!=2){break W}Zn(d)}f=zt(v[F>>2],n);X:{Y:{if(!(c&1)){g=w[i|0];break Y}c=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);t[d|0]=c;t[d+1|0]=c>>>8;t[d+2|0]=c>>>16;t[d+3|0]=c>>>24;c=w[o+4|0]|w[o+5|0]<<8;t[d+4|0]=c;t[d+5|0]=c>>>8;Z:{if(w[d+3|0]){break Z}g=w[f+21|0];c=w[zt(v[F>>2],n-1|0)+21|0];if((g|0)==(c|0)){break Z}t[d+3|0]=21;t[f+21|0]=c;t[d+5|0]=c}c=0;g=w[i|0];if(!(g-24>>>0<2|(g|0)==9|!g&(w[i+2|0]+7&255)>>>0<2)){break X}}_:{$:{aa:{ba:{ca:{da:{switch(g|0){case 5:c=w[f+17|0];break ca;case 0:ea:{c=w[i+2|0];if(c>>>0>=201){g=0;fa:{switch(c-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[f+16|0]=0;break $;case 9:if(!w[d|0]){t[d|0]=w[f+17|0]}t[d+4|0]=1;t[d+2|0]=15;break $;case 8:if((m&255)>>>0<2){break $}m=m-1|0;break aa;case 7:if((m&255)==255){m=255;break $}m=m+1|0;break aa;case 6:t[f+17|0]=b;if(w[f+18|0]!=(r&255)){break $}t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;u[f+32>>1]=0;v[f+8>>2]=0;break $;case 5:t[d+5|0]=242;t[d+3|0]=2;break $;case 4:t[d+5|0]=242;t[d+3|0]=3;break $;case 3:t[d+5|0]=244;t[d+3|0]=2;break $;case 2:t[d+5|0]=244;t[d+3|0]=3;break $;case 1:t[d+5|0]=248;t[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}t[d+5|0]=248;t[d+3|0]=3;break $}g=0;K=t[i+1|0];if((K|0)<0&c>>>0>99){break $}if((K|0)>=0){t[f+17|0]=b;t[d|0]=b;t[f+18|0]=r;t[d+1|0]=r;u[f+32>>1]=0;v[f+8>>2]=0;c=w[i+2|0]}b=c&255;if(!b){break $}la=f,ma=nk(+(b>>>0)*.64),t[la+19|0]=ma;j=z[f>>2];v[f>>2]=0;g=j!=C(0);break $}t[d+4|0]=0;t[d+2|0]=14;t[f+16|0]=1;break $;case 1:v[f+4>>2]=0;z[f>>2]=C(w[i+2|0])*C(.0333000011742115);break _;case 2:v[f+4>>2]=0;z[f>>2]=C(w[i+2|0])*C(-.0333000011742115);break _;case 12:t[e+272|0]=15;t[e+100|0]=w[i+3|0]>>>3;b=w[Vb(e+272|0,e+100|0)|0];t[e+272|0]=15;t[e+100|0]=w[i+2|0]>>>3;la=f,ma=w[Vb(e+272|0,e+100|0)|0]|b<<4,t[la+24|0]=ma;break _;case 3:v[f+12>>2]=0;b=w[i+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(.0333000011742115);break _;case 4:v[f+12>>2]=0;b=w[i+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(-.0333000011742115);break _;case 15:if(!w[i+2|0]|(b|0)<0){break _}g=b-w[f+17|0]|0;c=g>>31;c=(c^g<<5)-c|0;v[e+272>>2]=c;t[f+17|0]=b;v[f+8>>2]=0;t[d|0]=b;t[d+3|0]=4;b=rg((c>>>0)/(w[i+2|0]<<1>>>0)|0);t[d+5|0]=b;t[f+27|0]=b;v[e+100>>2]=B(b,(m&255)-1|0);la=f,ma=c-v[od(e+272|0,e+100|0)>>2]|0,u[la+32>>1]=ma;break _;case 13:t[e+272|0]=15;t[e+100|0]=w[i+3|0]>>>3;b=w[Vb(e+272|0,e+100|0)|0];t[e+272|0]=15;t[e+100|0]=w[i+2|0];la=f,ma=w[Vb(e+272|0,e+100|0)|0]|b<<4,t[la+23|0]=ma;break _;case 18:b=w[i+2|0]+w[f+17|0]&255;b=b?b>>>0<120?b:120:1;t[f+17|0]=b;t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;break ba;case 23:case 24:case 25:b=Pd(s);while(1){ga:{c=0;if(!b){break ga}g=b+13|0;if(!ut(i,g)){c=1;if(!ut(g,i)){break ga}b=b+4|0}b=v[b>>2];continue}break};if(c){t[d+3|0]=31;v[23516]=0;b=Q(711,s|0,i|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break M}t[d+5|0]=w[b|0];break _}b=v[Db(s)>>2];if(b>>>0>127){break _}v[e+96>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);c=v[ja>>2];v[23516]=0;v[e+12>>2]=v[e+96>>2];c=W(712,e+12|0,ue(ha,b&255)|0,c|0)|0;g=v[23516];v[23516]=0;ha:{if((g|0)==1){break ha}if(!c){break _}t[d+3|0]=31;v[23516]=0;c=Q(711,s|0,i|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break ha}b=b|-128;t[c|0]=b;t[d+5|0]=b;ca=(w[i|0]&254)==24|ca;break _}break M;case 16:if(!w[i+2|0]){break _}t[d+3|0]=15;v[e+272>>2]=15;v[e+100>>2]=w[i+3|0]+1;la=d,ma=v[od(e+272|0,e+100|0)>>2],t[la+5|0]=ma;u[f+30>>1]=B(w[i+2|0],w[i+3|0]+1|0);break _;case 9:t[d+3|0]=16;b=w[i+2|0];m=b?b:4;t[d+5|0]=m;break _;case 19:ia:{b=w[i+1|0];switch(b|0){case 0:case 4:break ia;default:break _}}g=128;g=(b|0)==4?w[i+3|0]:g;t[e+95|0]=g;t[e+272|0]=w[i+2|0];t[e+100|0]=100;b=e+272|0;r=e+100|0;c=w[Vb(b,r)|0];v[e+272>>2]=128;v[e+100>>2]=256-(g&255);g=v[od(b,r)>>2];t[e+272|0]=128;b=w[Vb(b,e+95|0)|0];g=(B(c,g)|0)/128|0;r=g&255;if((r|0)!=w[f+20|0]){t[f+20|0]=g;t[d+3|0]=21;g=Bc(((B(r,w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=g;t[d+5|0]=g}if(w[i+1|0]!=4|(x[a+480188>>1]-1|0)<=(n|0)){break _}g=n+1|0;i=zt(v[F>>2],g);b=B(b,c)>>>7|0;if(w[i+20|0]==(b&255)){break _}t[i+20|0]=b;b=B(g,6)+Z|0;t[b+3|0]=21;c=Bc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=c;t[b+5|0]=c;break _;case 10:case 11:case 17:case 20:t[d+3|0]=0;break _;case 7:b=w[i+2|0];t[f+25|0]=0;t[f+26|0]=0;t[f+22|0]=b;break _;case 8:t[f+22|0]=w[f+22|0]+w[i+2|0];break _;case 14:t[f+25|0]=w[i+3|0];t[f+26|0]=w[i+2|0];break _;case 6:break da;default:break _}}t[f+18|0]=r;t[f+17|0]=b;t[d+1|0]=r;c=b}t[d|0]=c;if((b|0)>=0){t[f+18|0]=r;t[d+1|0]=r}if(w[i|0]==5){t[d+4|0]=1;t[d+2|0]=11}c=w[f+22|0];b=w[f+26|0];if(!(b?1:c|w[i+2|0])){break ba}if(b){da=(Bi(+x[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{da=0}t[d+3|0]=44;la=d,ma=nk(da+ +(c+w[i+2|0]|0)),t[la+5|0]=ma}u[f+32>>1]=0;break _}t[d+5|0]=m;t[d+3|0]=16}b=Bc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!g&w[f+21|0]==(b&255))){t[f+21|0]=b;t[d+5|0]=b;t[d+3|0]=21}if(n&1|t[i+1|0]<=0|(x[a+480188>>1]-1|0)<=(n|0)){break _}b=v[l>>2];if(xh(b,v[l+4>>2])>>>0<=G>>>0){break _}if(w[rm(b,G)+132|0]!=1){break _}g=n+1|0;b=B(g,6)+Z|0;c=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[d+4|0]|w[d+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;t[b+1|0]=w[b+1|0]+1;b=zt(v[F>>2],g);t[b+19|0]=w[f+19|0];z[b>>2]=z[f>>2];z[b+4>>2]=z[f+4>>2];z[b+8>>2]=z[f+8>>2];z[b+12>>2]=z[f+12>>2];u[b+30>>1]=x[f+30>>1]}ja:{if(w[d|0]){t[f+16|0]=0;break ja}c=0;if(w[f+16|0]){break X}}ka:{if(!x[f+30>>1]){break ka}b=m&255;u[e+272>>1]=b;c=f+30|0;la=c,ma=x[ie(c,e+272|0)>>1]-b|0,u[la>>1]=ma;if(w[d+3|0]){break ka}t[d+3|0]=15;t[d+5|0]=0}j=z[f>>2];la:{if(j==C(0)){break la}b=m&255;j=C(C(j*C(b>>>0))+z[f+4>>2]);z[f+4>>2]=j;if(w[d+3|0]){break la}ma:{na:{oa:{pa:{if(b>>>0>=2){g=b-1|0;D=C(g|0);if(!(D<=j)){break pa}t[e+272|0]=15;la=e,ma=dh(C(j/D)),t[la+100|0]=ma;b=w[Vb(e+272|0,e+100|0)|0];z[f+4>>2]=j-C(B(b,g)|0);t[d+3|0]=22;c=b<<4;break ma}if(!(j>=C(1))){break oa}break na}if(j>=C(1)){break na}if(!(j<=C(1-b|0))){break oa}t[e+272|0]=15;la=e,ma=dh(C(C(-j)/D)),t[la+100|0]=ma;c=w[Vb(e+272|0,e+100|0)|0];z[f+4>>2]=j+C(B(g,c)|0);t[d+3|0]=22;break ma}if(!(j<=C(-1))){break la}t[e+272|0]=14;la=e,ma=dh(C(-j)),t[la+100|0]=ma;b=w[Vb(e+272|0,e+100|0)|0];z[f+4>>2]=j+C(b>>>0);t[d+3|0]=22;c=b|-16;break ma}t[e+272|0]=15;la=e,ma=dh(j),t[la+100|0]=ma;b=w[Vb(e+272|0,e+100|0)|0];z[f+4>>2]=j-C(b>>>0);t[d+3|0]=22;c=b<<4|15}t[d+5|0]=c}j=z[f+8>>2];qa:{if(j==C(0)){break qa}b=m&255;j=C(C(j*C(b>>>0))+z[f+12>>2]);z[f+12>>2]=j;ra:{if(!w[d+3|0]){sa:{ta:{if(b>>>0>=2){c=b-1|0;D=C(c|0);if(!(D<=j)){break ta}t[e+272|0]=223;la=e,ma=dh(C(j/D)),t[la+100|0]=ma;b=w[Vb(e+272|0,e+100|0)|0];z[f+12>>2]=j-C(B(b,c)|0);t[d+3|0]=2;t[d+5|0]=b;break qa}if(!(j>=C(1))){break sa}break ra}if(j>=C(1)){break ra}if(!(j<=C(1-b|0))){break sa}t[e+272|0]=223;la=e,ma=dh(C(C(-j)/D)),t[la+100|0]=ma;b=w[Vb(e+272|0,e+100|0)|0];z[f+12>>2]=j+C(B(b,c)|0);t[d+3|0]=3;t[d+5|0]=b;break qa}if(!(j<=C(-1))){break qa}t[e+272|0]=14;la=e,ma=dh(C(-j)),t[la+100|0]=ma;b=w[Vb(e+272|0,e+100|0)|0];z[f+12>>2]=j+C(b>>>0);t[d+3|0]=3;t[d+5|0]=b|240;break qa}if(w[d+2|0]|b>>>0<2){break qa}ea=C(j*C(.25));c=b-1|0;D=C(c|0);if(ea>=D){t[e+272|0]=9;la=e,ma=dh(C(j/D))>>>2|0,t[la+100|0]=ma;b=w[Vb(e+272|0,e+100|0)|0];z[f+12>>2]=j-C(B(b,c)<<2);t[d+2|0]=12;t[d+4|0]=b;break qa}if(!(C(1-b|0)>=ea)){break qa}t[e+272|0]=9;la=e,ma=dh(C(C(-j)/D))>>>2|0,t[la+100|0]=ma;b=w[Vb(e+272|0,e+100|0)|0];z[f+12>>2]=j+C(B(b,c)<<2);t[d+2|0]=13;t[d+4|0]=b;break qa}t[e+272|0]=15;la=e,ma=dh(j),t[la+100|0]=ma;b=w[Vb(e+272|0,e+100|0)|0];z[f+12>>2]=j-C(b>>>0);t[d+3|0]=2;t[d+5|0]=b|240}ua:{va:{wa:{xa:{ya:{za:{Aa:{b=w[d+3|0];switch(b|0){case 4:break ua;case 0:break Aa;default:break za}}Ba:{b=w[f+23|0];if(!b){b=w[f+24|0];if(b){break Ba}if(!x[f+32>>1]){break ua}c=f+32|0;break ya}t[d+3|0]=5;t[d+5|0]=b;if(!x[f+32>>1]){break ua}break xa}t[d+3|0]=8;t[d+5|0]=b;if(x[f+32>>1]){break xa}break ua}if(!x[f+32>>1]){break ua}c=f+32|0;if(b){break wa}}t[d+3|0]=4;break va}c=f+32|0}t[d+2|0]=11}u[e+272>>1]=B(w[f+27|0],(m&255)-1|0);la=f,ma=x[f+32>>1]-x[Rc(c,e+272|0)>>1]|0,u[la+32>>1]=ma}u[f+28>>1]=x[f+28>>1]+B(w[f+25|0],m&255)&1023;c=0;if(n&1){break X}b=w[f+18|0];if(!b){break X}g=v[l>>2];if(xh(g,v[l+4>>2])>>>0<b>>>0){break X}g=rm(g,b-1|0);if(!(w[g+142|0]&4)){break X}b=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[o|0]=b;t[o+1|0]=b>>>8;t[o+2|0]=b>>>16;t[o+3|0]=b>>>24;b=w[d+4|0]|w[d+5|0]<<8;t[o+4|0]=b;t[o+5|0]=b>>>8;c=1;b=w[e+65|0];if(!b|w[g+132|0]!=1){break X}t[e+65|0]=b+1}n=n+1|0;b=x[a+480188>>1];continue}}break}ve(c,Eh(Se(Le(e+272|0,16,Eb(w[h+14|0]|w[h+15|0]<<8)&255),0)))}b=ul(v[H>>2],v[H+4>>2]);la=e,ma=Eb(w[h+4|0]|w[h+5|0]<<8),u[la+272>>1]=ma;u[e+64>>1]=1;c=x[ie(e+272|0,e- -64|0)>>1];v[23516]=0;X(713,H|0,b|0,c|0,E&65535);b=v[23516];v[23516]=0;if((b|0)==1){break Q}b=ne((w[k+8|0]|w[k+9|0]<<8)<<16>>16);b=ne(ne((w[h+16|0]|w[h+17|0]<<8)<<16>>16)-b<<16>>16);t[h+16|0]=b;t[h+17|0]=b>>>8}b=h+32|0;continue}break}break M}d=ca&1;if(d){v[23516]=0;g=a+906300|0;b=Id(g,0);Y(287,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break M}v[b+16>>2]=1299020115;v[b+20>>2]=1869112133;v[b+24>>2]=655376;v[b+28>>2]=0;v[e+272>>2]=0;h=b+48|0;c=e+272|0;jV(b+32|0,h,c);v[23516]=0;c=Q(53,c|0,9585)|0;f=v[23516];v[23516]=0;if((f|0)==1){break M}BB(h,c);wb(c);v[23516]=0;c=Q(53,e+80|0,9578)|0;h=v[23516];v[23516]=0;if((h|0)==1){break M}wu(b+80|0,c);wb(c);v[23516]=0;b=Q(53,e- -64|0,9570)|0;c=v[23516];v[23516]=0;if((c|0)==1){break M}BB(Id(g,1)+48|0,b);wb(b)}b=0;while(1){if(x[a+480188>>1]>b>>>0){kB(a,b&65535);c=(b<<5)+a|0;t[c+480288|0]=d;u[c+480284>>1]=b<<8&256;b=b+1|0;continue}break}v[23516]=0;b=Q(1,e+48|0,12133)|0;c=v[23516];v[23516]=0;Ca:{Da:{Ea:{if((c|0)!=1){Gb(a+1298344|0,b);xb(b);v[23516]=0;b=Q(1,e+32|0,12351)|0;c=v[23516];v[23516]=0;if((c|0)==1){break M}Gb(a+1298356|0,b);xb(b);if(_){break Ea}v[23516]=0;b=Q(1,e+16|0,12133)|0;c=v[23516];v[23516]=0;if((c|0)==1){break M}break Da}break M}if(xh(v[l>>2],v[l+4>>2])>>>0<=128){v[23516]=0;b=Q(1,e+16|0,9327)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break Da}break M}v[23516]=0;b=Q(1,e+16|0,14883)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Ca}}Gb(a+1298368|0,b);xb(b);v[a+1298404>>2]=14;Hz(F);$P(s);_P(I);d=1;break m}}c=P()|0;O()|0;Hz(F);break j}$p(e+48|0);continue}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}yt(l);lc(A);kl(q);Ci(p);break c}c=P()|0;O()|0;break j}c=P()|0;O()|0}$P(s);_P(I);break a}c=P()|0;O()|0;xb(b);break a}c=P()|0;O()|0;break a}yb(c);v[23516]=0;c=d&65535;d=W(714,a|0,c|0,n|0)|0;g=v[23516];v[23516]=0;Fa:{Ga:{Ha:{Ia:{if((g|0)==1){break Ia}if(d){break Fa}v[23516]=0;d=W(715,a|0,c|0,n|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Ia}if(d){break Fa}v[23516]=0;d=W(716,a|0,c|0,n|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Ia}if(d){break Fa}v[23516]=0;d=Q(717,(B(c,104)+a|0)+484380|0,n|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Ia}if(d){break Fa}v[23516]=0;d=Q(1,e+448|0,16262)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Ha}g=v[F>>2];v[23516]=0;U(384,g|0,2,d|0);g=v[23516];v[23516]=0;if((g|0)==1){break Ga}xb(d);break Fa}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;xb(d);break e}Ja:{Ka:{La:{E=B(c,104)+a|0;if(w[E+484414|0]&64){d=x[i>>1];if(Yh(d)){break La}}d=v[l>>2];if(xh(d,v[l+4>>2])>>>0<=c>>>0){break Ka}if(w[rm(d,c)+132|0]!=2){break Ka}c=x[i>>1];if(!Yh(c)){break Ka}u[i>>1]=c+1;break Ka}c=d+1|0;u[i>>1]=c;G=B(c&65535,104)+a|0;o=G+484380|0;f=E+484380|0;d=v[f>>2];g=v[f+20>>2];Ma:{if(!Vd(d,g)){break Ma}h=x[f+34>>1];if((f|0)==(o|0)|(Hd(h)|0)!=2){break Ma}c=(f|0)==(o|0);if(!(Vd(v[o>>2],v[o+20>>2])?c:1)){break Ma}Vd(v[f>>2],v[f+20>>2]);if(!c){g=vt(d,Qm(h))}h=v[f+20>>2];if(!(h?g:0)){if(!c){sz(g)}break Ma}Na:{Oa:{switch(Qm(x[f+34>>1])-1|0){case 1:d=g;c=h;m=v[f+20>>2];k=v[f>>2];while(1){if(k){u[d>>1]=x[m>>1];u[c>>1]=x[m+2>>1];m=m+4|0;c=c+2|0;d=d+2|0;k=k-1|0;continue}break};break Na;case 0:break Oa;default:break Na}}d=g;c=h;m=v[f+20>>2];k=v[f>>2];while(1){if(k){t[d|0]=w[m|0];t[c|0]=w[m+1|0];m=m+2|0;c=c+1|0;d=d+1|0;k=k-1|0;continue}break}}d=_n(o,f);u[d+34>>1]=x[d+34>>1]&65471;v[o+20>>2]=g;g=_n(f,f);u[g+34>>1]=x[g+34>>1]&65471;v[f+20>>2]=h;h=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(h|0)){f=v[c+104>>2];if(!((f|0)!=(d|0)&(f|0)!=(g|0))){v[c+88>>2]=v[c+88>>2]&-65}c=c+872|0;continue}break}rj(d,a);rj(g,a)}v[23516]=0;c=Q(53,e+432|0,6323)|0;d=v[23516];v[23516]=0;if((d|0)==1){break Ja}xe(G+484423|0,c);wb(c);v[23516]=0;c=Q(53,e+416|0,6226)|0;d=v[23516];v[23516]=0;if((d|0)==1){break f}xe(E+484423|0,c);wb(c)}yb(n);dc(s);g=0;continue}break}c=P()|0;O()|0;break e}c=P()|0;O()|0}yb(n)}dc(s);break a}hb=e+672|0;return d|0}c=P()|0;O()|0}yt(l);lc(A);kl(q);Ci(p);S(c|0);L()}function Jt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ha=0,ia=0,ka=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ca=0,Da=0,Ea=C(0),Fa=0,Ga=0,Ha=0,Ia=C(0);i=hb-192|0;hb=i;$=Lb(a);q=i+160|0;t[q+26|0]=0;u[q+24>>1]=0;v[q+16>>2]=0;v[q+20>>2]=-1;v[q+8>>2]=-1;v[q+12>>2]=-1;v[q>>2]=0;v[q+4>>2]=0;M=v[d+16>>2];a=w[d+6|0];na=b+484360|0;e=v[na>>2];oa=(Fa=a,Ga=w[b+484376|0],Ha=pj(e,v[b+484364>>2])>>>0>a>>>0,Ha?Fa:Ga);a=oa&255;I=wj(e,a);v[23516]=0;r=Q(592,i+128|0,b|0)|0;e=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){l=v[r+4>>2];v[23516]=0;J=W(593,i+88|0,b|0,a|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break i}ca=c&7;h=v[d>>2];a=x[d+4>>1];while(1){e=a&65535;if(Oc(v[I>>2],v[I+4>>2])>>>0<=e>>>0){break g}v[23516]=0;e=Q(314,I|0,e|0)|0;n=v[23516];v[23516]=0;if((n|0)==1){break h}if(e){break g}a=a+1|0;h=0;continue}}k=P()|0;O()|0;break d}k=P()|0;O()|0;break e}k=P()|0;O()|0;v[d>>2]=h;u[d+4>>1]=a;break f}v[d>>2]=h;u[d+4>>1]=a;v[l+52>>2]=h;K=l+48|0;v[K>>2]=h;v[q+16>>2]=h;u[l+74>>1]=a;u[l+72>>1]=a;u[q+24>>1]=a;pa=ce(i+80|0);j:{if((ca|0)!=7){break j}a=hb-16|0;hb=a;e=a+8|0;Ab(e,pa,1);fo(e);hb=a+16|0;if((M|0)!=2){break j}a=v[I>>2];n=Oc(a,v[I+4>>2]);e=x[d+12>>1];if(n>>>0<=e>>>0){break j}n=v[b+484344>>2];f=v[b+484348>>2];a=x[$b(a,e)>>1];if(!te(n,f,a)){break j}e=Xb(n,a);n=v[d+8>>2];if(y[e+12>>2]<=n>>>0){break j}a=0;k=ed(v[e>>2],v[v[e+48>>2]+12>>2],n,0);e=x[b+480188>>1];n=v[r+8>>2];f=x[b+480192>>1];while(1){if((a|0)==(e|0)){break j}k:{l:{m:{n:{g=w[k|0];switch(g-253|0){case 1:case 2:break l;case 0:break n;default:break m}}if(f){break l}}if(!Wc(g)){break k}if(mm(w[k+2|0],w[k+3|0])){break k}}Fa=_e(n,a),Ga=-1,v[Fa>>2]=Ga}k=k+6|0;a=a+1|0;continue}}aa=c&1;if(aa){NN(l+223860|0)}V=l+74|0;wa=l+223872|0;xa=(M|0)!=3;N=l+80|0;ya=b+901692|0;za=b+902204|0;ha=l+44|0;ia=l+223860|0;ba=l+20|0;H=b+1074312|0;qa=l+616|0;ea=32768;ra=A[d+8>>3];o(+ra);a=j(1)|0;Aa=j(0)|0;ka=a;_=b+480188|0;G=b+480180|0;ma=b+484348|0;sa=(M|0)!=2;Ca=l+223884|0;ta=b+480192|0;Da=(ca|0)!=7;d=0;o:{p:{q:{r:{s:{t:while(1){n=ka;while(1){MN(i+16|0,v[G>>2],x[_>>1],l,p&1);if(!(!(A[r+24>>3]>=ra)|xa)){break p}g=w[i+16|0];a=65535;f=v[I>>2];h=Oc(f,v[I+4>>2]);e=x[l+72>>1];if(h>>>0>e>>>0){a=x[$b(f,e)>>1]}u[l+70>>1]=a;f=v[b+484344>>2];h=v[ma>>2];k=a&65535;if(!(te(f,h,k)|(k|0)==65535|sa)&(e|0)==(n&65535)){break p}u:{v:{while(1){a=a&65535;if(vf(f,h)>>>0>a>>>0){break u}k=x[l+72>>1];w:{x:{if((a|0)!=65535){e=v[I>>2];m=Oc(e,v[I+4>>2]);if(k>>>0<m>>>0){break x}}a=x[I+28>>1];if((k|0)==(a|0)){break u}e=v[I>>2];m=Oc(e,v[I+4>>2]);break w}a=k+1|0}u[l+72>>1]=a;k=65535;s=m;m=a&65535;if(s>>>0>m>>>0){k=x[$b(e,m)>>1]}u[l+74>>1]=a;u[l+70>>1]=k;y:{if(!te(f,h,k&65535)){e=Qp(i+16|0,qa);v[23516]=0;a=ga(594,J|0,a&65535,0,e|0,(g|0)!=0|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break y}if(a){break v}h=v[ma>>2];f=v[b+484344>>2]}a=x[l+70>>1];continue}break}k=P()|0;O()|0;break f}if(M>>>0<=1){a=x[l+72>>1];v[q+8>>2]=0;u[q+20>>1]=a;if(!M){break u}}v[23516]=0;a=W(595,J|0,V|0,K|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break q}if(!a){break u}A[q>>3]=A[r+24>>3];v[23516]=0;R(596,$|0,q|0);a=v[23516];v[23516]=0;if((a|0)==1){break q}v[q+16>>2]=v[K>>2];u[q+24>>1]=x[V>>1];v[23516]=0;Y(597,r|0);a=v[23516];v[23516]=0;if((a|0)==1){break q}a=x[l+74>>1];u[l+72>>1]=a;Fa=l,Ga=x[$b(v[I>>2],a)>>1],u[Fa+70>>1]=Ga;v[l+52>>2]=v[l+48>>2]}if(x[V>>1]==65535){break o}a=v[b+484344>>2];e=x[l+70>>1];if(!te(a,v[ma>>2],e)){a=x[l+72>>1];if((a|0)==x[I+28>>1]){if(!M){break o}v[23516]=0;a=W(595,J|0,V|0,K|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break q}if(!a){break o}A[q>>3]=A[r+24>>3];v[23516]=0;R(596,$|0,q|0);a=v[23516];v[23516]=0;if((a|0)==1){break q}v[q+16>>2]=v[K>>2];u[q+24>>1]=x[V>>1];v[23516]=0;Y(597,r|0);a=v[23516];v[23516]=0;if((a|0)==1){break q}v[l+52>>2]=v[l+48>>2];continue}u[V>>1]=a+1;continue}f=v[K>>2];if(f>>>0>=y[Xb(a,e)+12>>2]){v[K>>2]=0;f=0}if(!(x[l+72>>1]!=(n&65535)|sa)&(f|0)==(Aa|0)){break p}a=0;if(!((M|0)==3|y[J+28>>2]<ea>>>0)){v[r+24>>2]=0;v[r+28>>2]=2146435072;v[J+28>>2]=0;ea=ea>>>(ea>>>0>256)|0;f=v[K>>2];a=1}e=x[l+72>>1];h=Qp(i+16|0,qa);v[23516]=0;e=ga(594,J|0,e|0,f|0,h|0,(g|0)!=0|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break s}if((a|e)==1){if(M>>>0<=1){u[q+20>>1]=x[l+72>>1];v[q+8>>2]=v[l+48>>2];if(!M){break o}}v[23516]=0;a=W(595,J|0,V|0,K|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break r}if(!a){break o}A[q>>3]=A[r+24>>3];v[23516]=0;R(596,$|0,q|0);a=v[23516];v[23516]=0;if((a|0)==1){break r}v[q+16>>2]=v[K>>2];u[q+24>>1]=x[V>>1];v[23516]=0;Y(597,r|0);a=v[23516];v[23516]=0;if((a|0)==1){break r}v[l+52>>2]=v[l+48>>2];continue}u[q+22>>1]=x[l+72>>1];v[q+12>>2]=v[l+48>>2];KN(b,l,0);k=v[l+48>>2];e=Xb(v[b+484344>>2],x[l+70>>1]);if(k>>>0>=y[e+12>>2]){v[K>>2]=0;k=0}if(g){continue}break}a=0;k=ed(v[e>>2],v[v[e+48>>2]+12>>2],k,0);Ab(i+16|0,H,77);g=zb(v[v[i+16>>2]>>2],v[i+20>>2]);z:{while(1){if(x[_>>1]>a>>>0){A:{if(!(!Ty(k)&(!g|!(w[((a<<5)+b|0)+480281|0]&4)))){Zn((l+B(a,872)|0)+1404|0);break A}if($g(w[k|0])){B:{if(!Sd(w[Ca|0])){break B}e=w[k+1|0];if(e-251>>>0<5|!e){break B}f=w[k+5|0];p=w[k+3|0];h=ek(w[k+2|0],w[k+4|0]);n=i+16|0;t[n|0]=e-1;v[n+4>>2]=h&65535;v[23516]=0;e=Q(598,wa|0,n|0)|0;n=v[23516];v[23516]=0;if((n|0)==1){break z}Fa=e,Ia=C(C(ek(p,f)>>>0)/C(999)),z[Fa>>2]=Ia}Zn((l+B(a,872)|0)+1404|0);break A}e=l+B(a,872)|0;n=e+1408|0;f=w[k+4|0]|w[k+5|0]<<8;t[n|0]=f;t[n+1|0]=f>>>8;n=e+1404|0;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);t[n|0]=f;t[n+1|0]=f>>>8;t[n+2|0]=f>>>16;t[n+3|0]=f>>>24;C:{D:{E:{F:{switch(w[k+3|0]-16|0){case 0:h=w[k+5|0];break E;case 3:break C;case 4:break D;case 1:break F;default:break A}}Ab(i+16|0,H,5);if(!zb(v[v[i+16>>2]>>2],v[i+20>>2])){break A}h=w[k+5|0];if(!h){break A}}IN(b,l,h&255);break A}n=e+1409|0;f=w[n|0];G:{if(!(f|!(v[G>>2]&16777250))){t[n|0]=w[e+1449|0];break G}t[e+1449|0]=f}e=w[k+5|0];n=e&240;if((n|0)!=224){if((n|0)!=96){break A}v[l+24>>2]=v[l+24>>2]+(e&15);break A}if(v[ba>>2]){break A}e=e&15;if(e?0:w[G|0]&2){break A}v[ba>>2]=e+1;break A}e=w[k+5|0];if((e&240)!=224){break A}v[ba>>2]=(e&15)+1}k=k+6|0;a=a+1|0;continue}break}n=bl(l);v[i+16>>2]=1;a=v[Vc(ba,i+16|0)>>2];u[l+68>>1]=65535;v[l+60>>2]=-1;v[l+64>>2]=-1;D=n-1|0;a=n-a|0;F=B(a,1e4);k=0;while(1){if(x[_>>1]<=k>>>0){if(v[G>>2]==4&v[l+40>>2]==65535){break o}v[l+32>>2]=v[b+480216>>2];a=Xb(v[b+484344>>2],x[l+70>>1]);e=v[a+16>>2];if(HN(e,v[a+20>>2])){v[l+32>>2]=e}f=GN(b,l);a=B(f,n);A[r+24>>3]=A[r+24>>3]+ +(a>>>0)/+y[b+24620>>2];v[l>>2]=a+v[l>>2];H:{I:{J:{if(Da){break J}k=0;fa=(d|0)!=0&(d|0)!=(f|0);while(1){if(x[_>>1]<=k>>>0){break J}F=_e(v[r+8>>2],k);K:{if(v[F>>2]==-1){break K}m=l+B(k,872)|0;s=m+1404|0;T=v[m+1316>>2];if(!T){if(Ty(s)){break K}}a=m+1409|0;e=1;L:{M:{E=m+1407|0;switch(w[E|0]-4|0){case 0:case 2:break L;default:break M}}e=w[m+1406|0]==11}D=w[a|0];if(w[m+1405|0]){v[m+1276>>2]=0}g=m+616|0;h=D&15;p=0;N:{if(!Wc(w[s|0])){break N}if(!(!e|!w[F+4|0])){Sy(i+16|0,b,g,T,0);p=v[i+20>>2];v[m+624>>2]=v[i+16>>2];v[m+628>>2]=p}t[m+1418|0]=w[m+1415|0];T=m+1308|0;Z=v[T>>2];p=w[m+1419|0];if(p){Pp(b,g,p,e,1,1)}p=w[s|0];v[23516]=0;ja(599,b|0,g|0,p|0,e|0,1,0,65535);p=v[23516];v[23516]=0;if((p|0)==1){break I}D=D>>>4|0;FN(v[G>>2],x[_>>1],l,k&65535);ua=_e(v[r+8>>2],k);t[ua+4|0]=1;F=w[E|0];O:{if(!((w[a|0]&240)!=208|(F-19&255)>>>0>1)){p=h;if(h>>>0<n>>>0){break O}}p=(F|0)==33?n>>>0>D>>>0?D:0:0}va=v[ba>>2];if(!(!(v[G>>2]&16777250)|(!p|va>>>0<2))){p=B(va-1|0,v[l+24>>2]+v[l+40>>2]|0)+p|0}if(!e){v[ua>>2]=0}P:{if((F|0)==9){break P}Q:{if((F|0)!=19){if((F|0)!=20|(D|0)!=8){break Q}break P}if((D|0)==8){break P}}if(w[m+1406|0]!=2){break N}}v[T>>2]=Z}R:{if(!Wc(w[s|0])){Ab(i+16|0,H,114);if(!zb(v[v[i+16>>2]>>2],v[i+20>>2])){break R}}S:{T:{U:{V:{e=w[E|0];switch(e-42|0){case 1:break S;case 0:break T;case 2:break U;default:break V}}if((e|0)!=10){break S}e=x[l+70>>1];D=v[l+48>>2];v[23516]=0;da(600,b|0,g|0,k&65535,D|0,e|0);e=v[23516];v[23516]=0;if((e|0)!=1){break R}break H}F=rka(w[a|0],0,v[m+692>>2],0);D=kb;e=D>>>8|0;Pn(b,g,Bc((D&255)<<24|F>>>8,e));break R}if(!v[m+720>>2]){break S}v[23516]=0;X(601,r|0,k&65535,d|0,-1);e=v[23516];v[23516]=0;if((e|0)==1){break H}DN(g,w[a|0]);p=v[l+40>>2]-1|0;break R}if(w[m+1406|0]!=15){break R}D=v[m+720>>2];if(!D){break R}e=w[m+1408|0];if(e>>>0>9){break R}W:{if(!e){e=v[m+1280>>2];break W}e=v[Bb(D+68|0,e-1|0)>>2];v[m+1280>>2]=e}Pn(b,g,e)}X:{Y:{Z:{switch(w[s|0]-253|0){case 0:if(x[ta>>1]){break Y}break;case 1:case 2:break Y;default:break Z}}e=w[E|0];if(!((w[a|0]&240)!=192|(e-19&255)>>>0>1)&h>>>0<n>>>0){break Y}D=0;F=e&255;if((F|0)==33&(h|0)!=0&n>>>0>h+p>>>0){break Y}if((F|0)!=25){break X}}e=w[E|0];D=1}T=m+1304|0;F=e&255;_:{if((F|0)!=13){if(w[m+1406|0]!=1){break _}h=m+1408|0}else{h=a}v[T>>2]=w[h|0]<<2}$:{aa:{ba:{if(!v[m+720>>2]|D|F>>>0>45){break ba}Ab(i+16|0,pa,F);if(zb(v[v[i+16>>2]>>2],v[i+20>>2])){break aa}e=w[E|0];if((e|0)!=19){break ba}h=w[a|0]&240;if((h|0)==16){break aa}e=19;if((h|0)==32){break aa}}if(!D){break $}}hP(g);Fa=_e(v[r+8>>2],k),Ga=0,v[Fa>>2]=Ga;break K}if(fa){v[23516]=0;X(601,r|0,k&65535,d|0,-1);e=v[23516];v[23516]=0;if((e|0)==1){break H}e=w[E|0]}ca:{da:{ea:{fa:{ga:{e=e&255;if(e-6>>>0>=2){ha:{switch(e-19|0){case 1:break fa;case 0:break ga;default:break ha}}if(e-35>>>0<2){break da}if((e|0)==45){break ea}if((e|0)!=11){break ca}}if(!w[a|0]&v[G>>2]==1){break ca}e=m+1467|0;h=0;while(1){if((h|0)==(n|0)){break ca}t[e|0]=!h|w[e|0]&254;On(b,g,w[a|0]);h=h+1|0;continue}}e=w[a|0];a=e&15;if(!(v[G>>2]&1048580?1:a)){break ca}h=m+1467|0;t[h|0]=w[h|0]|1;e=e&240;if((e|0)!=176){if((e|0)!=160){break ca}Nn(b,g,a,0);break ca}Mn(b,g,a,0);break ca}ia:{ja:{ka:{a=w[a|0];switch(a-158|0){case 1:break ja;case 0:break ka;default:break ia}}v[23516]=0;X(601,r|0,k&65535,d|0,-1);a=v[23516];v[23516]=0;if((a|0)==1){break H}v[m+704>>2]=v[m+704>>2]&-129;break ca}v[23516]=0;X(601,r|0,k&65535,d|0,-1);a=v[23516];v[23516]=0;if((a|0)==1){break H}a=v[m+704>>2];v[m+704>>2]=a|128;if(v[g+4>>2]){break ca}e=v[m+692>>2];if(!e){break ca}if(!(Fa=Wc(w[s|0]),Ga=1,Ha=a&2,Ha?Fa:Ga)){break ca}v[g>>2]=-1;v[g+4>>2]=e-1;break ca}if((a&240)!=112|a>>>0<115){break ca}eP(g,a,v[G>>2]);break ca}BN(g,w[a|0]);break ca}v[23516]=0;a=k&65535;X(601,r|0,a|0,d|0,-1);e=v[23516];v[23516]=0;if((e|0)==1){break H}AN(b,a,l,0)}h=m+1467|0;a=w[h|0]|1;t[h|0]=a;la:{ma:{na:{oa:{pa:{E=m+1406|0;switch(w[E|0]-3|0){case 11:break ma;case 0:case 1:break na;case 3:break oa;case 2:break pa;default:break la}}a=w[m+1408|0];Ab(i+16|0,H,41);Nn(b,g,a,zb(v[v[i+16>>2]>>2],v[i+20>>2]));break la}a=w[m+1408|0];Ab(i+16|0,H,41);Mn(b,g,a,zb(v[v[i+16>>2]>>2],v[i+20>>2]));break la}e=w[m+1408|0];qa:{if(e){break qa}Ab(i+16|0,H,41);e=0;if(!zb(v[v[i+16>>2]>>2],v[i+20>>2])){break qa}e=w[m+1450|0];if(!e){break la}}e=w[E|0]==3?e<<4:e;a=0;while(1){if((a|0)==(n|0)){break la}t[h|0]=!a|w[h|0]&254;On(b,g,e&255);a=a+1|0;continue}}e=w[m+1408|0];if(e>>>0>1){break la}t[h|0]=a&247|!e<<3}if(w[h|0]&8){break K}a=1;ra:{sa:{ta:{e=w[s+3|0];if(e>>>0>28){break ta}g=1<<e;if(g&92){break ra}if(!(g&268959744)){break ta}if((w[s+5|0]-16&255)>>>0<32){break ra}break sa}if(e-38>>>0<4){break ra}}a=(w[s+2|0]-11&255)>>>0<3}if(a){e=_e(v[r+8>>2],k);a=v[e>>2];v[e>>2]=a+n;v[23516]=0;X(601,r|0,k&65535,f|0,a+p|0);a=v[23516];v[23516]=0;if((a|0)!=1){break K}k=P()|0;O()|0;break f}a=_e(v[r+8>>2],k);v[a>>2]=v[a>>2]+(n-p|0)}k=k+1|0;continue}}p=zN(b,l,I,0);d=f;continue t}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}g=l+B(k,872)|0;h=g+1404|0;ua:{if(Ty(h)){break ua}p=g+616|0;fa=g+1409|0;f=w[fa|0];T=g+1407|0;m=w[T|0];va:{wa:{if(!aa){break wa}s=w[h|0];e=s;E=g+1405|0;Z=w[E|0];if(Z){t[g+1415|0]=0;t[g+1419|0]=Z;Fa=_e(v[r+8>>2],k),Ga=255,t[Fa+5|0]=Ga;e=w[h|0]}if(Wc(e)){t[g+1415|0]=s;gP(p);e=w[h|0]}xa:{if(!(Fa=1,Ga=Wc(e),Ha=w[E|0],Ha?Fa:Ga)){break xa}Z=g+1419|0;e=w[Z|0];ya:{if(!e){e=0;break ya}if(x[ta>>1]<e>>>0){break ya}E=v[((e<<2)+b|0)+900380>>2];if(!E|!(t[E+15|0]&1)){break ya}Yp(p,v[E+8>>2],b);e=w[Z|0]}e=nq(b,s,e&255);if(!e){break xa}e=B(e,104)+b|0;if(!(w[e+484414|0]&32)){break xa}Yp(p,x[e+484408>>1],b)}za:{Aa:{Ba:{e=w[g+1406|0];switch(e-1|0){case 1:break wa;case 2:case 3:break Aa;case 0:break Ba;default:break za}}Fa=_e(v[r+8>>2],k),Ga=w[g+1408|0],t[Fa+5|0]=Ga;break wa}e=w[g+1408|0];if(!e){break wa}t[g+1450|0]=e;break wa}if((e|0)!=11){break wa}e=w[g+1408|0];if(!e){break wa}s=i+16|0;Ry(s,b,w[h+3|0],e,0);u[g+1384>>1]=x[i+16>>1];if(w[Re(s)|0]){break va}}Ca:{Da:{Ea:{Fa:{Ga:{switch(m-12|0){case 0:yN(b,l,k&65535);break Ca;case 2:e=xN(b,l,k&65535,f);if((e|0)==-1){break Ca}v[l+60>>2]=e;break Ca;case 5:Ab(i+16|0,H,5);if(zb(v[v[i+16>>2]>>2],v[i+20>>2])){break Ca}h=B(Ln(b,x[l+70>>1],v[l+48>>2],k&65535,0),1e4);Ha:{if(!aa|!(v[G>>2]&16777250)){break Ha}if(h>>>0>=1e4){t[g+1451|0]=(h>>>0)/1e4;break Ha}h=B(w[g+1451|0],1e4)}Ia:{if(h>>>0>319999){break Ia}s=(h>>>0)/1e4|0;h=B(F,s&15);e=v[ha>>2];if((s&240)==16){h=e+h|0;break Ia}h=e-h|0;h=e>>>0<h>>>0?0:h}v[ha>>2]=h;e=v[b+8>>2];h=v[e+20>>2];e=v[e+24>>2];Ab(i+16|0,H,8);Ko(ha,B(h,1e4),zb(v[v[i+16>>2]>>2],v[i+20>>2])?255e4:B(e,1e4));break Ca;case 8:Ja:{switch((f&240)-144>>>4|0){case 0:if(f>>>0>145){break Ca}v[g+704>>2]=v[g+704>>2]&-257|((f|0)==145)<<8;break Ca;case 1:t[g+1452|0]=f&15;break Ca;case 2:break Fa;case 6:break Ja;default:break Ca}}t[g+1460|0]=f&15;break Ca;case 1:case 3:case 4:case 6:break Ca;case 7:break Ga;default:break Da}}e=f&240;if((e|0)==240){break Ea}if((e|0)!=96){break Ca}}Qy(b,l,p,f&15);break Ca}t[g+1460|0]=f&15;break Ca}if((m|0)!=28|(f&240)!=160){break Ca}Ab(i+16|0,H,58);if(zb(v[v[i+16>>2]>>2],v[i+20>>2])){break Ca}t[g+1452|0]=f&15}if(!aa){break ua}Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{switch(m-2|0){case 0:if(!f){break Ka}Ab(i+16|0,H,90);if(!zb(v[v[i+16>>2]>>2],v[i+20>>2])){t[g+1428|0]=f}t[g+1427|0]=f;break va;case 1:if(!f){break Ka}Ab(i+16|0,H,90);if(!zb(v[v[i+16>>2]>>2],v[i+20>>2])){t[g+1427|0]=f}t[g+1428|0]=f;break va;case 2:if(!f){break Ka}u[g+1384>>1]=f;break va;case 8:if(!f){break Ka}v[g+1280>>2]=f<<8;break va;case 4:case 9:if(!f){break Ka}t[g+1425|0]=f;break va;case 11:Fa=_e(v[r+8>>2],k),Ga=f,t[Fa+5|0]=Ga;break va;case 21:e=v[G>>2];f=f<<(!(e&59593760)&f<<24>>24>=0);h=f&255;if(h>>>0<=128){v[N>>2]=h<<1;break va}if(e&16777250){break va}v[N>>2]=256;break va;case 22:Ab(i+16|0,H,9);Ta:{if(zb(v[v[i+16>>2]>>2],v[i+20>>2])){e=g+1433|0;if(f){t[e|0]=f;break Ta}f=w[e|0];break Ta}if(f){t[l+1433|0]=f;break Ta}f=w[l+1433|0]}e=f&240;h=f&15;Ua:{if(!(!e|(h|0)!=15)){f=e>>>4<<!(v[G>>2]&59593760);e=v[N>>2]+(f<<1)|0;break Ua}if(!(!h|(e|0)!=240)){f=h<<(v[G>>2]&59593760?1:2);e=v[N>>2]-f|0;break Ua}if(e){f=(f>>>3&30)<<!(v[G>>2]&59593760);e=v[N>>2]+B(a,f)|0;break Ua}f=h<<(v[G>>2]&59593760?1:2);e=v[N>>2]-B(a,f)|0}v[N>>2]=e;me(N,0,256);break va;case 19:if(f>>>0>64){break va}v[g+1364>>2]=f;break va;case 20:e=g+1432|0;Va:{if(f){t[e|0]=f;break Va}f=w[e|0]}m=f&255;s=g+1364|0;e=v[s>>2];E=f&240;h=f&15;Wa:{if(!(!E|(h|0)!=15)){v[i+16>>2]=e+(m>>>4|0);break Wa}if(!(!h|(E|0)!=240)){v[i+16>>2]=e-h;break Wa}if(h){v[i+16>>2]=e-B(a,h);break Wa}v[i+16>>2]=e+B(a,m>>>4|0)}me(i+16|0,0,64);v[s>>2]=v[i+16>>2];break va;case 7:lm(b,p,f,8);break va;case 29:case 30:break La;case 25:break Ma;case 6:break Na;case 24:break Oa;case 3:break Pa;case 5:break Qa;case 18:break Ra;case 17:break Sa;default:break va}}if(f>>>0>15){break Ra}e=(f&1)<<14;m=x[_>>1];h=0;while(1){if((h|0)==(m|0)){break Ra}s=l+B(h,872)|0;v[s+704>>2]=(e|v[s+704>>2]&-16385)^16384;h=h+1|0;continue}}if((f&240)!=128){break va}lm(b,p,f&15,4);break va}if(f){t[g+1425|0]=f}f=0}al(p,f);break va}wN(b,p,f);break va}vN(p,f);break va}uN(p,f);break va}Xa:{if(f<<24>>24>=0){e=ue(ya,w[g+1460|0]);break Xa}e=ue(za,f&127)}h=w[fa|0];v[23516]=0;la(602,b|0,l|0,k&65535,0,e|0,h|0);e=v[23516];v[23516]=0;if((e|0)!=1){break va}k=P()|0;O()|0;break f}f=0}Ya:{Za:{switch(w[g+1406|0]-2|0){case 0:lm(b,p,w[g+1408|0],6);break Ya;case 5:Ab(i+16|0,H,53);e=w[g+1408|0];if(zb(v[v[i+16>>2]>>2],v[i+20>>2])){t[g+1439|0]=e&15;break Ya}al(p,e<<4);break Ya;case 6:break Za;default:break Ya}}al(p,w[g+1408|0])}_a:{$a:{ab:{bb:{cb:{e=w[T|0];switch(e-5|0){case 1:break _a;case 3:break ab;case 0:case 2:break bb;default:break cb}}switch(e-26|0){case 1:break $a;case 0:break bb;default:break _a}}db:{if(v[G>>2]&16777248){e=n;if(!(w[b+480208|0]&4)){break db}}e=a}h=w[g+1439|0];Ab(i+16|0,H,21);g=g+1435|0;m=w[g|0];e=B(e,h);Fa=g,Ga=(zb(v[v[i+16>>2]>>2],v[i+20>>2])?e<<2:e)+m|0,t[Fa|0]=Ga;break _a}eb:{if(v[G>>2]&16777248){e=n;if(!(w[b+480208|0]&4)){break eb}}e=a}h=w[g+1442|0];Ab(i+16|0,H,21);g=g+1436|0;m=w[g|0];e=B(e,h);Fa=g,Ga=(zb(v[v[i+16>>2]>>2],v[i+20>>2])?e<<2:e)+m|0,t[Fa|0]=Ga;break _a}e=g+1437|0;t[e|0]=w[e|0]+B(D,w[g+1445|0]);sN(b,p)}Ab(i+16|0,H,78);if(!zb(v[v[i+16>>2]>>2],v[i+20>>2])){break ua}e=f&255;if(!e){break ua}rN(p,e)}k=k+1|0;continue}}break}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}k=P()|0;O()|0;break f}t[q+26|0]=1}fb:{if((ca|0)!=7){break fb}a=0;e=b+480188|0;while(1){if(x[e>>1]<=a>>>0){break fb}gb:{if(v[_e(v[r+8>>2],a)>>2]==-1){break gb}v[23516]=0;X(601,r|0,a&65535,d|0,-1);n=v[23516];v[23516]=0;if((n|0)!=1){break gb}k=P()|0;O()|0;break f}a=a+1|0;continue}}if(w[q+26|0]){u[q+20>>1]=x[l+72>>1];v[q+8>>2]=v[l+48>>2]}A[q>>3]=A[r+24>>3];v[23516]=0;R(596,$|0,q|0);a=v[23516];v[23516]=0;if((a|0)!=1){if(!aa){break a}if(!(M?w[q+26|0]:1)){break c}n=Dy(i+48|0);if(Sd(w[ia+24|0])){eN(n,ia)}Oy(ia);a=pc(b+1074376|0,l,614);f=0;while(1){if((f|0)==256){Bm(a+223848|0,l+223848|0);d=a+223860|0;f=w[d+24|0];e=l+223860|0;hb:{if((Sd(w[e+24|0])|0)==(f|0)){if(!f){break hb}f=gc(d);Ws(d,v[f>>2]);v[d>>2]=v[e>>2];v[d+4>>2]=v[e+4>>2];v[d+8>>2]=v[e+8>>2];ib:{if(!v[Db(d)>>2]){v[d>>2]=f;break ib}v[v[f>>2]+8>>2]=f;f=gc(e);v[e>>2]=f;v[f>>2]=0;Fa=Db(e),Ga=0,v[Fa>>2]=Ga}d=d+12|0;f=gc(d);Vs(d,v[f>>2]);e=e+12|0;v[d>>2]=v[e>>2];v[d+4>>2]=v[e+4>>2];v[d+8>>2]=v[e+8>>2];jb:{if(!v[Db(d)>>2]){v[d>>2]=f;break jb}v[v[f>>2]+8>>2]=f;d=gc(e);v[e>>2]=d;v[d>>2]=0;Fa=Db(e),Ga=0,v[Fa>>2]=Ga}break hb}if(f){Oy(d);break hb}eN(d,e)}}else{d=B(f,872);Mp((d+a|0)+616|0,(d+l|0)+616|0);f=f+1|0;continue}break}Ny(a);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];kb:{lb:{d=v[b+1298300>>2];if(!vd(d)){break lb}v[23516]=0;Y(603,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){break lb}break kb}while(1){if(x[b+480188>>1]<=a>>>0){a=Sz(i+16|0);Fa=i,Ga=Ei(v[n+12>>2]),v[Fa+8>>2]=Ga;e=b+906300|0;p=tf(n+12|0);while(1){d=v[i+8>>2];if(!Fg(d,p)){mb:{p=250;d=a;nb:{while(1){if(p>>>0>=32){if(v[a>>2]){a=1;break nb}else{p=p-32|0;a=a+4|0;continue}}break}a=(v[d+28>>2]&67108863)!=0}if(!a){break mb}a=0;while(1){if((a|0)==250){break mb}Ab(i,d,a);ob:{if(!zb(v[v[i>>2]>>2],v[i+4>>2])){break ob}f=v[Id(e,a)>>2];g=v[v[f>>2]+180>>2];v[23516]=0;Y(g|0,f|0);f=v[23516];v[23516]=0;if((f|0)!=1){break ob}break kb}a=a+1|0;continue}}Fa=i,Ga=Ei(v[n>>2]),v[Fa>>2]=Ga;a=tf(n);while(1){d=v[i>>2];if(Fg(d,a)){d=sd(d);f=gc(d);Fa=Id(e,w[d|0]),Ia=z[f>>2],z[Fa+144>>2]=Ia;Ig(i);continue}else{Op(n);break b}}}f=sd(d);N=Db(f);pb:{g=w[f|0];d=v[Id(e,g)>>2];if(d){Ab(i,a,g);if(!zb(v[v[i>>2]>>2],v[i+4>>2])){v[23516]=0;Q(604,a|0,g|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break pb}g=v[v[d>>2]+176>>2];v[23516]=0;R(g|0,d|0,-1);g=v[23516];v[23516]=0;if((g|0)==1){break pb}}Ea=z[N>>2];f=v[f+4>>2];g=v[v[d>>2]+44>>2];v[23516]=0;Ba(g|0,d|0,f|0,C(Ea));d=v[23516];v[23516]=0;if((d|0)==1){break pb}}Ig(i+8|0);continue}break}break kb}d=B(a,872)+b|0;e=w[d+1075791|0];if(e){t[d+1075794|0]=e}d=_e(v[r+8>>2],a);if(!((ca|0)==7|w[d+5|0]==255)){t[i+16|0]=64;Fa=(B(a,872)+b|0)+1075680|0,Ga=w[Vb(d+5|0,i+16|0)|0]<<2,v[Fa>>2]=Ga}qb:{e=B(a,872)+b|0;d=v[e+1075096>>2];rb:{if(!d|!(w[d+35|0]&2)){break rb}f=v[b+1298300>>2];if(!vd(f)){break rb}v[23516]=0;ka=f;f=a&65535;U(605,ka|0,f|0,d+68|0);d=v[23516];v[23516]=0;if((d|0)==1){break qb}d=v[b+1298300>>2];v[23516]=0;U(606,d|0,f|0,1);d=v[23516];v[23516]=0;if((d|0)==1){break qb}}v[e+1075008>>2]=0;a=a+1|0;continue}break}}k=P()|0;O()|0;Op(n);break f}k=P()|0;O()|0}_s(J)}pN(r)}Ci($);S(k|0);L()}if((c|0)==3){break b}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2]}a=oa&255;if((a|0)==w[b+484376|0]){break a}Dj(na,a)}if(c&9){a=b+1298264|0;if(v[a>>2]){hO(a);b=v[a>>2];Sj(a);Jb(b);Fa=Db(a),Ga=0,v[Fa>>2]=Ga;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[J>>2];v[a+4>>2]=v[J+4>>2];b=Db(J);Fa=Db(a),Ga=v[b>>2],v[Fa>>2]=Ga;v[b>>2]=0;v[J>>2]=0;v[J+4>>2]=0;a=a+12|0;c=gc(a);Sp(a,v[c>>2]);b=J+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];sb:{if(!v[Db(a)>>2]){v[a>>2]=c;break sb}v[v[c>>2]+8>>2]=c;a=gc(b);v[b>>2]=a;v[a>>2]=0;Fa=Db(b),Ga=0,v[Fa>>2]=Ga}}_s(J);pN(r);hb=i+192|0}function eS(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,A=C(0),D=C(0),E=0,F=0,G=0,H=0,I=C(0),J=C(0),K=0,M=C(0),N=C(0),O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=C(0),_=C(0),$=0,ba=C(0),ca=C(0),da=0,ea=0,fa=C(0),ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;U=hb-16|0;hb=U;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;Q=v[a+1420>>2];d=(Q|0)>0?Q:0;while(1){if((d|0)!=(E|0)){v[(B(E,20)+a|0)+1436>>2]=0;E=E+1|0;continue}break}b:{c:{d:{if((Q|0)>3){break d}E=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{h=b+d|0;if(w[h|0]!=79){break f}if(Qb(h,93576,4)){break f}g=d+26|0;if((g|0)>=(c|0)){break e}j=d+27|0;i=b+g|0;f=w[i|0];if((j+f|0)>=(c|0)){break e}k=f+27|0;E=0;e=0;while(1)if((e|0)==(f|0)){e=0;while(1){f=22;if((E|0)!=22){e=bx(e,w[(d+E|0)+b|0]);E=E+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;e=bx(e,0);continue}break}v[a+1420>>2]=Q+1;f=B(Q,20)+a|0;v[f+1432>>2]=e;v[f+1428>>2]=k-26;v[f+1424>>2]=w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24);e=w[(g+w[i|0]|0)+b|0]==255?-1:w[h+6|0]|w[h+7|0]<<8|(w[h+8|0]<<16|w[h+9|0]<<24);v[f+1436>>2]=g;v[f+1440>>2]=e;Q=v[a+1420>>2];if((Q|0)!=4){break f}Q=4;break d}else{k=w[(e+j|0)+b|0]+k|0;e=e+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(Q|0)?d:Q;while(1){if((d|0)==(i|0)){break b}E=0;f=B(d,20)+a|0;n=f+1428|0;h=v[n>>2];k=v[f+1436>>2];j=c-k|0;g=(h|0)<(j|0)?h:j;l=(g|0)>0?g:0;da=f+1432|0;e=v[da>>2];while(1){if((l|0)!=(E|0)){e=bx(e,w[(k+E|0)+b|0]);E=E+1|0;continue}break}v[n>>2]=h-g;v[da>>2]=e;if((h|0)<=(j|0)){h=e;e=f+1424|0;if((h|0)==v[e>>2]){v[a+1380>>2]=-1;v[a+992>>2]=0;v[a+1420>>2]=-1;b=v[(B(d,20)+a|0)+1440>>2];v[a+1060>>2]=b;v[a+1064>>2]=(b|0)!=-1;E=g+k|0;break c}f=Q-1|0;v[a+1420>>2]=f;f=B(f,20)+a|0;v[e+16>>2]=v[f+1440>>2];h=f+1432|0;g=v[h+4>>2];v[e+8>>2]=v[h>>2];v[e+12>>2]=g;f=f+1424|0;h=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=h;Q=v[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=E}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!UH(a)){v[f>>2]=0;c=0;break a}qa=U+12|0;da=hb-16|0;hb=da;v[a+1504>>2]=0;v[a+1508>>2]=0;h:{if(v[a+96>>2]){break h}i:{j:{k:{if(v[a+1380>>2]!=-1){break k}c=Ye(a);if(v[a+96>>2]){break i}if((c|0)!=79){break j}if((Ye(a)|0)!=103){break j}if((Ye(a)|0)!=103){break j}if((Ye(a)|0)!=83){break j}if(!TH(a)){break i}if(!(t[a+1375|0]&1)){break k}t[a+1376|0]=0;v[a+1384>>2]=0;bc(a,32);break i}k=_w(a);break i}bc(a,30)}if(!k){break h}if(mc(a,1)){bc(a,35);break h}s=da;l:{m:{if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){c=mc(a,am(v[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=v[a+408>>2]){break h}v[da+12>>2]=c;k=B(c,6)+a|0;if(!w[k+412|0]){h=v[a+112>>2];g=h>>1;break m}h=v[a+116>>2];g=h>>1;c=mc(a,1);j=mc(a,1);if(c|!w[k+412|0]){break m}v[U+4>>2]=h-v[a+112>>2]>>2;c=v[a+112>>2]+h>>2;break l}aa(6328,13226,3152,10753);L()}v[U+4>>2]=0;c=g}v[s+8>>2]=c;n:{if(!(!w[k+412|0]|j)){c=B(h,3);v[U+8>>2]=c-v[a+112>>2]>>2;h=c+v[a+112>>2]>>2;break n}v[U+8>>2]=g}v[da+4>>2]=h;h=1}if(h){E=v[U+4>>2];la=v[U+8>>2];ka=v[da+4>>2];O=hb-2368|0;hb=O;F=v[a+404>>2];oa=B(v[da+12>>2],6)+a|0;G=w[oa+413|0];R=F+B(G,40)|0;V=v[((w[oa+412|0]<<2)+a|0)+104>>2];ha=V>>1;sa=0-ha|0;o:{while(1){c=v[a+4>>2];if((c|0)>(n|0)){c=w[(v[R+4>>2]+B(n,3)|0)+2|0];P=(O+1344|0)+(n<<2)|0;v[P>>2]=0;h=w[(c+R|0)+9|0];if(!x[((h<<1)+a|0)+132>>1]){bc(a,21);c=0;break o}g=v[a+260>>2];p:{q:{if(!mc(a,1)){break q}c=2;k=v[((n<<2)+a|0)+996>>2];g=g+B(h,1596)|0;r=v[(w[g+1588|0]<<2)+72956>>2];h=am(r)-1|0;ta=k,ua=mc(a,h),u[ta>>1]=ua;ta=k,ua=mc(a,h),u[ta+2>>1]=ua;H=g+82|0;W=g+65|0;S=g+49|0;T=g+33|0;K=g+1|0;o=0;while(1){if(w[g|0]>o>>>0){p=w[o+K|0];q=w[p+S|0];l=-1<<q;X=w[p+T|0];r:{if(!q){i=0;break r}h=v[a+124>>2]+B(w[p+W|0],2096)|0;if(v[a+1396>>2]<=9){Uk(a)}j=v[a+1392>>2];i=u[(h+((j&1023)<<1)|0)+36>>1];s:{if((i|0)>=0){s=j;i=i&65535;j=w[i+v[h+8>>2]|0];v[a+1392>>2]=s>>>j;j=v[a+1396>>2]-j|0;v[a+1396>>2]=(j|0)>0?j:0;i=(j|0)>=0?i:-1;break s}i=$l(a,h)}if(!w[h+23|0]){break r}i=v[v[h+2088>>2]+(i<<2)>>2]}ea=l^-1;h=c+X|0;while(1){if((c|0)!=(h|0)){l=0;j=u[(H+(p<<4)|0)+((i&ea)<<1)>>1];t:{if((j|0)<0){break t}j=v[a+124>>2]+B(j&65535,2096)|0;if(v[a+1396>>2]<=9){Uk(a)}l=v[a+1392>>2];X=u[(j+((l&1023)<<1)|0)+36>>1];u:{if((X|0)>=0){s=l;X=X&65535;l=w[X+v[j+8>>2]|0];v[a+1392>>2]=s>>>l;l=v[a+1396>>2]-l|0;v[a+1396>>2]=(l|0)>0?l:0;l=(l|0)>=0?X:-1;break u}l=$l(a,j)}if(!w[j+23|0]){break t}l=v[v[j+2088>>2]+(l<<2)>>2]}i=i>>q;u[k+(c<<1)>>1]=l;c=c+1|0;continue}break}o=o+1|0;c=h;continue}break}if(v[a+1396>>2]==-1){break q}u[O+320>>1]=257;h=g+338|0;o=g+1088|0;c=2;while(1){l=v[g+1592>>2];if((l|0)<=(c|0)){c=0;while(1){if((c|0)>=(l|0)){break p}if(!w[(O+320|0)+c|0]){u[k+(c<<1)>>1]=65535;l=v[g+1592>>2]}c=c+1|0;continue}}else{j=c<<1;l=j+o|0;q=w[l|0];p=q<<1;i=x[p+h>>1];P=w[l+1|0];H=P<<1;W=u[k+p>>1];l=u[H+k>>1]-W|0;p=l>>31;i=(B((l^p)-p|0,x[h+j>>1]-i|0)|0)/(x[h+H>>1]-i|0)|0;l=W+((l|0)<0?0-i|0:i)|0;H=k+j|0;i=x[H>>1];v:{w:{if(i){j=O+320|0;t[j+P|0]=1;t[j+q|0]=1;t[c+j|0]=1;j=i<<16>>16;p=r-l|0;if((j|0)>=((l|0)>(p|0)?p:l)<<1){if((l|0)<(p|0)){break v}l=r+(i^-1)|0;break w}if(j&1){l=l-(j+1>>>1|0)|0;break w}l=(j>>1)+l|0;break w}t[(O+320|0)+c|0]=0}u[H>>1]=l}c=c+1|0;continue}}}v[P>>2]=1}n=n+1|0;continue}break}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){pc(O+320|0,O+1344|0,c<<2);g=x[R>>1];c=0;while(1){if((c|0)==(g|0)){c=F+B(G,40)|0}else{k=v[R+4>>2]+B(c,3)|0;h=w[k+1|0];l=O+1344|0;k=l+(w[k|0]<<2)|0;if(!(v[(h<<2)+l>>2]?v[k>>2]:0)){v[(O+1344|0)+(h<<2)>>2]=0;v[k>>2]=0}c=c+1|0;continue}break}X=c;i=0;while(1){x:{if(w[X+8|0]>i>>>0){l=0;c=v[a+4>>2];k=(c|0)>0?c:0;c=0;while(1){if((c|0)==(k|0)){break x}if(w[(v[R+4>>2]+B(c,3)|0)+2|0]==(i|0)){h=l+O|0;g=c<<2;y:{if(v[g+(O+1344|0)>>2]){g=0;n=1;break y}g=v[(a+g|0)+800>>2];n=0}t[h|0]=n;v[(O+256|0)+(l<<2)>>2]=g;l=l+1|0}c=c+1|0;continue}}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){k=(ha|0)>0?ha:0;h=x[R>>1];g=a+800|0;z:while(1){if((h|0)<=0){P=ha<<2;l=0;c=0;while(1){i=v[a+4>>2];if((i|0)<=(c|0)){while(1){if((i|0)>(l|0)){P=w[oa+412|0];R=V>>1;h=R<<2;X=v[a+92>>2];p=V>>3;W=V>>2;k=v[((l<<2)+a|0)+800>>2];c=R<<2;G=k+c|0;A:{if(v[a+80>>2]){j=vn(a,h);break A}j=Md(h)}h=(j+c|0)-8|0;g=v[((P<<2)+a|0)+1068>>2];i=g;c=k;while(1){if((c|0)!=(G|0)){z[h+4>>2]=C(z[c>>2]*z[i>>2])-C(z[i+4>>2]*z[c+8>>2]);z[h>>2]=C(z[c>>2]*z[i+4>>2])+C(z[c+8>>2]*z[i>>2]);c=c+16|0;i=i+8|0;h=h-8|0;continue}break}c=((R<<2)+k|0)-12|0;while(1){if(h>>>0>=j>>>0){z[h+4>>2]=C(z[c>>2]*z[i+4>>2])-C(z[c+8>>2]*z[i>>2]);z[h>>2]=C(C(-z[c+8>>2])*z[i+4>>2])-C(z[i>>2]*z[c>>2]);c=c-16|0;i=i+8|0;h=h-8|0;continue}break}c=W<<2;o=c+k|0;h=c+j|0;i=(g+(R<<2)|0)-32|0;c=j;n=k;while(1){if(g>>>0<=i>>>0){m=z[c>>2];A=z[h>>2];D=z[h+4>>2];I=z[c+4>>2];z[o+4>>2]=D+I;z[o>>2]=z[h>>2]+z[c>>2];D=C(D-I);m=C(A-m);z[n+4>>2]=C(D*z[i+16>>2])-C(z[i+20>>2]*m);z[n>>2]=C(m*z[i+16>>2])+C(D*z[i+20>>2]);m=z[c+8>>2];A=z[h+8>>2];D=z[h+12>>2];I=z[c+12>>2];z[o+12>>2]=D+I;z[o+8>>2]=z[h+8>>2]+z[c+8>>2];D=C(D-I);m=C(A-m);z[n+12>>2]=C(D*z[i>>2])-C(z[i+4>>2]*m);z[n+8>>2]=C(m*z[i>>2])+C(D*z[i+4>>2]);c=c+16|0;h=h+16|0;n=n+16|0;o=o+16|0;i=i-32|0;continue}break}h=am(V);c=V>>4;n=R-1|0;i=0-p|0;QH(c,k,n,i,g);QH(c,k,n-W|0,i,g);H=V>>5;c=0-c|0;mp(H,k,n,c,g,16);mp(H,k,n-p|0,c,g,16);mp(H,k,n-(p<<1)|0,c,g,16);mp(H,k,n+B(p,-3)|0,c,g,16);c=h-4>>1;o=(c|0)>2?c:2;c=2;while(1){B:{C:{D:{if((c|0)==(o|0)){c=h-7|0;ea=(c|0)<(o|0)?o:c;break D}i=0;p=2<<c;p=(p|0)>0?p:0;r=8<<c;q=V>>c+4;F=V>>c+2;S=0-(F>>1)|0;while(1){if((i|0)==(p|0)){break C}mp(q,k,n-B(i,F)|0,S,g,r);i=i+1|0;continue}}while(1){E:{if((o|0)!=(ea|0)){r=2<<o;S=8<<o;ma=S<<2;i=V>>o+6;Y=V>>o+2;$=0-(Y>>1)|0;h=n;c=g;while(1){if((i|0)<=0){break E}p=r;F=(h<<2)+k|0;q=F+($<<2)|0;T=B(S,12)+c|0;m=z[T>>2];K=(S<<3)+c|0;A=z[K>>2];s=(S<<2)+c|0;D=z[s>>2];I=z[T+4>>2];M=z[K+4>>2];Z=z[s+4>>2];_=z[c+4>>2];fa=z[c>>2];T=0-Y<<2;while(1){if((p|0)>0){K=q-4|0;N=z[K>>2];ba=z[F>>2];ca=z[q>>2];z[F>>2]=ba+ca;s=F-4|0;J=z[s>>2];z[s>>2]=J+z[K>>2];J=C(J-N);N=C(ba-ca);z[K>>2]=C(J*fa)+C(_*N);z[q>>2]=C(N*fa)-C(_*J);K=q-12|0;ba=z[K>>2];s=F-8|0;J=z[s>>2];ia=s;s=q-8|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-12|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*D)+C(Z*J);z[s>>2]=C(J*D)-C(Z*N);K=q-20|0;ba=z[K>>2];s=F-16|0;J=z[s>>2];ia=s;s=q-16|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-20|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*A)+C(M*J);z[s>>2]=C(J*A)-C(M*N);K=q-28|0;ba=z[K>>2];s=F-24|0;J=z[s>>2];ia=s;s=q-24|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-28|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*m)+C(I*J);z[s>>2]=C(J*m)-C(I*N);p=p-1|0;q=q+T|0;F=F+T|0;continue}break}i=i-1|0;h=h-8|0;c=(ma<<2)+c|0;continue}}c=(n<<2)+k|0;i=c-(H<<6)|0;m=z[g+(V>>3<<2)>>2];fa=C(-m);while(1){if(c>>>0>i>>>0){M=z[c>>2];h=c-32|0;Z=z[h>>2];z[c>>2]=M+Z;g=c-4|0;A=z[g>>2];n=g;g=c-36|0;_=z[g>>2];z[n>>2]=A+_;n=c-8|0;D=z[n>>2];s=n;n=c-40|0;J=z[n>>2];z[s>>2]=D+J;p=c-12|0;I=z[p>>2];s=p;p=c-44|0;N=z[p>>2];z[s>>2]=I+N;z[h>>2]=M-Z;z[g>>2]=A-_;g=c-16|0;A=z[g>>2];s=g;g=c-48|0;ba=z[g>>2];z[s>>2]=A+ba;D=C(D-J);I=C(I-N);z[n>>2]=m*C(D+I);z[p>>2]=m*C(I-D);n=c-28|0;D=z[n>>2];p=c-60|0;I=z[p>>2];r=c-24|0;M=z[r>>2];o=c-56|0;Z=z[o>>2];q=c-20|0;_=z[q>>2];s=q;q=c-52|0;J=z[q>>2];z[s>>2]=_+J;z[r>>2]=M+Z;z[n>>2]=D+I;z[g>>2]=_-J;z[q>>2]=-C(A-ba);A=C(D-I);D=C(M-Z);z[o>>2]=m*C(A-D);z[p>>2]=C(D+A)*fa;PH(c);PH(h);c=c+-64|0;continue}break}p=R-4|0;h=j+(p<<2)|0;i=(j+(W<<2)|0)-16|0;c=v[((P<<2)+a|0)+1100>>2];while(1){if(i>>>0>=j>>>0){g=(x[c>>1]<<2)+k|0;z[h+12>>2]=z[g>>2];z[h+8>>2]=z[g+4>>2];z[i+12>>2]=z[g+8>>2];z[i+8>>2]=z[g+12>>2];g=(x[c+2>>1]<<2)+k|0;z[h+4>>2]=z[g>>2];z[h>>2]=z[g+4>>2];z[i+4>>2]=z[g+8>>2];z[i>>2]=z[g+12>>2];c=c+4|0;h=h-16|0;i=i-16|0;continue}break}c=v[((P<<2)+a|0)+1084>>2];i=j;h=i+(R<<2)|0;g=h;while(1){n=g-16|0;if(n>>>0>i>>>0){m=z[i+4>>2];r=g-4|0;A=z[r>>2];D=C(m-A);I=z[c+4>>2];m=C(m+A);A=z[i>>2];o=g-8|0;M=z[o>>2];Z=C(A-M);_=z[c>>2];fa=C(C(I*m)-C(Z*_));z[i+4>>2]=D+fa;A=C(A+M);m=C(C(I*Z)+C(m*_));z[i>>2]=A+m;z[r>>2]=fa-D;z[o>>2]=A-m;m=z[i+8>>2];A=z[n>>2];D=C(m+A);I=z[c+12>>2];m=C(m-A);A=z[i+12>>2];g=g-12|0;M=z[g>>2];Z=C(A+M);_=z[c+8>>2];fa=C(C(I*m)+C(Z*_));z[i+8>>2]=D+fa;A=C(A-M);m=C(C(I*Z)-C(m*_));z[i+12>>2]=A+m;z[n>>2]=D-fa;z[g>>2]=m-A;i=i+16|0;c=c+16|0;g=n;continue}break}i=v[((P<<2)+a|0)+1076>>2]+(R<<2)|0;c=(p<<2)+k|0;g=((V<<2)+k|0)-16|0;while(1){n=h-32|0;if(n>>>0>=j>>>0){m=z[h-8>>2];A=z[i-4>>2];D=z[i-8>>2];I=z[h-4>>2];M=C(C(m*A)-C(D*I));z[k>>2]=M;z[c+12>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G>>2]=m;z[g+12>>2]=m;m=z[h-16>>2];A=z[i-12>>2];D=z[i-16>>2];I=z[h-12>>2];M=C(C(m*A)-C(D*I));z[k+4>>2]=M;z[c+8>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+4>>2]=m;z[g+8>>2]=m;m=z[h-24>>2];A=z[i-20>>2];D=z[i-24>>2];I=z[h-20>>2];M=C(C(m*A)-C(D*I));z[k+8>>2]=M;z[c+4>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+8>>2]=m;z[g+4>>2]=m;m=z[n>>2];A=z[i-28>>2];i=i-32|0;D=z[i>>2];I=z[h-28>>2];M=C(C(m*A)-C(D*I));z[k+12>>2]=M;z[c>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+12>>2]=m;z[g>>2]=m;g=g-16|0;c=c-16|0;G=G+16|0;k=k+16|0;h=n;continue}break}if(!v[a+80>>2]){Jb(j)}v[a+92>>2]=X;break B}o=o+1|0;continue}}c=c+1|0;continue}break}l=l+1|0;i=v[a+4>>2];continue}break}}else{h=c<<2;g=h+a|0;i=v[g+800>>2];F:{if(v[h+(O+320|0)>>2]){Rb(i,0,P);break F}F=v[g+996>>2];G:{h=w[(R+w[(v[R+4>>2]+B(c,3)|0)+2|0]|0)+9|0];if(!x[((h<<1)+a|0)+132>>1]){bc(a,21);break G}n=V>>1;p=v[a+260>>2]+B(h,1596)|0;H=p+338|0;W=p+838|0;k=B(w[p+1588|0],u[F>>1]);o=1;h=0;while(1){if(v[p+1592>>2]>(o|0)){g=w[o+W|0]<<1;j=u[g+F>>1];if((j|0)>=0){j=B(w[p+1588|0],j&65535);g=x[g+H>>1];if((g|0)!=(h|0)){q=j-k|0;r=g-h|0;G=(q|0)/(r|0)|0;H:{S=(g|0)<(n|0)?g:n;if((S|0)<=(h|0)){break H}s=q;q=q>>31;T=G>>31;T=((s^q)-q|0)-B(r,(T^G)-T|0)|0;K=q|1;q=i+(h<<2)|0;z[q>>2]=z[((k&255)<<2)+72976>>2]*z[q>>2];S=S-1|0;q=0;while(1){if((h|0)==(S|0)){break H}h=h+1|0;X=i+(h<<2)|0;q=q+T|0;ea=(q|0)<(r|0);k=(k+G|0)+(ea?0:K)|0;z[X>>2]=z[((k&255)<<2)+72976>>2]*z[X>>2];q=q-(ea?0:r)|0;continue}}h=g}k=j}o=o+1|0;continue}break}if((h|0)>=(n|0)){break G}g=(k<<2)+72976|0;while(1){if((h|0)==(n|0)){break G}k=i+(h<<2)|0;z[k>>2]=z[g>>2]*z[k>>2];h=h+1|0;continue}}}c=c+1|0;continue}break}SH(a);I:{if(w[a+1377|0]){v[a+1060>>2]=sa;t[a+1377|0]=0;v[a+1064>>2]=1;v[a+1412>>2]=V-ka;break I}c=v[a+1412>>2];if(!c){break I}h=la-E|0;if((h|0)<=(c|0)){v[a+1412>>2]=c-h;v[U+4>>2]=la;E=la;break I}E=c+E|0;v[U+4>>2]=E;v[a+1412>>2]=0}c=v[a+1064>>2];J:{K:{L:{M:{if(v[a+1388>>2]==v[a+1404>>2]){N:{if(!c|!(w[a+1375|0]&4)){break N}c=v[a+1408>>2];h=v[a+1060>>2];if(c>>>0>=h+(ka-E|0)>>>0){break N}h=c-h|0;c=(c>>>0<h>>>0?0:h)+E|0;c=(c|0)<(ka|0)?c:ka;v[qa>>2]=c;v[a+1060>>2]=c+v[a+1060>>2];break K}v[a+1064>>2]=1;c=v[a+1408>>2]+(E-ha|0)|0;break M}if(!c){break L}c=v[a+1060>>2]}v[a+1060>>2]=c+(la-E|0)}if(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0){break J}v[qa>>2]=ka}c=1;break o}aa(6328,13226,3451,5637);L()}h=h-1|0;c=v[R+4>>2]+B(h,3)|0;j=v[g+(w[c+1|0]<<2)>>2];i=v[g+(w[c|0]<<2)>>2];c=0;while(1){if((c|0)==(k|0)){continue z}n=c<<2;l=n+j|0;D=z[l>>2];n=i+n|0;m=z[n>>2];O:{if(m>C(0)){if(D>C(0)){A=C(m-D);break O}A=m;m=C(m+D);break O}if(D>C(0)){A=C(m+D);break O}A=m;m=C(m-D)}z[n>>2]=m;z[l>>2]=A;c=c+1|0;continue}}}aa(6328,13226,3335,5637);L()}W=O+256|0;n=0;q=hb-16|0;hb=q;G=v[a+4>>2];F=v[a+396>>2];o=w[(i+X|0)+24|0];p=F+B(o,24)|0;h=v[p+4>>2];ea=x[((o<<1)+a|0)+268>>1];c=ha<<((ea|0)==2);g=c>>>0>h>>>0?h:c;h=v[p>>2];P=(g-(c>>>0>h>>>0?h:c)>>>0)/y[p+8>>2]|0;k=P<<2;c=B(G,k+4|0);K=v[v[a+124>>2]+B(w[p+13|0],2096)>>2];ga=v[a+92>>2];P:{if(v[a+80>>2]){h=vn(a,c);G=v[a+4>>2];break P}h=Md(c)}j=(l|0)>0?l:0;H=ha<<2;g=0;c=(G|0)>0?G:0;r=(G<<2)+h|0;while(1){if((c|0)!=(g|0)){v[(g<<2)+h>>2]=r;g=g+1|0;r=k+r|0;continue}break}k=h;c=0;while(1){if((c|0)!=(j|0)){if(!w[c+O|0]){Rb(v[W+(c<<2)>>2],0,H)}c=c+1|0;continue}break}Q:{if(!((l|0)==1|(ea|0)!=2)){c=0;while(1){R:{if((c|0)!=(j|0)){if(w[c+O|0]){break R}}else{c=j}if((c|0)==(l|0)){break Q}r=F+B(o,24)|0;G=(l|0)!=2;F=(l|0)<3;while(1){if((n|0)==8){break Q}S:{if(!G){h=0;o=0;while(1){if((o|0)>=(P|0)){break S}c=v[p>>2]+B(v[p+8>>2],o)|0;v[q+12>>2]=c&1;v[q+8>>2]=c>>1;c=0;if(!n){j=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){Uk(a)}g=v[a+1392>>2];H=u[(j+((g&1023)<<1)|0)+36>>1];T:{if((H|0)>=0){s=g;H=H&65535;g=w[H+v[j+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?H:-1;break T}g=$l(a,j)}g=w[j+23|0]?v[v[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k>>2]+(h<<2)>>2]=v[v[r+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(o|0)>=(P|0))){g=v[p+8>>2];j=u[(v[r+20>>2]+(w[v[v[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(n<<1)>>1];U:{if((j|0)>=0){if(RH(a,v[a+124>>2]+B(j&65535,2096)|0,W,2,q+12|0,q+8|0,ha,g)){break U}break Q}g=v[p>>2]+(g+B(g,o)|0)|0;v[q+8>>2]=g>>1;v[q+12>>2]=g&1}o=o+1|0;c=c+1|0;continue}break}h=h+1|0;continue}}if(F){break S}h=0;o=0;while(1){if((o|0)>=(P|0)){break S}g=v[p>>2]+B(v[p+8>>2],o)|0;c=(g|0)/(l|0)|0;v[q+12>>2]=g-B(c,l);v[q+8>>2]=c;c=0;if(!n){j=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){Uk(a)}g=v[a+1392>>2];H=u[(j+((g&1023)<<1)|0)+36>>1];V:{if((H|0)>=0){s=g;H=H&65535;g=w[H+v[j+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?H:-1;break V}g=$l(a,j)}g=w[j+23|0]?v[v[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k>>2]+(h<<2)>>2]=v[v[r+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(o|0)>=(P|0))){g=v[p+8>>2];j=u[(v[r+20>>2]+(w[v[v[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(n<<1)>>1];W:{if((j|0)>=0){if(!RH(a,v[a+124>>2]+B(j&65535,2096)|0,W,l,q+12|0,q+8|0,ha,g)){break Q}break W}g=v[p>>2]+(g+B(g,o)|0)|0;j=(g|0)/(l|0)|0;v[q+8>>2]=j;v[q+12>>2]=g-B(j,l)}o=o+1|0;c=c+1|0;continue}break}h=h+1|0;continue}}n=n+1|0;continue}}c=c+1|0;continue}}ma=F+B(o,24)|0;l=0;while(1){if((l|0)==8){break Q}n=0;S=0;X:while(1){if((n|0)<(P|0)){h=0;c=0;Y:{if(l){break Y}while(1){if((c|0)==(j|0)){break Y}if(!w[c+O|0]){r=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){Uk(a)}g=v[a+1392>>2];o=u[(r+((g&1023)<<1)|0)+36>>1];Z:{if((o|0)>=0){s=g;o=o&65535;g=w[o+v[r+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?o:-1;break Z}g=$l(a,r)}g=w[r+23|0]?v[v[r+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k+(c<<2)>>2]+(S<<2)>>2]=v[v[ma+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((h|0)>=(K|0)){break $}c=0;if((n|0)>=(P|0)){break $}while(1){if((c|0)==(j|0)){break _}aa:{if(w[c+O|0]){break aa}g=c<<2;r=u[(v[ma+20>>2]+(w[v[v[g+k>>2]+(S<<2)>>2]+h|0]<<4)|0)+(l<<1)>>1];if((r|0)<0){break aa}G=v[a+124>>2]+B(r&65535,2096)|0;Y=v[g+W>>2];T=v[p+8>>2];H=v[p>>2]+B(T,n)|0;ba:{ca:{if(ea){F=0;while(1){g=1;if((F|0)>=(T|0)){break ba}$=Y+(H<<2)|0;g=T-F|0;o=0;m=C(0);da:{s=OH(a,G);if((s|0)<0){break da}r=v[G>>2];g=(g|0)>(r|0)?r:g;s=B(r,s);if(w[G+22|0]){r=0;g=(g|0)>0?g:0;o=1;while(1){if((g|0)==(r|0)){break da}ja=$+(r<<2)|0;m=C(m+z[v[G+28>>2]+(r+s<<2)>>2]);z[ja>>2]=z[ja>>2]+m;r=r+1|0;m=C(m+z[G+12>>2]);continue}}r=0;g=(g|0)>0?g:0;o=1;while(1){if((g|0)==(r|0)){break da}ja=$+(r<<2)|0;z[ja>>2]=z[ja>>2]+C(z[v[G+28>>2]+(r+s<<2)>>2]+C(0));r=r+1|0;continue}}if(!o){break ca}g=v[G>>2];H=g+H|0;F=g+F|0;continue}}F=0;r=(T|0)/v[G>>2]|0;s=(r|0)>0?r:0;ja=Y+(H<<2)|0;g=1;while(1){if((F|0)==(s|0)){break ba}o=F+H|0;Y=F<<2;F=F+1|0;ia=Y+ja|0;Y=T-o|0;$=0;m=C(0);ea:{na=OH(a,G);if((na|0)<0){break ea}o=0;$=v[G>>2];Y=(Y|0)>($|0)?$:Y;Y=(Y|0)>0?Y:0;na=B($,na);$=1;while(1){if((o|0)==(Y|0)){break ea}ra=(B(o,r)<<2)+ia|0;A=C(m+z[v[G+28>>2]+(o+na<<2)>>2]);z[ra>>2]=z[ra>>2]+A;m=w[G+22|0]?A:m;o=o+1|0;continue}}if($){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}}S=S+1|0;continue X}n=n+1|0;h=h+1|0;continue}}break}l=l+1|0;continue}}if(!v[a+80>>2]){Jb(k)}v[a+92>>2]=ga;hb=q+16|0;i=i+1|0;continue}}aa(6328,13226,3302,5637);L()}hb=O+2368|0}else{c=0}hb=da+16|0;if(!c){fa:{ga:{ha:{c=v[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}v[a+100>>2]=0;while(1){if(ta=0,ua=(rh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break fa}v[a+100>>2]=0;while(1){if(ta=0,ua=(rh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;c=1;break a}g=v[U+12>>2];j=v[U+4>>2];h=v[U+8>>2];ia:{ja:{k=v[a+992>>2];if(k){i=k<<1;ka:{if((i|0)==v[a+112>>2]){c=a+1092|0}else{c=0;if((i|0)!=v[a+116>>2]){break ka}c=a+1096|0}c=v[c>>2]}if(!c){break ja}n=(k|0)>0?k:0;while(1){if(v[a+4>>2]>(Q|0)){i=(Q<<2)+a|0;E=0;while(1){if((n|0)!=(E|0)){l=v[i+800>>2]+(j+E<<2)|0;s=l;A=z[l>>2];l=E<<2;z[s>>2]=C(A*z[l+c>>2])+C(z[l+v[i+928>>2]>>2]*z[c+(k+(E^-1)<<2)>>2]);E=E+1|0;continue}break}Q=Q+1|0;continue}break}Q=v[a+992>>2]}v[a+992>>2]=g-h;k=(g|0)<(h|0);i=(k?h:g)-h|0;while(1){if(v[a+4>>2]>(pa|0)){c=(pa<<2)+a|0;E=0;while(1){if((i|0)!=(E|0)){z[v[c+928>>2]+(E<<2)>>2]=z[v[c+800>>2]+(h+E<<2)>>2];E=E+1|0;continue}break}pa=pa+1|0;continue}break}if(!Q){break ja}c=(k?g:h)-j|0;v[a+1416>>2]=c+v[a+1416>>2];break ia}c=0}h=c;v[U+12>>2]=c;c=0;g=v[a+4>>2];k=(g|0)>0?g:0;while(1){if((c|0)!=(k|0)){i=(c<<2)+a|0;v[i+864>>2]=v[i+800>>2]+(j<<2);c=c+1|0;continue}break}if(d){v[d>>2]=g}v[f>>2]=h;v[e>>2]=a+864;c=v[a+32>>2]-b|0}hb=U+16|0;return c}function Zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=hb-1760|0;hb=d;xc(b);f=hb-16|0;hb=f;g=d+1632|0;BR(f+8|0,g);k=b;o=v[b+8>>2];b=v[f+12>>2];jc(f,v[k>>2],o,v[f+8>>2],b);h=v[f+4>>2];if((h|0)==(b|0)){Yb(k,v[f+12>>2])}hb=f+16|0;b=(b|0)==(h|0);if(!b){AR(g)}a:{if(!b){break a}if(!CR(d+1632|0)){break a}if(!Ob(v[k>>2],v[k+8>>2],Bc(256,0))){break a}b:{if(!c){break b}zd(a,1048576);$f(a);b=hb-16|0;hb=b;e=vc(b,4233);Xc(d+1376|0,e);xb(e);hb=b+16|0;b=x[d+1640>>1];v[d+160>>2]=b>>>8;v[23516]=0;v[d+16>>2]=b&255;R(441,d+88|0,d+16|0);b=v[23516];v[23516]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((b|0)!=1){v[23516]=0;X(427,d+272|0,d+1376|0,d+160|0,d+88|0);b=v[23516];v[23516]=0;if((b|0)==1){break m}b=d+272|0;Gb(a+1298344|0,b);xb(b);e=d+88|0;xb(e);f=d+1376|0;ac(f);g=vc(b,15228);Gb(a+1298356|0,g);xb(g);Ke(e,2,d+1642|0);Cc(f,e);v[23516]=0;U(11,b|0,8,f|0);b=v[23516];v[23516]=0;if((b|0)==1){break i}b=d+272|0;Gb(a+1298368|0,b);xb(b);e=d+1376|0;wb(e);v[a+1298404>>2]=8;Vz(e,2,d+1674|0);Cc(b,e);yc(a+1298308|0,b);wb(b);u[a+480188>>1]=x[d+1744>>1];f=w[d+1748|0];v[a+480204>>2]=125e4;v[a+480208>>2]=32792;G=a,H=Bd(f,1,31),v[G+480196>>2]=H;u[a+480192>>1]=x[d+1754>>1];u[a+480190>>1]=x[d+1756>>1];f=Bd(w[d+1749|0],1,32);v[a+480216>>2]=f;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=f<<2;Uu(k,e);f=a+484360|0;g=a+484376|0;Mq(Sb(v[f>>2],w[g|0]),e,x[d+1738>>1],65535,65535);Te(Sb(v[f>>2],w[g|0]),x[d+1740>>1]);p=Ng(k);Wd(b,k,p?274:0);A=hc(d+1352|0,b);yb(b);v[23516]=0;b=T(155,k|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break k}v[23516]=0;U(188,d+272|0,k|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break k}b=d+272|0;s=hc(d+1328|0,b);yb(b);b=a+480188|0;o=x[b>>1];if(p){u[b>>1]=o+8}z=c&1;if(!z){break j}v[23516]=0;R(224,a+484344|0,x[d+1742>>1]);b=v[23516];v[23516]=0;if((b|0)!=1){break j}g=P()|0;O()|0;break e}g=P()|0;O()|0;break l}g=P()|0;O()|0;xb(d+88|0)}ac(d+1376|0);break c}g=P()|0;O()|0;break d}q=a+484344|0;C=a+480188|0;g=0;while(1){n:{o:{p:{q:{r:{s:{if(x[d+1742>>1]<=r>>>0){b=x[d+1746>>1];if((b-2&65535)>>>0>=4998){break q}if(!(g&1)){break s}i=0;b=Dc(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break r}v[23516]=0;b=T(192,k|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break f}v[d+160>>2]=b;v[23516]=0;b=T(155,k|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break g}v[23516]=0;U(188,d+88|0,k|0,b+1&-2);b=v[23516];v[23516]=0;if((b|0)==1){break g}b=d+88|0;m=hc(d+272|0,b);yb(b);uc(d+160|0,1024);if(!z){break o}l=v[d+160>>2];if(!l){break o}v[23516]=0;b=W(225,q|0,r&65535,l|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){if(!b){break o}h=0;e=0;if(t[d+1750|0]&1){break p}t:while(1){if((h|0)==(l|0)){break o}e=0;b=Xb(v[q>>2],r);b=xf(v[b>>2],v[v[b+48>>2]+12>>2],h);while(1){if((e|0)==(o|0)){h=h+1|0;continue t}v[23516]=0;R(613,m|0,d+88|0);f=v[23516];v[23516]=0;if((f|0)!=1){g=yR(b+B(e,6)|0,d+88|0)|g;e=e+1|0;continue}break}break}break h}break h}i=2;b=Oe(2646e3/+(B(b,B(v[a+480216>>2],v[a+480196>>2]))>>>0)*1e4)}t[a+480224|0]=i;v[a+480204>>2]=b}h=a+480188|0;b=x[h>>1];v[23516]=0;t[d+272|0]=0;r=W(614,d+1312|0,b|0,d+272|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){i=a+1298320|0;l=a+1298332|0;n=a+484348|0;m=0;u:{v:{w:{x:{y:{z:{while(1){b=v[s+8>>2];e=v[s>>2];v[23516]=0;b=W(154,e|0,b|0,8)|0;e=v[23516];v[23516]=0;A:{if((e|0)!=1){if(b){break A}f=a+906300|0;g=v[r>>2];h=0;i=a+480188|0;while(1){e=x[i>>1];if(e>>>0<=h>>>0){v[d+264>>2]=0;v[d+268>>2]=0;v[d+256>>2]=0;v[d+260>>2]=0;v[d+248>>2]=0;v[d+252>>2]=0;v[d+240>>2]=0;v[d+244>>2]=0;B:{C:{if(!p){break C}e=0;v[23516]=0;R(615,A|0,d+272|0);b=v[23516];v[23516]=0;if((b|0)==1){break B}while(1){if((e|0)==8){e=0;v[23516]=0;h=Q(217,d+224|0,x[d+272>>1])|0;b=v[23516];v[23516]=0;if((b|0)!=1){D:{E:{F:{G:{while(1){if(x[d+272>>1]<=e>>>0){v[23516]=0;l=W(616,d+208|0,x[d+1742>>1],27100)|0;b=v[23516];v[23516]=0;if((b|0)==1){break E}j=a+484376|0;z=a+484348|0;C=a+480188|0;f=0;break F}v[23516]=0;b=T(192,k|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){v[23516]=0;U(188,d+160|0,k|0,b<<5);b=v[23516];v[23516]=0;if((b|0)==1){break G}f=d+160|0;b=hc(d+88|0,f);cd(Kg(v[h>>2],e),b);yb(b);e=e+1|0;yb(f);continue}break}g=P()|0;O()|0;break D}g=P()|0;O()|0;break D}while(1){if(x[d+1738>>1]<=f>>>0){gd(l);Nc(h);break C}H:{g=d+f|0;e=w[g+290|0];if(e>>>0>=x[d+272>>1]){break H}b=x[$b(v[Sb(v[a+484360>>2],w[j|0])>>2],f)>>1];if(b>>>0>=x[d+1742>>1]){break H}I:{i=$b(v[l>>2],b);n=x[i>>1];J:{if((n|0)==65535){u[i>>1]=e;break J}if((e|0)==(n|0)){break J}v[23516]=0;e=Q(617,q|0,b|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break I}if((e|0)==65535){break J}G=$b(v[Sb(v[a+484360>>2],w[j|0])>>2],f),H=e,u[G>>1]=H;b=e}if(!te(v[a+484344>>2],v[z>>2],b)){break H}p=Kg(v[h>>2],w[g+290|0]);xc(p);e=v[p>>2];v[23516]=0;e=T(158,e|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break I}D=e>>>5|0;i=0;K:while(1){e=Xb(v[q>>2],b);if(y[e+12>>2]<=i>>>0){break H}g=0;e=ed(v[e>>2],v[v[e+48>>2]+12>>2],i,x[C>>1]-8&65535);while(1){if((g|0)==8){i=i+1|0;continue K}Cj(d+88|0);n=x[d+92>>1];t[e+4|0]=n;t[e+5|0]=n>>>8;n=v[d+88>>2];t[e|0]=n;t[e+1|0]=n>>>8;t[e+2|0]=n>>>16;t[e+3|0]=n>>>24;L:{if(i>>>0>=D>>>0){break L}v[23516]=0;Q(618,p|0,d+88|0)|0;n=v[23516];v[23516]=0;if((n|0)==1){break I}if(t[d+88|0]>=0){break L}t[e|0]=61;t[e+1|0]=w[(d+256|0)+(g<<1)|0];n=w[d+88|0]&31;t[d+160|0]=n;if(n){sf(d+160|0,15);t[e+3|0]=20;t[e+5|0]=w[d+160|0]|208}t[e+2|0]=1;t[e+4|0]=w[d+89|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=P()|0;O()|0;gd(l);break D}f=f+1|0;continue}}g=P()|0;O()|0}Nc(h);break u}g=P()|0;O()|0;break u}f=e<<1;g=f+(d+256|0)|0;b=x[a+480192>>1]+1&65535;h=x[v[a+8>>2]+58>>1];while(1){M:{N:{i=b&65535;if(i>>>0<=h>>>0){if(v[((i<<2)+a|0)+900380>>2]){break N}}else{b=65535}b=b&65535;break M}b=b+1|0;continue}break}u[g>>1]=b;h=f+(d+240|0)|0;f=x[(d+f|0)+274>>1];u[h>>1]=f;O:{if((b|0)!=65535){v[23516]=0;b=W(253,a|0,b|0,f+1&65535)|0;f=v[23516];v[23516]=0;P:{Q:{if((f|0)!=1){if(!b){break O}v[23516]=0;R(289,d+160|0,4478);f=v[23516];v[23516]=0;if((f|0)==1){break Q}v[23516]=0;v[d+16>>2]=e+1;U(619,d+88|0,d+160|0,d+16|0);f=v[23516];v[23516]=0;if((f|0)==1){break P}f=b+492|0;b=d+88|0;Ac(f,b);wb(b);Ub(d+160|0);break O}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}g=P()|0;O()|0;Ub(d+160|0);break u}u[g>>1]=0}e=e+1|0;continue}}R:{S:{b=x[d+1750>>1]|x[d+1752>>1]<<16;if(!(b&2)){break S}b=(((b&8?x[a+480188>>1]:o)&65535)+(x[d+1640>>1]>591?m:0)|0)+(b>>>4&1)|0;f=0;T:while(1){e=0;if(x[d+1742>>1]<=f>>>0){break S}while(1){U:{if((b|0)!=(e|0)){g=v[k+8>>2];h=v[k>>2];v[23516]=0;g=W(154,h|0,g|0,4)|0;h=v[23516];v[23516]=0;if((h|0)==1){break R}if(g){break U}}f=f+1|0;continue T}v[23516]=0;R(620,x[d+1640>>1],k|0);g=v[23516];v[23516]=0;if((g|0)==1){break R}e=e+1|0;continue}}}v[23516]=0;q=Q(217,d+192|0,255)|0;b=v[23516];v[23516]=0;if((b|0)!=1){n=a+480208|0;f=0;while(1){V:{b=f;W:{if((b|0)==255){m=Sz(d+88|0);l=Sz(d+160|0);g=0;while(1){X:{Y:{Z:{if((g|0)==256){h=0;break Z}v[23516]=0;R(621,k|0,d+272|0);b=v[23516];v[23516]=0;if((b|0)==1){break Y}v[23516]=0;b=T(155,k|0)|0;e=v[23516];v[23516]=0;_:{$:{aa:{if((e|0)!=1){v[23516]=0;U(188,d+16|0,k|0,b|0);e=v[23516];v[23516]=0;if((e|0)==1){break aa}e=d+16|0;h=hc(d- -64|0,e);yb(e);if(x[d+1756>>1]>g>>>0){e=d+48|0;Ke(e,2,d+272|0);v[23516]=0;R(221,d+16|0,e|0);e=v[23516];v[23516]=0;if((e|0)==1){break _}e=d+16|0;Ac(((g<<5)+a|0)+946336|0,e);wb(e)}if(!b){break X}if(x[d+1756>>1]>g>>>0){break $}break X}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}v[23516]=0;b=B(g+1|0,104)+a|0;e=b+484380|0;R(280,e|0,32);f=v[23516];v[23516]=0;ba:{ca:{da:{if((f|0)!=1){Fo(e);v[23516]=0;R(622,h|0,d+16|0);f=v[23516];v[23516]=0;if((f|0)==1){break _}f=v[d+16>>2];v[e>>2]=f;v[b+484404>>2]=v[d+20>>2];if(w[d+24|0]>=2){i=b+484414|0;u[i>>1]=x[i>>1]|1;f=f>>>1|0;v[e>>2]=f}if(w[d+25|0]>=2){i=b+484414|0;u[i>>1]=x[i>>1]|64;v[e>>2]=f>>>1}i=2;switch(w[d+27|0]-1|0){case 0:break ca;case 1:break da;default:break ba}}break _}i=6}e=b+484414|0;u[e>>1]=x[e>>1]|i}v[b+484384>>2]=v[d+28>>2];v[b+484388>>2]=v[d+32>>2];u[b+484410>>1]=x[d+36>>1]>>>7;e=w[d+38|0];ea:{if((e|0)==128){e=b+484414|0;f=x[e>>1]|256;u[e>>1]=f;break ea}u[b+484408>>1]=(e<<24>>24)+128;f=x[b+484414>>1]}i=b+484414|0;u[i>>1]=f|32;t[b+484416|0]=w[d+39|0];e=w[d+26|0];if(e&2){b=d+48|0;Ab(b,l,g);fo(b);e=w[d+26|0]}if(e&5){u[i>>1]=x[i>>1]|16384}if(!(e&8)){break X}b=d+48|0;Ab(b,m,g);fo(b);e=0;while(1){if((e|0)==8){break X}b=e<<1;fa:{if(x[b+(d+240|0)>>1]!=(g|0)){break fa}b=v[((x[b+(d+256|0)>>1]<<2)+a|0)+900380>>2];if(!b){break fa}t[b+14|0]=0}e=e+1|0;continue}}g=P()|0;O()|0;yb(h);break W}while(1){ga:{ha:{if(x[d+1754>>1]<=h>>>0){if(!(c&2)){break ha}e=a+1298404|0;f=a+1298464|0;g=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{while(1){if(x[a+480190>>1]<=g>>>0){break ha}g=g+1|0;c=B(g,104)+a|0;h=c+484380|0;b=c+484416|0;sl(h,(+(t[b|0]-49|0)+ +t[c+484417|0]*-.0078125)/-12);u[b>>1]=0;b=x[c+484414>>1];if(!(b&16384)){b=Uc(d+272|0,b&1?16:8,b&64?3:1,0,11);v[23516]=0;W(218,b|0,h|0,k|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){continue}g=P()|0;O()|0;break W}v[23516]=0;h=T(155,k|0)|0;b=v[23516];v[23516]=0;qa:{if((b|0)==1){break qa}v[23516]=0;Q(186,k|0,12)|0;b=v[23516];v[23516]=0;if((b|0)==1){break qa}b=Kb(d+272|0);v[23516]=0;U(271,k|0,b|0,h|0);h=v[23516];v[23516]=0;if((h|0)==1){break pa}xe(c+484423|0,b);v[23516]=0;R(382,d- -64|0,16514);c=v[23516];v[23516]=0;if((c|0)==1){break oa}v[d+12>>2]=g;c=v[e>>2];v[23516]=0;U(11,d+48|0,c|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break na}v[23516]=0;X(427,d+16|0,d- -64|0,d+12|0,d+48|0);c=v[23516];v[23516]=0;if((c|0)==1){break ma}c=v[f>>2];v[23516]=0;U(384,c|0,2,d+16|0);c=v[23516];v[23516]=0;if((c|0)==1){break la}xb(d+16|0);xb(d+48|0);ac(d- -64|0);wb(b);continue}break}g=P()|0;O()|0;break W}g=P()|0;O()|0;break ia}g=P()|0;O()|0;break ia}g=P()|0;O()|0;break ja}g=P()|0;O()|0;break ka}g=P()|0;O()|0;xb(d+16|0)}xb(d+48|0)}ac(d- -64|0)}wb(b);break W}b=v[Kg(v[q>>2],h)>>2];v[23516]=0;b=T(158,b|0)|0;e=v[23516];v[23516]=0;ra:{sa:{if((e|0)!=1){if(!b){h=h+1|0;continue}b=Kg(v[q>>2],h);xc(b);v[23516]=0;R(623,b|0,d+272|0);b=v[23516];v[23516]=0;if((b|0)==1){break sa}i=Lb(d+16|0);v[23516]=0;U(624,k|0,i|0,x[d+272>>1]);b=v[23516];v[23516]=0;if((b|0)==1){break ra}h=h+1|0;b=v[((h<<2)+a|0)+900380>>2];if(!b|w[b+34|0]){break ga}v[b+4>>2]=32;e=0;Pt(b,0);n=b+108|0;j=b+236|0;while(1){if((e|0)==96){break ga}f=w[(d+e|0)+274|0];ta:{if(f>>>0>=x[d+272>>1]){break ta}g=_e(v[i>>2],f);p=e+12|0;z=$b(j,p);f=w[g|0];o=f+1|0;u[z>>1]=o;if(f>>>0>=x[a+480190>>1]){break ta}f=B(o,104)+a|0;t[f+484418|0]=w[d+370|0]&3;t[f+484419|0]=w[d+371|0];t[f+484420|0]=w[d+372|0];t[f+484421|0]=w[d+373|0];u[f+484412>>1]=w[g+1|0]<<1;t[f+484417|0]=w[g+2|0];f=o-1|0;Ab(d- -64|0,m,f);if(zb(v[v[d+64>>2]>>2],v[d+68>>2])){t[b+14|0]=0}Ab(d- -64|0,l,f);if(!zb(v[v[d+64>>2]>>2],v[d+68>>2])){break ta}G=Ib(n,p),H=61,t[G|0]=H}e=e+1|0;continue}}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}g=P()|0;O()|0;be(i);break W}Nc(q);dc(r);yb(s);yb(A);break b}be(i);continue}}g=P()|0;O()|0;break W}yb(h);g=g+1|0;continue}}v[23516]=0;R(621,k|0,d+160|0);e=v[23516];v[23516]=0;ua:{va:{wa:{xa:{if((e|0)!=1){v[23516]=0;e=T(155,k|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break xa}v[23516]=0;e=(e|0)==32?428:e;h=e?x[d+1640>>1]>513?e+4|0:e:e;U(188,d+88|0,k|0,h|0);e=v[23516];v[23516]=0;if((e|0)==1){break wa}g=d+88|0;e=hc(d+272|0,g);i=he(d+16|0,cd(Kg(v[q>>2],b),e));yb(e);f=b+1|0;yb(g);if(b>>>0>=x[d+1754>>1]){break V}v[23516]=0;b=f&65535;g=W(253,a|0,b|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break va}break ua}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}if(!g){break V}b=d+88|0;Ke(b,2,d+160|0);v[23516]=0;R(221,d+272|0,b|0);b=v[23516];v[23516]=0;ya:{if((b|0)!=1){b=d+272|0;Ac(g+492|0,b);wb(b);if(!h){break V}v[23516]=0;R(623,i|0,d+272|0);b=v[23516];v[23516]=0;if((b|0)!=1){m=3;h=0;if(x[d+1640>>1]<513){l=0;break ya}v[23516]=0;l=T(192,i|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break ua}if(x[d+1640>>1]<514){break ya}v[23516]=0;m=T(155,i|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break ya}break ua}break ua}break ua}v[g>>2]=x[d+374>>1];t[g+16|0]=w[(x[d+376>>1]&3)+27102|0];t[g+17|0]=w[(w[d+377|0]&3)+27102|0];t[g+18|0]=w[(x[d+376>>1]>>>12&3)+27106|0];while(1){za:{Aa:{if((h|0)==4){if(!(t[g+60|0]&1|w[g+16|0]==3)){v[g>>2]=32767}Ij(g,127,1);Hj(g,0,1);if(!l){break V}v[23516]=0;R(625,i|0,d+88|0);b=v[23516];v[23516]=0;if((b|0)==1){break ua}if(l&2){Ij(g,TA(v[n>>2],+x[d+90>>1]),1);Hj(g,w[d+92|0],1)}t[g+25|0]=w[d+89|0]==1;if(!(l&4)){break V}t[g+31|0]=w[d+95|0]+1;b=t[d+96|0];t[g+34|0]=b+1;if((b|0)<0){t[g+30|0]=w[d+103|0]+1}if(!w[d+100|0]){break Aa}h=g+108|0;e=0;while(1){if((e|0)==128){break Aa}b=e+1|0;v[d+64>>2]=b+t[d+100|0];vR(d- -64|0);G=Ib(h,e),H=v[d+64>>2],t[G|0]=H;e=b;continue}}if(!(m&1)){break za}v[23516]=0;R(626,i|0,d+88|0);b=v[23516];v[23516]=0;Ba:{if((b|0)!=1){b=Gh(g,w[h+27110|0]);Ca:{if((h|0)!=3){e=w[d+88|0];o=w[b+12|0]&-17;break Ca}e=w[d+88|0];o=w[b+12|0]&-17|e<<4&16}t[b+12|0]=e>>>1&2|(e<<1&4|(o&248|e&1));t[d+64|0]=w[d+89|0];t[d+48|0]=16;e=w[Vb(d- -64|0,d+48|0)|0];v[23516]=0;R(294,b|0,e|0);e=v[23516];v[23516]=0;if((e|0)==1){break Ba}e=w[d+90|0];t[b+15|0]=e;t[b+16|0]=e;t[b+13|0]=w[d+91|0];t[b+14|0]=w[d+92|0];e=0;o=v[b>>2];j=Qd(o,v[b+4>>2]);while(1){if((e|0)==(j|0)){break za}p=Bb(o,e);b=(d+88|0)+(e<<2)|0;u[p>>1]=w[b+8|0]|w[b+9|0]<<8;G=p,H=Bd(w[b+10|0]|w[b+11|0]<<8,0,64),t[G+2|0]=H;e=e+1|0;continue}}break ua}break ua}Pt(g,0);break V}h=h+1|0;m=m>>>1|0;continue}}g=P()|0;O()|0;yb(i)}Nc(q);break u}yb(i);continue}}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}else{b=t[Ib(g,h)|0];Da:{if((b|0)<=(h|0)|(b|0)>=(e|0)){break Da}b=w[((b<<5)+a|0)+480288|0];if(!b){break Da}e=((h<<5)+a|0)+480288|0;l=w[e|0];if(!l){t[e|0]=b;break Da}e=l-1|0;while(1){l=Id(f,e&255);e=Pm(v[l+28>>2]);if((e|0)!=255){continue}break}b=b-1&255;v[l+28>>2]=b>>>0<250?b+128|0:0}h=h+1|0;continue}}}g=P()|0;O()|0;break u}v[23516]=0;f=T(155,s|0)|0;b=v[23516];v[23516]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((b|0)!=1){v[23516]=0;b=T(155,s|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break Ma}v[23516]=0;U(188,d+272|0,s|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break Ma}e=d+272|0;b=hc(d+88|0,e);yb(e);if((f|0)==4674381){break Ia}if((f|0)==5068115){break Ha}if((f|0)==726487106){break La}if((f|0)==844387158){break Ga}e=0;if((f|0)==1280004692){break Ka}if((f|0)==1314144592){break Ja}if((f|0)!=1397445204){break Fa}v[23516]=0;e=T(192,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break w}e=e>>>0<256?48:e>>>8|0;v[a+480228>>2]=e;v[a+480232>>2]=e>>>1;e=0;while(1){if(x[h>>1]<=e>>>0){break Fa}v[23516]=0;f=Q(627,b|0,d+272|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break z}if(f){u[((e<<5)+a|0)+480286>>1]=x[d+272>>1]>>>10;G=Ib(v[r>>2],e),H=w[d+275|0],t[G|0]=H}e=e+1|0;continue}}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}if(g&1){break Fa}t[a+480224|0]=2;v[23516]=0;E=+ma(628,b|0);e=v[23516];v[23516]=0;if((e|0)==1){break Ea}if(!(E>1e-8)){break Fa}G=a,H=Oe(2646e3/(E*+(B(v[a+480216>>2],v[a+480196>>2])>>>0))*1e4),v[G+480204>>2]=H;break Fa}while(1){Na:{if(x[h>>1]<=e>>>0){break Fa}f=v[b>>2];v[23516]=0;f=W(154,f|0,v[d+96>>2],1)|0;j=v[23516];v[23516]=0;if((j|0)==1){break y}if(!f){break Fa}f=Kb(d+272|0);v[23516]=0;U(357,b|0,f|0,-1);j=v[23516];v[23516]=0;if((j|0)!=1){j=d+16|0;bg(j,3,Ic(f),Fb(f));v[23516]=0;R(221,d+160|0,j|0);j=v[23516];v[23516]=0;if((j|0)==1){break Na}j=d+160|0;wl(((e<<5)+a|0)+480289|0,j);wb(j);wb(f);e=e+1|0;continue}}break}g=P()|0;O()|0;wb(f);break v}while(1){if(x[d+1742>>1]<=e>>>0){break Fa}f=v[b>>2];v[23516]=0;f=W(154,f|0,v[d+96>>2],1)|0;j=v[23516];v[23516]=0;if((j|0)==1){break x}if(!f){break Fa}if(!Hm(v[a+484344>>2],v[n>>2],e&65535)){break Fa}f=Kb(d+272|0);v[23516]=0;U(357,b|0,f|0,-1);j=v[23516];v[23516]=0;Oa:{if((j|0)==1){break Oa}j=v[q>>2];v[23516]=0;R(284,Xb(j,e)|0,f|0);j=v[23516];v[23516]=0;if((j|0)==1){break Oa}wb(f);e=e+1|0;continue}break}g=P()|0;O()|0;wb(f);break v}v[23516]=0;Q(186,b|0,1)|0;e=v[23516];v[23516]=0;if((e|0)==1){break w}v[23516]=0;e=T(200,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break w}v[23516]=0;X(336,l|0,b|0,e|0,2);e=v[23516];v[23516]=0;if((e|0)!=1){break Fa}break w}v[23516]=0;Q(629,b|0,d+16|0)|0;e=v[23516];v[23516]=0;Pa:{if((e|0)!=1){e=Kb(d+272|0);v[23516]=0;U(357,b|0,e|0,-1);f=v[23516];v[23516]=0;if((f|0)==1){break Pa}if(qq(e,12650)){v[23516]=0;U(11,d+160|0,8,e|0);f=v[23516];v[23516]=0;if((f|0)==1){break Pa}f=d+160|0;Gb(i,f);xb(f)}wb(e);break Fa}g=P()|0;O()|0;break v}g=P()|0;O()|0;wb(e);break v}v[23516]=0;m=T(155,b|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break w}}yb(b);continue}break}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0}yb(b)}dc(r);break e}g=P()|0;O()|0;break e}while(1){b=v[m>>2];v[23516]=0;b=W(154,b|0,v[d+280>>2],1)|0;f=v[23516];v[23516]=0;Qa:{if((f|0)!=1){if(!b){break o}v[23516]=0;i=T(204,m|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break h}n=0;if((i|0)!=255){break Qa}v[23516]=0;n=T(204,m|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){v[23516]=0;i=T(204,m|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break Qa}}break h}break h}if(i&127){b=Xb(v[q>>2],r);f=ed(v[b>>2],v[v[b+48>>2]+12>>2],e,h&65535);Eu(d+88|0);if(i&1){v[23516]=0;b=T(204,m|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break n}t[d+88|0]=b}if(i&2){v[23516]=0;b=T(204,m|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break n}t[d+89|0]=b}if(i&4){v[23516]=0;b=T(204,m|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break n}t[d+90|0]=b}if(i&8){v[23516]=0;b=T(204,m|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break n}t[d+91|0]=b}if(i&16){v[23516]=0;b=T(204,m|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break n}t[d+92|0]=b}if(i&32){v[23516]=0;b=T(204,m|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break n}t[d+93|0]=b}if(i&64){v[23516]=0;b=T(204,m|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break n}t[d+94|0]=b}D=yR(f,d+88|0);v[d+16>>2]=n;v[d+64>>2]=l+(e^-1);F=v[Hb(d+16|0,d- -64|0)>>2];i=0;b=f;while(1){if((i|0)!=(F|0)){b=B(x[C>>1],6)+b|0;j=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=j;t[b+1|0]=j>>>8;t[b+2|0]=j>>>16;t[b+3|0]=j>>>24;j=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=j;t[b+5|0]=j>>>8;i=i+1|0;continue}break}g=g|D}e=(e+n|0)+1|0;while(1){if(e>>>0>=l>>>0){h=h+1|0;e=e-l|0;continue}break}if(o>>>0>(h&65535)>>>0){continue}break}}yb(m);r=r+1|0;continue}break}break h}g=P()|0;O()|0;wb(d+1376|0);break c}g=P()|0;O()|0;yb(m);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0}yb(s)}yb(A)}S(g|0);L()}e=1}hb=d+1760|0;return e|0}function Tia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=hb-1184|0;hb=d;xc(b);e=hb-16|0;hb=e;g=d+944|0;NT(e+8|0,g);m=v[e+12>>2];jc(e,v[b>>2],v[b+8>>2],v[e+8>>2],m);j=v[e+4>>2];if((j|0)==(m|0)){Yb(b,v[e+12>>2])}hb=e+16|0;e=(j|0)==(m|0);if(!e){MT(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!e){break o}if(!PT(d+944|0)){break o}if(!Ob(v[b>>2],v[b+8>>2],Bc(OT(v[d+948>>2]),kb))){break o}if(!c){f=1;break o}zd(a,16777216);$f(a);e=a+480208|0;v[e>>2]=v[e>>2]|16809984;f=d+480|0;oq(f,32);m=v[d+492>>2];e=a+1074320|0;v[e>>2]=v[d+488>>2];v[e+4>>2]=m;e=v[d+484>>2];v[a+1074312>>2]=v[d+480>>2];v[a+1074316>>2]=e;Mb(Mb(a+1074312|0,57,w[d+947|0]>5),114,1);e=po(d+896|0);H=e,I=Bd(w[d+1144|0],1,31),v[H+12>>2]=I;H=e,I=Bd(w[d+1145|0],1,12)-1|0,v[H+16>>2]=I;H=e,I=Eb(x[d+1146>>1])-1900|0,v[H+20>>2]=I;tB(a+1298408|0,e);u[a+480188>>1]=32;e=d+376|0;LT(e,3,d+1148|0);m=d+56|0;Cc(m,e);v[23516]=0;U(11,f|0,1,m|0);e=v[23516];v[23516]=0;p:{q:{if((e|0)!=1){e=d+480|0;Gb(a+1298368|0,e);xb(e);wb(d+56|0);r:{if(w[d+947|0]<=5){Qf(d+56|0,3927);break r}e=hb-16|0;hb=e;f=vc(e,3996);Xc(d+56|0,f);xb(f);hb=e+16|0}v[23516]=0;U(369,d+480|0,d+56|0,w[d+947|0]);e=v[23516];v[23516]=0;if((e|0)==1){break q}e=d+480|0;Gb(a+1298344|0,e);xb(e);f=d+56|0;ac(f);m=vc(e,15232);Gb(a+1298356|0,m);xb(m);v[a+1298404>>2]=12;Ke(f,3,d+952|0);Cc(e,f);yc(a+1298308|0,e);wb(e);v[a+480228>>2]=256;v[a+480200>>2]=384/(x[a+480188>>1]+3>>>0);if(w[d+947|0]>5){break p}H=d,I=Eb(x[d+1172>>1]),u[H+480>>1]=I;u[d+56>>1]=1;e=d+480|0;f=d+56|0;H=a,I=x[ie(e,f)>>1],v[H+480196>>2]=I;H=d,I=Eb(x[d+1174>>1]),u[H+480>>1]=I;u[d+56>>1]=1;H=a,I=B(x[ie(e,f)>>1],1e4),v[H+480204>>2]=I;H=d,I=Bc(((Eb(x[d+1176>>1])<<8)+2047>>>0)/4095|0,0),v[H+480>>2]=I;v[d+56>>2]=256;H=a,I=v[Hb(e,f)>>2],v[H+480200>>2]=I;H=d,I=Eb(x[d+1178>>1]),u[H+480>>1]=I;Bf(e,127);f=0;e=x[d+480>>1];while(1){if((e|0)==(f|0)){break p}H=d,I=Bc(((Ej(b)<<8)+2047>>>0)/4095|0,0),u[H+56>>1]=I;u[d+376>>1]=256;H=((f<<5)+a|0)+480284|0,I=x[Rc(d+56|0,d+376|0)>>1],u[H>>1]=I;f=f+1|0;continue}}a=P()|0;O()|0;wb(d+56|0);break a}a=P()|0;O()|0;ac(d+56|0);break a}Zc(b,_b(v[d+948>>2]));m=he(d+872|0,b);v[23516]=0;R(374,d+856|0,m|0);b=v[23516];v[23516]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{if((b|0)!=1){v[23516]=0;U(375,d+480|0,d+856|0,1346458707);b=v[23516];v[23516]=0;if((b|0)==1){break H}v[23516]=0;b=W(154,v[d+480>>2],v[d+488>>2],2)|0;e=v[23516];v[23516]=0;if((e|0)==1){break K}if(!b){break I}v[23516]=0;b=T(274,d+480|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break K}if((b-1&65535)>>>0>126){break I}u[a+480188>>1]=b;b=d+480|0;yb(b);v[23516]=0;U(375,b|0,d+856|0,1397706311);b=v[23516];v[23516]=0;if((b|0)!=1){break L}a=P()|0;O()|0;break c}a=P()|0;O()|0;break b}v[23516]=0;b=W(154,v[d+480>>2],v[d+488>>2],2)|0;e=v[23516];v[23516]=0;if((e|0)==1){break G}if(!b){break I}v[23516]=0;b=T(274,d+480|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break G}u[d+56>>1]=b;b=w[a+484376|0];e=v[a+484360>>2];v[23516]=0;f=T(274,d+480|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break G}Te(Sb(e,b),f);v[23516]=0;b=T(200,d+480|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break G}Bf(d+56|0,tl(b>>>1|0));b=w[a+484376|0];e=v[a+484360>>2];v[23516]=0;U(277,Sb(e,b)|0,d+480|0,x[d+56>>1]);b=v[23516];v[23516]=0;if((b|0)==1){break G}b=d+480|0;yb(b);v[23516]=0;U(375,b|0,d+856|0,1480806221);b=v[23516];v[23516]=0;if((b|0)!=1){break J}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d+480|0);break c}v[23516]=0;b=W(154,v[d+480>>2],v[d+488>>2],3)|0;e=v[23516];v[23516]=0;if((e|0)!=1){if(b){break F}b=160;while(1){M:{f=b;if(!b){f=0;break M}b=f-1|0;if(w[(d+b|0)+984|0]==32){continue}}break}v[23516]=0;X(342,a+1298332|0,d+984|0,f|0,4);b=v[23516];v[23516]=0;if((b|0)!=1){break E}break D}break D}yb(d+480|0);f=0;break s}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d+480|0);break c}v[23516]=0;b=T(274,d+480|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){v[23516]=0;X(336,a+1298332|0,d+480|0,b|0,4);b=v[23516];v[23516]=0;if((b|0)!=1){break E}}break D}b=d+480|0;yb(b);v[23516]=0;U(375,b|0,d+856|0,1413697073);b=v[23516];v[23516]=0;if((b|0)==1){break C}v[23516]=0;b=T(204,d+480|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break A}if(b){break B}v[23516]=0;b=Q(153,d+480|0,2648)|0;e=v[23516];v[23516]=0;if((e|0)==1){break A}if(!b){break B}f=0;v[23516]=0;b=T(282,d+480|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break A}while(1){if((f|0)==32){break B}e=((f<<5)+a|0)+480280|0;v[e>>2]=v[e>>2]&-1025|!(b>>>f&1)<<10;f=f+1|0;continue}}a=P()|0;O()|0;yb(d+480|0);break c}a=P()|0;O()|0;break c}b=d+480|0;yb(b);v[23516]=0;U(375,b|0,d+856|0,1413697074);b=v[23516];v[23516]=0;if((b|0)==1){break z}v[23516]=0;b=W(154,v[d+480>>2],v[d+488>>2],12)|0;e=v[23516];v[23516]=0;if((e|0)==1){break y}N:{if(!b){break N}v[23516]=0;R(376,d+56|0,d+480|0);b=v[23516];v[23516]=0;if((b|0)==1){break y}b=d+56|0;e=Re(b);f=gc(b);g=KT(b);j=Db(b);n=JT(b);e=B(Bd(Eb(w[e|0]|w[e+1|0]<<8),32,999),1e4);b=rka(Eb(w[f|0]|w[f+1|0]<<8),0,1e4,0)+32768|0;f=kb;f=b>>>0<32768?f+1|0:f;H=a,I=e+((Bc((f&65535)<<16|b>>>16,f>>>16|0)>>>0)%1e4|0)|0,v[H+480204>>2]=I;H=a,I=Bd(Eb(w[g|0]|w[g+1|0]<<8),1,255),v[H+480196>>2]=I;b=16/(Bd(Eb(w[n|0]|w[n+1|0]<<8),1,16)>>>0)|0;v[a+480216>>2]=b;H=a,I=B(Bd(Eb(w[j|0]|w[j+1|0]<<8),1,16),b),v[H+480220>>2]=I;if(!Eb(x[d+56>>1])){break N}v[23516]=0;b=T(274,d+480|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break y}e=a+480208|0;v[e>>2]=v[e>>2]&-17|!b<<4}b=d+480|0;yb(b);v[23516]=0;U(375,b|0,d+856|0,1414942540);b=v[23516];v[23516]=0;if((b|0)==1){break x}v[23516]=0;b=W(154,v[d+480>>2],v[d+488>>2],2)|0;e=v[23516];v[23516]=0;if((e|0)==1){break v}if(!b){break w}v[23516]=0;b=T(274,d+480|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break v}u[d+56>>1]=b;u[d+376>>1]=x[a+480188>>1];b=x[Rc(d+56|0,d+376|0)>>1];f=0;while(1){if((b|0)==(f|0)){break w}v[23516]=0;e=T(274,d+480|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break v}u[d+56>>1]=e;u[d+376>>1]=4096;H=((f<<5)+a|0)+480286|0,I=x[Rc(d+56|0,d+376|0)>>1]>>>6&255,u[H>>1]=I;f=f+1|0;continue}}a=P()|0;O()|0;yb(d+480|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d+480|0);break c}a=P()|0;O()|0;break c}yb(d+480|0);v[23516]=0;U(375,d+56|0,d+856|0,1296652368);b=v[23516];v[23516]=0;if((b|0)==1){break u}v[23516]=0;b=W(154,v[d+56>>2],v[d+64>>2],56)|0;e=v[23516];v[23516]=0;if((e|0)==1){break d}if(!b){break t}v[23516]=0;R(377,d+56|0,d+480|0);b=v[23516];v[23516]=0;if((b|0)==1){break d}if((Eb(x[d+514>>1])|0)!=4){break t}if((Eb(x[d+528>>1])|0)!=257){break t}H=d,I=Eb(x[d+520>>1]),u[H+376>>1]=I;u[d+840>>1]=16384;e=x[Rc(d+376|0,d+840|0)>>1];b=e>>>24|0;e=(e<<8)+2048|0;b=e>>>0<2048?b+1|0:b;H=a,I=Bc((b&4095)<<20|e>>>12,b>>>12|0),v[H+480200>>2]=I;g=a+480188|0;f=0;while(1){if(Eb(x[d+518>>1])>>>0<=(f&65535)>>>0){break t}v[23516]=0;R(378,d+56|0,d+376|0);b=v[23516];v[23516]=0;if((b|0)==1){break d}O:{if(w[d+376|0]){break O}b=Eb(x[d+378>>1]);if(b>>>0>=x[g>>1]){break O}b=(b<<5)+a|0;H=b+480284|0,I=Bc(((Eb(x[d+382>>1])<<8)+2047>>>0)/4095|0,0),u[H>>1]=I;h=b+480286|0;e=Eb(x[d+380>>1]);b=e>>>26|0;e=(e<<6)+2048|0;b=e>>>0<2048?b+1|0:b;H=h,I=Bc((b&4095)<<20|e>>>12,b>>>12|0)&255,u[H>>1]=I}f=f+1|0;continue}}a=P()|0;O()|0;yb(d+480|0);break c}a=P()|0;O()|0;break c}b=d+56|0;yb(b);v[23516]=0;U(379,b|0,d+856|0,1396788530);b=v[23516];v[23516]=0;if((b|0)==1){break e}H=d,I=Cb(v[d+56>>2]),v[H+792>>2]=I;f=c&2;j=d+480|2;n=Cb(v[d+60>>2]);g=a+480190|0;l=a+1298464|0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{while(1){e=v[d+792>>2];if(!Nb(e,n)){b=d+56|0;Nc(b);v[23516]=0;U(379,b|0,d+856|0,1396788560);b=v[23516];v[23516]=0;if((b|0)==1){break f}H=d,I=Cb(v[d+56>>2]),v[H+824>>2]=I;j=d+480|2;n=Cb(v[d+60>>2]);e=a+480190|0;break P}v[23516]=0;b=Q(380,e|0,d+480|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break R}Z:{_:{if(!b){break _}b=Eb(x[d+480>>1]);if(!b|b>>>0>3999){break _}if(Eb(x[d+528>>1])>>>0>1){break _}if(Eb(x[d+510>>1])>>>0>1){break _}if(b>>>0>x[g>>1]){u[g>>1]=b}v[23516]=0;k=B(b,104)+a|0;b=k+484380|0;R(381,d+480|0,b|0);h=v[23516];v[23516]=0;$:{aa:{ba:{if((h|0)==1){break ba}h=d+840|0;Gi(h,3,j);v[23516]=0;R(221,d+376|0,h|0);h=v[23516];v[23516]=0;if((h|0)==1){break aa}h=d+376|0;Ac(((Eb(x[d+480>>1])<<5)+a|0)+946304|0,h);wb(h);if(!f){break _}h=x[d+554>>1]|x[d+556>>1]<<16;v[23516]=0;h=Q(153,e|0,_b(h)-8|0)|0;p=v[23516];v[23516]=0;if((p|0)==1){break ba}if(!h){break _}if(Eb(x[d+510>>1])){break $}h=d+376|0;Uc(h,(Eb(w[d+512|0]|w[d+513|0]<<8)|0)==8?8:16,(Eb(w[d+516|0]|w[d+517|0]<<8)|0)==1?1:2,!Eb(w[d+514|0]|w[d+515|0]<<8),0);v[23516]=0;W(218,h|0,b|0,e|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break $}a=P()|0;O()|0;break Q}a=P()|0;O()|0;break Q}a=P()|0;O()|0;break Q}b=Kb(d+376|0);h=x[d+530>>1];v[23516]=0;U(271,e|0,b|0,Eb(h)|0);e=v[23516];v[23516]=0;if((e|0)==1){break T}xe(k+484423|0,b);if((Eb(x[d+510>>1])|0)==1){v[23516]=0;R(382,d+824|0,16514);e=v[23516];v[23516]=0;if((e|0)==1){break Z}v[23516]=0;U(11,d+808|0,0,b|0);e=v[23516];v[23516]=0;if((e|0)==1){break Y}v[23516]=0;X(383,d+840|0,d+824|0,x[d+480>>1],d+808|0);e=v[23516];v[23516]=0;if((e|0)==1){break X}e=v[l>>2];v[23516]=0;U(384,e|0,2,d+840|0);e=v[23516];v[23516]=0;if((e|0)==1){break W}xb(d+840|0);xb(d+808|0);ac(d+824|0)}wb(b)}Jf(d+792|0);continue}break}a=P()|0;O()|0;break S}a=P()|0;O()|0;break U}a=P()|0;O()|0;break V}a=P()|0;O()|0;xb(d+840|0)}xb(d+808|0)}ac(d+824|0);break S}a=P()|0;O()|0}wb(b);break Q}a=P()|0;O()|0}Nc(d+56|0);break c}ca:{while(1){da:{g=v[d+824>>2];if(!Nb(g,n)){Nc(d+56|0);v[23516]=0;U(379,d+840|0,d+856|0,1447382614);b=v[23516];v[23516]=0;if((b|0)!=1){break ca}a=P()|0;O()|0;break c}v[23516]=0;b=Q(385,g|0,d+480|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break da}ea:{fa:{if(!b){break fa}b=Eb(x[d+480>>1]);if(!b|b>>>0>3999){break fa}if(Eb(x[d+534>>1])){break fa}if(b>>>0>x[e>>1]){u[e>>1]=b}v[23516]=0;b=(B(b,104)+a|0)+484380|0;R(386,d+480|0,b|0);l=v[23516];v[23516]=0;if((l|0)==1){break da}l=d+840|0;Gi(l,3,j);v[23516]=0;R(221,d+376|0,l|0);l=v[23516];v[23516]=0;if((l|0)==1){break da}l=d+376|0;Ac(((Eb(x[d+480>>1])<<5)+a|0)+946304|0,l);wb(l);if(!f){break fa}l=x[d+510>>1];k=d+376|0;Uc(k,(Eb(x[d+514>>1])|0)==8?8:16,Eb(l)&1?2:1,1,0);v[23516]=0;W(218,k|0,b|0,g|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break ea}}Jf(d+824|0);continue}}break}a=P()|0;O()|0;Nc(d+56|0);break c}v[23516]=0;U(379,d+824|0,d+856|0,1413828182);b=v[23516];v[23516]=0;if((b|0)==1){break h}v[23516]=0;U(379,d+808|0,d+856|0,1346719318);b=v[23516];v[23516]=0;if((b|0)==1){break j}v[23516]=0;U(379,d+792|0,d+856|0,1229869908);b=v[23516];v[23516]=0;if((b|0)==1){break l}H=d,I=Cb(v[d+792>>2]),v[H+24>>2]=I;n=d+426|0;l=d+376|2;k=d+480|2;h=Cb(v[d+796>>2]);p=a+480190|0;q=a+480208|0;while(1){ga:{ha:{ia:{ja:{g=v[d+24>>2];if(!Nb(g,h)){Nc(d+792|0);v[23516]=0;U(379,d+376|0,d+856|0,1346458692);b=v[23516];v[23516]=0;if((b|0)!=1){break ja}a=P()|0;O()|0;break k}v[23516]=0;b=Q(387,g|0,d+480|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break n}if(!b){break ga}if(Eb(x[d+510>>1])){break ga}b=x[d+480>>1];v[23516]=0;e=W(253,a|0,Eb(b)|0,0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break n}if(!e){break ga}b=Eb(x[d+480>>1]);if(b>>>0>x[a+480192>>1]){u[a+480192>>1]=b}b=d+376|0;Gi(b,3,k);v[23516]=0;R(221,d+56|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break ia}b=d+56|0;Ac(e+492|0,b);wb(b);t[e+33|0]=2;if((ne(u[d+514>>1])|0)>0){t[e+15|0]=w[e+15|0]|1;f=ne(u[d+514>>1]);b=f>>>24|0;j=(f<<8&-256)+2047|0;f=b&255;H=e,I=Bc(uka(j,j>>>0<2047?f+1|0:f,4095,0),kb),v[H+8>>2]=I}j=e+108|0;i=e+236|0;b=0;while(1){ka:{v[d+56>>2]=128;v[d+376>>2]=128;f=b&255;if(f>>>0>=y[Hb(d+56|0,d+376|0)>>2]){v[23516]=0;R(388,d+56|0,e|0);b=v[23516];v[23516]=0;if((b|0)==1){break ka}H=d,I=Ei(v[d+56>>2]),v[H+376>>2]=I;f=tf(d+56|0);while(1){b=v[d+376>>2];if(Nb(b,f)){b=x[go(b)>>1];if(!(!b|b>>>0>x[p>>1])){H=(B(b,104)+a|0)+484410|0,I=Eb(x[d+512>>1]),u[H>>1]=I}Ig(d+376|0);continue}break}bu(d+56|0);Ij(e,127,1);Hj(e,0,1);b=Eb(x[d+530>>1]);if(!b){v[e>>2]=0;b=x[d+516>>1];v[23516]=0;X(389,e|0,0,Eb(b)|0,d+840|0);b=v[23516];v[23516]=0;if((b|0)==1){break n}b=x[d+520>>1];v[23516]=0;X(389,e|0,1,Eb(b)|0,d+808|0);b=v[23516];v[23516]=0;if((b|0)==1){break n}b=x[d+518>>1];v[23516]=0;X(389,e|0,2,Eb(b)|0,d+824|0);b=v[23516];v[23516]=0;if((b|0)!=1){break ga}break n}v[23516]=0;U(390,g|0,d+376|0,((b|0)==1?98:102)|0);b=v[23516];v[23516]=0;la:{ma:{na:{if((b|0)!=1){b=Eb(x[d+376>>1]);j=b&1;if(!j){break ha}f=b&24;if(f){break na}f=0;break ma}a=P()|0;O()|0;break m}if((f|0)!=8){break la}f=1}t[e+25|0]=f}oa:{pa:{qa:{ra:{if(!(b&2)){break ra}v[23516]=0;b=W(391,d+360|0,l|0,24)|0;f=v[23516];v[23516]=0;if((f|0)==1){break qa}v[23516]=0;z=+ma(392,b|0);f=v[23516];v[23516]=0;if((f|0)==1){break pa}wb(b);if(!(z>20)){break ra}Ij(e,TA(v[q>>2],z),1)}if(Eb(x[d+376>>1])&4){break oa}break ha}a=P()|0;O()|0;break m}a=P()|0;O()|0;wb(b);break m}v[23516]=0;b=W(391,d+344|0,n|0,24)|0;f=v[23516];v[23516]=0;sa:{if((f|0)!=1){v[23516]=0;z=+ma(392,b|0);f=v[23516];v[23516]=0;if((f|0)==1){break sa}wb(b);Hj(e,nk(z*127/24),1);break ha}a=P()|0;O()|0;break m}a=P()|0;O()|0;wb(b);break m}else{o=(d+480|0)+(f<<1)|0;H=$b(i,f),I=w[o+52|0],u[H>>1]=I;f=Ib(j,f);H=f,I=Cm(t[o+53|0]+w[f|0]|0),t[H|0]=I;b=b+1|0;continue}}break}a=P()|0;O()|0;break m}b=v[d+380>>2];e=v[d+376>>2];v[23516]=0;g=a+484344|0;R(224,g|0,wf(e,b)&65535);b=v[23516];v[23516]=0;ta:{if((b|0)!=1){v[d+48>>2]=v[a+480204>>2];v[d+40>>2]=v[a+480196>>2];H=d,I=Cb(v[d+376>>2]),v[H+8>>2]=I;o=c&1;b=d+56|0;r=b|4;A=b|2;C=b|1;D=Cb(v[d+380>>2]);E=a+480188|0;while(1){ua:{va:{wa:{xa:{ya:{za:{b=v[d+8>>2];if(!Nb(b,D)){v[23516]=0;U(375,d+56|0,d+856|0,1414414669);b=v[23516];v[23516]=0;if((b|0)!=1){break za}a=P()|0;O()|0;break ta}if(!o){break ua}c=v[b+8>>2];e=v[b>>2];v[23516]=0;c=W(154,e|0,c|0,24)|0;e=v[23516];v[23516]=0;if((e|0)==1){break ya}if(!c){break ua}v[23516]=0;j=T(274,b|0)|0;c=v[23516];v[23516]=0;Aa:{Ba:{Ca:{Da:{if((c|0)!=1){t[d+496|0]=0;v[d+488>>2]=0;v[d+492>>2]=0;v[d+480>>2]=0;v[d+484>>2]=0;v[23516]=0;R(393,b|0,d+480|0);c=v[23516];v[23516]=0;if((c|0)==1){break Da}v[23516]=0;p=T(274,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Ca}v[23516]=0;n=T(274,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Ba}v[23516]=0;l=T(274,b|0)|0;c=v[23516];v[23516]=0;Ea:{if((c|0)==1){break Ea}c=v[b+8>>2];e=v[b>>2];v[23516]=0;c=W(154,e|0,c|0,B(B(l,n),5)|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break Ea}if(!(c&p>>>0<2)){break ua}v[23516]=0;c=W(225,g|0,j|0,n|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break Ea}if(!c){break ua}c=v[g>>2];v[23516]=0;R(394,Xb(c,j)|0,d+480|0);c=v[23516];v[23516]=0;if((c|0)!=1){break Aa}}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ta}t[d+24|0]=0;c=ae(d+56|0,0,d+24|0);v[23516]=0;c=W(370,d+792|0,l|0,c|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break va}e=0;Fa:while(1){if((e|0)==(n|0)){gd(c);break ua}f=0;k=Xb(v[g>>2],j);F=xf(v[k>>2],v[v[k+48>>2]+12>>2],e);while(1){if((f|0)==(l|0)){e=e+1|0;continue Fa}h=sg(d+56|0);q=x[E>>1];v[23516]=0;R(395,b|0,d+24|0);k=v[23516];v[23516]=0;Ga:{if((k|0)==1){break Ga}k=B(f,6)+F|0;i=h;h=f>>>0<q>>>0;q=h?k:i;i=w[d+24|0];if((i-1&255)>>>0<=119){i=i+1|0;t[q|0]=i;H=$b(v[c>>2],f),I=i,t[H|0]=I}i=w[d+25|0];if(i){t[(h?k+1|0:C)|0]=i;H=$b(v[c>>2],f),I=i,t[H+1|0]=I}i=w[d+28|0];if(i){t[(h?k+2|0:A)|0]=1;t[(h?k+4|0:r)|0]=p?i-16|0:i>>>2|0}k=w[d+947|0];h=w[d+27|0];i=w[d+26|0];s=$b(v[c>>2],f);G=w[s+1|0];s=w[s|0];v[23516]=0;Da(372,a|0,q|0,i|0,h|0,k|0,s|0,G|0,d+48|0,d+40|0);k=v[23516];v[23516]=0;if((k|0)==1){break Ga}f=f+1|0;continue}break}break}a=P()|0;O()|0;gd(c);break ta}v[23516]=0;b=W(154,v[d+56>>2],v[d+64>>2],38)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(!b){break wa}v[23516]=0;b=T(274,d+56|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break xa}c=d+480|4;e=a+480188|0;f=0;Ha:{while(1){if(b>>>0<=(f&65535)>>>0){break wa}v[23516]=0;g=W(154,v[d+56>>2],v[d+64>>2],36)|0;j=v[23516];v[23516]=0;Ia:{if((j|0)!=1){if(g){break Ia}break wa}break xa}v[23516]=0;R(396,d+56|0,d+480|0);g=v[23516];v[23516]=0;if((g|0)!=1){Ja:{if(Eb(x[d+480>>1])){break Ja}if(Eb(x[d+482>>1])>>>0>=x[e>>1]){break Ja}g=d+8|0;Ke(g,3,c);v[23516]=0;R(221,d+24|0,g|0);g=v[23516];v[23516]=0;if((g|0)==1){break Ha}g=d+24|0;wl(((Eb(x[d+482>>1])<<5)+a|0)+480289|0,g);wb(g)}f=f+1|0;continue}break}break xa}break xa}break xa}a=P()|0;O()|0;break ta}a=P()|0;O()|0;yb(d+56|0);break ta}yb(d+56|0);Nc(d+376|0);Nc(d+808|0);Nc(d+824|0);Nc(d+840|0);f=1;break s}a=P()|0;O()|0;break ta}Jf(d+8|0);continue}}a=P()|0;O()|0}Nc(d+376|0);break k}a=P()|0;O()|0;break m}f=0;while(1){if(w[d+477|0]<=f>>>0){break ga}v[23516]=0;R(397,g|0,d+56|0);b=v[23516];v[23516]=0;Ka:{La:{if((b|0)!=1){v[d+8>>2]=33620480;H=d,I=(Eb(x[d+516>>1])|0)!=0,t[H+48|0]=I;H=d,I=(Eb(x[d+518>>1])|0)!=0,t[H+49|0]=I;H=d,I=(Eb(x[d+520>>1])|0)!=0,t[H+50|0]=I;H=d,I=j&(Eb(x[d+522>>1])|0)!=0,t[H+51|0]=I;if(!w[(d+48|0)+f|0]|f>>>0>3){break Ka}b=(f|0)!=3;if(!b&(t[e+100|0]&1)){break Ka}v[23516]=0;i=w[(d+8|0)+f|0];U(398,d+56|0,e|0,i|0);o=v[23516];v[23516]=0;if((o|0)==1){break La}if(!b){t[e+100|0]=w[e+100|0]|16}Ma:{switch(i|0){case 0:if(Eb(x[d+68>>1])&1){b=Eb(x[d+66>>1])&32767}else{b=0}v[e>>2]=b;break Ka;case 2:break Ma;default:break Ka}}if(!(Eb(x[d+68>>1])&2)){break Ka}H=d,I=Eb(x[d+62>>1]),u[H+40>>1]=I;u[d+46>>1]=1;b=x[ie(d+40|0,d+46|0)>>1];i=Bl(Bc(((Eb(x[d+58>>1])<<6|48)>>>0)/100|0,0));H=d,I=Eb(x[d+60>>1]),u[H+40>>1]=I;u[d+46>>1]=1;o=rg(256/x[ie(d+40|0,d+46|0)>>1]|0);r=x[d+480>>1];A=x[d+64>>1];v[23516]=0;s=Eb(r);r=Eb(A);la(399,a|0,s|0,w[(r>>>0<6?r:0)+26768|0],255/(b>>>0)|0,i|0,o|0);b=v[23516];v[23516]=0;if((b|0)!=1){break Ka}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}f=f+1|0;continue}}Jf(d+24|0);continue}}Ud(d+856|0);yb(m)}hb=d+1184|0;return f|0}a=P()|0;O()|0}Nc(d+792|0);break k}a=P()|0;O()|0}Nc(d+808|0);break i}a=P()|0;O()|0}Nc(d+824|0);break g}a=P()|0;O()|0}Nc(d+840|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d+56|0)}Ud(d+856|0)}yb(m)}S(a|0);L()}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,U=0,V=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0;o=hb-1152|0;hb=o;xc(b);a:{if(!jr(b,o+1128|0)){break a}if(!IL(o+1128|0)){break a}if(v[o+1136>>2]!=(nh(v[b>>2])|0)){break a}if(v[o+1144>>2]!=($e(b)|0)){break a}if(!c){i=1;break a}h=o+1072|0;Rb(h,0,56);g=-2;b:{if(!h){break b}v[h+44>>2]=0;v[h+48>>2]=0;v[h+52>>2]=0;v[h+20>>2]=0;v[h+24>>2]=0;v[h+8>>2]=0;d=v[h+32>>2];if(!d){v[h+32>>2]=1111;d=1111}if(!v[h+36>>2]){v[h+36>>2]=1112}d=lb[d|0](v[h+40>>2],1,43784)|0;g=-4;if(!d){break b}v[h+28>>2]=d;v[d+43780>>2]=1;v[d+10992>>2]=0;v[d+10996>>2]=0;v[d>>2]=0;v[d+11008>>2]=15;v[d+11e3>>2]=1;v[d+11004>>2]=0;g=0}if(g){break a}i=v[o+1144>>2];v[o+1068>>2]=i;H=v[o+1148>>2];U=kT(o+1056|0,H);c:{d:{while(1){if(!(!i|!H|(e|0)==1)){v[o+16>>2]=1024;d=o+16|0;V=v[Hb(d,o+1068|0)>>2];e=v[fc(o+24|0,o+32|0,V)>>2];v[23516]=0;X(163,d|0,b|0,e|0,v[o+28>>2]);e=v[23516];v[23516]=0;if((e|0)==1){break d}h=o+32|0;e=h;i=V;g=ba^-1;while(1){if(i>>>0<4){while(1){if(i){g=v[((w[e|0]^g&255)<<2)+63392>>2]^g>>>8;i=i-1|0;e=e+1|0;continue}break}ba=g^-1}else{d=v[((w[e|0]^g&255)<<2)+63392>>2]^g>>>8;d=d>>>8^v[((w[e+1|0]^d&255)<<2)+63392>>2];d=d>>>8^v[((w[e+2|0]^d&255)<<2)+63392>>2];g=d>>>8^v[((w[e+3|0]^d&255)<<2)+63392>>2];i=i-4|0;e=e+4|0;continue}break}v[o+1076>>2]=V;v[o+1072>>2]=h;v[o+1088>>2]=H;v[o+1084>>2]=v[U>>2]+ca;F=hb-16|0;hb=F;e=-2;p=o+1072|0;e:{if(!p){break e}j=v[p+28>>2];if(!j){break e}da=v[p+4>>2];v[j+11e3>>2]=0;f:{if(v[j+43780>>2]<0){break f}if(v[j+11004>>2]){break e}d=v[j+11008>>2];e=0;v[j+11004>>2]=0;g=v[j+10996>>2];if(!g){s=(d|0)>0?11:10;I=j+11012|0;i=v[p+4>>2];h=v[j+10992>>2];while(1){v[F+12>>2]=i;v[F+8>>2]=32768-h;d=0;g=0;r=0;G=0;J=0;K=0;_=0;$=hb-144|0;hb=$;e=v[F+8>>2];C=h+I|0;Y=s&4;Z=Y?-1:e+(C+(I^-1)|0)|0;E=Z+1|0;M=e+C|0;D=v[p>>2];N=v[F+12>>2];A=D+N|0;g:{if(!(E&Z?0:C>>>0>=I>>>0)){v[F+8>>2]=0;v[F+12>>2]=0;l=-3;break g}Q=v[j+60>>2];z=v[j+40>>2];e=v[j+36>>2];q=v[j+32>>2];h=v[j+56>>2];f=v[j+4>>2];l=-1;k=D;m=C;n=-1;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{i=v[j>>2];switch(i|0){case 36:break k;case 39:break n;case 10:break o;case 35:break p;case 17:break q;case 21:break r;case 37:break s;case 34:break t;case 42:break x;case 41:break y;case 53:break z;case 52:break A;case 51:break B;case 38:break C;case 27:break D;case 26:break E;case 25:break F;case 24:break G;case 23:break H;case 18:break I;case 16:break J;case 14:break K;case 11:break L;case 9:break M;case 7:break N;case 6:break O;case 3:break P;case 32:break Q;case 5:break R;case 2:break T;case 1:break U;case 0:break V;default:break j}}v[j+28>>2]=1;h=0;v[j+8>>2]=0;v[j+12>>2]=0;v[j+16>>2]=1;z=0;e=0;q=0;f=0;if(s&1){break U}break S}if((N|0)<=0){v[j>>2]=1;break i}v[j+8>>2]=w[D|0];k=D+1|0}if(k>>>0>=A>>>0){v[j>>2]=2;l=s&2?1:-4;break h}e=w[k|0];v[j+12>>2]=e;k=k+1|0;n=v[j+8>>2];W:{if(!(((e|n<<8)>>>0)%31|e&32)){g=n&15;d=(g|0)!=8;if(!Y){break W}e=0;i=36;if((g|0)!=8){break m}break S}i=36;d=1;if(Y){break m}}e=0;i=36;g=d;d=256<<(n>>>4);if(g|(d>>>0>32768|d>>>0>E>>>0)){break m}}d=0;break w}if((N|0)<=0){v[j>>2]=5;break i}K=f+8|0;k=D+1|0;h=w[D|0]<<f|h;d=2;break w}if((N|0)<=0){v[j>>2]=32;break i}f=f+8|0;k=D+1|0;i=e;break v}d=1;break w}d=4;break w}d=3;break w}d=7;break w}d=9;break w}d=10;break w}d=11;break w}d=12;break w}d=13;break w}d=14;break w}d=15;break w}d=16;break w}d=17;break w}d=8;break w}d=5;break w}d=6;break w}d=18;break w}i=2;break u}i=1;break u}X:while(1){Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{switch(d|0){case 0:if(f>>>0>2){break Ba}d=1;continue;case 1:break Ca;case 9:break ga;case 10:break ha;case 11:break ia;case 12:break ja;case 13:break ka;case 14:break la;case 15:break ma;case 16:break na;case 17:break oa;case 8:break ta;case 7:break ua;case 6:break va;case 5:break wa;case 4:break ya;case 3:break za;case 2:break Aa;default:break pa}}while(1){if(k>>>0>=A>>>0){v[j>>2]=3;l=s&2?1:-4;break h}h=w[k|0]<<f|h;k=k+1|0;f=f+8|0;if(f>>>0<3){continue}break}}g=h&7;v[j+20>>2]=g;d=g>>>1|0;v[j+24>>2]=d;f=f-3|0;h=h>>>3|0;if(g>>>0>=2){break sa}K=f;break qa}f=K&-8;h=h>>>(K&7)|0;e=0;d=0;break ra}if(k>>>0<A>>>0){break xa}v[j>>2]=7;l=s&2?1:-4;break h}while(1){if(k>>>0>=A>>>0){v[j>>2]=6;l=s&2?1:-4;break h}h=w[k|0]<<f|h;d=f>>>0>4294967287;k=k+1|0;f=f+8|0;if(d){continue}break}d=1;break ra}t[(e+j|0)+10528|0]=w[k|0];k=k+1|0;d=2;break ra}while(1){if(k>>>0>=A>>>0){v[j>>2]=51;l=s&2?1:-4;break h}h=w[k|0]<<f|h;d=f>>>0>4294967287;k=k+1|0;f=f+8|0;if(d){continue}break}break _}n=2;i=52;if(m>>>0>=M>>>0){break k}t[m|0]=q;e=e-1|0;m=m+1|0;break $}n=2;i=9;if(m>>>0>=M>>>0){break k}d=8;continue}if(k>>>0<A>>>0){g=M-m|0;d=A-k|0;d=d>>>0>g>>>0?g:d;d=d>>>0<e>>>0?d:e;e=e-d|0;m=pc(m,k,d)+d|0;k=d+k|0;break Z}v[j>>2]=38;l=s&2?1:-4;break h}i=0;Da:{switch(d-1|0){case 0:v[j+44>>2]=288;v[j+48>>2]=32;d=j+3552|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=j+3560|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=j+3568|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=j+3576|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=j- -64|0;g=0;while(1){i=144;if((g|0)==144){while(1){g=256;if((i|0)==256){while(1){i=280;if((g|0)==280){while(1){if((i|0)==288){break da}t[d|0]=8;i=i+1|0;d=d+1|0;continue}}else{t[d|0]=7;g=g+1|0;d=d+1|0;continue}}}else{t[d|0]=9;i=i+1|0;d=d+1|0;continue}}}else{t[d|0]=8;g=g+1|0;d=d+1|0;continue}};case 2:break o;default:break Da}}d=0;break fa}while(1){Ea:{Fa:{Ga:{Ha:{Ia:{switch(d|0){case 0:if(e>>>0>3){break Ha}if(!f){f=0;d=3;continue X}if(f>>>0>7){break Fa}d=4;continue X;case 1:t[(e+j|0)+10528|0]=h;f=f-8|0;h=h>>>8|0;break Ea;default:break Ia}}e=e+1|0;break Ga}e=x[j+10528>>1];if((e|0)==(x[j+10530>>1]^65535)){break $}break n}d=0;continue}d=1;continue}d=2;continue}}d=2;continue}n=2;i=53;if(m>>>0>=M>>>0){break k}t[m|0]=w[(Q-q&Z)+I|0];m=m+1|0;Q=Q+1|0;d=7;break aa}while(1){if(k>>>0>=A>>>0){v[j>>2]=27;l=s&2?1:-4;break h}h=w[k|0]<<f|h;k=k+1|0;f=f+8|0;if(z>>>0>f>>>0){continue}break}d=6;break aa}if(k>>>0>=A>>>0){v[j>>2]=26;l=s&2?1:-4;break h}h=w[k|0]<<f|h;k=k+1|0;f=f+8|0;d=4;if(f>>>0<15){break aa}d=5;break aa}while(1){if(k>>>0>=A>>>0){v[j>>2]=25;l=s&2?1:-4;break h}h=w[k|0]<<f|h;k=k+1|0;f=f+8|0;if(z>>>0>f>>>0){continue}break}d=3;break aa}n=2;i=24;if(m>>>0>=M>>>0){break k}t[m|0]=e;m=m+1|0;break ba}if(k>>>0>=A>>>0){v[j>>2]=23;l=s&2?1:-4;break h}h=w[k|0]<<f|h;k=k+1|0;f=f+8|0;d=0;if(f>>>0<15){break aa}d=1;break aa}while(1){if(k>>>0>=A>>>0){v[j>>2]=18;l=s&2?1:-4;break h}h=w[k|0]<<f|h;k=k+1|0;f=f+8|0;if(z>>>0>f>>>0){continue}break}_=q-16|0;d=3;break ca}if(k>>>0>=A>>>0){v[j>>2]=16;l=s&2?1:-4;break h}h=w[k|0]<<f|h;k=k+1|0;f=f+8|0;d=1;if(f>>>0<15){break ca}d=2;break ca}while(1){if(k>>>0>=A>>>0){v[j>>2]=14;l=s&2?1:-4;break h}h=w[k|0]<<f|h;k=k+1|0;f=f+8|0;if(f>>>0<3){continue}break}d=1;break ea}d=e+21732|0;while(1){if(k>>>0>=A>>>0){v[j>>2]=11;l=s&2?1:-4;break h}h=w[k|0]<<f|h;k=k+1|0;f=f+8|0;J=t[d|0];if(f>>>0<J>>>0){continue}break}i=e;d=1}while(1){Ja:{Ka:{La:{if(!d){if(i>>>0>2){break La}e=i;J=t[e+21732|0];if(J>>>0<=f>>>0){break Ja}d=9;continue X}e=i<<2;v[(e+j|0)+44>>2]=v[e+64928>>2]+((-1<<J^-1)&h);i=i+1|0;f=f-J|0;h=h>>>J|0;break Ka}e=0;Rb(j+7040|0,0,288);d=0;break ea}d=0;continue}d=1;continue}}while(1){Ma:{Na:{Oa:{if(!d){if(y[j+52>>2]<=e>>>0){break Oa}if(f>>>0>2){break Ma}d=10;continue X}t[(w[e+64944|0]+j|0)+7040|0]=h&7;e=e+1|0;f=f-3|0;h=h>>>3|0;break Na}v[j+52>>2]=19;break da}d=0;continue}d=1;continue}}G=v[j+24>>2];d=0}while(1){Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{switch(d|0){case 0:d=0;if((G|0)<0){break ba}R=Rb($,0,64);g=B(G,3488)+j|0;Rb(g+352|0,0,3200);N=g- -64|0;E=v[j+24>>2];i=v[((E<<2)+j|0)+44>>2];while(1){if((d|0)!=(i|0)){g=(w[d+N|0]<<2)+R|0;v[g>>2]=v[g>>2]+1;d=d+1|0;continue}break};v[R+64>>2]=0;v[R+68>>2]=0;l=0;d=1;g=0;while(1){if((d|0)!=16){n=d<<2;d=d+1|0;n=v[n+R>>2];g=n+g<<1;v[(R- -64|0)+(d<<2)>>2]=g;l=l+n|0;continue}break};T=0;n=-1;if((g|0)!=65536&l>>>0>=2){break p}while(1){if(i>>>0>T>>>0){l=w[N+T|0];Ya:{if(!l){break Ya}d=(R- -64|0)+(l<<2)|0;g=v[d>>2];v[d>>2]=g+1;d=0;i=l;while(1){if(i){d=g&1|d<<1;g=g>>>1|0;i=i-1|0;continue}break}if(l>>>0<=10){E=1<<l;i=l<<9|T;g=B(G,3488)+j|0;while(1){if(d>>>0>1023){break Ya}u[(g+(d<<1)|0)+352>>1]=i;d=d+E|0;continue}}E=B(G,3488)+j|0;g=E+((d&1023)<<1)|0;i=u[g+352>>1];Za:{if(i){g=n;n=i;break Za}u[g+352>>1]=n;g=n-2|0}d=d>>>9|0;while(1){d=d>>>1|0;i=d&1;if(l>>>0>=12){i=(E+(i+(n^-1)<<1)|0)+2400|0;n=u[i>>1];if(!n){u[i>>1]=g;n=g;g=g-2|0}l=l-1|0;continue}break}u[((B(G,3488)+j|0)+(i+(n^-1)<<1)|0)+2400>>1]=T;n=g}T=T+1|0;E=v[j+24>>2];i=v[((E<<2)+j|0)+44>>2];continue}break};d=0;if((E|0)!=2){break Qa}break Ua;case 1:d=u[(((h&1023)<<1)+j|0)+7328>>1];_a:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break _a}break Ta}i=10;if(f>>>0<11){break _a}while(1){$a:{n=h>>>i|0;g=i+2|0;i=i+1|0;d=u[(((n&1)+(d^-1)<<1)+j|0)+9376>>1];if((d|0)>=0){break $a}if(f>>>0>=g>>>0){continue}}break}if((d|0)>=0){break Ta}}d=11;continue X;case 2:d=10;q=u[(((h&1023)<<1)+j|0)+7328>>1];if((q|0)>=0){break Wa}while(1){g=h>>>d|0;d=d+1|0;q=u[(((g&1)+(q^-1)<<1)+j|0)+9376>>1];if((q|0)<0){continue}break};break Va;default:break Xa}}i=t[_+17941|0]+((-1<<z^-1)&h)|0;f=f-z|0;h=h>>>z|0;g=e+j|0;Rb(g+10532|0,(q|0)==16?w[g+10531|0]:0,i);d=e+i|0;break Ua}d=q>>9;q=q&511}f=f-d|0;h=h>>>d|0;if(q>>>0>15){break Sa}t[(e+j|0)+10532|0]=q;d=e+1|0}g=v[j+48>>2];i=v[j+44>>2];e=g+i|0;if(e>>>0<=d>>>0){break Ra}if(f>>>0<=14){if((A-k|0)<=1){e=d;d=1;continue}h=w[k|0]<<f|h|w[k+1|0]<<f+8;k=k+2|0;f=f+16|0}e=d}d=2;continue}if(!((q|0)!=16|e)){e=0;q=16;break q}_=q-16|0;z=t[q+21707|0];if(z>>>0<=f>>>0){break Pa}d=12;continue X}if((d|0)!=(e|0)){e=d;break r}e=j+10532|0;pc(j- -64|0,e,i);pc(j+3552|0,e+i|0,g);E=v[j+24>>2];e=d}G=E-1|0;v[j+24>>2]=G;d=0;continue}d=3;continue}}r=e;d=2}ab:while(1){bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{switch(d|0){case 0:d=u[(((h&1023)<<1)+j|0)+352>>1];ob:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break ob}break bb}i=10;if(f>>>0<11){break ob}while(1){pb:{n=h>>>i|0;g=i+2|0;i=i+1|0;d=u[(((n&1)+(d^-1)<<1)+j|0)+2400>>1];if((d|0)>=0){break pb}if(f>>>0>=g>>>0){continue}}break}if((d|0)>=0){break bb}}d=13;continue X;case 1:d=10;e=u[(((h&1023)<<1)+j|0)+352>>1];if((e|0)>=0){break mb}while(1){g=h>>>d|0;d=d+1|0;e=u[(((g&1)+(e^-1)<<1)+j|0)+2400>>1];if((e|0)<0){continue}break};break lb;case 2:while(1){d=A-k|0;if(!((M-m|0)>1&(d|0)>=4)){if(f>>>0>14){break bb}if((d|0)<=1){e=r;d=0;continue ab}h=w[k|0]<<f|h|w[k+1|0]<<f+8;f=f+16|0;k=k+2|0;break bb}if(f>>>0>14){g=k}else{h=(w[k|0]|w[k+1|0]<<8)<<f|h;f=f+16|0;g=k+2|0}d=10;r=u[(((h&1023)<<1)+j|0)+352>>1];qb:{if((r|0)>=0){d=r>>9;break qb}while(1){e=h>>>d|0;d=d+1|0;r=u[(((e&1)+(r^-1)<<1)+j|0)+2400>>1];if((r|0)<0){continue}break}}f=f-d|0;h=h>>>d|0;if(r&256){k=g;e=r;break kb}if(!(f>>>0>14)){h=(w[g|0]|w[g+1|0]<<8)<<f|h;g=g+2|0;f=f+16|0}l=f;k=g;d=10;e=u[(((h&1023)<<1)+j|0)+352>>1];rb:{if((e|0)>=0){d=e>>9;break rb}while(1){g=h>>>d|0;d=d+1|0;e=u[(((g&1)+(e^-1)<<1)+j|0)+2400>>1];if((e|0)<0){continue}break}}t[m|0]=r;f=l-d|0;h=h>>>d|0;if(!(e&256)){t[m+1|0]=e;m=m+2|0;continue}break};m=m+1|0;break kb;case 3:f=f-z|0;d=h>>>z|0;e=((-1<<z^-1)&h)+e|0;break jb;case 4:d=u[(((h&1023)<<1)+j|0)+3840>>1];sb:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break sb}break ib}i=10;if(f>>>0<11){break sb}while(1){tb:{n=h>>>i|0;g=i+2|0;i=i+1|0;d=u[(((n&1)+(d^-1)<<1)+j|0)+5888>>1];if((d|0)>=0){break tb}if(f>>>0>=g>>>0){continue}}break}if((d|0)>=0){break ib}}d=16;continue X;case 5:i=10;d=u[(((h&1023)<<1)+j|0)+3840>>1];if((d|0)>=0){break hb}while(1){g=h>>>i|0;i=i+1|0;d=u[(((g&1)+(d^-1)<<1)+j|0)+5888>>1];if((d|0)<0){continue}break};break gb;case 6:f=f-z|0;i=h>>>z|0;q=((-1<<z^-1)&h)+q|0;break fb;default:break nb}}r=-1;d=e;e=d-1|0;if(!d){break eb}d=18;continue X}d=e>>9;e=e&511}f=f-d|0;h=h>>>d|0;if(e>>>0>255){break kb}d=14;continue X}i=256;g=e&511;if((g|0)==256){break Y}d=g-257<<2;e=v[d+64416>>2];z=0;if(g-285>>>0<4294967276){d=h;break jb}z=v[d+64544>>2];if(z>>>0<=f>>>0){break db}d=15;continue X}if(f>>>0>14){h=d;break ib}if((A-k|0)<=1){h=d;d=4;continue}h=w[k|0]<<f|d|w[k+1|0]<<f+8;f=f+16|0;k=k+2|0}d=5;continue}i=d>>9;d=d&511}f=f-i|0;h=h>>>i|0;g=d<<2;q=v[g+64672>>2];z=0;if(d-30>>>0<4294967270){i=h;break fb}z=v[g+64800>>2];if(z>>>0<=f>>>0){break cb}d=17;continue X}Q=m-I|0;if(!(!Y|(q|0)!=0&Q>>>0>=q>>>0)){h=i;break s}d=(Q-q&Z)+I|0;if((d>>>0<m>>>0?m:d)+e>>>0>M>>>0){h=i;d=7;continue}r=e;while(1){if(r>>>0>=3){t[m|0]=w[d|0];t[m+1|0]=w[d+1|0];t[m+2|0]=w[d+2|0];r=r-3|0;d=d+3|0;m=m+3|0;continue}break}if(!r){h=i;r=0;break eb}t[m|0]=w[d|0];if((r|0)!=1){t[m+1|0]=w[d+1|0]}m=m+r|0;h=i}d=2;continue}d=3;continue}d=6;continue}d=1;continue}}if(!e|!f){break Z}if(f>>>0>7){break _}d=5;continue}f=f-8|0;q=h&255;h=h>>>8|0;d=6;continue}i=0;if(!e){break Y}d=7;continue}e=i;if(t[j+20|0]&1){break v}d=0;continue}}h=0;d=f>>>3|0;e=k-D|0;e=e>>>0>k>>>0?0:e;e=k>>>0>D>>>0?d>>>0<e>>>0?d:e:0;if((f&-8)==e<<3){k=k-e|0;g=0;d=0;e=i;f=0;if(!(s&1)){break t}i=0;break u}aa(6842,13204,2797,6852);L()}while(1){ub:{vb:{wb:{xb:{yb:{zb:{switch(i|0){case 0:if(g>>>0>3){e=g;f=d;break t}f=0;if(d){break yb}e=g;i=1;continue;case 1:break zb;default:break xb}}if(k>>>0<A>>>0){break vb}v[j>>2]=42;l=s&2?1:-4;break h}e=g;f=d;if(d>>>0>7){break wb}i=2;continue}while(1){if(k>>>0>=A>>>0){v[j>>2]=41;l=s&2?1:-4;break h}h=w[k|0]<<f|h;g=f>>>0>4294967287;k=k+1|0;d=f+8|0;f=d;if(g){continue}break}g=e}i=h&255;h=h>>>8|0;d=d-8|0;break ub}i=w[k|0];k=k+1|0;g=e;d=f}v[j+16>>2]=v[j+16>>2]<<8|i;g=g+1|0;i=0;continue}}n=0;i=34;break k}i=37;break l}i=21;break l}i=17;break l}i=35;break l}i=10;break l}i=39;break l}e=1}n=-1}v[j>>2]=i;l=n}g=f>>>3|0;d=k-D|0;d=d>>>0>k>>>0?0:d;d=k>>>0>D>>>0?d>>>0>g>>>0?g:d:0;k=k-d|0;f=f-(d<<3)|0;break h}l=s&2?1:-4}v[j+4>>2]=f;v[j+60>>2]=Q;v[j+40>>2]=z;v[j+36>>2]=e;v[j+32>>2]=q;v[j+56>>2]=(((f&63)>>>0>=32?0:-1<<f)^-1)&h;v[F+12>>2]=k-D;f=m-C|0;v[F+8>>2]=f;if(!(s&9)|(l|0)<0){break g}k=(f>>>0)%5552|0;e=v[j+28>>2];d=e>>>16|0;h=e&65535;while(1){i=0;if(f){while(1){if((i|7)>>>0<k>>>0){m=w[C|0]+h|0;D=m+w[C+1|0]|0;K=D+w[C+2|0]|0;r=K+w[C+3|0]|0;n=r+w[C+4|0]|0;g=n+w[C+5|0]|0;e=g+w[C+6|0]|0;h=e+w[C+7|0]|0;d=h+(e+(g+(n+(r+(K+(D+(d+m|0)|0)|0)|0)|0)|0)|0)|0;C=C+8|0;i=i+8|0;continue}break}e=k&7;i=k&8184;g=C;while(1){if((i|0)!=(k|0)){i=i+1|0;h=w[g|0]+h|0;d=h+d|0;g=g+1|0;continue}break}f=f-k|0;d=(d>>>0)%65521|0;h=(h>>>0)%65521|0;C=e+C|0;k=5552;continue}else{e=d<<16|h;v[j+28>>2]=e;if(l){break g}l=0;if(!(s&1)){break g}l=(e|0)==v[j+16>>2]?0:-2}break}}hb=$+144|0;v[j+43780>>2]=l;e=v[F+12>>2];v[p>>2]=e+v[p>>2];v[p+4>>2]=v[p+4>>2]-e;v[p+8>>2]=e+v[p+8>>2];v[p+48>>2]=v[j+28>>2];d=v[F+8>>2];v[j+10996>>2]=d;e=v[p+16>>2];g=d>>>0<e>>>0?d:e;pc(v[p+12>>2],v[j+10992>>2]+I|0,g);v[p+12>>2]=g+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-g;v[p+20>>2]=g+v[p+20>>2];d=v[j+10996>>2];v[j+10996>>2]=d-g;h=g+v[j+10992>>2]&32767;v[j+10992>>2]=h;if((l|0)<0){break f}if(!((l|0)!=1|da)){e=-5;break e}if(l){e=0;i=v[p+4>>2];if(!i|!v[p+16>>2]){break e}if((d|0)==(g|0)){continue}break e}break}e=(d|0)==(g|0);break e}d=v[p+16>>2];g=d>>>0>g>>>0?g:d;pc(v[p+12>>2],(v[j+10992>>2]+j|0)+11012|0,g);v[p+12>>2]=g+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-g;v[p+20>>2]=g+v[p+20>>2];d=v[j+10996>>2];v[j+10996>>2]=d-g;v[j+10992>>2]=g+v[j+10992>>2]&32767;if(v[j+43780>>2]){break e}e=(d|0)==(g|0);break e}e=-3}hb=F+16|0;i=v[o+1068>>2]-V|0;v[o+1068>>2]=i;d=H+ca|0;H=v[o+1088>>2];ca=d-H|0;continue}break}d=o+1072|0;Ab:{if(!d){break Ab}b=v[d+28>>2];if(!b){break Ab}lb[v[d+36>>2]](v[d+40>>2],b);v[d+28>>2]=0}i=0;Bb:{Cb:{if(!(v[o+1140>>2]!=(ba|0)|H|(e|0)!=1)){oe(o+8|0,v[U>>2],v[U+4>>2]);b=ce(o);e=v[b+4>>2];b=v[b>>2];v[23516]=0;e=ga(549,o+32|0,v[o+8>>2],v[o+12>>2],b|0,e|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break Cb}v[23516]=0;i=W(890,a|0,e|0,c|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break Bb}yb(e)}dc(U);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(e);break c}a=P()|0;O()|0}dc(U);S(a|0);L()}hb=o+1152|0;return i|0}function wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=C(0),Q=0,R=C(0),T=0,U=0,X=0,Y=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=C(0),ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=C(0);p=hb-11360|0;hb=p;xc(c);a:{while(1){b:{if(!Ob(v[c>>2],v[c+8>>2],4)){break b}e=p+16|0;d=hb-16|0;hb=d;c:{if(!Ob(v[c>>2],v[c+8>>2],3)){f=0;while(1){if((f|0)!=3){Ch(e+f|0);f=f+1|0;continue}break}break c}mv(d+8|0,e);pd(d,c,v[d+8>>2],v[d+12>>2])}hb=d+16|0;d:{e:{if(!Qb(e,15131,3)){e=p+4648|0;d=hb-16|0;hb=d;f:{if(!Ob(v[c>>2],v[c+8>>2],7)){f=0;while(1){if((f|0)!=7){Ch(e+f|0);f=f+1|0;continue}break}break f}yo(d+8|0,e);pd(d,c,v[d+8>>2],v[d+12>>2])}hb=d+16|0;H=0;i=3;while(1){if((i|0)==7){break d}e=w[(p+4648|0)+i|0];if(e&128){break e}i=i+1|0;H=e|H<<7;continue}}g:{if(Qb(p+16|0,14284,3)){break g}if(!OR(c,13599)){break g}Yb(c,zg(c)+16|0);continue}if(!Qb(p+16|0,30398,3)){continue}if(!Qb(p+16|0,30402,3)){continue}if(!w[p+16|0]){wg(c,2);continue}if(pP(p+16|0)){break b}}i=0;break a}Yb(c,H);continue}break}xc(c);e=p+11336|0;EA(e,c);ca=v[p+11336>>2];Y=Ee(e);X=Lb(p+11320|0);c=p+4648|0;Rb(c,0,6668);Zy(c);c=p+4640|0;v[c>>2]=0;v[c+4>>2]=0;c=p+4632|0;v[c>>2]=0;v[c+4>>2]=0;v[p+4624>>2]=0;v[p+4628>>2]=0;H=0;c=0;h:{while(1){d=Dc(ca,da);aa=p+16|0;I=p+4624|0;e=0;n=hb-17168|0;hb=n;v[n+17164>>2]=0;i:{j:{E=p+4648|0;k:{if(w[E+6152|0]!=255|(d|0)<5){break k}if(!op(E+6152|0,Y)){break k}i=gx(w[Y+1|0],w[Y+2|0],v[E+6148>>2])+np(Y)|0;v[n+17164>>2]=i;if((d|0)==(i|0)){i=d;break j}l:{if((d|0)>=(i+4|0)){if(op(Y,i+Y|0)){break l}}v[n+17164>>2]=0;break k}if(i){break j}}f=Y;J=Rb(E,0,6668)+6148|0;$=n+17164|0;i=0;j=0;D=d-4|0;q=(D|0)>0?D:0;while(1){m:{n:{o:{p:{if((i|0)==(q|0)){i=d;break p}if(!_H(f)){break n}h=gx(w[f+1|0],w[f+2|0],v[J>>2]);e=h+np(f)|0;g=4;o=i+4|0;q:{while(1){if(!(g>>>0>2303|h)){if((D|0)<=((g<<1)+i|0)){break q}h=0;m=f+g|0;r:{if(!op(f,m)){break r}k=g-np(f)|0;y=np(m)+k|0;if((d|0)<(y+(g+o|0)|0)){break r}if(!op(f,m+y|0)){break r}v[J>>2]=k;h=k;e=g}g=g+1|0;continue}break}if(!h|(d|0)<(e+i|0)){break q}y=d-i|0;g=0;A=0;while(1){s:{t:{if((A|0)!=10){k=(A|0)!=0;F=g;g=f+g|0;g=(F+gx(w[g+1|0],w[g+2|0],h)|0)+np(g)|0;if((y|0)<(g+4|0)){break s}if(op(f,f+g|0)){break t}k=0}else{k=1}break s}A=A+1|0;continue}break}if(!k){break q}j=e;break p}if((d|0)!=(e|0)|i){break o}i=0;j=d}v[$>>2]=j;e=i;break m}v[J>>2]=0}f=f+1|0;i=i+1|0;continue}break}i=v[n+17164>>2];if((d|0)>=(e+i|0)?i:0){break j}v[I>>2]=e;A=0;break i}d=e+Y|0;v[E+6152>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[I+4>>2]=e;v[I>>2]=e+i;v[I+8>>2]=w[d+3|0]>191?1:2;qa=I,ra=cI(w[d+1|0],w[d+2|0]),v[qa+12>>2]=ra;v[I+16>>2]=4-(w[d+1|0]>>>1&3);qa=I,ra=fx(w[d+1|0],w[d+2|0]),v[qa+20>>2]=ra;if(!aa){A=ex(w[d+1|0]);break i}bI(n+17152|0,d+4|0,i-4|0);if(!(t[d+1|0]&1)){fe(n+17152|0,16)}u:{if(v[I+16>>2]==3){A=0;m=n+17152|0;ja=n+3740|0;e=ja;f=0;g=w[d+1|0];i=B((g>>>3&1)+(g>>>4&1)|0,3)+(w[d+2|0]>>>2&3)|0;j=i-((i|0)!=0)|0;$=d;d=w[d+3|0]>191?1:2;v:{if(g&8){i=fe(m,9);d=d<<1;f=fe(m,d+7|0);break v}i=fe(m,d|8)>>>d|0}g=B(j,40);q=g+65264|0;o=g+65584|0;y=B(j,23)+65072|0;l=-1;h=0;w:{while(1){j=w[$+3|0];k=fe(m,12);u[e+4>>1]=k;g=fe(m,9);u[e+6>>1]=g;if((g&65535)>>>0>288){break w}g=j>>>0>191?f<<4:f;qa=e,ra=fe(m,8),t[qa+10|0]=ra;f=fe(m,w[$+1|0]&8?4:9);t[e+13|0]=22;t[e+14|0]=0;v[e>>2]=y;u[e+8>>1]=f;x:{if(fe(m,1)){f=fe(m,2);t[e+11|0]=f;if(!(f&255)){break w}f=fe(m,1);u[e+18>>1]=65287;t[e+12|0]=f;if(w[e+11|0]==2){y:{if(!(f&255)){v[e>>2]=q;t[e+18|0]=8;j=39;f=0;break y}v[e>>2]=o;j=30;f=w[$+1|0]&8?8:6}t[e+14|0]=j;t[e+13|0]=f;g=g&3855}f=fe(m,10);qa=e,ra=fe(m,3),t[qa+21|0]=ra;qa=e,ra=fe(m,3),t[qa+22|0]=ra;qa=e,ra=fe(m,3),t[qa+23|0]=ra;f=f<<5;break x}t[e+11|0]=0;t[e+12|0]=0;f=fe(m,15);qa=e,ra=fe(m,4),t[qa+18|0]=ra;j=fe(m,3);t[e+20|0]=255;t[e+19|0]=j}t[e+17|0]=f&31;t[e+15|0]=f>>>10;t[e+16|0]=f>>>5&31;h=(k&65535)+h|0;z:{if(w[$+1|0]&8){f=fe(m,1);break z}f=x[e+8>>1]>499}t[e+24|0]=f;qa=e,ra=fe(m,1),t[qa+25|0]=ra;f=fe(m,1);t[e+27|0]=g>>>12&15;t[e+26|0]=f;e=e+28|0;f=g<<4;d=d-1|0;if(d){continue}break}l=(v[m+4>>2]+h|0)>(v[m+8>>2]+(i<<3)|0)?-1:i}if(!((l|0)<0|v[n+17156>>2]>v[n+17160>>2])){h=n+17152|0;i=v[h+4>>2];f=v[h+8>>2];d=n+912|0;g=v[E+6144>>2];e=g-l|0;j=(g|0)<(l|0)?g:l;g=pc(d+12|0,(((e|0)>0?e:0)+E|0)+6156|0,j);e=(f-i|0)/8|0;pc(g+j|0,v[h>>2]+(v[h+4>>2]/8|0)|0,e);bI(d,g,e+j|0);A:{i=v[E+6144>>2]>=(l|0);if(!i){break A}ma=E+2304|0;na=n+8620|0;oa=n+3852|0;while(1){if((w[$+1|0]&8?2:1)>>>0<=A>>>0){break A}pa=Rb(oa,0,4608);d=v[I+8>>2];K=B(B(d,A),28)+ja|0;e=0;ka=(d|0)>0?d:0;G=n+912|0;y=G+7548|0;ba=E+6152|0;while(1){if((e|0)!=(ka|0)){o=B(e,28)+K|0;J=x[o+4>>1];D=v[G+4>>2];d=(G+B(e,39)|0)+16156|0;h=y;q=e;j=hb-48|0;hb=j;ia=w[o+25|0];l=B(!w[o+13|0]+(w[o+14|0]!=0)|0,28)+65904|0;B:{if(w[ba+1|0]&8){e=w[o+27|0];g=w[x[o+8>>1]+66e3|0];f=g&3;t[j+47|0]=f;t[j+46|0]=f;f=g>>>2|0;t[j+45|0]=f;t[j+44|0]=f;break B}e=(w[ba+3|0]&16)>>>4&(q|0)!=0;g=e?12:0;r=x[o+8>>1]>>>e|0;while(1){if((r|0)>=0){e=3;f=1;while(1){if((e|0)>=0){k=w[(e+g|0)+66016|0];t[(j+44|0)+e|0]=((r|0)/(f|0)|0)%(k|0);e=e-1|0;f=B(f,k);continue}break}g=g+4|0;r=r-f|0;continue}break}l=g+l|0;e=-16}g=d;f=j;m=f+44|0;r=0;while(1){C:{D:{E:{if((r|0)==4){break E}Q=w[l+r|0];if(!Q){break E}if(e&8){pc(f,g,Q);break D}fa=w[m+r|0];if(!fa){Rb(f,0,Q);Rb(g,0,Q);break D}d=(e|0)>=0?-1:-1<<fa^-1;k=0;while(1){if((k|0)==(Q|0)){break D}M=fe(G,fa);t[g+k|0]=(d|0)==(M|0)?-1:M;t[f+k|0]=M;k=k+1|0;continue}}t[f+2|0]=0;t[f|0]=0;t[f+1|0]=0;break C}e=e<<1;r=r+1|0;f=f+Q|0;g=g+Q|0;continue}break}F:{f=w[o+14|0];if(f){e=2-ia|0;m=w[o+23|0]<<e;k=w[o+22|0]<<e;g=w[o+21|0]<<e;d=w[o+13|0];e=0;while(1){if(e>>>0>=f>>>0){break F}M=j+(d+e|0)|0;t[M|0]=g+w[M|0];t[M+1|0]=k+w[M+1|0];t[M+2|0]=m+w[M+2|0];e=e+3|0;continue}}if(!w[o+24|0]){break F}e=0;while(1){if((e|0)==10){break F}d=e+j|0;t[d+11|0]=w[d+11|0]+w[e+66040|0];e=e+1|0;continue}}d=ia+1|0;e=0;s=dx(C(2048),((((w[ba+3|0]&224)==96)<<1)-w[o+10|0]|0)+258|0);while(1){if(w[o+13|0]+(f&255)>>>0>e>>>0){qa=(e<<2)+h|0,sa=dx(s,w[e+j|0]<<d),z[qa>>2]=sa;e=e+1|0;f=w[o+14|0];continue}break}hb=j+48|0;k=(G+B(q,2304)|0)+2940|0;ia=D+J|0;s=C(0);e=v[G+4>>2];f=v[G>>2]+((e|0)/8|0)|0;d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))<<(e&7);l=e|-8;r=f+4|0;T=v[o>>2];U=x[o+6>>1];e=0;while(1){G:{H:{if((U|0)>0){j=e+1|0;e=e+o|0;d=w[e+15|0];fa=(u[(d<<1)+70464>>1]<<1)+66080|0;ga=w[e+18|0];if(d>>>0>=16){M=w[d+70528|0];m=32-M|0;while(1){J=w[T|0]>>>1|0;D=(J|0)>(U|0)?U:J;s=z[h>>2];while(1){e=g>>>27|0;d=5;while(1){e=u[fa+(e<<1)>>1];if((e|0)<0){g=g<<d;f=e&7;e=(g>>>32-f|0)-(e>>3)|0;l=d+l|0;d=f;continue}break}f=e&65535;e=f>>>8|0;l=e+l|0;g=g<<e;d=0;while(1){if((d|0)!=2){F=f&15;I:{if((F|0)==15){l=l+M|0;e=g<<M;while(1){if((l|0)>=0){e=w[r|0]<<l|e;r=r+1|0;l=l-8|0;continue}break}F=(g>>>m|0)+15|0;g=F;J:{if((g|0)<=128){N=z[(g<<2)+70624>>2];break J}ha=g<<3;Q=g;g=g>>>0<1024;ha=g?ha:Q;Q=ha<<1&64;R=C(C((ha&63)-Q|0)/C(Q+(ha&-64)|0));N=C((g?C(16):C(256))*C(C(C(R*C(C(R*C(.2222222238779068))+C(1.3333333730697632)))+C(1))*z[(Q+ha>>6<<2)+70624>>2]))}N=C(C(s*N)*C(e>>31|1));break I}e=g;N=C(s*z[(((e>>>27&16|F)^16)<<2)+70560>>2])}z[k>>2]=N;f=f>>>4|0;k=k+4|0;d=d+1|0;g=(F|0)!=0;l=g+l|0;g=e<<g;continue}break}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}D=D-1|0;if(D){continue}break}h=h+4|0;T=T+1|0;U=U-J|0;if((U|0)<=0){break H}e=(ga|0)>0;ga=ga-1|0;if(e){continue}break}break H}while(1){m=w[T|0]>>>1|0;F=(m|0)>(U|0)?U:m;s=z[h>>2];while(1){e=g>>>27|0;d=5;while(1){e=u[fa+(e<<1)>>1];if((e|0)<0){g=g<<d;f=e&7;e=(g>>>32-f|0)-(e>>3)|0;l=d+l|0;d=f;continue}break}d=e&65535;e=d>>>8|0;l=e+l|0;g=g<<e;e=0;while(1){if((e|0)!=2){f=d&15;z[k>>2]=s*z[(((f|g>>>27&16)^16)<<2)+70560>>2];d=d>>>4|0;k=k+4|0;e=e+1|0;f=(f|0)!=0;l=f+l|0;g=g<<f;continue}break}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}F=F-1|0;if(F){continue}break}h=h+4|0;T=T+1|0;U=U-m|0;if((U|0)<=0){break H}e=(ga|0)>0;ga=ga-1|0;if(e){continue}break}break H}d=1-U|0;while(1){K:{f=w[o+26|0]?70448:70416;e=w[f+(g>>>28|0)|0];if(!(e&8)){e=w[f+((g<<4>>>32-(e&3))+(e>>>3)|0)|0]}f=e&7;l=f+l|0;if((ia|0)<((l+(r-v[G>>2]<<3)|0)-24|0)){break K}d=d-1|0;if(!d){d=w[T|0];if(d>>>0<2){break K}T=T+1|0;s=z[h>>2];h=h+4|0;d=d>>>1|0}g=g<<f;if(e&128){z[k>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}if(e&64){z[k+4>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}d=d-1|0;if(!d){d=w[T|0];if(d>>>0<2){break K}T=T+1|0;s=z[h>>2];h=h+4|0;d=d>>>1|0}if(e&32){z[k+8>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}if(e&16){z[k+12>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}k=k+16|0;continue}break}v[G+4>>2]=ia;break G}e=j;continue}break}e=q+1|0;continue}break}e=w[E+6155|0];L:{if(e&16){D=hb-16|0;hb=D;e=G+2940|0;g=e+2304|0;q=v[K>>2];o=w[K+14|0];f=o+w[K+13|0]|0;d=0;m=D+4|0;v[m+8>>2]=-1;v[m>>2]=-1;v[m+4>>2]=-1;while(1){if((d|0)!=(f|0)){y=d+q|0;j=w[y|0];h=0;M:{while(1){if(h>>>0>=j>>>0){break M}k=h<<2;if(z[k+g>>2]==C(0)){h=h+2|0;if(z[(k|4)+g>>2]==C(0)){continue}}break}v[m+((d>>>0)%3<<2)>>2]=d;j=w[y|0]}d=d+1|0;g=(j<<2)+g|0;continue}break}if(w[K+13|0]){g=v[D+4>>2];d=v[D+8>>2];g=(d|0)<(g|0)?g:d;d=v[D+12>>2];d=(d|0)<(g|0)?g:d;v[D+12>>2]=d;v[D+8>>2]=d;v[D+4>>2]=d}m=G+16195|0;j=o?3:1;g=f-j|0;h=0;while(1){if((h|0)!=(j|0)){f=g+h|0;d=f-j|0;if((d|0)<=v[(D+4|0)+(h<<2)>>2]){d=w[ba+1|0]<<28>>31&3}else{d=w[d+m|0]}t[f+m|0]=d;h=h+1|0;continue}break}q=v[K>>2];o=D+4|0;y=u[K+36>>1]&1;g=0;k=w[ba+1|0]&8?7:64;while(1){j=g+q|0;d=w[j|0];if(d){f=w[ba+3|0]&32;N:{O:{if(v[o+((g>>>0)%3<<2)>>2]>=(g|0)){break O}h=w[g+m|0];if(h>>>0>=k>>>0){break O}N=f?C(1.4142135381698608):C(1);P:{if(w[ba+1|0]&8){f=h<<3;s=z[f+71156>>2];R=z[f+71152>>2];break P}R=dx(C(1),h+1>>>1<<y);f=h&1;s=f?C(1):R;R=f?R:C(1)}R=C(N*R);s=C(N*s);h=0;while(1){if((d|0)!=(h|0)){f=(h<<2)+e|0;N=z[f>>2];z[f+2304>>2]=N*s;z[f>>2]=N*R;h=h+1|0;continue}break}break N}if(!f){break N}ZH(e,d)}g=g+1|0;e=(w[j|0]<<2)+e|0;continue}break}hb=D+16|0;break L}if((e&224)!=96){break L}ZH(G+2940|0,576)}k=G+7708|0;e=0;while(1){if((e|0)!=(ka|0)){d=w[E+6153|0];q=(w[K+12|0]!=0)<<1<<((B((d>>>3&1)+(d>>>4&1)|0,3)+(w[E+6154|0]>>>2&3)|0)==2);j=(G+B(e,2304)|0)+2940|0;g=j;if(w[K+14|0]){r=v[K>>2]+w[K+13|0]|0;h=((G+B(e,2304)|0)+B(q,72)|0)+2940|0;d=h;f=k;while(1){o=w[r|0];if(o){y=o<<1;l=0;while(1){if((l|0)!=(o|0)){z[f>>2]=z[d>>2];z[f+4>>2]=z[(o<<2)+d>>2];z[f+8>>2]=z[(y<<2)+d>>2];d=d+4|0;l=l+1|0;f=f+12|0;continue}break}r=r+3|0;d=(y<<2)+d|0;continue}break}pc(h,k,f-k|0);f=q-1|0}else{f=31}while(1){d=0;if((f|0)>0){while(1){if((d|0)!=8){y=d<<2;h=y+g|0;la=z[h+72>>2];F=h;N=z[y+71216>>2];R=z[y+71248>>2];h=(17-d<<2)+g|0;s=z[h>>2];z[F+72>>2]=C(la*N)-C(R*s);z[h>>2]=C(la*R)+C(s*N);d=d+1|0;continue}break}g=g+72|0;f=f-1|0;continue}break}d=j;f=B(e,1152)+E|0;g=w[K+11|0];if(q){YH(d,f,71280,q);f=B(q,36)+f|0;d=B(q,72)+d|0}Q:{if((g|0)==2){h=32-q|0;m=hb-80|0;hb=m;q=m|8;o=m|4;while(1){if((h|0)>0){y=pc(m,d,72);g=v[f+20>>2];v[d+16>>2]=v[f+16>>2];v[d+20>>2]=g;g=v[f+12>>2];v[d+8>>2]=v[f+8>>2];v[d+12>>2]=g;g=v[f+4>>2];v[d>>2]=v[f>>2];v[d+4>>2]=g;g=f+24|0;cx(y,d+24|0,g);cx(o,d+48|0,g);cx(q,f,g);d=d+72|0;f=f+36|0;h=h-1|0;continue}break}hb=m+80|0;break Q}YH(d,f,B((g|0)==3,72)+71280|0,32-q|0)}h=0;f=j+72|0;while(1){d=1;if(h>>>0<=31){while(1){if(d>>>0<=17){g=(d<<2)+f|0;z[g>>2]=-z[g>>2];d=d+2|0;continue}break}f=f+144|0;h=h+2|0;continue}break}K=K+28|0;e=e+1|0;continue}break}$H(ma,pa,18,v[I+8>>2],aa,na);A=A+1|0;aa=B(v[I+8>>2],1152)+aa|0;continue}}g=n+912|0;d=v[g+8>>2]>>>3|0;e=v[g+4>>2]+7>>>3|0;j=d-e|0;f=(j|0)<511?j:511;if((j|0)>0){dj(E+6156|0,(g+(j>>>0>511?d-511|0:e)|0)+12|0,f)}v[E+6144>>2]=f;break u}Zy(E);break i}q=n+17152|0;f=0;g=0;h=0;A=0;e=d;R:{S:{T:{d=w[d+3|0];i=d>>>6|0;switch(i-1|0){case 2:break R;case 0:break T;default:break S}}g=(d>>>2&12)+4|0;break R}g=32}k=w[e+1|0];U:{if((k&6)==6){i=72684;d=32;break U}if(!(k&8)){i=72687;d=30;break U}d=w[e+2|0];j=d>>>2&3;d=fx(k,d)>>>((i|0)!=3)|0;d=d?d:192;if(d>>>0<=55){i=72708;d=(j|0)==2?12:8;break U}i=72696;d=d>>>0>95?(j|0)!=1?30:27:27}t[n+768|0]=d;t[n+769|0]=(d|0)>(g|0)?g:d;d=i;j=72592;while(1){g=w[n+768|0];if(g>>>0<=f>>>0){f=0;while(1){j=g<<1&510;if(j>>>0>f>>>0){i=f+n|0;V:{if(!w[i+770|0]){d=6;break V}d=2;if((w[e+1|0]&6)==6){break V}d=fe(q,2);g=w[n+768|0]}t[i+834|0]=d;f=f+1|0;continue}break}g=n+770|0;o=n+834|0;e=n;f=0;while(1){if((f|0)!=(j|0)){d=w[g|0];i=d?19>>>w[f+o|0]&3|4:0;g=g+1|0;y=B(d,3)-6|0;s=C(0);d=4;while(1){if(d){if(d&i){k=fe(q,6);h=(k|0)/3|0;s=C(z[(y+(B(h,-3)+k|0)<<2)+72720>>2]*C(2097152>>>h|0))}z[e>>2]=s;d=d>>>1|0;e=e+4|0;continue}break}f=f+1|0;continue}break}f=w[n+769|0];e=w[n+768|0];e=e>>>0<f>>>0?f:e;while(1){if((e|0)!=(f|0)){t[((f<<1)+n|0)+771|0]=0;f=f+1|0;continue}break}}else{if((f|0)==(A|0)){j=w[d|0]+72592|0;A=w[d+2|0]+f|0;h=w[d+1|0];d=d+3|0}k=f<<1;g=w[fe(q,h)+j|0];t[(k+n|0)+770|0]=g;i=w[n+769|0];if(i>>>0>f>>>0){g=w[fe(q,h)+j|0];i=w[n+769|0]}t[((k|1)+n|0)+770|0]=i?g:0;f=f+1|0;continue}break}i=0;d=Rb(n+3852|0,0,4608);q=E+2304|0;o=n+8620|0;A=0;W:{while(1){if((A|0)==3){break W}y=d+(i<<2)|0;D=n+17152|0;j=0;J=v[I+16>>2]|1;m=(J|0)>0?J:0;l=576;while(1){if((j|0)!=4){f=y+(B(j,J)<<2)|0;g=0;while(1){if(w[n+768|0]<<1>>>0>g>>>0){X:{k=w[(g+n|0)+770|0];if(!k){break X}if(k>>>0<=16){h=(-1<<k-1)+1|0;e=0;while(1){if((e|0)==(m|0)){break X}qa=(e<<2)+f|0,sa=C(fe(D,k)+h|0),z[qa>>2]=sa;e=e+1|0;continue}}h=2<<k-17;k=h>>>1|0;$=h|1;e=0;h=fe(D,(h-(h>>>3|0)|0)+3|0);while(1){if((e|0)==(m|0)){break X}F=h;h=(h>>>0)/($>>>0)|0;z[(e<<2)+f>>2]=F-(k+B($,h)|0)|0;e=e+1|0;continue}}g=g+1|0;f=(l<<2)+f|0;l=18-l|0;continue}break}j=j+1|0;continue}break}i=(J<<2)+i|0;if((i|0)==12){j=(A<<2)+n|0;e=d;i=w[n+769|0];f=d+B(i,72)|0;pc(f+2304|0,f,B(w[n+768|0]-i|0,72));g=0;while(1){if(w[n+768|0]>g>>>0){f=0;while(1){if((f|0)!=12){i=(f<<2)+e|0;z[i>>2]=z[j>>2]*z[i>>2];i=i+2304|0;z[i>>2]=z[j+12>>2]*z[i>>2];f=f+1|0;continue}break}j=j+24|0;e=e+72|0;g=g+1|0;continue}break}$H(q,d,12,v[I+8>>2],aa,o);Rb(d,0,4608);aa=B(v[I+8>>2],768)+aa|0;i=0}A=A+1|0;if(v[n+17156>>2]<=v[n+17160>>2]){continue}break}Zy(E);A=0;break i}i=1}A=B(ex(w[E+6153|0]),i)}hb=n+17168|0;e=v[p+4624>>2];if((e|0)<0|!e&(A|0)!=0|!(e|A)){break h}Y:{if(e){e=v[p+4636>>2];if((e|0)!=(H|0)?H:0){break h}d=v[p+4632>>2];if((d|0)!=(c|0)?c:0){break h}if(d-3>>>0<4294967294|(e|0)<=0){break Y}v[p+12>>2]=0;qa=p,ra=Dc(ca,da),v[qa+8>>2]=ra;c=v[Gj(p+4624|0,p+12|0,p+8|0)>>2];v[p+12>>2]=0;qa=p,ra=Dc(ca,da),v[qa+8>>2]=ra;Y=c+Y|0;c=ca;f=v[Gj(p+4624|0,p+12|0,p+8|0)>>2];ca=c-f|0;da=da-((f>>31)+(c>>>0<f>>>0)|0)|0;Z:{if(!A){break Z}v[23516]=0;c=p+16|0;W(586,X|0,c|0,c+(B(d,A)<<1)|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break Z}H=V(92664)|0;if((O()|0)==(ea(92664)|0)){_(H|0)|0;v[23516]=0;Z(18);f=v[23516];v[23516]=0;H=e;c=d;if((f|0)!=1){break h}H=P()|0;O()|0}gd(X);Qc(p+11336|0);S(H|0);L()}H=e;c=d}if((Oc(v[X>>2],v[X+4>>2])>>>0)/(c>>>0)>>>0>268435456){break h}if(!!ca&(da|0)>=0|(da|0)>0){continue}break h}break}H=e;c=d}i=0;_:{if(!H|!c){break _}d=v[X>>2];e=v[X+4>>2];if(nc(d,e)){break _}if((Oc(d,e)>>>0)/(c>>>0)>>>0>268435456){break _}bt(a,b);e=B(b,104)+a|0;d=e+484380|0;qa=d,ra=(Oc(v[X>>2],v[X+4>>2])>>>0)/(c>>>0)|0,v[qa>>2]=ra;a=e+484414|0;b=x[a>>1];u[a>>1]=(c|0)==2?b|65:b&65470|1;Jg(d);a=e+484400|0;i=Vd(v[d>>2],v[a>>2]);if(!i){break _}Qn(Cb(v[X>>2]),Cb(v[X+4>>2]),v[a>>2]);i=Vd(v[d>>2],v[d+20>>2])}gd(X);Qc(p+11336|0)}hb=p+11360|0;return i|0}function iA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),A=0,E=0,F=0,G=0,I=C(0),J=0,K=0,M=0,N=0,O=C(0);r=hb-1520|0;hb=r;e=r+8|0;M=Rb(e,0,1512),N=-1,v[M+1420>>2]=N;t[r+56|0]=1;v[r+48>>2]=a+b;v[r+40>>2]=a;l=hb-1024|0;hb=l;t[e+1377|0]=1;a:{if(!cs(e)){break a}b=w[e+1375|0];if(!(b&2)){bc(e,34);break a}if(b&4){bc(e,34);break a}if(b&1){bc(e,34);break a}if(v[e+1116>>2]!=1){bc(e,34);break a}b=w[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!$w(e,l+1018|0,6)|w[l+1018|0]!=102|(w[l+1019|0]!=105|w[l+1020|0]!=115)){break b}if(w[l+1021|0]!=104|w[l+1022|0]!=101|w[l+1023|0]!=97){break b}if((Ye(e)|0)!=100){break b}if(Ye(e)){break b}bc(e,38);break a}bc(e,34);break a}if((Ye(e)|0)!=1){bc(e,34);break a}if(!$w(e,l+1018|0,6)){bc(e,10);break a}if(!Zw(l+1018|0)){bc(e,34);break a}if(bj(e)){bc(e,34);break a}b=Ye(e);v[e+4>>2]=b;if(!b){bc(e,34);break a}if(b>>>0>=17){bc(e,5);break a}b=bj(e);v[e>>2]=b;if(!b){bc(e,34);break a}bj(e);bj(e);bj(e);b=Ye(e);j=b>>>4|0;v[e+116>>2]=1<<j;g=b&15;v[e+112>>2]=1<<g;if(g-14>>>0<=4294967287){bc(e,20);break a}if((b<<24)+536870912>>24>=0){bc(e,20);break a}c:{if(g>>>0>j>>>0){bc(e,20);break c}if(!(Ye(e)&1)){bc(e,34);break c}if(!cs(e)){break a}if(!_w(e)){break a}if(!ax(e)){break a}if((rh(e)|0)==3){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=rh(e),t[M|0]=N;f=f+1|0;continue}break}if(!Zw(l+1018|0)){bc(e,20);break c}b=Yw(e);f=ee(e,b+1|0);v[e+20>>2]=f;if(f){f=0;g=(b|0)>0?b:0;while(1){if((f|0)!=(g|0)){j=rh(e);t[v[e+20>>2]+f|0]=j;f=f+1|0;continue}break}t[b+v[e+20>>2]|0]=0;b=Yw(e);v[e+28>>2]=0;v[e+24>>2]=b;d:{if((b|0)<=0){break d}b=ee(e,b<<2);v[e+28>>2]=b;if(b){break d}bc(e,3);break c}while(1){e:{f:{if(v[e+24>>2]>(h|0)){b=Yw(e);f=ee(e,b+1|0);g=h<<2;v[g+v[e+28>>2]>>2]=f;if(!v[g+v[e+28>>2]>>2]){break f}f=0;j=(b|0)>0?b:0;while(1){if((f|0)==(j|0)){break e}i=rh(e);t[v[g+v[e+28>>2]>>2]+f|0]=i;f=f+1|0;continue}}if(!(rh(e)&1)){bc(e,20);break c}NH(e,w[e+1376|0]);t[e+1376|0]=0;while(1){b=ax(e);NH(e,b);t[e+1376|0]=0;if(b){continue}break}f=0;if(!_w(e)){break a}if(!UH(e)){if(v[e+100>>2]!=21){break a}v[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){j=b<<24;g=0;while(1){if((g|0)!=8){j=j>>31&79764919^j<<1;g=g+1|0;continue}break}v[(b<<2)+462944>>2]=j;b=b+1|0;continue}break}if((rh(e)|0)==5){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=rh(e),t[M|0]=N;f=f+1|0;continue}break}if(!Zw(l+1018|0)){bc(e,20);break c}b=mc(e,8)+1|0;v[e+120>>2]=b;b=ee(e,B(b,2096));v[e+124>>2]=b;if(!b){bc(e,3);break c}Rb(b,0,B(v[e+120>>2],2096));g:{h:{while(1){i:{if(v[e+120>>2]>(E|0)){b=v[e+124>>2];if((mc(e,8)&255)!=66){bc(e,20);break c}if((mc(e,8)&255)!=67){bc(e,20);break c}if((mc(e,8)&255)!=86){bc(e,20);break c}g=b+B(E,2096)|0;M=g,N=mc(e,8)&255|mc(e,8)<<8,v[M>>2]=N;M=g,N=mc(e,8)&255|(mc(e,8)<<8&65280|mc(e,8)<<16),v[M+4>>2]=N;k=g+4|0;f=0;m=mc(e,1);if(!m){f=mc(e,1)}t[g+23|0]=f;h=v[k>>2];if(v[g>>2]){b=h;break i}b=0;if(!h){break i}bc(e,20);break c}b=mc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!mc(e,16)){continue}break}bc(e,20);break c}b=mc(e,6)+1|0;v[e+128>>2]=b;b=ee(e,B(b,1596));v[e+260>>2]=b;k:{if(b){E=0;k=0;l:while(1){if(v[e+128>>2]<=(k|0)){break k}b=mc(e,16);u[((k<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){bc(e,20);break c}if(!b){b=v[e+260>>2]+B(k,1596)|0;M=b,N=mc(e,8),t[M|0]=N;M=b,N=mc(e,16),u[M+2>>1]=N;M=b,N=mc(e,16),u[M+4>>1]=N;M=b,N=mc(e,6),t[M+6|0]=N;M=b,N=mc(e,8),t[M+7|0]=N;j=mc(e,4)+1|0;t[b+8|0]=j;h=b+9|0;f=0;while(1){if((j&255)>>>0>f>>>0){M=f+h|0,N=mc(e,8),t[M|0]=N;f=f+1|0;j=w[b+8|0];continue}break}bc(e,4);break c}f=v[e+260>>2]+B(k,1596)|0;b=mc(e,5);t[f|0]=b;m=f+1|0;j=0;g=-1;while(1)if((b&255)>>>0<=j>>>0){h=g+1|0;g=f+82|0;i=f+65|0;o=f+49|0;n=f+33|0;b=0;while(1){if((b|0)!=(h|0)){M=b+n|0,N=mc(e,3)+1|0,t[M|0]=N;q=b+o|0;p=mc(e,2);t[q|0]=p;j=0;m:{if(!(p&255)){break m}p=mc(e,8);t[b+i|0]=p;if(v[e+120>>2]>(p&255)){break m}bc(e,20);break c}n:{while(1){if(1<<w[q|0]<=(j|0)){break n}p=mc(e,8)-1|0;u[(g+(b<<4)|0)+(j<<1)>>1]=p;j=j+1|0;if(v[e+120>>2]>p<<16>>16){continue}break}bc(e,20);break c}b=b+1|0;continue}break}g=2;M=f,N=mc(e,2)+1|0,t[M+1588|0]=N;b=mc(e,4);v[f+1592>>2]=2;h=0;u[f+338>>1]=0;t[f+1589|0]=b;u[f+340>>1]=1<<b;b=f+338|0;i=0;while(1){if(w[f|0]>i>>>0){o=n+w[i+m|0]|0;j=0;while(1){if(w[o|0]>j>>>0){g=mc(e,w[f+1589|0]);u[b+(v[f+1592>>2]<<1)>>1]=g;g=v[f+1592>>2]+1|0;v[f+1592>>2]=g;j=j+1|0;continue}break}i=i+1|0;continue}break}while(1){if((g|0)>(h|0)){g=x[b+(h<<1)>>1];j=(l+16|0)+(h<<2)|0;u[j+2>>1]=h;u[j>>1]=g;h=h+1|0;g=v[f+1592>>2];continue}break}MH(l+16|0,g,1113);j=0;g=v[f+1592>>2];h=g-1|0;h=(h|0)>0?h:0;o:{while(1){if((h|0)==(j|0)){h=f+838|0;j=0;break o}i=l+16|0;n=x[i+(j<<2)>>1];j=j+1|0;if((n|0)!=x[i+(j<<2)>>1]){continue}break}bc(e,20);break c}while(1){if((g|0)>(j|0)){t[h+j|0]=w[((l+16|0)+(j<<2)|0)+2|0];j=j+1|0;g=v[f+1592>>2];continue}break}q=f+1088|0;j=2;while(1){if((g|0)>(j|0)){v[l+12>>2]=0;v[l+8>>2]=0;g=0;p=(j|0)>0?j:0;i=b+(j<<1)|0;m=65536;n=-1;while(1){if((g|0)!=(p|0)){o=b+(g<<1)|0;h=x[o>>1];if(!((n|0)>=(h|0)|x[i>>1]<=h>>>0)){v[l+12>>2]=g;h=x[o>>1];n=h}if(!((h|0)>=(m|0)|x[i>>1]>=h>>>0)){v[l+8>>2]=g;m=x[o>>1]}g=g+1|0;continue}break}h=q+(j<<1)|0;t[h|0]=v[l+12>>2];t[h+1|0]=v[l+8>>2];j=j+1|0;g=v[f+1592>>2];continue}break}E=(g|0)>(E|0)?g:E;k=k+1|0;continue l}else{b=mc(e,4);t[j+m|0]=b;b=b&255;g=(b|0)>(g|0)?b:g;j=j+1|0;b=w[f|0];continue}}}bc(e,3);break c}b=mc(e,6)+1|0;v[e+264>>2]=b;b=ee(e,B(b,24));v[e+396>>2]=b;if(!b){bc(e,3);break c}k=0;Rb(b,0,B(v[e+264>>2],24));p:{q:{r:{while(1){if(v[e+264>>2]>(k|0)){b=v[e+396>>2];h=mc(e,16);u[((k<<1)+e|0)+268>>1]=h;if((h&65535)>>>0>=3){bc(e,20);break c}g=b+B(k,24)|0;M=g,N=mc(e,24),v[M>>2]=N;b=mc(e,24);v[g+4>>2]=b;if(b>>>0<y[g>>2]){bc(e,20);break c}M=g,N=mc(e,24)+1|0,v[M+8>>2]=N;M=g,N=mc(e,6)+1|0,t[M+12|0]=N;b=mc(e,8);t[g+13|0]=b;if(v[e+120>>2]<=(b&255)){break r}f=0;while(1){b=w[g+12|0];if(b>>>0>f>>>0){h=(l+16|0)+f|0;b=mc(e,3);if(mc(e,1)){i=mc(e,5)}else{i=0}t[h|0]=b+(i<<3);f=f+1|0;continue}break}b=ee(e,b<<4);v[g+20>>2]=b;if(!b){break q}h=0;while(1){if(w[g+12|0]>h>>>0){b=w[(l+16|0)+h|0];f=0;while(1){if((f|0)!=8){s:{if(b>>>f&1){j=mc(e,8);m=f<<1;i=h<<4;u[m+(i+v[g+20>>2]|0)>>1]=j;if(v[e+120>>2]>u[m+(i+v[g+20>>2]|0)>>1]){break s}bc(e,20);break c}u[(v[g+20>>2]+(h<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}h=h+1|0;continue}break}h=ee(e,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);v[g+16>>2]=h;if(!h){bc(e,3);break c}b=0;Rb(h,0,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);while(1){h=v[e+124>>2]+B(w[g+13|0],2096)|0;if(v[h+4>>2]>(b|0)){f=v[h>>2];j=ee(e,f);h=b<<2;v[h+v[g+16>>2]>>2]=j;j=b;if(v[h+v[g+16>>2]>>2]){while(1){if((f|0)>0){f=f-1|0;t[f+v[h+v[g+16>>2]>>2]|0]=(j|0)%w[g+12|0];j=(j|0)/w[g+12|0]|0;continue}break}b=b+1|0;continue}else{bc(e,3);break c}}break}k=k+1|0;continue}break}b=mc(e,6)+1|0;v[e+400>>2]=b;b=ee(e,B(b,40));v[e+404>>2]=b;if(!b){bc(e,3);break c}Rb(b,0,B(v[e+400>>2],40));i=0;while(1){if(v[e+400>>2]>(i|0)){b=v[e+404>>2];if(mc(e,16)){bc(e,20);break c}h=b+B(i,40)|0;b=ee(e,B(v[e+4>>2],3));v[h+4>>2]=b;if(!b){bc(e,3);break c}if(mc(e,1)){b=mc(e,4)+1|0}else{b=1}t[h+8|0]=b;t:{if(mc(e,1)){b=mc(e,8)+1|0;u[h>>1]=b;f=0;g=v[e+4>>2];if((g|0)<(b&65535)){bc(e,20);break c}while(1){if((b&65535)>>>0<=f>>>0){break t}g=mc(e,am(g-1|0));b=B(f,3);t[b+v[h+4>>2]|0]=g;g=mc(e,am(v[e+4>>2]-1|0));t[(b+v[h+4>>2]|0)+1|0]=g;g=v[e+4>>2];b=b+v[h+4>>2]|0;j=w[b|0];if((g|0)<=(j|0)){bc(e,20);break c}b=w[b+1|0];if((b|0)>=(g|0)){bc(e,20);break c}if((b|0)!=(j|0)){f=f+1|0;b=x[h>>1];continue}break}bc(e,20);break c}u[h>>1]=0}if(mc(e,2)){bc(e,20);break c}g=0;b=0;f=0;u:{if(w[h+8|0]>=2){while(1){if(v[e+4>>2]<=(b|0)){break u}f=mc(e,4);j=B(b,3);t[(j+v[h+4>>2]|0)+2|0]=f;b=b+1|0;if(w[(j+v[h+4>>2]|0)+2|0]<w[h+8|0]){continue}break}bc(e,20);break c}while(1){if(v[e+4>>2]<=(f|0)){break u}t[(v[h+4>>2]+B(f,3)|0)+2|0]=0;f=f+1|0;continue}}v:{while(1){if(w[h+8|0]<=g>>>0){break v}mc(e,8);b=g+h|0;M=b,N=mc(e,8),t[M+9|0]=N;f=mc(e,8);t[b+24|0]=f;if(v[e+128>>2]<=w[b+9|0]){bc(e,20);break c}g=g+1|0;if(v[e+264>>2]>(f&255)){continue}break}bc(e,20);break c}i=i+1|0;continue}break}f=mc(e,6)+1|0;v[e+408>>2]=f;h=e+412|0;j=0;w:{while(1){if((f|0)<=(j|0)){break w}b=h+B(j,6)|0;M=b,N=mc(e,1),t[M|0]=N;M=b,N=mc(e,16),u[M+2>>1]=N;M=b,N=mc(e,16),u[M+4>>1]=N;f=mc(e,8);t[b+1|0]=f;if(x[b+2>>1]){bc(e,20);break c}if(x[b+4>>1]){bc(e,20);break c}if(v[e+400>>2]>(f&255)){j=j+1|0;f=v[e+408>>2];continue}break}bc(e,20);break c}SH(e);v[e+992>>2]=0;h=E<<1;f=0;while(1){if(v[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=ee(e,v[e+116>>2]<<2),v[M+800>>2]=N;M=b,N=ee(e,v[e+116>>2]<<1&2147483646),v[M+928>>2]=N;g=ee(e,h);v[b+996>>2]=g;j=v[b+800>>2];if(g?!j|!v[b+928>>2]:1){bc(e,3);break c}Rb(j,0,v[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!LH(e,0,v[e+112>>2])){break a}if(!LH(e,1,v[e+116>>2])){break a}v[e+104>>2]=v[e+112>>2];h=v[e+116>>2];v[e+108>>2]=h;b=v[e+264>>2];i=(b|0)>0?b:0;b=(h|0)/2|0;g=0;while(1){if((f|0)!=(i|0)){j=v[e+396>>2]+B(f,24)|0;k=v[j+4>>2];n=b>>>0>k>>>0?k:b;k=v[j>>2];j=(n-(b>>>0>k>>>0?k:b)>>>0)/y[j+8>>2]|0;g=(g|0)<(j|0)?j:g;f=f+1|0;continue}break}b=h<<1&2147483646;h=B(v[e+4>>2],(g<<2)+4|0);b=b>>>0>h>>>0?b:h;v[e+12>>2]=b;x:{if(!v[e+80>>2]){break x}h=v[e+92>>2];if((h|0)!=v[e+84>>2]){break p}if(h>>>0>=(b+v[e+88>>2]|0)+1512>>>0){break x}bc(e,3);break c}y:{if(v[e+1380>>2]==-1){v[e+52>>2]=w[e+48|0]?0:v[e+32>>2]-v[e+36>>2]|0;break y}v[e+52>>2]=0}f=1;break a}bc(e,20);break c}bc(e,3);break c}aa(7304,13226,4196,8858);L()}z:{if(f&255){j=vn(e,b);break z}j=ee(e,b);v[g+8>>2]=j}if(!j){bc(e,3);break c}i=0;A:{if(!m){f=0;while(1){b=v[k>>2];if((f|0)>=(b|0)){break A}B:{C:{if(w[g+23|0]){if(!mc(e,1)){break C}}b=mc(e,5)+1|0;t[f+j|0]=b;if((b&255)!=32){i=i+1|0;break B}bc(e,20);break c}t[f+j|0]=255}f=f+1|0;continue}}h=mc(e,5);f=0;while(1){b=v[k>>2];if((f|0)>=(b|0)){break A}m=mc(e,am(b-f|0));h=h+1|0;if((h|0)>=32){bc(e,20);break c}b=f+m|0;if((b|0)>v[k>>2]){bc(e,20);break c}else{Rb(f+j|0,h,m);f=b;continue}}}D:{E:{F:{if(w[g+23|0]){if(b>>2>(i|0)){break F}if(v[e+16>>2]<(b|0)){v[e+16>>2]=b;b=v[k>>2]}b=ee(e,b);v[g+8>>2]=b;if(!b){bc(e,3);break c}pc(b,j,v[k>>2]);aj(e,j,v[k>>2]);j=v[g+8>>2];t[g+23|0]=0;b=v[k>>2]}h=0;i=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(i|0)){h=((w[f+j|0]-11&255)>>>0<244)+h|0;f=f+1|0;continue}break}v[g+2092>>2]=h;b=ee(e,b<<2);v[g+32>>2]=b;if(b){m=g+2092|0;f=0;break E}bc(e,3);break c}v[g+2092>>2]=i;m=g+2092|0;G:{if(!i){f=0;h=0;break G}b=ee(e,i);v[g+8>>2]=b;if(!b){bc(e,3);break c}b=vn(e,v[m>>2]<<2);v[g+32>>2]=b;if(!b){bc(e,3);break c}f=vn(e,v[m>>2]<<2);if(!f){break D}b=v[k>>2];h=v[m>>2]}b=(h<<3)+b|0;if(b>>>0<=y[e+16>>2]){break E}v[e+16>>2]=b}n=v[k>>2];b=0;h=hb-128|0;hb=h;o=Rb(h,0,128);h=(n|0)>0?n:0;while(1){H:{I:{if((b|0)!=(h|0)){if(w[b+j|0]==255){break I}h=b}if((h|0)==(n|0)){b=1;if(!v[g+2092>>2]){break H}aa(15830,13226,1103,7548);L()}b=h+j|0;i=w[b|0];if(i>>>0<32){JH(g,0,h,0,i,f);q=1;i=w[b|0]+1|0;b=1;J:{while(1){if((b|0)==(i|0)){K:while(1){L:{b=1;h=h+1|0;if((n|0)<=(h|0)){break H}F=h+j|0;i=w[F|0];if((i|0)==255){continue}b=i;if(b>>>0>=32){break L}while(1){if((b|0)<=0){b=0;break H}G=o+(b<<2)|0;p=v[G>>2];if(!p){b=b-1|0;continue}break}v[G>>2]=0;JH(g,_l(p),h,q,i,f);q=q+1|0;i=w[F|0];if((i|0)==(b|0)){continue}while(1){if((b|0)>=(i|0)){continue K}F=o+(i<<2)|0;if(v[F>>2]){break J}v[F>>2]=p+(1<<32-i);i=i-1|0;continue}}break}}else{v[o+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}aa(15334,13226,1118,7548);L()}aa(15874,13226,1133,7548);L()}aa(15341,13226,1104,7548);L()}b=b+1|0;continue}break}hb=o+128|0;if(!b){if(w[g+23|0]){aj(e,f,0)}bc(e,20);break c}b=v[m>>2];if(b){b=ee(e,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){bc(e,3);break c}b=ee(e,(v[m>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){bc(e,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;b=0;i=0;M:{N:{O:{if(w[g+23|0]){while(1){i=v[g+2092>>2];if((i|0)<=(b|0)){break O}h=b<<2;M=h+v[g+2084>>2]|0,N=_l(v[h+v[g+32>>2]>>2]),v[M>>2]=N;b=b+1|0;continue}}while(1){if(v[g+4>>2]>(b|0)){if(IH(w[g+23|0],w[b+j|0])){M=v[g+2084>>2]+(i<<2)|0,N=_l(v[v[g+32>>2]+(b<<2)>>2]),v[M>>2]=N;i=i+1|0}b=b+1|0;continue}break}if(v[g+2092>>2]!=(i|0)){break N}}MH(v[g+2084>>2],i,1114);v[v[g+2084>>2]+(v[g+2092>>2]<<2)>>2]=-1;h=0;b=v[g+(w[g+23|0]?2092:4)>>2];p=(b|0)>0?b:0;P:{while(1){if((h|0)!=(p|0)){b=h;i=w[g+23|0];b=i?v[(b<<2)+f>>2]:b;F=w[b+j|0];Q:{if(!IH(i,F)){break Q}G=h<<2;n=_l(v[G+v[g+32>>2]>>2]);b=v[g+2092>>2];i=0;while(1){if((b|0)>=2){o=b>>>1|0;J=o+i|0;q=n>>>0<y[v[g+2084>>2]+(J<<2)>>2];b=q?o:b-o|0;i=q?i:J;continue}break}b=i<<2;if((n|0)!=v[b+v[g+2084>>2]>>2]){break P}if(w[g+23|0]){v[b+v[g+2088>>2]>>2]=v[f+G>>2];t[v[g+8>>2]+i|0]=F;break Q}v[b+v[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break M}aa(12267,13226,1230,10001);L()}aa(7489,13226,1200,10001);L()}}if(w[g+23|0]){aj(e,f,v[m>>2]<<2);aj(e,v[g+32>>2],v[m>>2]<<2);aj(e,j,v[k>>2]);v[g+32>>2]=0}i=g;b=0;f=0;while(1){if((b|0)!=1024){u[(i+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=v[i+(w[i+23|0]?2092:4)>>2];b=(b|0)<32767?b:32767;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){R:{if(w[v[i+8>>2]+f|0]>10){break R}S:{if(w[i+23|0]){b=_l(v[v[i+2084>>2]+(f<<2)>>2]);break S}b=v[v[i+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break R}u[(i+(b<<1)|0)+36>>1]=f;b=(1<<w[v[i+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=mc(e,4);t[i+21|0]=b;b=b&255;if(b>>>0>=3){bc(e,20);break c}if(b){M=i,O=KH(mc(e,32)),z[M+12>>2]=O;M=i,O=KH(mc(e,32)),z[M+16>>2]=O;M=i,N=mc(e,4)+1|0,t[M+20|0]=N;M=i,N=mc(e,1),t[M+22|0]=N;f=v[i>>2];h=v[k>>2];T:{if(w[i+21|0]==1){A=H(ux(+C(C(xp(+C(h|0)))/C(f|0))));U:{if(D(A)<2147483648){b=~~A;break U}b=-2147483648}A=+(f|0);K=H($j(+C(C(b|0)+C(1)),A));V:{if(D(K)<2147483648){f=~~K;break V}f=-2147483648}b=((f|0)<=(h|0))+b|0;s=C(b|0);if($j(+C(s+C(1)),A)<=+(h|0)){f=-1}else{A=H($j(+s,A));W:{if(D(A)<2147483648){f=~~A;break W}f=-2147483648}f=(f|0)>(h|0)?-1:b}if((f|0)>=0){break T}bc(e,20);break c}f=B(f,h)}v[i+24>>2]=f;if(!f){bc(e,20);break c}n=vn(e,f<<1);if(!n){break h}f=0;while(1){j=v[i+24>>2];if((j|0)>(f|0)){b=mc(e,w[i+20|0]);if((b|0)==-1){aj(e,n,v[i+24>>2]<<1);bc(e,20);break c}else{u[n+(f<<1)>>1]=b;f=f+1|0;continue}}break}X:{Y:{if(w[i+21|0]==1){o=w[i+23|0];Z:{if(o){f=v[m>>2];if(f){break Z}break X}f=v[k>>2]}b=ee(e,B(v[i>>2],f)<<2);v[i+28>>2]=b;if(!b){aj(e,n,v[i+24>>2]<<1);bc(e,3);break c}h=0;b=v[(o?m:k)>>2];m=(b|0)>0?b:0;q=i+2088|0;s=C(0);while(1){if((h|0)==(m|0)){break Y}g=h;g=o?v[v[q>>2]+(g<<2)>>2]:g;j=v[i>>2];f=0;b=1;while(1){if((f|0)<(j|0)){I=C(s+C(C(C(x[n+(((g>>>0)/(b>>>0)>>>0)%y[i+24>>2]<<1)>>1])*z[i+16>>2])+z[i+12>>2]));z[v[i+28>>2]+(B(h,j)+f<<2)>>2]=I;s=w[i+22|0]?I:s;f=f+1|0;j=v[i>>2];if((f|0)>=(j|0)){continue}k=v[i+24>>2];rka(k,0,b,0);if(kb){aj(e,n,k<<1);bc(e,20);break c}else{b=B(b,k);continue}}break}h=h+1|0;continue}}b=ee(e,j<<2);v[i+28>>2]=b;if(!b){break g}f=0;s=C(0);while(1){j=v[i+24>>2];if((j|0)<=(f|0)){break X}I=C(s+C(C(C(x[n+(f<<1)>>1])*z[i+16>>2])+z[i+12>>2]));z[v[i+28>>2]+(f<<2)>>2]=I;s=w[i+22|0]?I:s;f=f+1|0;continue}}t[i+21|0]=2;j=v[i+24>>2]}aj(e,n,j<<1)}E=E+1|0;continue}break}bc(e,3);break c}bc(e,3);break c}aj(e,n,v[i+24>>2]<<1);bc(e,3);break c}bc(e,20);break c}bc(e,3);break c}t[b+v[v[e+28>>2]+(h<<2)>>2]|0]=0;h=h+1|0;continue}}bc(e,3);break c}bc(e,20)}f=0}hb=l+1024|0;_:{$:{if(!f){v[d>>2]=v[r+104>>2]?1:v[r+108>>2];break $}b=ee(r+8|0,1512);if(b){M=c,N=v[pc(b,r+8|0,1512)+32>>2]-a|0,v[M>>2]=N;v[d>>2]=0;break _}}VH(r+8|0);b=0}hb=r+1520|0;return b}function GG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0;s=hb-48|0;hb=s;a:{if(c>>>0<=2){c=c<<2;I=v[c+79788>>2];J=v[c+79776>>2];while(1){c=v[b+4>>2];b:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=md(b)}if(Nk(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=md(b)}e:{f:{while(1){if(t[g+4955|0]==(c|32)){g:{if(g>>>0>6){break g}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=md(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){v[b+4>>2]=v[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}i=hb-16|0;hb=i;l=(p(C(C(o|0)*C(N))),j(2));b=l&2147483647;h:{if(b-8388608>>>0<=2130706431){r=b<<25;c=(b>>>7|0)+1065353216|0;break h}r=l<<25;c=l>>>7|2147418112;if(b>>>0>=2139095040){break h}r=0;c=0;if(!b){break h}c=b;b=E(b);Hf(i,c,0,0,0,b+81|0);k=v[i>>2];h=v[i+4>>2];r=v[i+8>>2];c=v[i+12>>2]^65536|16265-b<<16}v[s>>2]=k;v[s+4>>2]=h;v[s+8>>2]=r;v[s+12>>2]=l&-2147483648|c;hb=i+16|0;k=v[s+8>>2];h=v[s+12>>2];i=v[s>>2];l=v[s+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(t[g+9997|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=md(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=v[b+4>>2];o:{if((g|0)!=v[b+104>>2]){v[b+4>>2]=g+1;g=w[g|0];break o}g=md(b)}if((g&-33)==88){g=d;c=0;f=hb-432|0;hb=f;p:{q:{d=v[b+4>>2];if((d|0)!=v[b+104>>2]){v[b+4>>2]=d+1;c=w[d|0];break q}d=0;break p}d=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!d){c=md(b);break y}if((c|0)!=48){l=1073676288;if((c|0)==46){break w}break v}d=v[b+4>>2];if((d|0)==v[b+104>>2]){break x}n=1;v[b+4>>2]=d+1;c=w[d|0]}d=1;continue}n=1;break s}c=v[b+4>>2];z:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break z}c=md(b)}if((c|0)==48){break u}F=1}break t}while(1){c=r;r=c-1|0;u=u-!c|0;F=1;c=v[b+4>>2];A:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break A}c=md(b)}if((c|0)==48){continue}break}n=1}while(1){e=c|32;B:{C:{M=c-48|0;if(M>>>0<10){break C}if(!((c|0)==46|e-97>>>0<6)){d=c;break r}d=46;if((c|0)!=46){break C}if(F){break r}F=1;r=k;u=h;break B}c=(c|0)>57?e-87|0:M;D:{if((h|0)<=0&k>>>0<=7|(h|0)<0){x=c+(x<<4)|0;break D}if(!h&k>>>0<=28){Xg(f+48|0,c);Fd(f+32|0,G,H,i,l,0,0,0,1073414144);G=v[f+32>>2];H=v[f+36>>2];i=v[f+40>>2];l=v[f+44>>2];Fd(f+16|0,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2],G,H,i,l);Dg(f,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2],m,q,A,D);A=v[f+8>>2];D=v[f+12>>2];m=v[f>>2];q=v[f+4>>2];break D}if(!c|z){break D}Fd(f+80|0,G,H,i,l,0,0,0,1073610752);Dg(f- -64|0,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2],m,q,A,D);A=v[f+72>>2];D=v[f+76>>2];z=1;m=v[f+64>>2];q=v[f+68>>2]}c=k+1|0;h=c?h:h+1|0;k=c;n=1}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0]}else{c=md(b)}continue}}d=0;continue}break}E:{if(!n){c=v[b+116>>2];F:{G:{if((c|0)>0|(c|0)>=0){c=v[b+4>>2];v[b+4>>2]=c-1;if(!g){break G}v[b+4>>2]=c-2;if(!F){break F}v[b+4>>2]=c-3;break F}if(g){break F}}li(b,0,0)}Wi(f+96|0,+(o|0)*0);m=v[f+96>>2];q=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2];break E}if((h|0)<=0&k>>>0<=7|(h|0)<0){i=k;l=h;while(1){x=x<<4;c=i+1|0;l=c?l:l+1|0;i=c;if((c|0)!=8|l){continue}break}}H:{I:{J:{if((d&-33)==80){i=FG(b,g);c=kb;l=c;if(i|(c|0)!=-2147483648){break H}if(g){c=v[b+116>>2];if((c|0)>0|(c|0)>=0){break J}break I}m=0;q=0;li(b,0,0);c=0;b=0;break E}i=0;l=0;if(v[b+116>>2]<0){break H}}v[b+4>>2]=v[b+4>>2]-1}i=0;l=0}if(!x){Wi(f+112|0,+(o|0)*0);m=v[f+112>>2];q=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break E}b=F?r:k;h=(F?u:h)<<2|b>>>30;b=i+(b<<2)|0;d=h+l|0;d=b>>>0<i>>>0?d+1|0:d;k=b-32|0;h=d-(b>>>0<32)|0;b=h;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){v[115992]=68;Xg(f+160|0,o);Fd(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Fd(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);m=v[f+128>>2];q=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break E}b=I-226|0;c=b>>31;if((h|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(h|0)){if((x|0)>=0){while(1){Dg(f+416|0,m,q,A,D,0,0,0,-1073807360);c=iT(m,q,A,D,1073610752);b=(c|0)<0;Dg(f+400|0,m,q,A,D,b?m:v[f+416>>2],b?q:v[f+420>>2],b?A:v[f+424>>2],b?D:v[f+428>>2]);b=k;k=b-1|0;h=h-!b|0;A=v[f+408>>2];D=v[f+412>>2];m=v[f+400>>2];q=v[f+404>>2];x=x<<1|(c|0)>=0;if((x|0)>=0){continue}break}}d=h-((I>>31)+(k>>>0<I>>>0)|0)|0;b=(k-I|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<J>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:J;K:{if((c|0)>=113){Xg(f+384|0,o);r=v[f+392>>2];u=v[f+396>>2];G=v[f+384>>2];H=v[f+388>>2];h=0;b=0;break K}Wi(f+352|0,Vj(1,144-c|0));Xg(f+336|0,o);G=v[f+336>>2];H=v[f+340>>2];r=v[f+344>>2];u=v[f+348>>2];IG(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],G,H,r,u);K=v[f+376>>2];L=v[f+380>>2];h=v[f+372>>2];b=v[f+368>>2]}c=!(x&1)&((zm(m,q,A,D,0,0,0,0)|0)!=0&(c|0)<32);gn(f+320|0,c+x|0);Fd(f+304|0,G,H,r,u,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;Dg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,h,K,L);b=c;Fd(f+288|0,G,H,r,u,b?0:m,b?0:q,b?0:A,b?0:D);Dg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Px(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,h,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];h=v[f+252>>2];if(!zm(b,c,d,h,0,0,0,0)){v[115992]=68}HG(f+224|0,b,c,d,h,k);m=v[f+224>>2];q=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break E}v[115992]=68;Xg(f+208|0,o);Fd(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Fd(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);m=v[f+176>>2];q=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2]}v[s+16>>2]=m;v[s+20>>2]=q;v[s+24>>2]=b;v[s+28>>2]=c;hb=f+432|0;k=v[s+24>>2];h=v[s+28>>2];i=v[s+16>>2];l=v[s+20>>2];break a}if(v[b+116>>2]<0){break n}v[b+4>>2]=v[b+4>>2]-1}g=b;f=o;x=d;d=0;o=0;e=hb-8976|0;hb=e;K=I+J|0;L=0-K|0;L:{M:{while(1){if((c|0)!=48){N:{if((c|0)!=46){break L}b=v[g+4>>2];if((b|0)==v[g+104>>2]){break N}v[g+4>>2]=b+1;c=w[b|0];break M}}else{b=v[g+4>>2];if((b|0)!=v[g+104>>2]){d=1;v[g+4>>2]=b+1;c=w[b|0]}else{d=1;c=md(g)}continue}break}c=md(g)}n=1;if((c|0)!=48){break L}while(1){b=k;k=b-1|0;h=h-!b|0;b=v[g+4>>2];O:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break O}c=md(g)}if((c|0)==48){continue}break}d=1}v[e+784>>2]=0;P:{Q:{b=(c|0)==46;m=c-48|0;R:{S:{T:{U:{if(b|m>>>0<=9){while(1){V:{if(b&1){if(!n){k=i;h=l;n=1;break V}b=!d;break U}b=i+1|0;l=b?l:l+1|0;i=b;if((o|0)<=2044){F=(c|0)==48?F:i;b=(e+784|0)+(o<<2)|0;if(z){m=(B(v[b>>2],10)+c|0)-48|0}v[b>>2]=m;d=1;c=z+1|0;b=(c|0)==9;z=b?0:c;o=b+o|0;break V}if((c|0)==48){break V}v[e+8960>>2]=v[e+8960>>2]|1;F=18396}b=v[g+4>>2];W:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break W}c=md(g)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}k=n?k:i;h=n?h:l;if(!(!d|(c&-33)!=69)){m=FG(g,x);b=kb;q=b;X:{if(m|(b|0)!=-2147483648){break X}if(!x){break R}m=0;q=0;if(v[g+116>>2]<0){break X}v[g+4>>2]=v[g+4>>2]-1}if(!d){break S}h=h+q|0;b=k+m|0;h=b>>>0<m>>>0?h+1|0:h;k=b;break Q}b=!d;if((c|0)<0){break T}}if(v[g+116>>2]<0){break T}v[g+4>>2]=v[g+4>>2]-1}if(!b){break Q}}v[115992]=28}i=0;l=0;li(g,0,0);c=0;b=0;break P}b=v[e+784>>2];if(!b){Wi(e,+(f|0)*0);i=v[e>>2];l=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break P}if(!((k|0)!=(i|0)|(h|0)!=(l|0)|(i>>>0>9&(l|0)>=0|(l|0)>0)|(b>>>J|0?(J|0)<=30:0))){Xg(e+48|0,f);gn(e+32|0,b);Fd(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);i=v[e+16>>2];l=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break P}if(k>>>0>(I|0)/-2>>>0&(h|0)>=0|(h|0)>0){v[115992]=68;Xg(e+96|0,f);Fd(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Fd(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);i=v[e+64>>2];l=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break P}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){v[115992]=68;Xg(e+144|0,f);Fd(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Fd(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);i=v[e+112>>2];l=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break P}if(z){if((z|0)<=8){b=(e+784|0)+(o<<2)|0;g=v[b>>2];while(1){g=B(g,10);z=z+1|0;if((z|0)!=9){continue}break}v[b>>2]=g}o=o+1|0}Y:{n=k;if((F|0)>(k|0)|(F|0)>8|(k|0)>17){break Y}if((n|0)==9){Xg(e+192|0,f);gn(e+176|0,v[e+784>>2]);Fd(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);i=v[e+160>>2];l=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break P}if((n|0)<=8){Xg(e+272|0,f);gn(e+256|0,v[e+784>>2]);Fd(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);Xg(e+224|0,v[(0-n<<2)+79776>>2]);WP(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);i=v[e+208>>2];l=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break P}b=(J+B(n,-3)|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}Xg(e+352|0,f);gn(e+336|0,c);Fd(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);Xg(e+304|0,v[(n<<2)+79704>>2]);Fd(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);i=v[e+288>>2];l=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break P}while(1){c=o;o=c-1|0;if(!v[(e+784|0)+(o<<2)>>2]){continue}break}b=(n|0)%9|0;Z:{if(!b){z=0;b=0;break Z}z=0;d=(n|0)<0?b+9|0:b;_:{if(!c){b=0;c=0;break _}k=v[(0-d<<2)+79776>>2];l=1e9/(k|0)|0;m=0;g=0;b=0;while(1){h=m;i=(e+784|0)+(g<<2)|0;o=v[i>>2];m=(o>>>0)/(k>>>0)|0;h=h+m|0;v[i>>2]=h;h=!h&(b|0)==(g|0);b=h?b+1&2047:b;n=h?n-9|0:n;m=B(l,o-B(k,m)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!m){break _}v[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}n=(n-d|0)+9|0}while(1){o=(e+784|0)+(b<<2)|0;g=(n|0)<36;$:{while(1){aa:{if(g){break aa}if((n|0)!=36){break $}if(y[o>>2]<=10384592){break aa}n=36;break $}d=c+2047|0;m=0;while(1){i=d&2047;x=(e+784|0)+(i<<2)|0;d=v[x>>2];l=d>>>3|0;h=d<<29;k=h+m|0;d=l;d=h>>>0>k>>>0?d+1|0:d;h=d;if(!h&k>>>0<1000000001){m=0}else{m=uka(k,h,1e9,0);d=rka(m,kb,-1e9,-1)+k|0;k=d}v[x>>2]=k;c=(i|0)!=(c-1&2047)?c:(b|0)==(i|0)?c:k?c:i;d=i-1|0;if((b|0)!=(i|0)){continue}break}z=z-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;k=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[k>>2]=v[k>>2]|v[d+(c<<2)>>2]}n=n+9|0;v[(e+784|0)+(b<<2)>>2]=m;continue}break}ba:{ca:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;da:{while(1){d=b;g=0;ea:{while(1){fa:{b=d+g&2047;if((b|0)==(c|0)){break fa}b=v[(e+784|0)+(b<<2)>>2];i=v[(g<<2)+79728>>2];if(b>>>0<i>>>0){break fa}if(b>>>0>i>>>0){break ea}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break ea}k=0;h=0;g=0;i=0;l=0;while(1){b=d+g&2047;if((b|0)==(c|0)){c=c+1&2047;v[((c<<2)+e|0)+780>>2]=0}gn(e+768|0,v[(e+784|0)+(b<<2)>>2]);Fd(e+752|0,k,h,i,l,0,0,1342177280,1075633366);Dg(e+736|0,v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2],v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2]);i=v[e+744>>2];l=v[e+748>>2];k=v[e+736>>2];h=v[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}Xg(e+720|0,f);Fd(e+704|0,k,h,i,l,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);i=v[e+712>>2];l=v[e+716>>2];k=0;h=0;m=v[e+704>>2];q=v[e+708>>2];x=z+113|0;o=x-I|0;n=(o|0)<(J|0);b=n?(o|0)>0?o:0:J;if((b|0)<=112){break da}break ba}z=h+z|0;b=c;if((d|0)==(b|0)){continue}break}o=1e9>>>h|0;m=-1<<h^-1;g=0;b=d;while(1){i=g;g=(e+784|0)+(d<<2)|0;x=v[g>>2];i=i+(x>>>h|0)|0;v[g>>2]=i;i=!i&(b|0)==(d|0);b=i?b+1&2047:b;n=i?n-9|0:n;g=B(o,m&x);d=d+1&2047;if((d|0)!=(c|0)){continue}break}if(!g){continue}if((b|0)!=(k|0)){v[(e+784|0)+(c<<2)>>2]=g;c=k;continue ca}v[l>>2]=v[l>>2]|1;continue}break}break}Wi(e+656|0,Vj(1,225-b|0));IG(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],m,q,i,l);G=v[e+696>>2];H=v[e+700>>2];A=v[e+688>>2];D=v[e+692>>2];Wi(e+640|0,Vj(1,113-b|0));mP(e+672|0,m,q,i,l,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);k=v[e+672>>2];h=v[e+676>>2];r=v[e+680>>2];u=v[e+684>>2];Px(e+624|0,m,q,i,l,k,h,r,u);Dg(e+608|0,A,D,G,H,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);i=v[e+616>>2];l=v[e+620>>2];m=v[e+608>>2];q=v[e+612>>2]}g=d+4&2047;ga:{if((g|0)==(c|0)){break ga}g=v[(e+784|0)+(g<<2)>>2];ha:{if(g>>>0<=499999999){if(!g&(d+5&2047)==(c|0)){break ha}Wi(e+496|0,+(f|0)*.25);Dg(e+480|0,k,h,r,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);r=v[e+488>>2];u=v[e+492>>2];k=v[e+480>>2];h=v[e+484>>2];break ha}if((g|0)!=5e8){Wi(e+592|0,+(f|0)*.75);Dg(e+576|0,k,h,r,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);r=v[e+584>>2];u=v[e+588>>2];k=v[e+576>>2];h=v[e+580>>2];break ha}O=+(f|0);if((d+5&2047)==(c|0)){Wi(e+528|0,O*.5);Dg(e+512|0,k,h,r,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);r=v[e+520>>2];u=v[e+524>>2];k=v[e+512>>2];h=v[e+516>>2];break ha}Wi(e+560|0,O*.75);Dg(e+544|0,k,h,r,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);r=v[e+552>>2];u=v[e+556>>2];k=v[e+544>>2];h=v[e+548>>2]}if((b|0)>111){break ga}mP(e+464|0,k,h,r,u,0,0,0,1073676288);if(zm(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break ga}Dg(e+448|0,k,h,r,u,0,0,0,1073676288);r=v[e+456>>2];u=v[e+460>>2];k=v[e+448>>2];h=v[e+452>>2]}Dg(e+432|0,m,q,i,l,k,h,r,u);Px(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],A,D,G,H);i=v[e+424>>2];l=v[e+428>>2];m=v[e+416>>2];q=v[e+420>>2];ia:{if((-2-K|0)>=(x&2147483647)){break ia}v[e+408>>2]=i;v[e+412>>2]=l&2147483647;v[e+400>>2]=m;v[e+404>>2]=q;Fd(e+384|0,m,q,i,l,0,0,0,1073610752);d=iT(v[e+400>>2],v[e+404>>2],v[e+408>>2],v[e+412>>2],1081081856);c=(d|0)<0;i=c?i:v[e+392>>2];l=c?l:v[e+396>>2];m=c?m:v[e+384>>2];q=c?q:v[e+388>>2];z=((d|0)>=0)+z|0;if((zm(k,h,r,u,0,0,0,0)|0)!=0&(c?n:n&(b|0)!=(o|0))?0:(L|0)>=(z+110|0)){break ia}v[115992]=68}HG(e+368|0,m,q,i,l,z);i=v[e+368>>2];l=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[s+40>>2]=b;v[s+44>>2]=c;v[s+32>>2]=i;v[s+36>>2]=l;hb=e+8976|0;k=v[s+40>>2];h=v[s+44>>2];i=v[s+32>>2];l=v[s+36>>2];break a;case 3:break j;default:break m}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}break i}ja:{c=v[b+4>>2];ka:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ka}c=md(b)}if((c|0)==40){g=1;break ja}h=2147450880;if(v[b+116>>2]<0){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];la:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break la}c=md(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}ma:{if(d){if(g){break ma}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(g){continue}break}break a}v[115992]=28;li(b,0,0)}h=0}v[a>>2]=i;v[a+4>>2]=l;v[a+8>>2]=k;v[a+12>>2]=h;hb=s+48|0}function sfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;d=hb-384|0;hb=d;xc(b);a:{if(!mo(b,d+368|0)){break a}if(!fR(d+368|0)){break a}q=he(d+344|0,b);o=Lb(d+328|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!c){v[23516]=0;R(651,d+40|0,q|0);b=v[23516];v[23516]=0;if((b|0)==1){break z}break B}v[23516]=0;R(652,d+40|0,q|0);b=v[23516];v[23516]=0;if((b|0)==1){break A}}b=d+40|0;Dt(o,b);Ud(b);v[23516]=0;U(653,b|0,o|0,1413891155);b=v[23516];v[23516]=0;C:{D:{if((b|0)!=1){v[23516]=0;e=Q(654,d+40|0,14213)|0;b=v[23516];v[23516]=0;if((b|0)==1){break D}yb(d+40|0);if(!c){break b}if(!(e^1)){break C}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(d+40|0);break c}v[23516]=0;R(248,a|0,4194304);b=v[23516];v[23516]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[23516]=0;U(653,d+304|0,o|0,1280592212);b=v[23516];v[23516]=0;if((b|0)==1){break e}v[23516]=0;b=T(158,v[d+304>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break g}v[23516]=0;U(452,d+304|0,a+1298308|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break g}i=a+484360|0;j=a+484376|0;Gc(Sb(v[i>>2],w[j|0]));k=Lb(d+288|0);t[d+287|0]=0;v[23516]=0;U(655,d+272|0,o|0,1196314451);b=v[23516];v[23516]=0;if((b|0)==1){break i}A=d,C=Cb(v[d+272>>2]),v[A+264>>2]=C;p=d+252|0;r=Cb(v[d+276>>2]);E:{F:{while(1){b=v[d+264>>2];if(!Nb(b,r)){break F}l=he(d+40|0,b);v[23516]=0;e=Q(656,l|0,d+24|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break E}b=1;if(!(!e|w[d+33|0]!=1)){A=a,C=Bd(w[d+34|0],x[a+480188>>1],127),u[A+480188>>1]=C;v[23516]=0;h=T(657,d+208|0)|0;b=v[23516];v[23516]=0;G:{H:{I:{J:{K:{if((b|0)!=1){b=d+192|0;lf(b,d+24|0,9,1);v[23516]=0;R(221,d+160|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break K}b=d+8|0;fc(b,p,10);e=b;b=d+160|0;Cl(e,b);wb(b);b=Sb(v[a+484360>>2],w[j|0]);if(nc(v[b>>2],v[b+4>>2])){break H}v[23516]=0;b=T(275,i|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break J}if((b|0)!=255){break I}b=2;break G}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=Sb(v[a+484360>>2],w[j|0])}v[23516]=0;U(5,d+160|0,5,p|0);e=v[23516];v[23516]=0;if((e|0)==1){break n}v[23516]=0;R(276,b|0,d+160|0);b=v[23516];v[23516]=0;if((b|0)==1){break o}xb(d+160|0);v[23516]=0;R(652,d+192|0,l|0);b=v[23516];v[23516]=0;if((b|0)==1){break p}A=d,C=Cb(v[d+192>>2]),v[A+184>>2]=C;n=Cb(v[d+196>>2]);L:{M:{while(1){b=v[d+184>>2];if(!Nb(b,n)){b=0;if(x[d+244>>1]==65535|x[d+246>>1]==65535){break L}b=w[j|0];e=v[a+484360>>2];v[23516]=0;Y(658,Sb(e,b)|0);b=v[23516];v[23516]=0;if((b|0)!=1){v[23516]=0;R(659,k|0,h|0);e=v[23516];v[23516]=0;b=0;if((e|0)!=1){break L}}b=P()|0;O()|0;break m}so(d+160|0,b);Zh(d+8|0,v[b>>2],v[b+4>>2]);e=1;N:{g=v[d+8>>2];O:{if((g|0)!=1212960847){b=0;if((g|0)!=1312903248){break O}while(1){if(x[a+480188>>1]<=b>>>0){break O}v[23516]=0;g=W(154,v[d+160>>2],v[d+168>>2],2)|0;f=v[23516];v[23516]=0;if((f|0)!=1){if(!g){break O}v[23516]=0;R(263,d+136|0,d+160|0);g=v[23516];v[23516]=0;P:{Q:{R:{S:{if((g|0)!=1){switch(w[d+136|0]){case 4:break Q;case 2:break R;case 0:break S;default:break P}}break q}g=Kc(d+136|0);A=Ib(v[h>>2],b),C=w[g|0]^128,t[A|0]=C;g=d+144|0;Ab(g,v[d+232>>2],b);We(g,0);break P}A=Ib(v[h>>2],b),C=128,t[A|0]=C;g=d+144|0;Ab(g,v[d+232>>2],b);We(g,1);break P}A=Ib(v[h>>2],b),C=128,t[A|0]=C;g=d+144|0;Ab(g,v[d+232>>2],b);We(g,0)}b=b+1|0;continue}break}break q}if(y[d+12>>2]<9){break O}b=0;v[23516]=0;Q(186,d+160|0,2)|0;e=v[23516];v[23516]=0;g=65535;if((e|0)==1){break N}while(1){T:{v[23516]=0;e=W(154,v[d+160>>2],v[d+168>>2],1)|0;f=v[23516];v[23516]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{if((f|0)!=1){if(!e){break T}v[23516]=0;f=T(204,d+160|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break q}e=0;switch(f|0){case 0:break T;case 14:break V;case 13:break W;case 12:break X;case 8:break Y;case 7:break Z;case 4:break _;case 1:break $;default:break O}}break q}e=Sb(v[a+484360>>2],w[j|0]);if(x[d+244>>1]==65535){A=d,C=ul(v[e>>2],v[e+4>>2]),u[A+244>>1]=C}e=ul(v[e>>2],v[e+4>>2]);v[23516]=0;u[d+246>>1]=e;e=Q(660,d+160|0,d+287|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break q}aa:{ba:{switch(e-254|0){case 1:e=65535;break aa;case 0:break ba;default:break aa}}e=65534}f=w[j|0];m=v[a+484360>>2];v[23516]=0;R(531,Sb(m,f)|0,e|0);e=v[23516];v[23516]=0;if((e|0)==1){break q}g=(g&65535)==65535?b:g;break U}v[23516]=0;e=T(192,d+160|0)|0;f=v[23516];v[23516]=0;ca:{da:{if((f|0)!=1){if(e>>>0>=(g&65535)>>>0){break da}e=x[d+248>>1];break ca}break q}e=e-g|0;u[d+248>>1]=e}Te(Sb(v[a+484360>>2],w[j|0]),e&65535);break U}v[23516]=0;e=T(204,d+160|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break q}t[d+251|0]=e;break U}v[23516]=0;e=T(204,d+160|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break q}t[d+250|0]=e;break U}v[23516]=0;f=Q(629,d+160|0,d+144|0)|0;m=v[23516];v[23516]=0;if((m|0)!=1){if(w[d+144|0]|!f|(w[d+146|0]|w[d+145|0]!=255)){break O}if(w[d+147|0]|w[d+148|0]!=1){break O}if(!w[d+149|0]){break U}break O}break q}v[23516]=0;R(543,d+152|0,d+160|0);e=v[23516];v[23516]=0;ea:{fa:{ga:{ha:{if((e|0)!=1){m=Kc(d+152|0);e=v[h>>2];z=ad(e,v[d+212>>2]);f=w[d+152|0];if(z>>>0<=f>>>0){break U}switch(w[Re(d+152|0)|0]){case 4:break fa;case 2:break ga;case 0:break ha;default:break ea}}break q}A=Ib(e,f),C=w[m|0]^128,t[A|0]=C;e=d+144|0;Ab(e,v[d+232>>2],w[d+152|0]);We(e,0);break ea}A=Ib(e,f),C=128,t[A|0]=C;e=d+144|0;Ab(e,v[d+232>>2],w[d+152|0]);We(e,1);break ea}A=Ib(e,f),C=128,t[A|0]=C;e=d+144|0;Ab(e,v[d+232>>2],w[d+152|0]);We(e,0)}ia:{if(s){break ia}s=0;e=v[k+4>>2];if(!cq(v[k>>2],e)){break U}f=e-56|0;e=w[d+152|0];if(w[Ib(v[f>>2],e)|0]!=w[Ib(v[h>>2],e)|0]){break ia}Ab(d+144|0,v[f+24>>2],e);e=zb(v[v[d+144>>2]>>2],v[d+148>>2]);Ab(d+136|0,v[d+232>>2],w[d+152|0]);if((zb(v[v[d+136>>2]>>2],v[d+140>>2])|0)==(e|0)){break U}}s=1;break U}v[23516]=0;R(263,d+144|0,d+160|0);e=v[23516];v[23516]=0;if((e|0)==1){break q}e=v[d+220>>2];m=ad(e,v[d+224>>2]);f=w[d+144|0];if(m>>>0<=f>>>0){break U}m=Kc(d+144|0);A=Ib(e,f),C=(w[m|0]>>>2|0)+1|0,t[A|0]=C}b=b+1|0;continue}break}e=1}yb(d+160|0);if(!e){break M}Em(d+184|0);continue}break}break q}b=1}Ud(d+192|0)}Ct(h)}yb(l);if(!b){Jf(d+264|0);continue}break}e=0;if((b|0)!=2){break w}}e=0;Dj(i,0);b=v[k>>2];if(nc(b,v[k+4>>2])){break w}if(!(c&2)){break x}v[23516]=0;U(655,d+160|0,o|0,1347244868);b=v[23516];v[23516]=0;if((b|0)!=1){A=d,C=Cb(v[d+160>>2]),v[A+8>>2]=C;e=a+480190|0;g=d+53|0;h=d+57|0;j=Cb(v[d+164>>2]);l=w[d+287|0];while(1){b=v[d+8>>2];if(!Nb(b,j)){Nc(d+160|0);b=v[k>>2];break x}ja:{ka:{la:{if(!l){v[23516]=0;f=Q(661,b|0,d+40|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break ja}if(!f){break ka}f=x[d+92>>1];i=f+1|0;u[d+144>>1]=i;if(f>>>0>3998){break la}A=a,C=x[ie(e,d+144|0)>>1],u[A+480190>>1]=C;v[23516]=0;R(662,d+40|0,(B(i&65535,104)+a|0)+484380|0);f=v[23516];v[23516]=0;if((f|0)==1){break ja}f=d+24|0;eR(f,g);v[23516]=0;R(221,d+192|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break y}f=d+192|0;Ac(((x[d+144>>1]<<5)+a|0)+946304|0,f);wb(f);break la}v[23516]=0;f=Q(663,b|0,d+40|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break y}if(!f){break ka}f=x[d+96>>1];i=f+1|0;u[d+144>>1]=i;if(f>>>0>3998){break la}A=a,C=x[ie(e,d+144|0)>>1],u[A+480190>>1]=C;v[23516]=0;R(664,d+40|0,(B(i&65535,104)+a|0)+484380|0);f=v[23516];v[23516]=0;if((f|0)==1){break y}f=d+24|0;eR(f,h);v[23516]=0;R(221,d+192|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break y}f=d+192|0;Ac(((x[d+144>>1]<<5)+a|0)+946304|0,f);wb(f)}f=x[d+144>>1];if((f-1&65535)>>>0>3998){break ka}i=Uc(d+40|0,8,1,0,2);v[23516]=0;W(218,i|0,(B(f,104)+a|0)+484380|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break ka}break y}Jf(d+8|0);continue}break}break y}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;Nc(d+160|0);break j}b=Qz(b,0);v[a+480196>>2]=w[b+43|0];v[a+480204>>2]=B(w[b+42|0],1e4);Te(Sb(v[a+484360>>2],w[a+484376|0]),x[b+40>>1]);b=0;while(1){if(x[a+480188>>1]>b>>>0){e=(b<<5)+a|0;g=e+480280|0;af(g);h=Qz(v[k>>2],0);A=e+480286|0,C=w[Ib(v[h+12>>2],b)|0],u[A>>1]=C;A=e+480284|0,C=w[Ib(v[h>>2],b)|0],u[A>>1]=C;Ab(d+40|0,v[h+24>>2],b);A=g,C=v[g>>2]&-257|(zb(v[v[d+40>>2]>>2],v[d+44>>2])?256:0),v[A>>2]=C;b=b+1|0;continue}break}v[23516]=0;b=Q(1,d+192|0,(w[d+287|0]?17228:17101)|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break r}Gb(a+1298344|0,b);xb(b);v[23516]=0;b=Q(1,d+24|0,10156)|0;e=v[23516];v[23516]=0;if((e|0)==1){break s}Gb(a+1298356|0,b);xb(b);v[a+1298404>>2]=5;e=1;if(!(c&1)|!x[a+480188>>1]){break w}v[23516]=0;U(655,d+8|0,o|0,1146045008);b=v[23516];v[23516]=0;if((b|0)==1){break t}b=v[d+12>>2];c=v[d+8>>2];v[23516]=0;l=a+484344|0;R(224,l|0,wf(c,b)&65535);b=v[23516];v[23516]=0;if((b|0)==1){break v}A=d,C=Cb(v[d+8>>2]),v[A+144>>2]=C;r=Cb(v[d+12>>2]);while(1){j=v[d+144>>2];if(!Nb(j,r)){ma:{na:{b=v[k>>2];e=v[k+4>>2];if(cq(b,e)>>>0<2){break na}j=a+484348|0;g=0;while(1){if(cq(b,e)>>>0<=g>>>0){break na}i=v[a+484344>>2];n=v[j>>2];h=wj(v[a+484360>>2],g&255);m=v[h>>2];c=Qz(b,g);f=x[c+36>>1];if(te(i,n,x[$b(m,f)>>1])){v[23516]=0;e=Q(367,h|0,f|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break ma}oa:{if(!s){break oa}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break oa}Ab(d+40|0,v[c+24>>2],b);f=zb(v[v[d+40>>2]>>2],v[d+44>>2]);h=Xb(v[l>>2],e);pa:{if(f){ve(h,Eh(no(Se(Le(d+40|0,20,145),0),b&65535)));break pa}ve(h,Eh(no(Se(Le(d+40|0,9,w[Ib(v[c>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;ve(Xb(v[l>>2],e),Eh(Se(Le(b,16,w[c+43|0]),0)));ve(Xb(v[l>>2],e),Eh(Se(Le(b,17,w[c+42|0]),0)));e=v[k+4>>2];b=v[k>>2]}g=g+1|0;continue}}Nc(d+8|0);e=1;break w}b=P()|0;O()|0;break u}b=v[j>>2];v[23516]=0;b=T(158,b|0)|0;c=v[23516];v[23516]=0;qa:{ra:{sa:{ta:{ua:{va:{wa:{if((c|0)==1){break wa}v[23516]=0;c=T(155,j|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break wa}if((b|0)!=(c|0)){break qa}b=v[j>>2];v[23516]=0;b=Q(665,b|0,8)|0;c=v[23516];v[23516]=0;if((c|0)==1){break wa}if(!b){break qa}v[23516]=0;i=Q(660,j|0,d+287|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break ra}v[23516]=0;p=T(192,j|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break sa}v[23516]=0;b=W(225,l|0,i|0,p|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break sa}if(!b){break qa}f=0;while(1){if((f|0)==(p|0)){break qa}b=Xb(v[l>>2],i);c=xf(v[b>>2],v[v[b+48>>2]+12>>2],f);v[23516]=0;b=T(192,j|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break va}xa:{if(b>>>0>=3){v[23516]=0;U(188,d+160|0,j|0,b-2|0);b=v[23516];v[23516]=0;if((b|0)==1){break ta}b=d+160|0;h=hc(d+40|0,b);yb(b);while(1){b=v[h>>2];v[23516]=0;b=W(154,b|0,v[d+48>>2],3)|0;e=v[23516];v[23516]=0;if((e|0)==1){break xa}if(b){v[23516]=0;R(263,d+160|0,h|0);b=v[23516];v[23516]=0;ya:{za:{Aa:{Ba:{if((b|0)!=1){u[d+136>>1]=x[a+480188>>1]-1;A=d,C=w[Kc(d+160|0)|0],u[A+264>>1]=C;e=x[Rc(d+136|0,d+264|0)>>1];g=c+B(e,6)|0;b=t[d+160|0];if((b|0)>=0){break ya}v[23516]=0;b=T(204,h|0)|0;n=v[23516];v[23516]=0;if((n|0)==1){break ua}if(w[d+287|0]){break Aa}if((b|0)!=255){break Ba}b=254;break za}break ua}if(b>>>0>128){break za}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break za}b=b>>>0<85?b+36|0:b}t[g|0]=b;b=w[d+160|0]}if(b&64){v[23516]=0;b=T(204,h|0)|0;n=v[23516];v[23516]=0;if((n|0)==1){break ua}t[g+1|0]=b+1;b=w[d+160|0]}if(b&32){v[23516]=0;b=T(204,h|0)|0;n=v[23516];v[23516]=0;if((n|0)==1){break ua}t[d+136|0]=b;t[g+2|0]=1;t[d+264|0]=127;A=g,C=w[Vb(d+136|0,d+264|0)|0]+1>>>1|0,t[A+4|0]=C;b=w[d+160|0]}if(!(b&16)){continue}v[23516]=0;R(263,d+136|0,h|0);b=v[23516];v[23516]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((b|0)!=1){b=w[Kc(d+136|0)|0];t[g+5|0]=b;switch(w[d+136|0]-1|0){case 72:break Da;case 71:break Ea;case 70:break Fa;case 61:break Ga;case 60:break Ha;case 53:break Ia;case 52:break Ja;case 51:break Ka;case 50:break Ma;case 43:break Na;case 42:break Oa;case 41:break Pa;case 40:break Qa;case 31:break Ra;case 30:break Sa;case 23:break Ta;case 22:break Ua;case 21:break Va;case 20:break Wa;case 18:break Xa;case 17:break Ya;case 15:break Za;case 16:break _a;case 14:break $a;case 13:break ab;case 12:break bb;case 11:break cb;case 10:break db;case 3:break eb;case 2:break fb;case 1:break gb;case 0:break hb;default:break Ca}}break ua}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b<<4|15;continue}t[g+5|0]=b<<3|15;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b<<4;continue}t[g+5|0]=b<<3&240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b|240;continue}t[g+5|0]=b>>>1|240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b&15;continue}if(b>>>0<=1){t[g+5|0]=b|240;continue}t[g+5|0]=b>>>1&15;continue}t[(c+B(e,6)|0)+3|0]=2;A=g,C=Bt(b,w[d+287|0])|240,t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=2;A=g,C=Bt(b,w[d+287|0]),t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=3;A=g,C=Bt(b,w[d+287|0])|240,t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=3;A=g,C=Bt(b,w[d+287|0]),t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=4;if(w[d+287|0]){continue}t[g+5|0]=(b&252)>>>2;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&1|16;continue}t[(c+B(e,6)|0)+3|0]=6;t[g+5|0]=b&240;continue}t[(c+B(e,6)|0)+3|0]=6;t[g+5|0]=(b&240)>>>4;continue}t[(c+B(e,6)|0)+3|0]=20;continue}t[(c+B(e,6)|0)+3|0]=5;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|48;continue}t[(c+B(e,6)|0)+3|0]=7;t[g+5|0]=b|240;continue}t[(c+B(e,6)|0)+3|0]=7;continue}t[(c+B(e,6)|0)+3|0]=8;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|64;continue}t[(c+B(e,6)|0)+3|0]=10;v[23516]=0;b=T(204,h|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break La}break ua}t[(c+B(e,6)|0)+3|0]=15;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|192;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|208;continue}t[(c+B(e,6)|0)+3|0]=12;b=(b&254)>>>1|0}t[g+5|0]=b;v[23516]=0;Q(186,h|0,1)|0;b=v[23516];v[23516]=0;if((b|0)!=1){continue}break ua}t[(c+B(e,6)|0)+3|0]=14;t[g+5|0]=0;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|176;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|224;continue}t[(c+B(e,6)|0)+3|0]=16;continue}t[(c+B(e,6)|0)+3|0]=17;continue}t[(c+B(e,6)|0)+3|0]=1;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|32;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|128;continue}t[(c+B(e,6)|0)+3|0]=0;continue}break}yb(h)}f=f+1|0;continue}break}break ua}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;yb(h);break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}Jf(d+144|0);continue}}Nc(d+272|0);cR(k);yb(d+304|0);break b}b=P()|0;O()|0}Nc(d+8|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;yb(d+160|0);break m}b=P()|0;O()|0;break l}b=P()|0;O()|0;xb(d+160|0);break l}b=P()|0;O()|0;break l}Ud(d+192|0)}Ct(h)}yb(l)}Nc(d+272|0);break h}b=P()|0;O()|0}cR(k);break f}b=P()|0;O()|0}yb(d+304|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}Ud(o);yb(q);S(b|0);L()}Ud(o);yb(q)}hb=d+384|0;return e|0}function pha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=hb-480|0;hb=d;xc(b);h=d+472|0;e=Au(b,h);if(!e){ES(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!e){break k}if(!FS(d+472|0)){break k}if(!c){D=1;break k}H=he(d+448|0,b);v[23516]=0;R(502,d+432|0,H|0);b=v[23516];v[23516]=0;l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((b|0)!=1){v[23516]=0;U(503,d+408|0,d+432|0,20041);b=v[23516];v[23516]=0;if((b|0)==1){break u}v[23516]=0;e=T(176,v[d+408>>2])|0;b=v[23516];v[23516]=0;if((b|0)==1){break m}if(!e){break l}v[23516]=0;e=Q(504,d+408|0,d+312|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break m}if(!e){break l}v[23516]=0;R(248,a|0,16384);b=v[23516];v[23516]=0;if((b|0)==1){break m}v[a+480208>>2]=8;v[23516]=0;e=W(267,a+1074312|0,9,1)|0;b=v[23516];v[23516]=0;if((b|0)==1){break m}v[23516]=0;e=W(267,e|0,114,1)|0;b=v[23516];v[23516]=0;if((b|0)==1){break m}v[23516]=0;e=Q(268,e|0,21)|0;b=v[23516];v[23516]=0;if((b|0)==1){break m}v[23516]=0;Q(268,e|0,30)|0;b=v[23516];v[23516]=0;if((b|0)==1){break m}v[23516]=0;e=Q(1,d+296|0,8309)|0;b=v[23516];v[23516]=0;if((b|0)==1){break r}Gb(a+1298344|0,e);xb(e);v[23516]=0;e=Q(1,d+280|0,10741)|0;b=v[23516];v[23516]=0;if((b|0)==1){break q}Gb(a+1298356|0,e);xb(e);v[23516]=0;g=Q(1,d+264|0,17598)|0;b=v[23516];v[23516]=0;if((b|0)==1){break p}e=15154;b=w[d+476|0];switch(b-16|0){case 1:break n;case 0:break t;default:break s}}f=P()|0;O()|0;break a}f=P()|0;O()|0;break b}e=15135;break n}if(!b){break o}e=21751;break n}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}e=13299}v[23516]=0;h=Q(1,d+248|0,e|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break e}v[23516]=0;U(2,d+208|0,g|0,h|0);b=v[23516];v[23516]=0;if((b|0)==1){break f}e=d+208|0;Gb(a+1298368|0,e);xb(e);xb(h);xb(g);v[a+1298404>>2]=5;b=d+96|0;Ke(b,3,d+312|0);v[23516]=0;R(221,e|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break g}b=d+208|0;yc(a+1298308|0,b);wb(b);b=d+232|0;Aj(b,3,d+344|0);v[23516]=0;R(221,d+96|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break h}v[23516]=0;U(11,d+208|0,5,d+96|0);b=v[23516];v[23516]=0;if((b|0)==1){break i}b=d+208|0;Gb(a+1298320|0,b);xb(b);wb(d+96|0);v[a+480200>>2]=w[d+368|0]+1;I=a,J=Bd(w[d+369|0],1,255),v[I+480196>>2]=J;I=a,J=B(Bd(w[d+370|0],4,255),1e4),v[I+480204>>2]=J;h=v[a+484360>>2];e=a+484376|0;b=w[e|0];v[23516]=0;da(347,Sb(h,b)|0,d+408|0,x[d+364>>1],65535,65535);b=v[23516];v[23516]=0;if((b|0)==1){break m}Te(Sb(v[a+484360>>2],w[e|0]),x[d+366>>1]);u[a+480188>>1]=0;b=0;while(1){if((b|0)==32){v[23516]=0;U(503,d+208|0,d+432|0,17741);b=v[23516];v[23516]=0;if((b|0)!=1){b=d+208|0;h=cd(d+408|0,b);yb(b);b=v[h>>2];v[23516]=0;e=T(158,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break m}v[23516]=0;X(336,a+1298332|0,h|0,e|0,0);b=v[23516];v[23516]=0;if((b|0)==1){break m}v[23516]=0;U(503,d+208|0,d+432|0,21321);b=v[23516];v[23516]=0;if((b|0)!=1){b=d+208|0;j=cd(h,b);yb(b);b=v[j>>2];v[23516]=0;e=T(176,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break m}v:{w:{if(e){v[23516]=0;U(503,d+208|0,d+432|0,16723);b=v[23516];v[23516]=0;if((b|0)==1){break v}v[23516]=0;g=T(204,j|0)|0;b=v[23516];v[23516]=0;x:{if((b|0)!=1){h=c&2;i=a+480190|0;while(1){if(g>>>0<=(n&255)>>>0){break x}v[23516]=0;p=T(204,j|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break w}if(!p){break x}e=v[j+8>>2];b=v[j>>2];v[23516]=0;e=W(154,b|0,e|0,56)|0;b=v[23516];v[23516]=0;if((b|0)==1){break w}if(!e){break x}if(p>>>0>x[i>>1]){u[i>>1]=p}v[23516]=0;o=B(p,104)+a|0;s=o+484380|0;R(280,s|0,0);b=v[23516];v[23516]=0;if((b|0)==1){break w}lo(s);v[23516]=0;U(317,j|0,((p<<5)+a|0)+946304|0,32);b=v[23516];v[23516]=0;if((b|0)==1){break w}v[23516]=0;R(320,j|0,o+484423|0);b=v[23516];v[23516]=0;if((b|0)==1){break w}y:{if(w[d+476|0]<=15){v[23516]=0;f=T(192,j|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break y}break w}v[23516]=0;f=T(155,j|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break w}}v[o+484404>>2]=f<<1;v[23516]=0;e=T(155,j|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break w}v[s>>2]=e;v[23516]=0;e=T(155,j|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break w}D=o+484384|0;v[D>>2]=e;v[23516]=0;e=T(155,j|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break w}F=o+484388|0;v[F>>2]=e;if(e){b=o+484414|0;u[b>>1]=x[b>>1]|2;v[F>>2]=e+v[D>>2]}v[23516]=0;e=T(204,j|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break w}if(w[d+476|0]<=15){u[o+484410>>1]=e}v[23516]=0;p=T(204,j|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break w}b=o+484414|0;e=x[b>>1];k=8;if(p&1){e=e|1;u[b>>1]=e;v[s>>2]=v[s>>2]>>>1;v[D>>2]=v[D>>2]>>>1;v[F>>2]=v[F>>2]>>>1;k=16}u[b>>1]=e&65531|p<<1&4;b=Uc(d+96|0,k,1,0,((p&12)!=0)<<3);z:{if(!h){break z}v[23516]=0;W(218,b|0,s|0,d+208|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break z}break w}n=n+1|0;continue}}break w}yb(d+208|0)}v[23516]=0;U(503,d+208|0,d+432|0,18761);b=v[23516];v[23516]=0;A:{if((b|0)!=1){b=d+208|0;m=cd(j,b);yb(b);b=v[m>>2];v[23516]=0;e=T(176,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break m}if(!e){break A}y=Lb(d+96|0);q=Lb(d+232|0);z=Lb(d+192|0);v[23516]=0;U(503,d+168|0,d+432|0,17750);b=v[23516];v[23516]=0;B:{if((b|0)==1){break B}b=v[d+180>>2];e=d- -64|0;v[e>>2]=v[d+176>>2];v[e+4>>2]=b;v[d+72>>2]=v[d+184>>2];v[23516]=0;b=v[d+172>>2];v[d+56>>2]=v[d+168>>2];v[d+60>>2]=b;R(505,d+56|0,y|0);b=v[23516];v[23516]=0;if((b|0)==1){break B}v[23516]=0;U(503,d+144|0,d+432|0,17744);b=v[23516];v[23516]=0;if((b|0)==1){break B}b=v[d+156>>2];v[d+40>>2]=v[d+152>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+160>>2];v[23516]=0;b=v[d+148>>2];v[d+32>>2]=v[d+144>>2];v[d+36>>2]=b;R(505,d+32|0,q|0);b=v[23516];v[23516]=0;if((b|0)==1){break B}v[23516]=0;U(503,d+120|0,d+432|0,17734);b=v[23516];v[23516]=0;if((b|0)==1){break B}b=v[d+132>>2];v[d+16>>2]=v[d+128>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+136>>2];v[23516]=0;b=v[d+124>>2];v[d+8>>2]=v[d+120>>2];v[d+12>>2]=b;R(505,d+8|0,z|0);b=v[23516];v[23516]=0;if((b|0)==1){break B}v[23516]=0;o=T(204,m|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break B}j=d+208|1;s=a+480190|0;k=0;while(1){if(o>>>0<=(k&255)>>>0){ao(z);ao(q);ao(y);break A}v[23516]=0;R(263,d+80|0,m|0);b=v[23516];v[23516]=0;C:{if((b|0)!=1){G=Kc(d+80|0);D:{E:{if(!w[d+80|0]){break E}h=v[m+8>>2];e=v[m>>2];b=w[G|0];v[23516]=0;e=W(154,e|0,h|0,B(b,14)+32|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break B}if(!e){break E}v[23516]=0;f=W(253,a|0,w[d+80|0],0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break B}if(f){break D}}b=w[G|0];v[23516]=0;Q(186,m|0,B(b,14)+32|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break C}break B}v[23516]=0;U(317,m|0,f+492|0,32);b=v[23516];v[23516]=0;if((b|0)==1){break B}D=f+88|0;F=f+68|0;p=f+48|0;i=f+236|0;b=0;n=0;while(1){if(w[G|0]<=(n&255)>>>0){break C}v[23516]=0;R(506,m|0,d+208|0);e=v[23516];v[23516]=0;if((e|0)==1){break B}e=w[d+208|0];F:{if(!e|e>>>0>x[s>>1]){break F}if(w[j|0]>=129){t[j|0]=128}while(1){e=b&255;g=w[d+209|0];if(e>>>0>g>>>0){e=v[y+4>>2];b=v[y>>2];v[23516]=0;X(507,p|0,w[d+211|0],b|0,e|0);b=v[23516];v[23516]=0;if((b|0)==1){break B}e=v[q+4>>2];b=v[q>>2];v[23516]=0;X(507,F|0,w[d+213|0],b|0,e|0);b=v[23516];v[23516]=0;if((b|0)==1){break B}e=v[z+4>>2];b=v[z>>2];v[23516]=0;X(507,D|0,w[d+221|0],b|0,e|0);b=v[23516];v[23516]=0;if((b|0)==1){break B}v[f>>2]=x[d+214>>1]+1>>>1;e=w[d+208|0];G:{if(w[d+211|0]&64){u[(B(e,104)+a|0)+484410>>1]=w[d+210|0];break G}b=(B(e,104)+a|0)+484414|0;u[b>>1]=x[b>>1]|32768}u[d+118>>1]=w[d+212|0]<<1;u[d+116>>1]=254;r=B(e,104)+a|0;I=r+484408|0,J=x[Rc(d+118|0,d+116|0)>>1],u[I>>1]=J;t[r+484418|0]=w[(w[d+219|0]&3)+26836|0];e=r+484419|0;A=w[d+218|0];t[e|0]=A;h=w[d+217|0]+3>>>2|0;t[r+484420|0]=h;t[r+484421|0]=w[d+216|0];b=g+1|0;if(A){h=Bl(Bc(((h<<8|A>>>1)>>>0)/(A>>>0)|0,0))}else{h=255}t[e|0]=h;if(!(w[d+213|0]&64)){break F}e=r+484414|0;u[e>>1]=x[e>>1]|32}else{I=$b(i,e),J=w[d+208|0],u[I>>1]=J;b=b+1|0;continue}break}}n=n+1|0;continue}}break B}k=k+1|0;continue}}f=P()|0;O()|0;ao(z);ao(q);ao(y);break c}f=P()|0;O()|0;break c}D=1;y=Lb(d+232|0);H:{if(!(c&1)){break H}v[23516]=0;U(503,d+208|0,d+432|0,21076);b=v[23516];v[23516]=0;I:{J:{K:{L:{M:{N:{if((b|0)!=1){g=cd(m,d+208|0);b=v[g>>2];v[23516]=0;c=T(176,b|0)|0;b=v[23516];v[23516]=0;O:{P:{Q:{if((b|0)!=1){yb(d+208|0);if(!c){break O}v[23516]=0;e=T(192,g|0)|0;c=v[23516];v[23516]=0;b=1;if((c|0)==1){break Q}v[23516]=0;h=e+1|0;R(508,y|0,h|0);c=v[23516];v[23516]=0;if((c|0)==1){break Q}while(1){if((b|0)==(h|0)){break O}v[23516]=0;e=T(192,g|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break P}v[23516]=0;U(188,d+96|0,g|0,e|0);c=v[23516];v[23516]=0;if((c|0)==1){break P}c=d+96|0;e=hc(d+208|0,c);cd(Kg(v[y>>2],b),e);yb(e);b=b+1|0;yb(c);continue}}f=P()|0;O()|0;yb(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}v[23516]=0;U(503,d+208|0,d+432|0,16720);b=v[23516];v[23516]=0;if((b|0)==1){break K}E=cd(g,d+208|0);b=v[E>>2];v[23516]=0;c=T(176,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break L}yb(d+208|0);if(!c){break N}v[23516]=0;j=T(204,E|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break J}k=0;R:{S:{T:while(1){U:{if(j>>>0<=(k&65535)>>>0){v[23516]=0;Q(153,E|0,1)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break U}break J}n=32;V:{if(w[d+476|0]<16){break V}v[23516]=0;R(509,E|0,d+208|0);b=v[23516];v[23516]=0;if((b|0)==1){break R}n=w[d+208|0];if(n>>>0<=x[a+480188>>1]|n>>>0>32){break V}u[a+480188>>1]=n}b=0;while(1){h=b&65535;if(h>>>0>=n>>>0){k=k+1|0;continue T}v[23516]=0;e=T(192,E|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break S}if(!(!e|h>>>0>31|h>>>0<x[a+480188>>1])){u[a+480188>>1]=b+1}b=b+1|0;continue}}break}v[23516]=0;r=a+484344|0;R(224,r|0,j|0);b=v[23516];v[23516]=0;if((b|0)==1){break J}F=d+208|2;m=0;while(1){if((j|0)==(m|0)){break N}G=Kb(d+96|0);W:{if(w[d+476|0]<16){o=32;h=64;break W}v[23516]=0;R(509,E|0,d+208|0);b=v[23516];v[23516]=0;if((b|0)==1){break M}c=w[d+209|0];o=w[d+208|0];b=d+80|0;lf(b,F,16,3);v[23516]=0;R(221,d+192|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break M}b=d+192|0;yc(G,b);wb(b);h=c+1|0}v[23516]=0;c=W(225,r|0,m&65535,h|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break M}X:{if(!c){v[23516]=0;Q(186,E|0,o<<1)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break X}break M}b=v[r>>2];v[23516]=0;R(284,Xb(b,m)|0,G|0);b=v[23516];v[23516]=0;if((b|0)==1){break M}p=h-1|0;s=0;while(1){A=s&65535;if(A>>>0>=o>>>0){break X}v[23516]=0;c=T(192,E|0)|0;b=v[23516];v[23516]=0;Y:{if((b|0)!=1){if(!c){break Y}b=v[y>>2];if(wf(b,v[y+4>>2])>>>0<=c>>>0|A>>>0>=x[a+480188>>1]){break Y}C=Kg(b,c);xc(C);c=0;Z:while(1){e=c;if(h>>>0<=e>>>0){break Y}c=v[C+8>>2];b=v[C>>2];v[23516]=0;c=W(154,b|0,c|0,1)|0;b=v[23516];v[23516]=0;_:{$:{aa:{ba:{ca:{if((b|0)!=1){if(!c){break Y}b=Xb(v[r>>2],m);b=ed(v[b>>2],v[v[b+48>>2]+12>>2],e,A);v[23516]=0;g=T(204,C|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break M}f=g>>>2|0;switch((g&3)-1|0){case 2:break $;case 1:break aa;case 0:break ba;default:break ca}}break M}c=(e+f|0)+1|0;continue}c=0;if(!e){continue}c=Xb(v[r>>2],m);i=ed(v[c>>2],v[v[c+48>>2]+12>>2],e-1|0,A);while(1){c=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[i+4|0]|w[i+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;c=e+1|0;if((e|0)==(p|0)){continue Z}b=B(x[a+480188>>1],6)+b|0;g=f&255;e=c;f=f-1|0;if(g){continue}break}continue}if(e>>>0<=f>>>0){break _}c=Xb(v[r>>2],m);g=ed(v[c>>2],v[v[c+48>>2]+12>>2],f,A);c=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;break _}if(f&1){v[23516]=0;g=T(204,C|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break M}t[b|0]=g>>>0>120?-1:g}if(f&2){v[23516]=0;g=T(204,C|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break M}t[b+1|0]=g}n=0;c=0;da:{if(f&4){v[23516]=0;c=T(204,C|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break da}}k=0;if(f&8){v[23516]=0;i=T(204,C|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break da}k=i>>>4|0;n=i&15}q=0;i=0;if(f&16){v[23516]=0;i=T(204,C|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break da}}if(f&32){v[23516]=0;q=T(204,C|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break da}}l=hb-32|0;hb=l;g=l+24|0;CS(g,n,i);z=Kc(g);g=l+16|0;CS(g,((k-1&255)>>>0<6?k+15|0:k)&255,q);f=Kc(g);ea:{fa:{ga:{if(w[l+24|0]==10){i=w[f|0];g=w[z|0]&15;t[z|0]=g?-1:i;k=i|g<<8;q=w[l+16|0];if((q|0)!=10){break ga}q=0;t[l+16|0]=0;break ga}if(w[l+16|0]!=10){break fa}g=w[f|0]&15;t[f|0]=g?-1:0;k=g<<8;q=w[l+24|0]}if(k-256>>>0>4294967038){break fa}if(Hi(q)>>>0>=Hi(10)>>>0){break fa}t[b+5|0]=k;t[b+2|0]=15;t[b+3|0]=10;t[b+4|0]=k>>>8;break ea}if(c){t[b+2|0]=1;t[b+4|0]=c+2>>>2}Hu(l+24|0,z,l+16|0,f);i=w[l+24|0];ha:{if(!i){break ha}g=w[l+16|0];if(!g){t[l+16|0]=i;t[f|0]=w[z|0];t[l+24|0]=0;break ha}if(!((i|0)==20|(g|0)!=(i|0))){t[l+24|0]=0;break ha}if(!c){to(l+8|0,b,i,w[z|0],g,w[f|0]);break ea}if(Hi(i)>>>0<=Hi(g)>>>0){break ha}Bh(l+24|0,l+16|0);Bh(z,f)}c=w[l+16|0];t[b+5|0]=w[f|0];t[b+3|0]=c}hb=l+32|0;break _}break M}c=e+1|0;continue}}break M}s=s+1|0;continue}}wb(G);m=m+1|0;continue}}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}v[23516]=0;U(503,d+208|0,d+432|0,20048);b=v[23516];v[23516]=0;ia:{ja:{if((b|0)!=1){h=cd(E,d+208|0);b=v[h>>2];v[23516]=0;c=T(176,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break ja}yb(d+208|0);if(!c){break H}e=a+484348|0;while(1){if(!vf(v[a+484344>>2],v[e>>2])){break H}c=v[h+8>>2];b=v[h>>2];v[23516]=0;c=W(154,b|0,c|0,16)|0;b=v[23516];v[23516]=0;if((b|0)==1){break ia}if(!c){break H}v[23516]=0;R(393,h|0,d+208|0);b=v[23516];v[23516]=0;if((b|0)!=1){b=v[a+484344>>2];v[23516]=0;R(394,Xb(b,0)|0,d+208|0);b=v[23516];v[23516]=0;if((b|0)!=1){continue}}break}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;yb(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;wb(G);break I}f=P()|0;O()|0;yb(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0}Nc(y);break c}Nc(y);break l}f=P()|0;O()|0;yb(d+208|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}i=(b<<5)+a|0;g=i+480280|0;af(g);h=t[(b+d|0)+371|0];e=h<<1&254;u[i+480284>>1]=(e|0)==254?256:e;ka:{if((h|0)<0){v[g>>2]=v[g>>2]|1024;break ka}u[a+480188>>1]=b+1}v[23516]=0;R(510,d+408|0,i+480289|0);e=v[23516];v[23516]=0;if((e|0)==1){break j}b=b+1|0;continue}}f=P()|0;O()|0;break c}yb(d+408|0);Ud(d+432|0);yb(H)}hb=d+480|0;return D|0}f=P()|0;O()|0;break c}f=P()|0;O()|0;wb(d+96|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;xb(h);break d}f=P()|0;O()|0}xb(g)}yb(d+408|0)}Ud(d+432|0)}yb(H);S(f|0);L()}function uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=hb-240|0;hb=d;xc(b);e=hb-16|0;hb=e;h=d+216|0;iu(e+8|0,h);g=v[e+12>>2];jc(e,v[b>>2],v[b+8>>2],v[e+8>>2],g);j=v[e+4>>2];if((j|0)==(g|0)){Yb(b,v[e+12>>2])}hb=e+16|0;e=(g|0)==(j|0);if(!e){mU(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!nU(d+216|0)){break n}if(!c){f=1;break n}zd(a,1024);$f(a);v[a+480208>>2]=v[a+480208>>2]|12;Lf(a+1074312|0,21);e=Eb(x[d+232>>1]);if(e){v[a+480204>>2]=B(e,1e4)}e=Eb(x[d+230>>1]);if(e){v[a+480196>>2]=e}if(!w[d+226|0]){jh(a,1)}xu(b,a+1298308|0,_b(v[d+220>>2])-14|0);b=he(d+112|0,b);v[23516]=0;R(345,d+200|0,b|0);e=v[23516];v[23516]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((e|0)!=1){yb(b);v[23516]=0;U(346,d+112|0,d+200|0,1395544366);b=v[23516];v[23516]=0;if((b|0)==1){break s}v[23516]=0;b=T(278,v[d+112>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break y}if(!b){break r}v[23516]=0;b=T(274,d+112|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break y}v[23516]=0;e=T(274,d+112|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break y}v[23516]=0;Q(186,d+112|0,4)|0;f=v[23516];v[23516]=0;if((f|0)==1){break y}f=a+484376|0;g=w[f|0];h=v[a+484360>>2];v[23516]=0;da(347,Sb(h,g)|0,d+112|0,b|0,65535,65535);b=v[23516];v[23516]=0;if((b|0)==1){break y}Te(Sb(v[a+484360>>2],w[f|0]),e);b=d+112|0;yb(b);v[23516]=0;U(346,b|0,d+200|0,1346458708);b=v[23516];v[23516]=0;if((b|0)==1){break x}v[23516]=0;e=T(278,v[d+112>>2])|0;b=v[23516];v[23516]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}v[23516]=0;e=T(274,d+112|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break w}u[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}v[23516]=0;b=T(274,d+112|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break w}v[23516]=0;R(224,a+484344|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break w}b=0;v[23516]=0;o=T(282,d+112|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break w}switch(o-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}e=P()|0;O()|0;yb(b);break a}e=P()|0;O()|0;yb(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;yb(d+112|0);break b}if(o){break t}}b=1}yb(d+112|0);if(!b){break o}v[23516]=0;U(346,d+176|0,d+200|0,1398157625);b=v[23516];v[23516]=0;if((b|0)==1){break d}v[23516]=0;b=T(278,v[d+176>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}if(!b){break q}v[23516]=0;Q(186,d+176|0,2)|0;b=v[23516];v[23516]=0;if((b|0)==1){break c}v[23516]=0;b=T(282,d+176|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}G=a,H=Oe((+(b>>>0)*2.3283064365386963e-10+ +(y[a+480204>>2]/1e4>>>0))*1e4),v[G+480204>>2]=H;b=0;v[23516]=0;Q(348,d+176|0,d+112|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}f=x[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){G=d,H=Eb(x[(d+112|0)+(b<<1)>>1]),v[G+48>>2]=H;v[d+32>>2]=180;e=v[od(d+48|0,d+32|0)>>2]-90|0;g=e>>31;G=((b<<5)+a|0)+480284|0,H=Dc(ska(e<<7|45,g<<7|e>>>25,90,0),kb)+128|0,u[G>>1]=H;b=b+1|0;continue}else{z:{v[23516]=0;Q(186,d+176|0,16)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break z}break c}}break}v[23516]=0;b=W(154,v[d+176>>2],v[d+184>>2],2)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}A:{if(b){v[23516]=0;b=T(274,d+176|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break A}u[d+48>>1]=b;u[d+32>>1]=256;G=a,H=x[Rc(d+48|0,d+32|0)>>1],v[G+480200>>2]=H}v[23516]=0;Q(186,d+176|0,128)|0;b=v[23516];v[23516]=0;if((b|0)==1){break c}v[23516]=0;b=Q(348,d+176|0,d+48|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){if(!b){break q}e=x[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){G=d,H=Eb(x[(d+48|0)+(b<<1)>>1]),v[G+32>>2]=H;v[d+16>>2]=128;G=((b<<5)+a|0)+480286|0,H=v[od(d+32|0,d+16|0)>>2]/2&255,u[G>>1]=H;b=b+1|0;continue}else{v[a+480228>>2]=v[a+480228>>2]<<1;break q}}break c}break c}e=P()|0;O()|0;break b}yb(d+112|0);break p}yb(d+176|0);v[23516]=0;U(346,d+112|0,d+200|0,1413830740);b=v[23516];v[23516]=0;B:{C:{if((b|0)!=1){v[23516]=0;b=T(278,v[d+112>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break e}if(!b){break B}v[23516]=0;R(349,d+112|0,d+48|0);b=v[23516];v[23516]=0;if((b|0)==1){break e}if((Eb(x[d+58>>1])|0)!=65535){break C}v[23516]=0;Q(186,d+112|0,1)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break C}break e}e=P()|0;O()|0;break b}v[23516]=0;b=T(200,d+112|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break e}v[23516]=0;X(336,a+1298332|0,d+112|0,b|0,2);b=v[23516];v[23516]=0;if((b|0)==1){break e}}yb(d+112|0);v[23516]=0;U(346,d+48|0,d+200|0,1229869908);b=v[23516];v[23516]=0;if((b|0)==1){break h}v[23516]=0;b=T(278,v[d+48>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break l}if(b){D:{v[23516]=0;b=T(274,d+48|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break i}E:{F:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break F}v[23516]=0;e=W(154,v[d+48>>2],v[d+56>>2],B(f,(b>>>14&2)+50|0)|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break g}if(!e){break F}u[a+480190>>1]=f;g=a+480190|0;h=d+130|0;j=(b|0)>=0;b=1;G:{H:{I:{J:{while(1){if(f>>>0<(b&65535)>>>0){v[23516]=0;b=T(274,d+48|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break G}break g}K:{if(j){p=b}else{v[23516]=0;e=T(274,d+48|0)|0;m=v[23516];v[23516]=0;if((m|0)==1){break K}p=e+1|0}u[d+16>>1]=p;v[23516]=0;R(350,d+48|0,d+112|0);e=v[23516];v[23516]=0;if((e|0)==1){break J}e=x[d+16>>1];if((e-4e3&65535)>>>0>=61537){G=a,H=x[ie(g,d+16|0)>>1],u[G+480190>>1]=H;m=x[d+234>>1]|x[d+236>>1]<<16;v[23516]=0;X(351,d+112|0,(B(e,104)+a|0)+484380|0,_b(m)|0,o|0);e=v[23516];v[23516]=0;if((e|0)==1){break I}e=d+32|0;xl(e,2,h);v[23516]=0;R(221,d+176|0,e|0);e=v[23516];v[23516]=0;if((e|0)==1){break H}e=d+176|0;Ac(((x[d+16>>1]<<5)+a|0)+946304|0,e);wb(e)}b=b+1|0;continue}break}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}if((b|0)!=4){break E}u[d+112>>1]=x[a+480190>>1];u[d+176>>1]=255;h=a+480192|0;b=d+176|0;G=h,H=x[Rc(d+112|0,b)>>1],u[G>>1]=H;v[23516]=0;U(346,b|0,d+200|0,1229278806);b=v[23516];v[23516]=0;if((b|0)==1){break j}L:{M:while(1){v[23516]=0;b=W(154,v[d+48>>2],v[d+56>>2],15)|0;e=v[23516];v[23516]=0;if((e|0)==1){break L}if(b){v[23516]=0;R(352,d+48|0,d+32|0);b=v[23516];v[23516]=0;if((b|0)==1){break k}b=Eb(x[d+32>>1]);if(b>>>0>=x[h>>1]){continue}e=B(b,104)+a|0;t[e+484524|0]=w[d+40|0];f=w[d+39|0];t[e+484523|0]=255;t[e+484525|0]=f;v[23516]=0;b=b+1&65535;e=W(253,a|0,b|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break k}if(!e){continue}G=d,H=Eb(w[d+37|0]|w[d+38|0]<<8),u[G+112>>1]=H;u[d+16>>1]=4095;G=e,H=x[Rc(d+112|0,d+16|0)>>1],v[G>>2]=H;b=w[d+35|0];if((b|0)==255){continue}v[23516]=0;b=Q(153,d+176|0,B(b,34)+2|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break k}if(!b){continue}v[23516]=0;R(353,d+176|0,d+112|0);b=v[23516];v[23516]=0;if((b|0)==1){break k}t[e+60|0]=w[e+60|0]|1;b=x[d+112>>1];v[d+20>>2]=16;v[d+24>>2]=240;G=d,H=Eb(b),v[G+16>>2]=H;b=zB(d+16|0);v[23516]=0;R(294,e+48|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break k}g=v[e+52>>2];f=v[e+48>>2];b=0;while(1){j=Qd(f,g);if(j>>>0<=b>>>0){b=w[d+36|0];if((b|0)!=255){t[e- -64|0]=b;t[e+63|0]=b;t[e+60|0]=w[e+60|0]|4}if(nc(f,g)){continue M}b=j-1|0;t[e+62|0]=b;t[e+61|0]=b;t[e+60|0]=w[e+60|0]|2;continue M}else{t[d+16|0]=64;j=(d+112|0)+(b<<1)|0;t[d+12|0]=w[j+2|0];m=Vb(d+16|0,d+12|0);i=Bb(f,b);t[i+2|0]=w[m|0];u[i>>1]=w[j+3|0];b=b+1|0;continue}}}break}yb(d+176|0);break D}break k}yb(d+48|0);break p}}}yb(d+48|0);v[23516]=0;U(354,d+176|0,d+200|0,1145131092);b=v[23516];v[23516]=0;if((b|0)==1){break m}G=d,H=Cb(v[d+176>>2]),v[G+16>>2]=H;m=a+484344|0;A=c&1;q=d+48|4;C=Cb(v[d+180>>2]);r=(o|0)!=841887798;s=a+480188|0;D=(o|0)!=841887796;while(1){N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{g=v[d+16>>2];if(!Nb(g,C)){Nc(d+176|0);v[23516]=0;U(346,d+112|0,d+200|0,1346458702);b=v[23516];v[23516]=0;if((b|0)!=1){break _}e=P()|0;O()|0;break b}v[23516]=0;Q(186,g|0,4)|0;b=v[23516];v[23516]=0;if((b|0)!=1){v[23516]=0;i=T(274,g|0)|0;b=v[23516];v[23516]=0;$:{if((b|0)!=1){v[23516]=0;j=T(274,g|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break P}j=r?j:(j>>>0)/y[a+480196>>2]|0;if(!A|i>>>0>255){break N}v[23516]=0;b=W(225,m|0,i|0,j|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break P}if(b){break $}break N}e=P()|0;O()|0;break O}if(!r){h=0;v[23516]=0;Q(186,g|0,4)|0;b=v[23516];v[23516]=0;if((b|0)==1){break P}while(1){z=h&65535;if(z>>>0>=x[s>>1]){break N}v[23516]=0;b=T(274,g|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break Z}v[23516]=0;U(188,d+48|0,g|0,b+(b&1)&65535);b=v[23516];v[23516]=0;if((b|0)==1){break Q}b=d+48|0;f=hc(d+112|0,b);yb(b);v[d+48>>2]=0;v[d+52>>2]=0;e=0;aa:{while(1){b=v[f>>2];v[23516]=0;b=W(154,b|0,v[d+120>>2],6)|0;k=v[23516];v[23516]=0;if((k|0)==1){break aa}k=v[d+48>>2];if(b&k>>>0<j>>>0){b=Xb(v[m>>2],i);b=ed(v[b>>2],v[v[b+48>>2]+12>>2],k,z);v[23516]=0;R(355,d+32|0,f|0);k=v[23516];v[23516]=0;ba:{ca:{if((k|0)!=1){k=d+32|0;l=Kc(k);E=Re(k);F=Ji(k);p=gc(k);n=t[d+32|0];if((n-1&255)>>>0>95){break ca}t[b|0]=n+13;if(!v[d+52>>2]){break ba}t[b+3|0]=19;v[d+12>>2]=15;G=b,H=w[od(q,d+12|0)|0]|208,t[G+5|0]=H;break ba}break R}if((n|0)>=0){break ba}if(v[d+52>>2]){t[b+3|0]=19;v[d+12>>2]=15;G=b,H=w[od(q,d+12|0)|0]|192,t[G+5|0]=H;break ba}t[b|0]=254}if(w[l|0]){t[b+2|0]=1;t[d+12|0]=64;G=b,H=w[Vb(l,d+12|0)|0],t[G+4|0]=H}l=w[E|0];if(l){t[b+1|0]=l}l=w[F|0];n=w[p|0];if(l|n){Nf(b,l,n)}l=d+48|0;b=w[k+5|0];if(b&128){v[23516]=0;k=T(204,f|0)|0;n=v[23516];v[23516]=0;if((n|0)==1){break R}b=k|b<<8&32512}e=b+e|0;pB(l,e,v[a+480196>>2]);continue}break}yb(f);h=h+1|0;continue}break}break R}h=0;b=Xb(v[m>>2],i);b=ed(v[b>>2],v[v[b+48>>2]+12>>2],0,0);da:while(1){f=0;if((h|0)==(j|0)){break N}while(1){if(x[s>>1]<=(f&65535)>>>0){h=h+1|0;continue da}v[23516]=0;R(356,d+48|0,g|0);e=v[23516];v[23516]=0;if((e|0)!=1){t[d+12|0]=0;ea:{if(!D){e=v[d+48>>2];v[d+112>>2]=e;i=d+112|0;k=Kc(i);l=Re(i);n=Ji(i);if(e<<24>>24>0){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}e=w[k|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[k|0]}t[b+1|0]=e<<4&48|w[l|0]>>>4;i=w[l|0]&15;t[d+12|0]=i;e=w[n|0];t[b+5|0]=e;break ea}e=v[d+48>>2];v[d+8>>2]=e;v[d+4>>2]=e;e=d+32|0;gu(e,d+4|0,b);i=d+112|0;hB(i,d+12|0,b+5|0);gB(i,e);G=b,H=w[b+1|0]|w[Ib(d+48|0,0)|0]&48,t[G+1|0]=H;e=w[b+5|0];i=w[d+12|0]}Nf(b,i,e&255);e=w[b+3|0];fa:{if(e>>>0>11){break fa}e=1<<e;ga:{if(!(e&2240)){if(!(e&12)){break fa}if(!w[b+5|0]){break ga}break fa}e=w[b+5|0];i=e&240;if(i){t[b+5|0]=i;break fa}if(e){break fa}}t[b+3|0]=0}b=b+6|0;f=f+1|0;continue}break}break}e=P()|0;O()|0;break O}e=P()|0;O()|0;break O}v[23516]=0;b=T(278,v[d+112>>2])|0;e=v[23516];v[23516]=0;ha:{ia:{ja:{ka:{la:{if((e|0)!=1){if(b){f=Kb(d+48|0);e=a+484348|0;b=0;ma:{while(1){na:{v[23516]=0;g=W(154,v[d+112>>2],v[d+120>>2],1)|0;h=v[23516];v[23516]=0;if((h|0)==1){break na}if(!g){break ma}if(vf(v[a+484344>>2],v[e>>2])>>>0<=b>>>0){break ma}v[23516]=0;U(357,d+112|0,f|0,32);g=v[23516];v[23516]=0;if((g|0)==1){break na}g=v[m>>2];v[23516]=0;R(284,Xb(g,b)|0,f|0);g=v[23516];v[23516]=0;if((g|0)==1){break na}b=b+1|0;continue}break}e=P()|0;O()|0;wb(f);break la}wb(f)}b=d+112|0;yb(b);v[23516]=0;U(346,b|0,d+200|0,1414679374);b=v[23516];v[23516]=0;if((b|0)==1){break ka}v[23516]=0;b=T(278,v[d+112>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break T}if(!b){break ha}f=Kb(d+48|0);e=a+480188|0;b=0;while(1){v[23516]=0;g=W(154,v[d+112>>2],v[d+120>>2],1)|0;h=v[23516];v[23516]=0;if((h|0)==1){break ja}if(!(g&x[e>>1]>b>>>0)){break ia}v[23516]=0;U(357,d+112|0,f|0,32);g=v[23516];v[23516]=0;if((g|0)==1){break ja}wl(((b<<5)+a|0)+480289|0,f);b=b+1|0;continue}}e=P()|0;O()|0}yb(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;wb(f);break S}wb(f)}b=d+112|0;yb(b);v[23516]=0;U(354,b|0,d+200|0,1145129300);b=v[23516];v[23516]=0;if((b|0)==1){break U}G=d,H=Cb(v[d+112>>2]),v[G+48>>2]=H;e=c&2;f=Cb(v[d+116>>2]);g=a+480190|0;oa:{pa:{qa:{ra:{sa:{ta:{while(1){b=v[d+48>>2];if(!Nb(b,f)){Nc(d+112|0);b=Kb(d+48|0);if((o|0)!=841887798){break sa}v[23516]=0;c=Q(1,d+112|0,9519)|0;e=v[23516];v[23516]=0;if((e|0)==1){break ta}Gb(b,c);xb(c);break ra}v[23516]=0;c=T(274,b|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break V}ua:{if(!(!e|c>>>0>=x[g>>1])){c=B(c,104)+a|0;h=x[c+484518>>1];h=Uc(d+176|0,h&1?16:8,h&64?2:1,1,0);v[23516]=0;W(218,h|0,c+484484|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break ua}}Jf(d+48|0);continue}break}break V}e=P()|0;O()|0;break W}v[23516]=0;U(346,d+112|0,d+200|0,1447383635);c=v[23516];v[23516]=0;va:{wa:{xa:{ya:{za:{if((c|0)!=1){v[23516]=0;c=T(278,v[d+112>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break qa}if(!c){break wa}v[23516]=0;c=T(282,d+112|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break za}v[23516]=0;R(269,d+32|0,4295);e=v[23516];v[23516]=0;if((e|0)==1){break ya}v[d+16>>2]=c>>>4;v[23516]=0;v[d+12>>2]=c&15;X(358,d+176|0,d+32|0,d+16|0,d+12|0);c=v[23516];v[23516]=0;if((c|0)==1){break xa}c=d+176|0;Gb(b,c);xb(c);ac(d+32|0);break va}e=P()|0;O()|0;break W}e=P()|0;O()|0;break X}e=P()|0;O()|0;break X}e=P()|0;O()|0;ac(d+32|0);break X}v[23516]=0;c=Q(1,d+176|0,8538)|0;e=v[23516];v[23516]=0;if((e|0)==1){break Y}Gb(b,c);xb(c)}yb(d+112|0)}v[23516]=0;c=Q(1,d+32|0,8538)|0;e=v[23516];v[23516]=0;if((e|0)==1){break pa}Gb(a+1298344|0,c);xb(c);v[23516]=0;c=Q(1,d+16|0,10152)|0;e=v[23516];v[23516]=0;if((e|0)==1){break oa}Gb(a+1298356|0,c);xb(c);Gb(a+1298368|0,b);v[a+1298404>>2]=14;xb(b);f=1;break o}e=P()|0;O()|0;break X}e=P()|0;O()|0;break W}e=P()|0;O()|0;break W}e=P()|0;O()|0;break O}e=P()|0;O()|0}yb(d+112|0)}xb(b);break b}e=P()|0;O()|0;Nc(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}yb(d+112|0);break b}e=P()|0;O()|0;yb(f);break O}e=P()|0;O()|0;break O}e=P()|0;O()|0}Nc(d+176|0);break b}Jf(d+16|0);continue}}f=0}Ud(d+200|0)}hb=d+240|0;return f|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;break f}e=P()|0;O()|0;yb(d+176|0);break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break b}e=P()|0;O()|0}yb(d+48|0);break b}e=P()|0;O()|0;yb(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;yb(d+176|0)}Ud(d+200|0)}S(e|0);L()}function vV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=hb-464|0;hb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!di(b,d+456|0)){break F}if(!DB(d+456|0)){break F}if(!c){p=1;break F}q=he(d+432|0,b);v[23516]=0;R(264,d+416|0,q|0);b=v[23516];v[23516]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){v[23516]=0;U(265,d+240|0,d+416|0,1229866575);b=v[23516];v[23516]=0;if((b|0)==1){break da}v[23516]=0;p=Q(266,d+240|0,d+400|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break fa}yb(d+240|0);if(!p){break G}v[23516]=0;R(248,a|0,524288);b=v[23516];v[23516]=0;ga:{if((b|0)==1){break ga}$f(a);v[a+480208>>2]=12;H=a+480188|0,I=Bd(Eb(x[d+408>>1]),1,127),u[H>>1]=I;H=d,I=Eb(x[d+400>>1]),u[H+240>>1]=I;u[d+344>>1]=255;H=a+480192|0,I=x[Rc(d+240|0,d+344|0)>>1],u[H>>1]=I;H=d,I=Eb(x[d+402>>1]),u[H+240>>1]=I;u[d+344>>1]=3999;H=a+480190|0,I=x[Rc(d+240|0,d+344|0)>>1],u[H>>1]=I;v[23516]=0;b=W(267,a+1074312|0,6,1)|0;e=v[23516];v[23516]=0;if((e|0)==1){break ga}v[23516]=0;b=Q(268,b|0,21)|0;e=v[23516];v[23516]=0;if((e|0)==1){break ga}v[23516]=0;Q(268,b|0,13)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break ea}}b=P()|0;O()|0;break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(d+240|0);break b}v[23516]=0;b=Q(1,d+384|0,9311)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}Gb(a+1298344|0,b);xb(b);v[23516]=0;b=Q(1,d+368|0,10336)|0;e=v[23516];v[23516]=0;if((e|0)==1){break d}Gb(a+1298356|0,b);xb(b);v[23516]=0;R(269,d+344|0,4339);b=v[23516];v[23516]=0;if((b|0)==1){break e}v[23516]=0;R(270,d+320|0,d+456|4);b=v[23516];v[23516]=0;if((b|0)==1){break g}v[23516]=0;R(270,d+296|0,d+456|5);b=v[23516];v[23516]=0;if((b|0)==1){break i}v[23516]=0;X(109,d+240|0,d+344|0,d+320|0,d+296|0);b=v[23516];v[23516]=0;if((b|0)==1){break j}b=d+240|0;Gb(a+1298368|0,b);xb(b);xb(d+296|0);xb(d+320|0);b=d+344|0;ac(b);v[a+1298404>>2]=14;v[23516]=0;U(265,b|0,d+416|0,1312902469);b=v[23516];v[23516]=0;if((b|0)==1){break k}v[23516]=0;b=T(158,v[d+344>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break m}v[23516]=0;g=a+1298308|0;U(271,d+344|0,g|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break m}v[23516]=0;U(265,d+320|0,d+416|0,1397706311);b=v[23516];v[23516]=0;if((b|0)==1){break n}h=a+484360|0;e=a+484376|0;Gc(Sb(v[h>>2],w[e|0]));k=Eb(x[d+404>>1]);ha:{ia:{while(1){if(k>>>0<=(f&65535)>>>0){break ha}v[23516]=0;b=W(154,v[d+320>>2],v[d+328>>2],46)|0;j=v[23516];v[23516]=0;ja:{if((j|0)!=1){if(!b){break ha}v[23516]=0;R(272,d+320|0,d+240|0);b=v[23516];v[23516]=0;if((b|0)!=1){if(!Pe(g)){break ja}v[23516]=0;Q(273,g|0,d+240|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break ja}}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[23516]=0;j=T(274,d+320|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break ca}b=Sb(v[a+484360>>2],w[e|0]);if(!nc(v[b>>2],v[b+4>>2])){v[23516]=0;b=T(275,h|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break ca}if((b|0)==255){break ha}b=Sb(v[a+484360>>2],w[e|0])}v[23516]=0;U(5,d+296|0,14,d+240|0);i=v[23516];v[23516]=0;if((i|0)!=1){v[23516]=0;R(276,b|0,d+296|0);b=v[23516];v[23516]=0;if((b|0)==1){break ia}xb(d+296|0);b=w[e|0];i=v[a+484360>>2];v[23516]=0;U(277,Sb(i,b)|0,d+320|0,j|0);b=v[23516];v[23516]=0;if((b|0)==1){break ca}f=f+1|0;continue}break}b=P()|0;O()|0;break o}b=P()|0;O()|0;xb(d+296|0);break o}Dj(h,0);v[23516]=0;U(265,d+296|0,d+416|0,1229869908);b=v[23516];v[23516]=0;if((b|0)==1){break ba}v[23516]=0;b=T(278,v[d+296>>2])|0;f=v[23516];v[23516]=0;if((f|0)==1){break p}ka:{if(!b){break ka}g=a+480192|0;f=1;la:{while(1){b=f&65535;if(b>>>0>x[g>>1]){v[23516]=0;U(265,d+216|0,d+416|0,1447382614);b=v[23516];v[23516]=0;if((b|0)!=1){break la}break p}v[23516]=0;R(279,d+296|0,d+240|0);e=v[23516];v[23516]=0;if((e|0)==1){break p}e=x[d+270>>1];v[23516]=0;b=W(253,a|0,b|0,Eb(e)|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break p}ma:{na:{if(!b){break na}if(Eb(x[d+270>>1])>>>0>3999){break na}e=d+128|0;CB(e,2,d+240|0);v[23516]=0;R(221,d+152|0,e|0);e=v[23516];v[23516]=0;if((e|0)==1){break ma}e=d+152|0;Ac(b+492|0,e);wb(e);h=d+128|0;CB(h,2,d+240|0);v[23516]=0;R(221,e|0,h|0);e=v[23516];v[23516]=0;if((e|0)==1){break p}e=d+152|0;Ac(((Eb(x[d+270>>1])<<5)+a|0)+946304|0,e);wb(e);v[b>>2]=0;H=b,I=ne(u[d+286>>1])+128&65535,v[H+8>>2]=I;uc(b+8|0,256);t[b+15|0]=w[b+15|0]|1;b=x[d+270>>1];v[23516]=0;b=B(Eb(b),104)+a|0;R(280,b+484380|0,0);e=v[23516];v[23516]=0;if((e|0)==1){break p}H=d,I=Eb(x[d+272>>1]),u[H+152>>1]=I;u[d+128>>1]=64;H=b+484410|0,I=x[Rc(d+152|0,d+128|0)>>1]<<2,u[H>>1]=I;H=b+484404|0,I=_b(x[d+274>>1]|x[d+276>>1]<<16),v[H>>2]=I;e=_b(x[d+282>>1]|x[d+284>>1]<<16);if(!e){break na}h=Eb(x[d+288>>1]);if(!(h&3)){break na}k=e;e=_b(x[d+278>>1]|x[d+280>>1]<<16);v[b+484388>>2]=k+e;v[b+484384>>2]=e;b=b+484414|0;e=x[b>>1];u[b>>1]=e|2;if(!(h&2)){break na}u[b>>1]=e|6}f=f+1|0;continue}break}break p}b=v[d+228>>2];v[d+32>>2]=v[d+224>>2];v[d+36>>2]=b;v[d+40>>2]=v[d+232>>2];v[23516]=0;b=v[d+220>>2];v[d+24>>2]=v[d+216>>2];v[d+28>>2]=b;X(281,d+24|0,0,a|0,0);b=v[23516];v[23516]=0;if((b|0)==1){break p}v[23516]=0;U(265,d+192|0,d+416|0,1346719318);b=v[23516];v[23516]=0;if((b|0)==1){break p}b=v[d+204>>2];v[d+8>>2]=v[d+200>>2];v[d+12>>2]=b;v[d+16>>2]=v[d+208>>2];v[23516]=0;b=v[d+196>>2];v[d>>2]=v[d+192>>2];v[d+4>>2]=b;X(281,d|0,1,a|0,w[d+460|0]>2|0);b=v[23516];v[23516]=0;if((b|0)==1){break p}e=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break ka}f=v[((b<<2)+a|0)+900380>>2];if(!(!f|t[f+60|0]&1)){v[f>>2]=32767}b=b+1|0;continue}}yb(d+296|0);v[23516]=0;U(265,d+240|0,d+416|0,1346458708);b=v[23516];v[23516]=0;if((b|0)==1){break q}v[23516]=0;b=T(176,v[d+240>>2])|0;f=v[23516];v[23516]=0;if((f|0)==1){break s}if(!(!(c&1)|b^1)){v[23516]=0;U(265,d+296|0,d+416|0,1347305805);b=v[23516];v[23516]=0;if((b|0)==1){break t}v[23516]=0;Q(186,d+296|0,1)|0;b=v[23516];v[23516]=0;if((b|0)==1){break v}b=x[d+406>>1];v[23516]=0;m=a+484344|0;R(224,m|0,Eb(b)|0);b=v[23516];v[23516]=0;if((b|0)==1){break v}b=d+128|0;A=b|3;C=b|1;i=Lb(d+176|0);D=a+480188|0;h=0;while(1){if(Eb(x[d+406>>1])>>>0<=l>>>0){gd(i);e=h;yb(d+296|0);if(!(c&4)){break $}f=0;if(!E){break aa}g=x[a+480188>>1];b=0;f=1;while(1){if((b|0)==(g|0)){break aa}h=(b<<5)+a|0;t[h+480288|0]=1;h=h+480280|0;v[h>>2]=v[h>>2]|67108864;b=b+1|0;continue}}v[23516]=0;b=T(274,d+240|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break x}v[23516]=0;f=T(282,d+240|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break y}v[23516]=0;U(188,d+128|0,d+240|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break z}f=d+128|0;j=hc(d+152|0,f);yb(f);v[23516]=0;f=W(225,m|0,l&65535,b|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break B}oa:{if(f){o=Kb(d+112|0);v[23516]=0;R(283,d+296|0,o|0);f=v[23516];v[23516]=0;if((f|0)==1){break oa}f=v[m>>2];v[23516]=0;R(284,Xb(f,l)|0,o|0);f=v[23516];v[23516]=0;if((f|0)==1){break oa}n=0;f=Xb(v[m>>2],l);y=xf(v[f>>2],v[v[f+48>>2]+12>>2],0);Gc(i);F=(b>>>0>1?b:1)-1|0;pa:while(1){b=v[j>>2];v[23516]=0;b=W(154,b|0,v[d+160>>2],1)|0;f=v[23516];v[23516]=0;if((f|0)==1){break C}qa:{if(!b){break qa}v[23516]=0;f=T(204,j|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break C}if(!f){H=d,I=Cb(v[i>>2]),v[H+104>>2]=I;f=Cb(v[i+4>>2]);while(1){b=v[d+104>>2];if(Nb(b,f)){ve(Xb(v[m>>2],l),Se(Le(d+128|0,w[b|0],w[b+1|0]),n));Qe(d+104|0);continue}else{Gc(i);if((n|0)==(F|0)){break qa}b=Xb(v[m>>2],l);n=n+1|0;y=xf(v[b>>2],v[v[b+48>>2]+12>>2],n);continue pa}}}Cj(d+128|0);e=x[D>>1];v[23516]=0;b=T(204,j|0)|0;g=v[23516];v[23516]=0;ra:{sa:{if((g|0)!=1){r=B(f-1|0,6)+y|0;s=e>>>0<f>>>0;k=s?d+128|0:r;ta:{if(!(b&1)){break ta}v[23516]=0;f=T(204,j|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break C}if((f|0)!=31){if((f-1&255)>>>0>252){break ta}e=(B(f>>>4|0,12)+(f&15)|0)+13|0}else{e=255}t[k|0]=e}if(!(b&2)){break ra}v[23516]=0;f=T(204,j|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break sa}}break C}t[(s?C:r+1|0)|0]=f}if(!(b&60)){continue}f=0;e=0;if(b&4){v[23516]=0;e=T(204,j|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break C}}if(b&8){v[23516]=0;f=T(204,j|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break C}}g=0;z=0;if(b&16){v[23516]=0;z=T(204,j|0)|0;G=v[23516];v[23516]=0;if((G|0)==1){break C}}if(b&32){v[23516]=0;g=T(204,j|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break C}}b=d+104|0;nV(b,z,g);g=Kc(b);b=d+96|0;nV(b,e,f);f=Kc(b);b=w[d+96|0];ua:{if((b|0)!=13){if(b){break ua}b=0;if(w[d+104|0]==13){break ua}}Bh(d+104|0,d+96|0);Bh(g,f);b=w[d+96|0]}to(d+88|0,k,w[d+104|0],w[g|0],b&255,w[f|0]);if(mV(w[d+88|0],w[d+89|0])){b=v[cc(d+80|0,Cb(v[i>>2]))>>2];v[23516]=0;U(285,i|0,b|0,d+88|0);b=v[23516];v[23516]=0;if((b|0)==1){break C}}b=w[(s?A:r+3|0)|0];if((b|0)==43){E=1;continue}if((b|0)!=31){continue}h=1;continue}break}wb(o)}yb(j);l=l+1|0;continue}break}break C}e=0;f=0;if(c&4){break aa}break H}b=P()|0;O()|0;break b}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[d+176>>2]=-1778364416;v[d+180>>2]=-16756736;v[23516]=0;U(265,d+296|0,d+416|0,1146310725);b=v[23516];v[23516]=0;if((b|0)==1){break E}v[23516]=0;b=T(278,v[d+296>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break D}if(b){v[23516]=0;k=T(274,d+296|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break D}j=a+480188|0;b=0;g=f;while(1){va:{if((b|0)==(k|0)){v[23516]=0;R(286,d+296|0,d+176|0);b=v[23516];v[23516]=0;if((b|0)!=1){break va}break D}v[23516]=0;h=T(204,d+296|0)|0;i=v[23516];v[23516]=0;wa:{xa:{if((i|0)!=1){if(x[j>>1]<=b>>>0){break wa}if(!f){break xa}i=((b<<5)+a|0)+480280|0;v[i>>2]=v[i>>2]&-67108865|((h|0)!=0)<<26;break wa}break D}if(h){break wa}g=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}f=g&1}yb(d+296|0);if(!f){break $}v[23516]=0;b=Id(a+906300|0,0);Y(287,b|0);f=v[23516];v[23516]=0;if((f|0)==1){break _}v[b+16>>2]=810369604;v[b+20>>2]=1869112133;v[b+24>>2]=655376;v[b+28>>2]=0;v[d+296>>2]=0;g=b+48|0;jV(b+32|0,g,d+296|0);v[23516]=0;f=Q(53,d+152|0,9585)|0;h=v[23516];v[23516]=0;if((h|0)==1){break Z}BB(g,f);wb(f);v[23516]=0;f=Q(53,d+128|0,9549)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Y}wu(b+80|0,f);wb(f);v[23516]=0;R(288,b+4|0,8);f=v[23516];v[23516]=0;if((f|0)==1){break _}iV(d+296|0,w[d+177|0],w[d+179|0],w[d+181|0],w[d+183|0]);f=v[d+300>>2];b=v[b+4>>2];g=v[d+296>>2];t[b|0]=g;t[b+1|0]=g>>>8;t[b+2|0]=g>>>16;t[b+3|0]=g>>>24;t[b+4|0]=f;t[b+5|0]=f>>>8;t[b+6|0]=f>>>16;t[b+7|0]=f>>>24}if(!e){break H}f=a+902204|0;b=0;while(1){if((b|0)==32){break H}v[d+104>>2]=B(b,127)>>>5;v[23516]=0;R(289,d+176|0,4096);e=v[23516];v[23516]=0;if((e|0)==1){break X}v[23516]=0;R(290,d+112|0,d+104|0);e=v[23516];v[23516]=0;if((e|0)==1){break W}v[23516]=0;U(291,d+296|0,d+176|0,d+112|0);e=v[23516];v[23516]=0;if((e|0)==1){break V}e=d+296|0;Be(d+72|0,e);cf(ue(f,b),v[d+72>>2],v[d+76>>2]);wb(e);wb(d+112|0);e=d+176|0;Ub(e);v[23516]=0;R(289,e|0,4078);e=v[23516];v[23516]=0;if((e|0)==1){break T}v[23516]=0;R(290,d+112|0,d+104|0);e=v[23516];v[23516]=0;if((e|0)==1){break S}v[23516]=0;U(291,d+296|0,d+176|0,d+112|0);e=v[23516];v[23516]=0;if((e|0)==1){break R}e=d+296|0;Be(d- -64|0,e);cf(ue(f,b+32|0),v[d+64>>2],v[d+68>>2]);wb(e);wb(d+112|0);e=d+176|0;Ub(e);v[23516]=0;R(289,e|0,4069);e=v[23516];v[23516]=0;if((e|0)==1){break P}v[23516]=0;R(290,d+112|0,d+104|0);e=v[23516];v[23516]=0;if((e|0)==1){break O}v[23516]=0;U(291,d+296|0,d+176|0,d+112|0);e=v[23516];v[23516]=0;if((e|0)==1){break N}e=d+296|0;Be(d+56|0,e);cf(ue(f,b- -64|0),v[d+56>>2],v[d+60>>2]);wb(e);wb(d+112|0);e=d+176|0;Ub(e);v[23516]=0;R(289,e|0,4042);e=v[23516];v[23516]=0;if((e|0)==1){break L}v[23516]=0;R(290,d+112|0,d+104|0);e=v[23516];v[23516]=0;if((e|0)==1){break K}v[23516]=0;U(291,d+296|0,d+176|0,d+112|0);e=v[23516];v[23516]=0;if((e|0)==1){break J}e=d+296|0;Be(d+48|0,e);cf(ue(f,b+96|0),v[d+48>>2],v[d+52>>2]);b=b+1|0;wb(e);wb(d+112|0);Ub(d+176|0);continue}}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break U}b=P()|0;O()|0;wb(d+112|0)}Ub(d+176|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break Q}b=P()|0;O()|0;wb(d+112|0)}Ub(d+176|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break M}b=P()|0;O()|0;wb(d+112|0)}Ub(d+176|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break I}b=P()|0;O()|0;wb(d+112|0)}Ub(d+176|0);break r}v[23516]=0;U(265,d+296|0,d+416|0,1397575756);b=v[23516];v[23516]=0;ya:{if((b|0)!=1){v[23516]=0;b=T(176,v[d+296>>2])|0;f=v[23516];v[23516]=0;if((f|0)!=1){za:{f=1;if(!(c&2)|b^1){break ya}c=a+480190|0;while(1){e=f&65535;if(e>>>0>x[c>>1]){break ya}v[23516]=0;b=T(282,d+296|0)|0;g=v[23516];v[23516]=0;Aa:{if((g|0)!=1){v[23516]=0;g=T(282,d+296|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break za}if(!(b&7)){break Aa}e=(B(e,104)+a|0)+484380|0;v[e>>2]=g;b=Uc(d+176|0,b&4?32:b&2?16:8,1,1,0);v[23516]=0;W(218,b|0,e|0,d+296|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break Aa}break za}break za}f=f+1|0;continue}}}b=P()|0;O()|0;yb(d+296|0);break r}b=P()|0;O()|0;break r}yb(d+296|0);yb(d+240|0);yb(d+320|0);yb(d+344|0)}Ud(d+416|0);yb(q)}hb=d+464|0;return p|0}b=P()|0;O()|0;break r}b=P()|0;O()|0;yb(d+296|0);break r}b=P()|0;O()|0;wb(o);break A}b=P()|0;O()|0}yb(j);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0}gd(i);break u}b=P()|0;O()|0}yb(d+296|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0}yb(d+240|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;yb(d+296|0)}yb(d+320|0);break l}b=P()|0;O()|0;break l}b=P()|0;O()|0}yb(d+344|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;xb(d+296|0);break h}b=P()|0;O()|0}xb(d+320|0);break f}b=P()|0;O()|0}ac(d+344|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}Ud(d+416|0)}yb(q);S(b|0);L()}function Pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0;f=hb-496|0;hb=f;xc(b);i=hb-16|0;hb=i;e=f+288|0;wQ(i+8|0,e);n=b;g=v[b+8>>2];b=v[i+12>>2];jc(i,v[n>>2],g,v[i+8>>2],b);g=v[i+4>>2];if((g|0)==(b|0)){Yb(n,v[i+12>>2])}hb=i+16|0;b=(b|0)==(g|0);if(!b){vQ(e)}a:{if(!b){break a}if(!xQ(f+288|0)){break a}if(!c){d=1;break a}zd(a,134217728);b=f+8|0;Qf(b,3956);v[23516]=0;U(688,f+120|0,b|0,x[f+292>>1]);b=v[23516];v[23516]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=f+120|0;Gb(a+1298344|0,b);xb(b);ac(f+8|0);b=vc(b,9003);Gb(a+1298356|0,b);xb(b);v[a+480188>>2]=4;v[a+1298404>>2]=14;V=a,X=Eb(x[f+424>>1]),v[V+480196>>2]=X;b=x[f+428>>1];v[a+480260>>2]=56;v[a+480264>>2]=13696;V=a,X=uQ(Eb(b)),v[V+480204>>2]=X;Aq(Sb(v[a+484360>>2],w[a+484376|0]),f+296|0,w[f+294|0]);q=a+480190|0;m=a+480188|0;o=Lb(f+272|0);z=Lb(f+256|0);h:{i:{j:{k:{while(1){if(Eb(x[f+488>>1])>>>0<=(l&65535)>>>0){break k}v[23516]=0;b=T(274,n|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break g}u[f+232>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}d=Eb(x[f+490>>1]);if((Eb(x[f+292>>1])|0)==2){v[23516]=0;b=T(282,n|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break h}d=b-2|0}v[23516]=0;U(188,f+8|0,n|0,d|0);b=v[23516];v[23516]=0;if((b|0)==1){break i}b=f+8|0;h=hc(f+120|0,b);yb(b);C=x[ie(q,f+232|0)>>1];u[q>>1]=C;v[23516]=0;j=B(x[f+232>>1],104)+a|0;e=j+484380|0;R(280,e|0,1);b=v[23516];v[23516]=0;l:{m:{n:{if((b|0)==1){break n}if(Eb(x[f+292>>1])>>>0>1){break m}v[23516]=0;R(689,h|0,j+484423|0);b=v[23516];v[23516]=0;if((b|0)==1){break n}v[23516]=0;Q(186,h|0,1)|0;b=v[23516];v[23516]=0;if((b|0)==1){break n}v[23516]=0;U(330,h|0,((x[f+232>>1]<<5)+a|0)+946304|0,30);b=v[23516];v[23516]=0;if((b|0)!=1){break l}}e=P()|0;O()|0;break f}b=Kb(f+8|0);v[23516]=0;U(357,h|0,b|0,257);i=v[23516];v[23516]=0;o:{p:{if((i|0)==1){break p}xe(j+484423|0,b);v[23516]=0;Q(186,h|0,1)|0;i=v[23516];v[23516]=0;if((i|0)==1){break p}v[23516]=0;U(357,h|0,b|0,31);i=v[23516];v[23516]=0;if((i|0)==1){break p}Ac(((x[f+232>>1]<<5)+a|0)+946304|0,b);if(!(t[f+128|0]&1)){break o}v[23516]=0;Q(186,h|0,1)|0;i=v[23516];v[23516]=0;if((i|0)!=1){break o}}e=P()|0;O()|0;wb(b);break f}wb(b)}v[23516]=0;R(690,h|0,f+8|0);b=v[23516];v[23516]=0;q:{if((b|0)==1){break q}d=hb-16|0;hb=d;i=_b(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24));v[e>>2]=i;t[d+15|0]=w[f+12|0];t[d+14|0]=64;V=e,X=w[Vb(d+15|0,d+14|0)|0]<<2,u[V+30>>1]=X;g=_b(w[f+14|0]|w[f+15|0]<<8|(w[f+16|0]<<16|w[f+17|0]<<24));v[e+4>>2]=g;b=_b(w[f+14|0]|w[f+15|0]<<8|(w[f+16|0]<<16|w[f+17|0]<<24))+_b(w[f+18|0]|w[f+19|0]<<8|(w[f+20|0]<<16|w[f+21|0]<<24))|0;v[e+8>>2]=b;if(g>>>0>=i>>>0){g=i-1|0;v[e+4>>2]=g}if(b>>>0>i>>>0){v[e+8>>2]=i;b=i}r:{if(b>>>0<g>>>0){v[e+4>>2]=0;v[e+8>>2]=0;break r}if(b>>>0<=g>>>0){break r}u[e+34>>1]=x[e+34>>1]|2;V=Bb(e+68|0,0),X=g,v[V>>2]=X}hb=d+16|0;s:{t:{switch(Eb(x[f+292>>1])|0){case 2:t[j+484417|0]=w[f+26|0]<<3;break;case 0:break s;default:break t}}v[23516]=0;R(213,z|0,C|0);b=v[23516];v[23516]=0;if((b|0)==1){break q}v[23516]=0;R(691,o|0,C|0);b=v[23516];v[23516]=0;if((b|0)==1){break q}i=Jd(v[o>>2],x[f+232>>1]-1|0);Gc(i);v[23516]=0;b=T(274,n|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break j}e=v[n+8>>2];d=v[n>>2];v[23516]=0;e=W(154,d|0,e|0,b<<3)|0;d=v[23516];v[23516]=0;if((d|0)==1){break j}if(e){v[23516]=0;R(692,i|0,b|0);e=v[23516];v[23516]=0;if((e|0)==1){break j}d=0;v[f+248>>2]=0;if(!(!(w[j+484414|0]&2)|b)){b=v[j+484384>>2];v[f+240>>2]=b;e=v[j+484388>>2];v[23516]=0;v[f+244>>2]=e-b;R(693,i|0,f+240|0);b=v[23516];v[23516]=0;if((b|0)!=1){break s}e=P()|0;O()|0;break f}while(1){if(b>>>0<=(d&65535)>>>0){break s}v[23516]=0;e=T(282,n|0)|0;g=v[23516];v[23516]=0;u:{if((g|0)==1){break u}v[23516]=0;v[f+240>>2]=e;e=T(282,n|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break u}v[23516]=0;v[f+244>>2]=e;R(693,i|0,f+240|0);e=v[23516];v[23516]=0;if((e|0)==1){break u}d=d+1|0;continue}break}e=P()|0;O()|0;break f}yb(h);break c}yb(h);l=l+1|0;continue}break}e=P()|0;O()|0;break f}v:{w:{x:{y:{if(Eb(x[f+292>>1])){A=w[f+295|0];u[f+238>>1]=4;D=128;break y}v[23516]=0;D=T(274,n|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){e=P()|0;O()|0;break e}b=x[f+292>>1];A=w[f+295|0];u[f+238>>1]=4;if(!Eb(b)){break x}}i=v[n+8>>2];e=0;while(1){z:{if((e&65535)>>>0>=D>>>0){break z}v[23516]=0;b=T(274,n|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break w}if((b|0)==65535){break z}v[23516]=0;A=T(274,n|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break w}v[23516]=0;b=T(274,n|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break w}u[f+238>>1]=b;if(b>>>0>127){break c}V=m,X=x[ie(m,f+238|0)>>1],u[V>>1]=X;v[23516]=0;Q(186,n|0,B(b,A)<<2)|0;b=v[23516];v[23516]=0;if((b|0)==1){break w}e=e+1|0;continue}break}v[23516]=0;Q(153,n|0,i|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break v}}b=x[m>>1];v[23516]=0;E=Q(694,f+240|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){J=a+484344|0;N=c&1;F=Eb(x[f+426>>1]);b=0;i=0;while(1){A:{B:{C:{D:{if((b&65535)>>>0>=D>>>0){break D}E:{if(!Eb(x[f+292>>1])){d=x[f+238>>1];e=b;break E}v[23516]=0;e=T(274,n|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break A}if((e|0)==65535){break D}v[23516]=0;A=T(274,n|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break A}v[23516]=0;d=T(274,n|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break A}u[f+238>>1]=d}g=v[n+8>>2];h=v[n>>2];v[23516]=0;r=g;G=A&65535;g=G<<2;d=W(154,h|0,r|0,B(g,d&65535)|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break A}if(!d){break D}if(!N){break C}v[23516]=0;K=e&65535;e=W(225,J|0,K|0,G|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break A}if(!e){break C}s=0;F:while(1){if((s|0)==(G|0)){break B}e=0;d=Xb(v[J>>2],K);j=xf(v[d>>2],v[v[d+48>>2]+12>>2],s);H=0;r=0;G:{H:{I:{switch((F&3)-1|0){case 0:r=!(s&3);break H;case 1:r=!(s&1);break H;case 2:break I;default:break G}}r=(s&3)!=3}}while(1){if(x[f+238>>1]<=e>>>0){s=s+1|0;continue F}d=v[E>>2];v[23516]=0;R(356,f+232|0,n|0);g=v[23516];v[23516]=0;if((g|0)==1){break A}h=B(e,9)+d|0;d=f+232|0;g=Kc(d);p=Re(d);m=j+B(e,6)|0;t[m+1|0]=w[f+232|0];k=w[g|0];t[m|0]=k;g=w[Ji(d)|0];t[m+5|0]=g;l=m+5|0;if(k){t[m|0]=k+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;g=w[l|0]}k=g&255;p=w[p|0];J:{if(p>>>0>=240){d=k|(p&15)<<8;if(d){V=l,X=nk(+(uQ(d)>>>0)/1e4),t[V|0]=X;t[m+3|0]=17;break J}t[m+3|0]=0;break J}I=k>>>4|0;M=k<<4;d=I|M;K:{switch(p|0){case 0:d=j+B(e,6)|0;if(g&255){t[d+3|0]=1;break J}t[d+3|0]=0;break J;case 1:t[(j+B(e,6)|0)+3|0]=2;break J;case 2:t[(j+B(e,6)|0)+3|0]=3;break J;case 3:t[f+228|0]=15;V=h,X=w[Vb(l,f+228|0)|0]|16,t[V|0]=X;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 4:t[f+228|0]=15;V=h,X=w[Vb(l,f+228|0)|0]|32,t[V|0]=X;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=g;t[h|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 6:t[h+7|0]=0;t[h+2|0]=g;t[h|0]=0;t[h+1|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 7:t[(j+B(e,6)|0)+3|0]=23;i=0;break J;case 8:t[(j+B(e,6)|0)+3|0]=0;i=d;break J;case 9:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Vb(l,f+228|0)|0]|16,t[V|0]=X;break J;case 10:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Vb(l,f+228|0)|0]|32,t[V|0]=X;break J;case 11:t[h+3|0]=d;t[(j+B(e,6)|0)+3|0]=0;break J;case 12:d=j+B(e,6)|0;t[d+4|0]=g;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break J;case 13:p=j+B(e,6)|0;L:{M:{if(k&240){t[(j+B(e,6)|0)+2|0]=4;d=(g&240)>>>4|0;break M}if(!(k&15)){break L}t[(j+B(e,6)|0)+2|0]=3;d=g&15}t[p+4|0]=d}t[h+3|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 14:t[(j+B(e,6)|0)+3|0]=19;t[l|0]=!(g&255);break J;case 15:t[(j+B(e,6)|0)+3|0]=16;t[l|0]=(g&240)>>>4;F=g&15;break J;case 16:t[h+5|0]=0;t[h+4|0]=g;t[(j+B(e,6)|0)+3|0]=0;break J;case 17:t[h+6|0]=k&15?g:0;t[(j+B(e,6)|0)+3|0]=0;break J;case 18:t[(j+B(e,6)|0)+3|0]=14;break J;case 19:t[h+8|0]=0;t[h+7|0]=g;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(j+B(e,6)|0)+3|0]=0;break J;case 20:t[(j+B(e,6)|0)+3|0]=12;break J;case 22:d=w[m+1|0];N:{if(!d){break N}k=v[o>>2];if(ud(k,v[o+4>>2])>>>0<d>>>0){break N}g=g-1|0;t[l|0]=g;v[23516]=0;T(695,f+120|0)|0;p=v[23516];v[23516]=0;if((p|0)==1){break A}v[f+228>>2]=9;d=Jd(k,d-1|0);V=f,X=ud(v[d>>2],v[d+4>>2]),v[V+116>>2]=X;if(y[Hb(f+228|0,f+116|0)>>2]<=(g&255)>>>0){break N}d=j+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[l|0]}t[(j+B(e,6)|0)+3|0]=0;break J;case 23:d=w[m+1|0];O:{if(!d){break O}k=v[o>>2];if(ud(k,v[o+4>>2])>>>0<d>>>0){break O}g=g-1|0;t[l|0]=g;d=Jd(k,d-1|0);k=v[d>>2];p=ud(k,v[d+4>>2]);d=g&255;if(p>>>0<=d>>>0){break O}d=Jd(k,d);g=x[d+8>>1];P:{if(g){break P}g=0;k=x[q>>1];if(!Yh(k)){break P}g=k+1|0;u[q>>1]=g;u[d+8>>1]=g}t[m+1|0]=g}t[(j+B(e,6)|0)+3|0]=0;break J;case 24:d=w[m+1|0];Q:{if(!d){break Q}k=v[o>>2];if(ud(k,v[o+4>>2])>>>0<d>>>0){break Q}g=g-1|0;t[l|0]=g;v[23516]=0;T(695,f+8|0)|0;p=v[23516];v[23516]=0;if((p|0)==1){break A}v[f+228>>2]=9;d=Jd(k,d-1|0);V=f,X=ud(v[d>>2],v[d+4>>2]),v[V+116>>2]=X;if(y[Hb(f+228|0,f+116|0)>>2]>(g&255)>>>0){d=j+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[l|0]}d=$b(v[z>>2],w[m+1|0]-1|0);g=x[d>>1];R:{if(g){break R}g=0;k=x[q>>1];if(!Yh(k)){break R}g=k+1|0;u[q>>1]=g;u[d>>1]=g}t[m+1|0]=g}t[(j+B(e,6)|0)+3|0]=0;break J;case 25:d=w[m+1|0];S:{if(!d){break S}k=v[o>>2];if(ud(k,v[o+4>>2])>>>0<d>>>0){break S}g=g-1|0;t[l|0]=g;d=Jd(k,d-1|0);k=v[d>>2];p=ud(k,v[d+4>>2]);d=g&255;if(p>>>0<=d>>>0){break S}d=Jd(k,d);g=x[d+10>>1];T:{if(g){break T}g=0;k=x[q>>1];if(!Yh(k)){break T}g=k+1|0;u[q>>1]=g;u[d+10>>1]=g}t[m+1|0]=g}t[(j+B(e,6)|0)+3|0]=0;break J;case 29:t[(j+B(e,6)|0)+3|0]=11;t[l|0]=d;if(k&15){t[l|0]=M|15;break J}if((g&255)>>>0<16){break J}t[l|0]=I|240;break J;case 32:if(k&240){t[h+3|0]=I;t[(j+B(e,6)|0)+3|0]=0;break J}t[(j+B(e,6)|0)+3|0]=19;t[l|0]=g&15|192;break J;case 33:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Vb(l,f+228|0)|0]|208,t[V|0]=X;break J;case 34:t[(j+B(e,6)|0)+3|0]=19;t[f+228|0]=15;V=l,X=w[Vb(l,f+228|0)|0]|144,t[V|0]=X;break J;case 73:t[(j+B(e,6)|0)+3|0]=10;break J;case 78:if((g&112|128)==224){t[(j+B(e,6)|0)+3|0]=19;break J}t[(j+B(e,6)|0)+3|0]=0;break J;case 79:d=j+B(e,6)|0;if((g&255)>>>0<=31){t[d+3|0]=16;F=0;break J}t[d+3|0]=17;break J;default:break K}}t[(j+B(e,6)|0)+3|0]=0}k=0;g=w[h+3|0];if(!(w[m+2|0]|!g)){U:{if(g>>>0>=16){t[m+2|0]=5;g=g>>>4|0;break U}t[m+2|0]=6}t[m+4|0]=g;k=1}V:{if(w[m+3|0]){break V}d=w[h+1|0];W:{if(d){t[m+3|0]=2;break W}d=w[h+2|0];if(d){t[m+3|0]=3;break W}d=w[h|0];if(d){t[m+3|0]=19;break W}d=w[h+7|0];if(d){t[m+3|0]=4;t[h+8|0]=d;break W}d=w[h+4|0];if(d){t[m+3|0]=5;t[h+5|0]=d;break W}d=w[h+3|0];if(!(!d|k)){t[m+3|0]=11;t[l|0]=d;if(d&15){d=d|-16;break W}if(!(d&240)){break V}d=d|15;break W}d=w[h+6|0];if(d){t[m+3|0]=8;break W}if(r){t[m+3|0]=20;r=0;d=97;break W}r=0;if(H){break V}d=i&255;if(!d){break V}t[m+3|0]=24;t[l|0]=i;if(i&15){d=i|-16}else{if(!(d&240)){H=1;break V}d=i|15}H=1}t[l|0]=d}e=e+1|0;continue}}}v[a+480228>>2]=256/x[a+480188>>1];k=1;jh(a,1);if(Eb(x[f+292>>1])){X:{while(1){b=v[n+8>>2];i=v[n>>2];v[23516]=0;b=W(154,i|0,b|0,2)|0;i=v[23516];v[23516]=0;if((i|0)==1){break A}if(!b){break X}v[23516]=0;b=T(274,n|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break A}if((b|0)==65535){break X}v[23516]=0;Q(186,n|0,2)|0;b=v[23516];v[23516]=0;if((b|0)==1){break A}v[23516]=0;b=T(282,n|0)|0;i=v[23516];v[23516]=0;if((i|0)!=1){v[23516]=0;Q(186,n|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){continue}}break}break A}v[23516]=0;Q(186,n|0,34)|0;b=v[23516];v[23516]=0;if((b|0)==1){break A}}Y:{if(!(c&2)){break Y}while(1){b=k&65535;if(b>>>0>C>>>0){break Y}Z:{e=(B(b,104)+a|0)+484380|0;if(!v[e>>2]){break Z}c=Uc(f+232|0,8,1,0,0);v[23516]=0;W(218,c|0,e|0,n|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break A}c=v[o>>2];if(ud(c,v[o+4>>2])>>>0<b>>>0){break Z}j=b-1|0;g=Jd(c,j);c=0;b=0;m=hb-112|0;hb=m;_:{h=v[e>>2];if(!Vd(h,v[e+20>>2])){break _}q=v[g>>2];i=ud(q,v[g+4>>2]);if(i>>>0<2){break _}d=_n(m+8|0,e);v[d+20>>2]=0;v[d>>2]=0;$:{while(1){if((c|0)==(i|0)){break $}aa:{l=Jd(q,c);s=v[l>>2];if(s>>>0>=h>>>0){break aa}l=v[l+4>>2];if(l>>>0>h-s>>>0|268435456-l>>>0<b>>>0){break aa}b=b+l|0;v[d>>2]=b;c=c+1|0;continue}break}i=c}if(!Jg(d)){break _}l=d+68|0;b=0;c=0;while(1){if((c|0)==(i|0)){um(e);b=_n(e,d);v[b+4>>2]=0;v[b+8>>2]=v[b>>2];u[b+34>>1]=x[b+34>>1]|2;break _}r=v[d+20>>2]+b|0;q=v[e+20>>2];h=Jd(v[g>>2],c);pc(r,q+v[h>>2]|0,v[h+4>>2]);v[h>>2]=b;if(c-10>>>0>=4294967287){V=Bb(l,c-1|0),X=b,v[V>>2]=X}c=c+1|0;b=v[h+4>>2]+b|0;continue}}hb=m+112|0;b=x[$b(v[z>>2],j)>>1];if(b){Mz(e,(B(b,104)+a|0)+484380|0,0,v[e>>2],0)}b=Jd(v[o>>2],j);V=f,X=Cb(v[b>>2]),v[V+232>>2]=X;c=Cb(v[b+4>>2]);while(1){b=v[f+232>>2];if(!Nb(b,c)){break Z}i=x[b+8>>1];if(i){Mz(e,(B(i,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],1)}i=x[b+10>>1];if(i){Mz(e,(B(i,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],0)}gq(f+232|0);continue}}k=k+1|0;continue}}bq(E);d=1;break b}v[23516]=0;Q(186,n|0,B(g,x[f+238>>1])|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break B}break A}b=b+1|0;continue}break}e=P()|0;O()|0;bq(E);break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break f}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;ac(f+8|0);break d}e=P()|0;O()|0;break e}yb(h)}gd(z);rQ(o)}S(e|0);L()}d=0}gd(z);rQ(o)}hb=f+496|0;return d|0}function Wda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=hb-592|0;hb=d;xc(b);a:{if(!KA(b,d+512|0)){break a}if(!BP(d+512|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(AP(d+512|0),kb))){break a}b:{if(!c){break b}zd(a,4);$f(a);t[a+1074368|0]=4;k=Kb(d+496|0);c:{d:{e:{f:{l=d+550|0;g:{if(!(Qb(l,17894,20)|v[d+572>>2]!=276)){if(x[d+570>>1]<260){break g}e=MA(d+529|0,0,20)?1154:34;break e}if(!Qb(l,17873,20)){e=1;break e}g=d- -64|0;Aj(g,3,l);v[23516]=0;R(221,d+104|0,g|0);g=v[23516];v[23516]=0;h:{i:{if((g|0)!=1){v[23516]=0;U(11,d+208|0,5,d+104|0);g=v[23516];v[23516]=0;if((g|0)==1){break i}g=d+208|0;Gb(k,g);xb(g);wb(d+104|0);if(Qb(l,17711,8)){break h}e=1048;break e}f=P()|0;O()|0;break c}f=P()|0;O()|0;wb(d+104|0);break c}if(!Qb(l,17611,12)){e=16;if(!Qb(d+562|0,17915,8)){break e}t[a+1074368|0]=5;break e}if(Qb(l,11693,20)){break f}}e=48;break e}if(!Qb(l,27264,15)){v[23516]=0;g=Q(268,a+1074312|0,54)|0;e=v[23516];v[23516]=0;C=1;if((e|0)==1){break d}v[23516]=0;Q(268,g|0,51)|0;g=v[23516];v[23516]=0;e=16;if((g|0)==1){break d}break e}j:{if(Qb(l,27280,14)){if(Qb(l,27295,14)){break j}}v[23516]=0;g=Q(268,a+1074312|0,57)|0;e=v[23516];v[23516]=0;if((e|0)==1){break d}v[23516]=0;Q(268,g|0,51)|0;g=v[23516];v[23516]=0;e=16;if((g|0)!=1){break e}break d}e=Qb(l,17699,11)?16:256}g=d+104|0;s=d+529|0;Aj(g,3,s);v[23516]=0;R(221,d+208|0,g|0);g=v[23516];v[23516]=0;k:{l:{m:{n:{o:{p:{q:{if((g|0)!=1){g=d+208|0;yc(a+1298308|0,g);wb(g);v[a+480260>>2]=1;v[a+480264>>2]=31999;Te(Sb(v[a+484360>>2],w[a+484376|0]),x[d+578>>1]);u[a+480188>>1]=x[d+580>>1];u[d+208>>1]=x[d+584>>1];u[d+104>>1]=255;F=a+480192|0,G=x[Rc(g,d+104|0)>>1],u[F>>1]=G;g=x[d+588>>1];if(g){v[a+480196>>2]=g}g=x[d+590>>1];if(g){g=B(g,1e4);g=g>>>0<1e7?g:1e7;v[a+480204>>2]=g>>>0>32e4?g:32e4}g=x[d+586>>1];v[a+480208>>2]=g<<4&16|g<<3&32768;f=w[a+484376|0];n=v[a+484360>>2];v[23516]=0;da(347,Sb(n,f)|0,b|0,x[d+576>>1],65535,65535);f=v[23516];v[23516]=0;if((f|0)==1){break d}f=g>>>12&1?(e|0)==34?146:e:e;if(!(x[d+576>>1]|f&1024)){g=w[a+484376|0];e=v[a+484360>>2];v[23516]=0;Y(749,Sb(e,g)|0);g=v[23516];v[23516]=0;if((g|0)==1){break d}}v[23516]=0;Q(153,b|0,v[d+572>>2]+60|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(x[d+570>>1]>=260){v[23516]=0;U(750,b|0,d+512|0,a|0);g=v[23516];v[23516]=0;if((g|0)==1){break d}}t[d+495|0]=0;z=c&2;D=d+122|0;o=d+241|0;n=Lb(d+480|0);E=a+480192|0;g=-1;p=1;while(1){e=p&65535;if(e>>>0>x[E>>1]){if(!(!(f&2)|q&255)){f=MA(s,0,20)?f|16:f}if(x[d+570>>1]>259){break o}if(c&3){v[23516]=0;U(750,b|0,d+512|0,a|0);c=v[23516];v[23516]=0;if((c|0)==1){break n}}if(!z){break o}o=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>x[o>>1]){break o}i=v[n>>2];v[23516]=0;W(218,Bb(i,c-1|0)|0,(B(c,104)+a|0)+484380|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}v[23516]=0;i=T(155,b|0)|0;h=v[23516];v[23516]=0;r:{s:{if((h|0)!=1){wg(b,4);v[23516]=0;U(751,b|0,d+208|0,(i?i:263)|0);i=v[23516];v[23516]=0;if((i|0)==1){break p}t:{if((f|0)==1){i=v[d+208>>2];if((i|0)!=263){f=16;if((i|0)!=245){break t}v[a+1074308>>2]=16777381;v[23516]=0;f=Q(1,d+192|0,13395)|0;i=v[23516];v[23516]=0;if((i|0)!=1){Gb(k,f);xb(f);f=17;break t}f=P()|0;O()|0;break k}v[a+1074308>>2]=16777395;v[23516]=0;f=Q(1,d+176|0,13310)|0;i=v[23516];v[23516]=0;if((i|0)!=1){Gb(k,f);xb(f);f=17;break t}f=P()|0;O()|0;break k}if(w[d+235|0]|w[d+236|0]<<8){break t}i=v[d+208>>2];if(!(!(f&2)|(w[d+237|0]|w[d+238|0]<<8|(w[d+239|0]<<16|w[d+240|0]<<24))|(i|0)!=263)){f=f|16;break t}if(!(!(f&256)|(i|0)==29)){f=f&-257;break t}if(!(f&160)){break t}f=(i|0)==33?f:0}v[23516]=0;i=W(253,a|0,e|0,0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break p}if(!i){break r}i=((e<<2)+a|0)+900380|0;e=v[i>>2];v[23516]=0;R(752,d+208|0,e|0);e=v[23516];v[23516]=0;if((e|0)==1){break p}e=w[d+234|0];u:{if((g|0)==-1){g=e;break u}if(!(f&32)|(e|0)==(g|0)){break u}f=f&-161|128}e=w[d+235|0]|w[d+236|0]<<8;if(!e){break r}v[23516]=0;h=w[d+455|0];j=w[d+451|0]|w[d+452|0]<<8;m=w[d+450|0];r=w[d+449|0];U(753,d+160|0,a|0,e|0);e=v[23516];v[23516]=0;if((e|0)==1){break q}f=h|(j|(m|r))?f&-4:f;i=v[i>>2]+236|0;e=12;h=v[d+160>>2];j=Oc(h,v[d+164>>2]);v:{while(1){w:{if((e|0)==108){if(x[d+570>>1]>259){Gc(n)}e=0;v[23516]=0;i=Q(754,d+144|0,w[d+235|0]|w[d+236|0]<<8)|0;h=v[23516];v[23516]=0;if((h|0)!=1){break w}f=P()|0;O()|0;break v}m=$b(i,e);if(j>>>0>x[m>>1]){F=m,G=x[$b(h,x[$b(i,e)>>1])>>1],u[F>>1]=G}e=e+1|0;continue}break}x:{y:{z:{A:{while(1){h=w[d+235|0]|w[d+236|0]<<8;if(e>>>0>=h>>>0){e=0;if(x[d+570>>1]<=259){break s}B:{while(1){if(e>>>0>=h>>>0){break s}j=w[Bb(v[n>>2],e)+3|0];h=v[Bb(v[i>>2],e)>>2];v[23516]=0;U(188,d- -64|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=v[23516];v[23516]=0;if((h|0)!=1){j=d- -64|0;h=hc(d+104|0,j);yb(j);j=v[d+160>>2];if(!(!z|Oc(j,v[d+164>>2])>>>0<=e>>>0)){m=x[$b(j,e)>>1];j=Bb(v[n>>2],e);j=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);v[23516]=0;v[d+56>>2]=j;v[d>>2]=j;j=fa(755,(B(m,104)+a|0)+484380|0,d|0,h|0,d+495|0)|0;m=v[23516];v[23516]=0;if((m|0)==1){break B}A=j^1|A}yb(h);e=e+1|0;h=w[d+235|0]|w[d+236|0]<<8;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;yb(h);break x}v[23516]=0;R(756,b|0,d+104|0);h=v[23516];v[23516]=0;if((h|0)==1){break y}h=d- -64|0;j=w[d+118|0];C:{if(!(j&48|w[d+121|0]!=173)){Uc(h,8,1,0,10);break C}Uc(h,j&16?16:8,j&32?3:1,0,2)}v[23516]=0;R(757,n|0,h|0);h=v[23516];v[23516]=0;if((h|0)!=1){F=Bb(v[i>>2],e),G=v[d+104>>2],v[F>>2]=G;m=w[d+121|0];h=v[d+160>>2];if(Oc(h,v[d+164>>2])>>>0>e>>>0){j=x[$b(h,e)>>1];v[23516]=0;h=(B(j,104)+a|0)+484380|0;R(758,d+104|0,h|0);r=v[23516];v[23516]=0;if((r|0)==1){break A}t[h+38|0]=w[o+202|0];t[h+39|0]=w[o+203|0];t[h+40|0]=w[o+204|0];t[h+41|0]=w[o+205|0];h=d+88|0;xl(h,3,D);v[23516]=0;R(221,d- -64|0,h|0);h=v[23516];v[23516]=0;if((h|0)==1){break z}h=d- -64|0;Ac(((j<<5)+a|0)+946304|0,h);wb(h);f=(w[d+118|0]&3)==3?(f&2)>>>1|0?f|4:f:f}q=m|q;e=e+1|0;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0}lc(i)}gd(d+160|0);break k}f=P()|0;O()|0;break k}lc(i);gd(d+160|0)}p=p+1|0;continue}}f=P()|0;O()|0;break c}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}D:{if(!(A&1)){break D}v[23516]=0;c=Q(1,d+104|0,16726)|0;e=v[23516];v[23516]=0;E:{if((e|0)!=1){e=v[a+1298464>>2];v[23516]=0;U(384,e|0,2,c|0);e=v[23516];v[23516]=0;if((e|0)==1){break E}xb(c);break D}f=P()|0;O()|0;break k}f=P()|0;O()|0;xb(c);break k}v[23516]=0;c=Q(410,b|0,5561)|0;e=v[23516];v[23516]=0;if((e|0)==1){break n}if(c){v[23516]=0;c=T(155,b|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break n}v[23516]=0;X(336,a+1298332|0,b|0,c|0,0);c=v[23516];v[23516]=0;if((c|0)==1){break n}f=f|16}v[23516]=0;o=Q(410,b|0,14175)|0;c=v[23516];v[23516]=0;if((c|0)==1){break l}if(o){v[23516]=0;c=T(155,b|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break l}v[23516]=0;e=a+901404|0;U(759,b|0,e|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break l}LA(e);f=f|16}v[23516]=0;c=Q(410,b|0,13937)|0;e=v[23516];v[23516]=0;if((e|0)==1){break l}if(!c){break m}v[23516]=0;c=T(155,b|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){u[d+208>>1]=c>>>5;F=d,G=vf(v[a+484344>>2],v[a+484348>>2]),u[F+64>>1]=G;c=x[Rc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break m}v[23516]=0;R(574,b|0,d+208|0);i=v[23516];v[23516]=0;F:{if((i|0)==1){break F}i=v[a+484344>>2];v[23516]=0;R(575,Xb(i,e)|0,d+208|0);i=v[23516];v[23516]=0;if((i|0)==1){break F}e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[23516]=0;c=Q(410,b|0,13942)|0;e=v[23516];v[23516]=0;if((e|0)==1){break l}G:{if(!c){break G}v[23516]=0;c=T(155,b|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){u[d+208>>1]=(c>>>0)/20;u[d+64>>1]=x[a+480188>>1];c=x[Rc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break G}v[23516]=0;U(421,b|0,((e<<5)+a|0)+480289|0,20);i=v[23516];v[23516]=0;if((i|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}c=v[b+8>>2];e=v[b>>2];v[23516]=0;c=W(154,e|0,c|0,8)|0;e=v[23516];v[23516]=0;if((e|0)==1){break l}H:{I:{J:{K:{if(c){c=v[b+8>>2];v[23516]=0;Q(422,a|0,b|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break K}f=(c|0)==v[b+8>>2]?f:f|16}L:{if(!(f&16)){break L}if(f&4){v[a+1074308>>2]=17367040;v[23516]=0;c=Q(1,d+208|0,14782)|0;e=v[23516];v[23516]=0;if((e|0)!=1){Gb(k,c);xb(c);break L}f=P()|0;O()|0;break k}if(!(f&2)){break L}v[a+1074308>>2]=18219008;v[23516]=0;c=Q(1,d+208|0,14945)|0;e=v[23516];v[23516]=0;if((e|0)==1){break J}Gb(k,c);xb(c)}M:{N:{O:{P:{Q:{R:{S:{if(!Qb(l,17711,8)){v[23516]=0;c=W(391,d- -64|0,d+558|0,12)|0;e=v[23516];v[23516]=0;if((e|0)==1){break S}v[23516]=0;U(11,d+160|0,1,c|0);e=v[23516];v[23516]=0;if((e|0)==1){break R}v[23516]=0;e=T(760,d+160|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break Q}v[a+1074308>>2]=e;xb(d+160|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;wb(c);f=24}if(!(!v[a+1074308>>2]|f&8)){t[a+1074368|0]=0;Zt(a+1074312|0)}c=f&32;T:{if(!c){break T}t[a+1074368|0]=5;if(!o){jq(a+901404|0)}if(x[d+570>>1]<260){break T}v[23516]=0;W(267,a+1074312|0,4,1)|0;e=v[23516];v[23516]=0;if((e|0)==1){break l}}if(!oh(v[k+4>>2],w[k+11|0])){break M}if(!(f&256)|q&255|g+1>>>0>1){break N}v[23516]=0;c=Q(1,d+160|0,8321)|0;g=v[23516];v[23516]=0;if((g|0)==1){break O}Gb(k,c);xb(c);break M}f=P()|0;O()|0;break k}f=P()|0;O()|0;break P}f=P()|0;O()|0;xb(d+160|0)}wb(c);break k}f=P()|0;O()|0;break k}if(c){v[23516]=0;c=Q(1,d+160|0,12105)|0;g=v[23516];v[23516]=0;if((g|0)!=1){Gb(k,c);xb(c);break M}f=P()|0;O()|0;break k}v[23516]=0;c=Q(1,d+160|0,9769)|0;g=v[23516];v[23516]=0;if((g|0)==1){break I}Gb(k,c);xb(c)}t[d+55|0]=0;U:{if(x[a+480192>>1]){v[23516]=0;c=Q(430,a|0,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break U}t[d+55|0]=c}v[23516]=0;X(431,a|0,b|0,1,d+55|0);b=v[23516];v[23516]=0;if((b|0)==1){break U}e=v[a+1074308>>2];V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if(w[d+55|0]){if(e>>>0>18284543){break ha}v[a+1074308>>2]=18284544;break ha}if(e>>>0<18284544){break ga}}v[23516]=0;b=Q(1,d+40|0,17711)|0;c=v[23516];v[23516]=0;if((c|0)==1){break fa}c=v[a+1074308>>2];v[23516]=0;R(761,d+24|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break ea}v[23516]=0;U(2,d+88|0,b|0,d+24|0);c=v[23516];v[23516]=0;if((c|0)==1){break da}c=d+88|0;Gb(k,c);xb(c);xb(d+24|0);xb(b);e=v[a+1074308>>2]}ia:{if(e-1>>>0>19005952){break ia}b=v[a+484344>>2];f=v[a+484348>>2];if(!te(b,f,254)){b=w[a+484376|0];c=v[a+484360>>2];v[23516]=0;Y(762,Sb(c,b)|0);b=v[23516];v[23516]=0;if((b|0)==1){break U}f=v[a+484348>>2];b=v[a+484344>>2]}if(te(b,f,255)){break ia}aA(Sb(v[a+484360>>2],w[a+484376|0]),255,65535)}v[23516]=0;R(763,d+24|0,4105);b=v[23516];v[23516]=0;if((b|0)==1){break ba}b=x[d+570>>1];v[d+20>>2]=b>>>8;v[23516]=0;v[d+4>>2]=b&255;R(441,d+8|0,d+4|0);b=v[23516];v[23516]=0;if((b|0)==1){break aa}v[23516]=0;X(427,d+88|0,d+24|0,d+20|0,d+8|0);b=v[23516];v[23516]=0;if((b|0)==1){break $}c=d+88|0;b=Gb(a+1298344|0,c);xb(c);xb(d+8|0);ac(d+24|0);Gb(a+1298368|0,k);v[a+1298404>>2]=C?8:v[a+1074308>>2]?8:5;if(!w[d+495|0]){break W}Gb(a+1298380|0,b);v[23516]=0;c=Q(1,d+88|0,15382)|0;g=v[23516];v[23516]=0;if((g|0)==1){break Z}Gb(b,c);xb(c);v[23516]=0;b=Q(1,d+24|0,10120)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Y}Gb(a+1298356|0,b);xb(b);v[23516]=0;b=Q(1,d+8|0,10121)|0;c=v[23516];v[23516]=0;if((c|0)==1){break X}Gb(a+1298392|0,b);break V}f=P()|0;O()|0;break k}f=P()|0;O()|0;break ca}f=P()|0;O()|0;xb(d+24|0)}xb(b);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break _}f=P()|0;O()|0;xb(d+8|0)}ac(d+24|0);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[23516]=0;b=Q(1,d+88|0,10121)|0;c=v[23516];v[23516]=0;if((c|0)==1){break H}Gb(a+1298356|0,b)}xb(b);lc(n);xb(k);break b}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0}lc(n);break c}f=P()|0;O()|0}xb(k);S(f|0);L()}e=1}hb=d+592|0;return e|0}function _ea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=hb-336|0;hb=e;xc(b);a:{b:{c:{if(!Et(b,e+240|0)){break c}if(!RQ(e+240|0)){break c}if(!Ob(v[b>>2],v[b+8>>2],Bc(QQ(e+240|0),kb))){break c}if(!c){s=1;break c}zd(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;i=Kb(e+224|0);d=x[e+280>>1];j=(d|0)==20479?x[e+294>>1]:d-16464|0;d:{e:{f:{g:{h:{i:{switch(d>>>12|0){case 0:if((d|0)!=520){break d}v[23516]=0;d=Q(1,e+208|0,12345)|0;g=v[23516];v[23516]=0;if((g|0)!=1){Gb(i,d);break e}b=P()|0;O()|0;break a;case 1:j:{if(x[e+302>>1]|(d|0)!=4896){break j}if(!(x[e+278>>1]&65455|(w[e+292|0]|w[e+272|0]&15))){k:{if(t[e+291|0]<0){v[a+1074308>>2]=18219008;v[23516]=0;d=Q(1,e+208|0,14852)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break k}b=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[23516]=0;d=Q(1,e+208|0,13395)|0;f=v[23516];v[23516]=0;if((f|0)==1){break h}}Gb(i,d);xb(d);v[23516]=0;f=1;W(267,a+1074312|0,81,1)|0;d=v[23516];v[23516]=0;g=1;if((d|0)!=1){break d}break b}if(w[e+293|0]|(w[e+292|0]|x[e+278>>1])){break j}v[23516]=0;d=Q(1,e+208|0,9505)|0;g=v[23516];v[23516]=0;if((g|0)!=1){Gb(i,d);break e}b=P()|0;O()|0;break a}v[23516]=0;d=Q(1,e+208|0,8523)|0;f=v[23516];v[23516]=0;k=1;if((f|0)!=1){Gb(i,d);xb(d);break f}b=P()|0;O()|0;break a;case 2:v[23516]=0;d=Q(1,e+208|0,6776)|0;f=v[23516];v[23516]=0;g=1;if((f|0)!=1){Gb(i,d);xb(d);break f}b=P()|0;O()|0;break a;case 3:l:{m:{n:{o:{if(d>>>0<=12820){v[23516]=0;f=Q(1,e+208|0,8586)|0;g=v[23516];v[23516]=0;if((g|0)!=1){Gb(i,f);xb(f);break o}b=P()|0;O()|0;break a}v[23516]=0;R(439,e+208|0,4018);f=v[23516];v[23516]=0;if((f|0)==1){break n}v[23516]=0;v[e+192>>2]=x[e+280>>1]-12820;U(440,e+48|0,e+208|0,e+192|0);f=v[23516];v[23516]=0;if((f|0)==1){break m}f=e+48|0;Gb(i,f);xb(f);ac(e+208|0)}f=x[e+280>>1];if(f>>>0<12807){break g}g=v[e+296>>2];if(g){break l}break g}b=P()|0;O()|0;break a}b=P()|0;O()|0;ac(e+208|0);break a}f=NC(f,g);g=po(e+48|0);v[g+44>>2]=f;v[23516]=0;R(442,a+1298408|0,g|0);f=v[23516];v[23516]=0;if((f|0)!=1){break g}b=P()|0;O()|0;break a;case 4:p:{q:{if((d|0)==16640){v[23516]=0;f=Q(1,e+208|0,8369)|0;g=v[23516];v[23516]=0;if((g|0)!=1){Gb(i,f);xb(f);f=81;break q}b=P()|0;O()|0;break a}v[23516]=0;U(443,e+48|0,d|0,x[e+294>>1]);f=v[23516];v[23516]=0;r:{if((f|0)!=1){f=e+48|0;Gb(i,f);xb(f);v[a+480260>>2]=1;if((j|0)<4201){break r}v[23516]=0;W(267,a+1074312|0,7,1)|0;g=v[23516];v[23516]=0;f=38;if((g|0)==1){break b}break q}b=P()|0;O()|0;break a}f=38;if((j|0)<2386){break p}}v[23516]=0;W(267,a+1074312|0,f|0,1)|0;f=v[23516];v[23516]=0;if((f|0)==1){break b}}h=(d|0)!=16640;g=1;f=0;break d;case 5:d=d&4095;v[a+1074308>>2]=d<<16|(d>>>0>296?x[e+294>>1]:0)&65535;v[23516]=0;d=Q(1,e+208|0,17711)|0;f=v[23516];v[23516]=0;s:{t:{u:{if((f|0)!=1){f=v[a+1074308>>2];v[23516]=0;R(138,e+192|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break u}f=0;v[23516]=0;U(2,e+48|0,d|0,e+192|0);g=v[23516];v[23516]=0;if((g|0)==1){break t}g=e+48|0;Gb(i,g);xb(g);xb(e+192|0);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break s}b=P()|0;O()|0;xb(e+192|0)}xb(d);break a;case 6:v[23516]=0;d=Q(1,e+208|0,8369)|0;h=v[23516];v[23516]=0;if((h|0)!=1){Gb(i,d);xb(d);v[23516]=0;W(267,a+1074312|0,81,1)|0;d=v[23516];v[23516]=0;h=0;if((d|0)==1){break b}break d}b=P()|0;O()|0;break a;case 7:v[23516]=0;d=Q(1,e+208|0,8381)|0;g=v[23516];v[23516]=0;if((g|0)!=1){Gb(i,d);break e}b=P()|0;O()|0;break a;default:break i}}if((d|0)!=51712){break d}v[23516]=0;d=Q(1,e+208|0,9304)|0;g=v[23516];v[23516]=0;if((g|0)!=1){Gb(i,d);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[23516]=0;f=W(267,a+1074312|0,7,1)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}v[23516]=0;f=W(267,f|0,23,1)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}v[23516]=0;f=W(267,f|0,38,1)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}v[23516]=0;W(267,f|0,107,1)|0;f=v[23516];v[23516]=0;if((f|0)==1){break b}g=1;v[a+480260>>2]=1;f=0;if(d>>>0>12820){break d}}v[23516]=0;Y(680,e+192|0);d=v[23516];v[23516]=0;v:{w:{x:{if((d|0)!=1){d=x[e+280>>1];v[e+160>>2]=d>>>8&15;v[23516]=0;v[e+136>>2]=d&255;R(441,e+176|0,e+136|0);d=v[23516];v[23516]=0;if((d|0)==1){break x}f=0;v[23516]=0;da(681,e+48|0,e+192|0,i|0,e+160|0,e+176|0);d=v[23516];v[23516]=0;if((d|0)==1){break w}d=e+48|0;Gb(i,d);xb(d);xb(e+176|0);ac(e+192|0);break d}b=P()|0;O()|0;break a}b=P()|0;O()|0;break v}b=P()|0;O()|0;xb(e+176|0)}ac(e+192|0);break a}xb(d);g=0}v[23516]=0;d=Q(1,e+192|0,15139)|0;l=v[23516];v[23516]=0;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{if((l|0)!=1){Gb(a+1298344|0,d);xb(d);v[23516]=0;d=Q(1,e+176|0,10493)|0;l=v[23516];v[23516]=0;if((l|0)==1){break H}Gb(a+1298356|0,d);xb(d);l=Gb(a+1298368|0,i);v[a+1298404>>2]=v[a+1074308>>2]?8:5;if(g){v[23516]=0;d=Q(268,a+1074312|0,77)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}v[23516]=0;d=Q(268,d|0,78)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}v[23516]=0;d=Q(268,d|0,79)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}v[23516]=0;d=Q(268,d|0,80)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}v[23516]=0;d=Q(268,d|0,82)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}v[23516]=0;d=Q(268,d|0,96)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}v[23516]=0;Q(268,d|0,113)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}}d=x[e+280>>1];g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|d>>>0>12819|f}v[23516]=0;d=a+901404|0;Y(682,d|0);g=v[23516];v[23516]=0;if((g|0)==1){break b}if(!f){jq(d)}d=e+160|0;Gi(d,1,e+240|0);v[23516]=0;R(221,e+48|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break C}d=e+48|0;yc(a+1298308|0,d);wb(d);d=x[e+278>>1];if(d&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(d&1){v[a+480208>>2]=v[a+480208>>2]|131072}o=x[e+280>>1];if(!(d&64?0:(o|0)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}d=w[e+289|0];v[a+480196>>2]=d;if(!d){break G}if((d|0)!=255){break F}if(k){break G}d=w[e+290|0];f=d>>>0<33;g=B(d,1e4);k=0;d=32e4;break D}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[a+480196>>2]=6;d=w[e+290|0];f=d>>>0<33;g=B(d,1e4);break E}d=w[e+290|0];f=d>>>0<33;g=B(d,1e4)}d=32e4;if(!k){break D}d=125e4}v[a+480204>>2]=f?d:g;t[e+48|0]=w[e+288|0];t[e+160|0]=64;d=w[Vb(e+48|0,e+160|0)|0];v[a+480200>>2]=d<<2;if(!(d|o>>>0>4895)){v[a+480200>>2]=256}g=w[e+291|0];I:{if(!(x[e+282>>1]!=1|g>>>0>7)){v[e+48>>2]=(g<<4)+16;v[e+160>>2]=127;f=v[od(e+48|0,e+160|0)>>2];break I}f=32;if((g|16)==18){break I}d=g&127;f=48;if(!d){break I}v[e+48>>2]=d;v[e+160>>2]=16;f=v[Ne(e+48|0,e+160|0)>>2]}v[a+480228>>2]=f;d=0;o=v[a+1074308>>2]!=0|g<<24>>24<0;if(!o){H=a,I=Bc(uka(f<<3|5,f>>>29|0,11,0),kb),v[H+480228>>2]=I}r=a+480188|0;u[r>>1]=4;v[a+480232>>2]=h?(j|0)<3299?64:36:36;f=wh(e+152|0);while(1){if((d|0)==32){d=a+480188|0;if(!x[d>>1]){u[d>>1]=1}d=w[a+484376|0];g=v[a+484360>>2];v[23516]=0;da(347,Sb(g,d)|0,b|0,x[e+272>>1],255,254);d=v[23516];v[23516]=0;if((d|0)!=1){o=Lb(e+160|0);v[23516]=0;W(216,b|0,o|0,x[e+274>>1])|0;d=v[23516];v[23516]=0;if((d|0)!=1){r=Lb(e+136|0);v[23516]=0;W(216,b|0,r|0,x[e+276>>1])|0;d=v[23516];v[23516]=0;J:{if((d|0)!=1){if(w[e+293|0]!=252){break B}d=0;v[23516]=0;R(683,b|0,e+48|0);g=v[23516];v[23516]=0;if((g|0)==1){break J}while(1){if((d|0)==32){break B}g=w[(e+48|0)+d|0];K:{if(!(g&32)){break K}if(k){Pc(e+32|0,f,d);if(zb(v[v[e+32>>2]>>2],v[e+36>>2])){break K}}u[((d<<5)+a|0)+480284>>1]=(((g&15)<<8|8)>>>0)/15}d=d+1|0;continue}}break A}break A}b=P()|0;O()|0;break z}b=P()|0;O()|0;break a}g=(d<<5)+a|0;j=g+480280|0;af(j);h=w[(d+e|0)+304|0];p=h&127;L:{if((h|0)!=255){h=h<<24>>24;u[r>>1]=d+1;if(o){u[g+480284>>1]=h&8?204:51}if((h|0)>=0){break L}}v[j>>2]=1024}if((p-16&255)>>>0<=13){u[g+480284>>1]=128;g=e+48|0;Pc(g,f,d);fo(g)}d=d+1|0;continue}}b=P()|0;O()|0;break a}u[e+48>>1]=x[e+274>>1];u[e+32>>1]=3999;f=x[Rc(e+48|0,e+32|0)>>1];u[a+480190>>1]=f;j=c&2;p=e+96|0;d=0;g=0;h=0;M:{N:{O:{while(1){if((f&65535)>>>0<=d>>>0){if(!k){break N}if(!(!(g&1)|h&65535)&x[e+280>>1]!=4864){break O}v[23516]=0;d=h&65535;f=W(267,a+1074312|0,79,d>>>0>1|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break A}v[23516]=0;d=d>>>0<2;f=W(267,f|0,107,d|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break A}v[23516]=0;W(267,f|0,38,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break A}v[23516]=0;d=h&65535;Q(131,l|0,(d>>>0>1?17272:17279)|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break A}if(d>>>0<2){break N}v[a+480228>>2]=48;break N}f=$b(v[o>>2],d);f=w[f|0]|w[f+1|0]<<8;v[23516]=0;f=Q(153,b|0,f<<4)|0;n=v[23516];v[23516]=0;if((n|0)==1){break M}P:{Q:{if(!f){break Q}v[23516]=0;f=Q(684,b|0,e+48|0)|0;n=v[23516];v[23516]=0;if((n|0)==1){break M}if(!f){break Q}v[23516]=0;f=d+1|0;n=(B(f,104)+a|0)+484380|0;U(685,e+48|0,n|0,k|0);m=v[23516];v[23516]=0;if((m|0)==1){break M}m=e+16|0;Gi(m,1,p);v[23516]=0;R(221,e+32|0,m|0);m=v[23516];v[23516]=0;if((m|0)==1){break P}m=((f<<5)+a|0)+946304|0;f=e+32|0;Ac(m,f);wb(f);if(w[e+48|0]>1){break Q}R:{if(!j|!v[e+64>>2]){break R}f=OQ(e+48|0);v[23516]=0;f=Q(153,b|0,f|0)|0;m=v[23516];v[23516]=0;if((m|0)==1){break A}if(!f){break R}f=e+32|0;NQ(f,w[e+78|0],w[e+79|0],x[e+282>>1]==1);v[23516]=0;W(218,f|0,n|0,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break A}g=1}h=x[e+88>>1]|h}d=d+1|0;f=x[a+480190>>1];continue}break}break A}v[23516]=0;d=Q(1,e+48|0,9769)|0;f=v[23516];v[23516]=0;if((f|0)==1){break A}Gb(l,d);xb(d)}s=1;if(!(c&1)){break y}c=x[e+280>>1];u[e+32>>1]=x[e+276>>1];u[e+16>>1]=255;y=x[Rc(e+32|0,e+16|0)>>1];v[23516]=0;k=a+484344|0;R(224,k|0,y|0);d=v[23516];v[23516]=0;if((d|0)==1){break M}z=c>>>0<4896;c=e+32|0;m=c|5;D=c|3;A=c|4;E=c|2;F=c|1;G=a+480188|0;h=0;p=0;n=0;while(1){if((h|0)==(y|0)){if(!z){break y}a=x[a+480188>>1];if((a|0)>(n+p|0)|(a|0)<=(p-n|0)){break y}d=vf(v[k>>2],v[k+4>>2])-1&65535;b=0;S:{if(vf(v[k>>2],v[k+4>>2])>>>0<=d>>>0){break S}while(1){c=b&65535;if(c>>>0>d>>>0){break S}a=ag(v[k>>2],c);f=v[a>>2];if(Nb(f,v[a+4>>2])){a=Cb(f);f=Cb(v[ag(v[k>>2],c)+4>>2]);c=hb-16|0;hb=c;v[c+8>>2]=a;while(1){if(Nb(a,f)){if(w[a+3|0]==31){t[a+3|0]=20;t[a+5|0]=w[a+5|0]|128}a=v[vk(c+8|0)>>2];continue}break}hb=c+16|0}b=b+1|0;continue}}break y}v[23516]=0;c=W(225,k|0,h&65535,64)|0;d=v[23516];v[23516]=0;if((d|0)==1){break M}T:{if(!c){break T}c=$b(v[r>>2],h);c=w[c|0]|w[c+1|0]<<8;if(!c){break T}v[23516]=0;c=Q(153,b|0,c<<4)|0;d=v[23516];v[23516]=0;if((d|0)==1){break M}if(!c){break T}v[23516]=0;Q(186,b|0,2)|0;c=v[23516];v[23516]=0;if((c|0)==1){break M}d=0;c=Xb(v[k>>2],h);c=xf(v[c>>2],v[v[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break T}f=d;v[23516]=0;l=T(204,b|0)|0;d=v[23516];v[23516]=0;U:{if((d|0)!=1){if(l){break U}d=64;if(f>>>0>62){continue}c=Xb(v[k>>2],h);d=f+1|0;c=xf(v[c>>2],v[v[c+48>>2]+12>>2],d);continue}break A}g=l&31;d=B(g,6)+c|0;q=sg(e+32|0);j=g>>>0<x[G>>1];C=j?d:q;if(l&32){v[23516]=0;R(263,e+16|0,b|0);g=v[23516];v[23516]=0;V:{W:{X:{if((g|0)!=1){q=Kc(e+16|0);g=w[e+16|0];if(g>>>0>239){break X}g=MQ((B(g>>>4|0,12)+(g&15)|0)+13|0);break W}break A}Y:{switch(g-254|0){case 0:break W;case 1:break Y;default:break V}}g=0}t[C|0]=g}t[(j?d+1|0:F)|0]=w[q|0]}Z:{if(!(l&64)){break Z}v[23516]=0;q=T(204,b|0)|0;g=v[23516];v[23516]=0;_:{if((g|0)!=1){g=j?d+2|0:E;q=q<<24>>24;t[e+16|0]=q;if((q|0)>-64){break _}t[g|0]=2;t[(j?d+4|0:A)|0]=w[e+16|0]^128;break Z}break A}t[g|0]=1;t[e+15|0]=64;H=j?d+4|0:A,I=w[Vb(e+16|0,e+15|0)|0],t[H|0]=I}$:{if(!(l&128)){break $}v[23516]=0;R(263,e+16|0,b|0);g=v[23516];v[23516]=0;aa:{ba:{if((g|0)!=1){JA(C,w[e+16|0],w[Kc(e+16|0)|0],0);l=j?d+3|0:D;g=w[l|0];if((g|0)==10){break aa}if((g|0)==31){break ba}if((g|0)!=20){break $}d=j?d+5|0:m;g=w[d|0];if((g&240)!=160|x[e+280>>1]>4895){break $}t[d|0]=g&15^136;break $}break A}d=w[(j?d+5|0:m)|0];if(d>>>0>15){z=0;break $}if(d>>>0<=7){n=n+1|0;break $}p=((d|0)!=8)+p|0;break $}if(w[(j?d+5|0:m)|0]|x[e+280>>1]>4865){break $}t[l|0]=37}d=f;continue}}h=h+1|0;continue}}}b=P()|0;O()|0;gd(r)}gd(o);break a}gd(r);gd(o);xb(i)}hb=e+336|0;return s|0}b=P()|0;O()|0}xb(i);S(b|0);L()}function Md(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=hb-16|0;hb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){f=v[116024];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=f>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+464136|0;d=v[a+464144>>2];a=v[d+8>>2];l:{if((b|0)==(a|0)){m=464096,n=vka(-2,c)&f,v[m>>2]=n;break l}v[a+12>>2]=b;v[b+8>>2]=a}a=d+8|0;b=c<<3;v[d+4>>2]=b|3;b=b+d|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[116026];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;d=(c|a)+(b>>>a|0)|0;a=d<<3;b=a+464136|0;g=v[a+464144>>2];a=v[g+8>>2];m:{if((b|0)==(a|0)){f=vka(-2,d)&f;v[116024]=f;break m}v[a+12>>2]=b;v[b+8>>2]=a}v[g+4>>2]=h|3;c=g+h|0;a=d<<3;d=a-h|0;v[c+4>>2]=d|1;v[a+g>>2]=d;if(k){a=k>>>3|0;b=(a<<3)+464136|0;e=v[116029];a=1<<a;n:{if(!(a&f)){v[116024]=a|f;a=b;break n}a=v[b+8>>2]}v[b+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=b;v[e+8>>2]=a}a=g+8|0;v[116029]=c;v[116026]=d;break a}j=v[116025];if(!j){break k}b=(0-j&j)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+464400>>2];d=(v[b+4>>2]&-8)-h|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-h|0;e=c>>>0<d>>>0;d=e?c:d;b=e?a:b;c=a;continue}break}i=v[b+24>>2];e=v[b+12>>2];if((e|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=e;v[e+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;e=a;c=a+20|0;a=v[c>>2];if(a){continue}c=e+16|0;a=v[e+16>>2];if(a){continue}break}v[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=v[116025];if(!j){break k}d=0-h|0;f=0;p:{if(h>>>0<256){break p}f=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|h>>>a+21&1)+28|0}c=v[(f<<2)+464400>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=h<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-h|0;if(g>>>0>=d>>>0){break t}e=c;d=g;if(d){break t}d=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|e)){e=0;a=2<<f;a=(0-a|a)&j;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+464400>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-h|0;c=b>>>0<d>>>0;d=c?b:d;e=c?a:e;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!e|v[116026]-h>>>0<=d>>>0){break k}f=v[e+24>>2];b=v[e+12>>2];if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=e+20|0;a=v[c>>2];if(!a){a=v[e+16>>2];if(!a){break i}c=e+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[116026];if(c>>>0>=h>>>0){d=v[116029];b=c-h|0;u:{if(b>>>0>=16){v[116026]=b;a=d+h|0;v[116029]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=h|3;break u}v[116029]=0;v[116026]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[116027];if(i>>>0>h>>>0){b=i-h|0;v[116027]=b;c=v[116030];a=c+h|0;v[116030]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(v[116142]){c=v[116144]}else{v[116145]=-1;v[116146]=-1;v[116143]=4096;v[116144]=4096;v[116142]=l+12&-16^1431655768;v[116147]=0;v[116135]=0;c=4096}g=j+c|0;e=0-c|0;c=g&e;if(c>>>0<=h>>>0){break a}d=v[116134];if(d){b=v[116132];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[464540]&4){break f}v:{w:{d=v[116030];if(d){a=464544;while(1){b=v[a>>2];if(b>>>0<=d>>>0&d>>>0<b+v[a+4>>2]>>>0){break w}a=v[a+8>>2];if(a){continue}break}}b=lp(0);if((b|0)==-1){break g}f=c;d=v[116143];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=h>>>0|f>>>0>2147483646){break g}d=v[116134];if(d){a=v[116132];e=a+f|0;if(d>>>0<e>>>0|a>>>0>=e>>>0){break g}}a=lp(f);if((b|0)!=(a|0)){break v}break e}f=e&g-i;if(f>>>0>2147483646){break g}b=lp(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|h+48>>>0<=f>>>0)){b=v[116144];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((lp(b)|0)!=-1){f=b+f|0;b=a;break e}lp(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}e=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[116135]=v[116135]|4}if(c>>>0>2147483646){break d}b=v[23435];c=c+3&-4;a=b+c|0;x:{y:{if(!c|a>>>0>b>>>0){if(Sw()>>>0>=a>>>0){break y}if(xa(a|0)|0){break y}a=v[23435]}else{a=b}v[115992]=48;b=-1;break x}v[23435]=a}if(Sw()>>>0<a>>>0){if(!(xa(a|0)|0)){break d}}v[23435]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}f=a-b|0;if(f>>>0<=h+40>>>0){break d}}a=v[116132]+f|0;v[116132]=a;if(a>>>0>y[116133]){v[116133]=a}z:{A:{B:{g=v[116030];if(g){a=464544;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break B}a=v[a+8>>2];if(a){continue}break}break A}a=v[116028];if(!(a>>>0<=b>>>0?a:0)){v[116028]=b}a=0;v[116137]=f;v[116136]=b;v[116032]=-1;v[116033]=v[116142];v[116139]=0;while(1){d=a<<3;c=d+464136|0;v[d+464144>>2]=c;v[d+464148>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116027]=c;a=a+b|0;v[116030]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116031]=v[116146];break z}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break A}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[116030]=c;b=v[116027]+f|0;a=b-a|0;v[116027]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[116031]=v[116146];break z}if(y[116028]>b>>>0){v[116028]=b}d=b+f|0;c=464544;C:{while(1){if((d|0)!=v[c>>2]){a=464544;c=v[c+8>>2];if(c){continue}break C}break}a=464544;if(w[c+12|0]&8){break C}v[c>>2]=b;v[c+4>>2]=v[c+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=h|3;e=d+(d+8&7?-8-d&7:0)|0;i=h+j|0;c=e-i|0;D:{if((e|0)==(g|0)){v[116030]=i;a=v[116027]+c|0;v[116027]=a;v[i+4>>2]=a|1;break D}if(v[116029]==(e|0)){v[116029]=i;a=v[116026]+c|0;v[116026]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break D}a=v[e+4>>2];if((a&3)==1){f=a&-8;E:{if(a>>>0<=255){d=v[e+8>>2];a=a>>>3|0;b=v[e+12>>2];if((b|0)==(d|0)){m=464096,n=v[116024]&vka(-2,a),v[m>>2]=n;break E}v[d+12>>2]=b;v[b+8>>2]=d;break E}h=v[e+24>>2];b=v[e+12>>2];F:{if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break F}G:{a=e+20|0;d=v[a>>2];if(d){break G}a=e+16|0;d=v[a>>2];if(d){break G}b=0;break F}while(1){g=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break E}d=v[e+28>>2];a=(d<<2)+464400|0;H:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break H}m=464100,n=v[116025]&vka(-2,d),v[m>>2]=n;break E}v[h+(v[h+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break E}}v[b+24>>2]=h;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break E}v[b+20>>2]=a;v[a+24>>2]=b}c=c+f|0;e=e+f|0;a=v[e+4>>2]}v[e+4>>2]=a&-2;v[i+4>>2]=c|1;v[c+i>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+464136|0;c=v[116024];a=1<<a;I:{if(!(c&a)){v[116024]=a|c;a=b;break I}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break D}a=31;if(c>>>0<=16777215){a=c>>>8|0;e=a+1048320>>>16&8;a=a<<e;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(d|e))|0;a=(a<<1|c>>>a+21&1)+28|0}v[i+28>>2]=a;v[i+16>>2]=0;v[i+20>>2]=0;e=(a<<2)+464400|0;J:{d=v[116025];b=1<<a;K:{if(!(d&b)){v[116025]=b|d;v[e>>2]=i;v[i+24>>2]=e;break K}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[e>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break J}b=a>>>29|0;a=a<<1;e=d+(b&4)|0;b=v[e+16>>2];if(b){continue}break}v[e+16>>2]=i;v[i+24>>2]=d}v[i+12>>2]=i;v[i+8>>2]=i;break D}a=v[d+8>>2];v[a+12>>2]=i;v[d+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=d;v[i+8>>2]=a}a=j+8|0;break a}while(1){L:{c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break L}}a=v[a+8>>2];continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116027]=c;a=a+b|0;v[116030]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116031]=v[116146];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[116139];v[c+16>>2]=v[116138];v[c+20>>2]=a;a=v[116137];v[c+8>>2]=v[116136];v[c+12>>2]=a;v[116138]=c+8;v[116137]=f;v[116136]=b;v[116139]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break z}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){a=e>>>3|0;b=(a<<3)+464136|0;c=v[116024];a=1<<a;M:{if(!(c&a)){v[116024]=a|c;a=b;break M}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break z}a=31;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;v[g+16>>2]=0;v[g+20>>2]=0;d=(a<<2)+464400|0;N:{c=v[116025];b=1<<a;O:{if(!(c&b)){v[116025]=b|c;v[d>>2]=g;v[g+24>>2]=d;break O}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((e|0)==(v[b+4>>2]&-8)){break N}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break z}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[116027];if(a>>>0<=h>>>0){break d}b=a-h|0;v[116027]=b;c=v[116030];a=c+h|0;v[116030]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;v[115992]=48;break a}P:{if(!f){break P}c=v[e+28>>2];a=(c<<2)+464400|0;Q:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break Q}j=vka(-2,c)&j;v[116025]=j;break P}v[f+(v[f+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break P}}v[b+24>>2]=f;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break P}v[b+20>>2]=a;v[a+24>>2]=b}R:{if(d>>>0<=15){a=d+h|0;v[e+4>>2]=a|3;a=a+e|0;v[a+4>>2]=v[a+4>>2]|1;break R}v[e+4>>2]=h|3;f=e+h|0;v[f+4>>2]=d|1;v[d+f>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+464136|0;c=v[116024];a=1<<a;S:{if(!(c&a)){v[116024]=a|c;a=b;break S}a=v[b+8>>2]}v[b+8>>2]=f;v[a+12>>2]=f;v[f+12>>2]=b;v[f+8>>2]=a;break R}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[f+28>>2]=a;v[f+16>>2]=0;v[f+20>>2]=0;b=(a<<2)+464400|0;T:{c=1<<a;U:{if(!(c&j)){v[116025]=c|j;v[b>>2]=f;break U}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);h=v[b>>2];while(1){b=h;if((v[b+4>>2]&-8)==(d|0)){break T}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=v[c+16>>2];if(h){continue}break}v[c+16>>2]=f}v[f+24>>2]=b;v[f+12>>2]=f;v[f+8>>2]=f;break R}a=v[b+8>>2];v[a+12>>2]=f;v[b+8>>2]=f;v[f+24>>2]=0;v[f+12>>2]=b;v[f+8>>2]=a}a=e+8|0;break a}V:{if(!i){break V}c=v[b+28>>2];a=(c<<2)+464400|0;W:{if(v[a>>2]==(b|0)){v[a>>2]=e;if(e){break W}m=464100,n=vka(-2,c)&j,v[m>>2]=n;break V}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=e;if(!e){break V}}v[e+24>>2]=i;a=v[b+16>>2];if(a){v[e+16>>2]=a;v[a+24>>2]=e}a=v[b+20>>2];if(!a){break V}v[e+20>>2]=a;v[a+24>>2]=e}X:{if(d>>>0<=15){a=d+h|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break X}v[b+4>>2]=h|3;e=b+h|0;v[e+4>>2]=d|1;v[d+e>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+464136|0;g=v[116029];a=1<<a;Y:{if(!(a&f)){v[116024]=a|f;a=c;break Y}a=v[c+8>>2]}v[c+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=a}v[116029]=e;v[116026]=d}a=b+8|0}hb=l+16|0;return a|0}function u6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=hb-32|0;hb=g;a:{b:{c:{d:{e:{if(re(b,21751)){Kb(a);break e}if(re(b,9912)){b=hb-128|0;hb=b;f=Kb(a);v[23516]=0;Y(132,b+96|0);a=v[23516];v[23516]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[23516]=0;v[b+64>>2]=0;R(1068,b+80|0,b- -64|0);a=v[23516];v[23516]=0;if((a|0)==1){break p}v[23516]=0;a=Q(820,f|0,b+80|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break o}wb(b+80|0);v[23516]=0;a=Q(955,a|0,16868)|0;c=v[23516];v[23516]=0;q:{if((c|0)==1){break q}v[23516]=0;v[b+64>>2]=7;R(1068,b+80|0,b- -64|0);c=v[23516];v[23516]=0;if((c|0)==1){break n}v[23516]=0;a=Q(820,a|0,b+80|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break m}wb(b+80|0);v[23516]=0;a=Q(955,a|0,16868)|0;c=v[23516];v[23516]=0;if((c|0)==1){break q}v[23516]=0;v[b+64>>2]=0;R(1068,b+80|0,b- -64|0);c=v[23516];v[23516]=0;if((c|0)==1){break l}v[23516]=0;a=Q(820,a|0,b+80|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break k}c=b+80|0;wb(c);v[23516]=0;c=Q(53,c|0,14973)|0;d=v[23516];v[23516]=0;if((d|0)==1){break j}d=Fb(c);wb(c);if(!d){break i}v[23516]=0;Q(955,a|0,14973)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;wb(b+80|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;wb(b+80|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;wb(b+80|0);break h}a=P()|0;O()|0;break h}c=Lb(b- -64|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=v[b+108>>2];if(d){v[23516]=0;v[b+16>>2]=d;R(1068,b+32|0,b+16|0);d=v[23516];v[23516]=0;if((d|0)==1){break D}v[23516]=0;U(981,b+48|0,8993,b+32|0);d=v[23516];v[23516]=0;if((d|0)==1){break C}v[23516]=0;R(181,c|0,b+48|0);d=v[23516];v[23516]=0;if((d|0)==1){break B}wb(b+48|0);wb(b+32|0)}if(!Sd(w[b+112|0])){break x}v[23516]=0;d=Q(53,b+48|0,12806)|0;e=v[23516];v[23516]=0;if((e|0)==1){break z}v[23516]=0;R(181,c|0,d|0);e=v[23516];v[23516]=0;if((e|0)==1){break y}wb(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;wb(b+48|0)}wb(b+32|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;wb(d);break r}if(!Sd(w[b+113|0])){break w}v[23516]=0;d=Q(53,b+48|0,12577)|0;e=v[23516];v[23516]=0;if((e|0)==1){break v}v[23516]=0;R(181,c|0,d|0);e=v[23516];v[23516]=0;if((e|0)==1){break u}wb(d)}if(Sd(w[b+114|0])){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;wb(d);break r}v[23516]=0;d=Q(53,b+32|0,11102)|0;e=v[23516];v[23516]=0;E:{if((e|0)!=1){v[23516]=0;R(181,c|0,d|0);e=v[23516];v[23516]=0;if((e|0)==1){break E}wb(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;wb(d);break r}if(nc(v[c>>2],v[c+4>>2])){break f}v[23516]=0;a=Q(955,a|0,16898)|0;d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;d=Q(53,b|0,16868)|0;e=v[23516];v[23516]=0;F:{G:{H:{if((e|0)!=1){v[23516]=0;U(1069,b+16|0,c|0,d|0);e=v[23516];v[23516]=0;if((e|0)==1){break H}v[23516]=0;Q(820,a|0,b+16|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break G}wb(b+16|0);wb(d);break f}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;wb(b+16|0)}wb(d);break r}a=P()|0;O()|0}Me(c)}Af(b+96|0)}wb(f);break a}Me(c);Af(b+96|0);hb=b+128|0;break e}if(re(b,8161)){v[g>>2]=0;wp(a,g);break e}if(re(b,8139)){v[g>>2]=7;wp(a,g);break e}if(re(b,10822)){v[g>>2]=0;wp(a,g);break e}if(re(b,10615)){Fc(a,14973);break e}if(re(b,11439)){b=Fc(g,14973);c=Fb(b);v[23516]=0;Q(53,a|0,(c?15903:15573)|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break d}wb(b);break e}if(re(b,7372)){b=hb-48|0;hb=b;SD(b+16|0);v[23516]=0;Y(149,b|0);c=v[23516];v[23516]=0;I:{J:{K:{L:{if((c|0)!=1){v[23516]=0;U(150,b+32|0,b+16|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break L}v[23516]=0;R(1029,a|0,b+32|0);a=v[23516];v[23516]=0;if((a|0)==1){break K}xb(b+32|0);xb(b);xb(b+16|0);hb=b+48|0;break e}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;xb(b+32|0)}xb(b)}xb(b+16|0);break a}if(re(b,9928)){b=hb-16|0;hb=b;e=hb-16|0;hb=e;v[e+8>>2]=101;c=hb-112|0;hb=c;f=Lb(c+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[e+8>>2];if(d&1){v[23516]=0;R(138,c- -64|0,19988497);d=v[23516];v[23516]=0;if((d|0)==1){break $}v[23516]=0;R(122,f|0,c- -64|0);d=v[23516];v[23516]=0;if((d|0)==1){break _}xb(c- -64|0);d=v[e+8>>2]}if(!(d&4)){break Y}v[23516]=0;d=ha(139)|0;h=v[23516];v[23516]=0;if((h|0)==1){break X}if(!d){break Z}break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;xb(c- -64|0);break N}v[23516]=0;Y(140,c- -64|0);d=v[23516];v[23516]=0;aa:{if((d|0)!=1){v[23516]=0;R(122,f|0,c- -64|0);d=v[23516];v[23516]=0;if((d|0)==1){break aa}xb(c- -64|0);break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;xb(c- -64|0);break N}ba:{d=v[e+8>>2];if(!(d&32)){break ba}v[23516]=0;Y(132,c- -64|0);d=v[23516];v[23516]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((d|0)!=1){v[23516]=0;R(141,c+48|0,c- -64|0);d=v[23516];v[23516]=0;if((d|0)==1){break da}d=oh(v[c+52>>2],w[c+59|0]);xb(c+48|0);if(!d){v[23516]=0;Y(142,c+32|0);d=v[23516];v[23516]=0;if((d|0)==1){break ua}v[23516]=0;R(141,c+16|0,c- -64|0);d=v[23516];v[23516]=0;if((d|0)==1){break ta}v[23516]=0;U(143,c+48|0,c+32|0,c+16|0);d=v[23516];v[23516]=0;if((d|0)==1){break sa}v[23516]=0;R(122,f|0,c+48|0);d=v[23516];v[23516]=0;if((d|0)==1){break ra}xb(c+48|0);xb(c+16|0);ac(c+32|0)}d=So(c- -64|0);if(!oh(v[d+4>>2],w[d+11|0])){v[23516]=0;Y(144,c+32|0);h=v[23516];v[23516]=0;if((h|0)==1){break oa}v[23516]=0;U(145,c+48|0,c+32|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break na}v[23516]=0;R(122,f|0,c+48|0);d=v[23516];v[23516]=0;if((d|0)==1){break ma}xb(c+48|0);ac(c+32|0)}v[23516]=0;R(146,c+48|0,c- -64|0);d=v[23516];v[23516]=0;if((d|0)==1){break ka}d=oh(v[c+52>>2],w[c+59|0]);xb(c+48|0);if(!d){v[23516]=0;Y(142,c+32|0);d=v[23516];v[23516]=0;if((d|0)==1){break ja}v[23516]=0;R(146,c+16|0,c- -64|0);d=v[23516];v[23516]=0;if((d|0)==1){break ia}v[23516]=0;U(143,c+48|0,c+32|0,c+16|0);d=v[23516];v[23516]=0;if((d|0)==1){break ha}v[23516]=0;R(122,f|0,c+48|0);d=v[23516];v[23516]=0;if((d|0)==1){break ga}xb(c+48|0);xb(c+16|0);ac(c+32|0)}Af(c- -64|0);d=v[e+8>>2];break ba}d=P()|0;O()|0;break N}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break pa}d=P()|0;O()|0;break qa}d=P()|0;O()|0;xb(c+48|0)}xb(c+16|0)}ac(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break la}d=P()|0;O()|0;xb(c+48|0)}ac(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ea}d=P()|0;O()|0;break fa}d=P()|0;O()|0;xb(c+48|0)}xb(c+16|0)}ac(c+32|0);break ca}d=P()|0;O()|0}Af(c- -64|0);break N}va:{if(!(d&64)){break va}v[23516]=0;d=ha(139)|0;h=v[23516];v[23516]=0;if((h|0)==1){break X}if(d){break va}d=c- -64|0;Kb(d);v[23516]=0;R(122,f|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break O}xb(c- -64|0)}if(w[e+8|0]&128){v[23516]=0;Y(147,c- -64|0);d=v[23516];v[23516]=0;if((d|0)==1){break W}v[23516]=0;R(122,f|0,c- -64|0);d=v[23516];v[23516]=0;if((d|0)==1){break V}xb(c- -64|0)}v[23516]=0;h=Q(1,c- -64|0,21751)|0;d=v[23516];v[23516]=0;if((d|0)==1){break U}v[23516]=0;U(148,c|0,f|0,h|0);d=v[23516];v[23516]=0;if((d|0)==1){break T}v[23516]=0;Y(149,c+48|0);d=v[23516];v[23516]=0;if((d|0)==1){break S}v[23516]=0;U(150,b|0,c|0,c+48|0);d=v[23516];v[23516]=0;if((d|0)==1){break R}xb(c+48|0);xb(c);xb(h);Il(f);hb=c+112|0;break M}d=P()|0;O()|0;break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;xb(c- -64|0);break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;break P}d=P()|0;O()|0;break Q}d=P()|0;O()|0;xb(c+48|0)}xb(c)}xb(h);break N}d=P()|0;O()|0;xb(c- -64|0)}Il(f);S(d|0);L()}hb=e+16|0;v[23516]=0;R(1029,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(b);hb=b+16|0;break e}break b}if(re(b,10544)){b=hb-48|0;hb=b;nr(b);v[23516]=0;R(141,b+32|0,b|0);c=v[23516];v[23516]=0;wa:{xa:{if((c|0)!=1){v[23516]=0;R(1029,a|0,b+32|0);a=v[23516];v[23516]=0;if((a|0)==1){break xa}xb(b+32|0);Af(b);hb=b+48|0;break e}a=P()|0;O()|0;break wa}a=P()|0;O()|0;xb(b+32|0)}Af(b);break a}if(re(b,11402)){b=hb-32|0;hb=b;nr(b);v[23516]=0;R(1029,a|0,So(b)|0);a=v[23516];v[23516]=0;if((a|0)!=1){Af(b);hb=b+32|0;break e}a=P()|0;O()|0;Af(b);break a}if(re(b,9941)){b=hb-48|0;hb=b;nr(b+16|0);c=v[b+28>>2];ya:{if(c){v[23516]=0;v[b+12>>2]=c;R(1068,a|0,b+12|0);a=v[23516];v[23516]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;Af(b+16|0);break a}Kb(a)}Af(b+16|0);hb=b+48|0;break e}if(re(b,12796)){nr(g);b=w[g+16|0];v[23516]=0;Q(53,a|0,(Sd(b)?15573:15903)|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){Af(g);break e}a=P()|0;O()|0;Af(g);break a}if(re(b,9957)){nr(g);b=w[g+17|0];v[23516]=0;Q(53,a|0,(Sd(b)?15573:15903)|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){Af(g);break e}a=P()|0;O()|0;Af(g);break a}if(re(b,12249)){nr(g);b=w[g+18|0];v[23516]=0;Q(53,a|0,(Sd(b)?15573:15903)|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){Af(g);break e}a=P()|0;O()|0;Af(g);break a}if(re(b,12551)){b=hb-16|0;hb=b;c=hb-32|0;hb=c;d=Kb(b);v[23516]=0;Y(132,c|0);f=v[23516];v[23516]=0;za:{Aa:{Ba:{if((f|0)!=1){v[23516]=0;R(133,d|0,So(c)|0);f=v[23516];v[23516]=0;if((f|0)==1){break Ba}Af(c);hb=c+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;Af(c)}xb(d);break a}v[23516]=0;R(1029,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(b);hb=b+16|0;break e}break b}if(re(b,8282)){b=hb-16|0;hb=b;c=hb-48|0;hb=c;d=Kb(b);v[23516]=0;R(135,c+16|0,4138);f=v[23516];v[23516]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((f|0)!=1){v[c+12>>2]=15;v[c+8>>2]=0;v[23516]=0;v[c+4>>2]=0;da(136,c+32|0,c+16|0,c+12|0,c+8|0,c+4|0);f=v[23516];v[23516]=0;if((f|0)==1){break Ga}v[23516]=0;Q(96,d|0,c+32|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break Fa}xb(c+32|0);ac(c+16|0);hb=c+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;xb(c+32|0)}ac(c+16|0)}xb(d);S(a|0);L()}v[23516]=0;R(1029,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(b);hb=b+16|0;break e}break b}if(re(b,6825)){b=hb-16|0;hb=b;_m(b,0,19697);v[23516]=0;R(1029,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(b);hb=b+16|0;break e}break b}if(re(b,6458)){b=hb-48|0;hb=b;c=vc(b+16|0,17758);v[23516]=0;R(1070,b|0,2);d=v[23516];v[23516]=0;Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){v[23516]=0;U(2,b+32|0,c|0,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break Ka}v[23516]=0;R(1029,a|0,b+32|0);a=v[23516];v[23516]=0;if((a|0)==1){break Ja}xb(b+32|0);xb(b);xb(c);hb=b+48|0;break e}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;xb(b+32|0)}xb(b)}xb(c);break a}if(re(b,11425)){b=hb-16|0;hb=b;_m(b,0,18097);v[23516]=0;R(1029,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(b);hb=b+16|0;break e}break b}if(re(b,10551)){b=hb-16|0;hb=b;kr(b,0);v[23516]=0;R(1029,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(b);hb=b+16|0;break e}break b}if(re(b,10526)){b=hb-16|0;hb=b;kr(b,2);v[23516]=0;R(1029,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(b);hb=b+16|0;break e}break b}if(re(b,10511)){b=hb-16|0;hb=b;kr(b,3);v[23516]=0;R(1029,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(b);hb=b+16|0;break e}break b}Kb(a)}hb=g+32|0;break c}a=P()|0;O()|0;wb(b);break a}return}a=P()|0;O()|0;xb(b)}S(a|0);L()}function zaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;c=v[a+1074308>>2];if(!(c>>>0>18285125|(c|0)==18284544)){Lf(a+1074312|0,0)}i=a+1074308|0;e=f+32|0;h=a+1074312|0;Ab(e,h,0);b=zb(v[v[f+32>>2]>>2],v[f+36>>2]);g=a+480180|0;c=v[g>>2];Ab(e,h,0);s=b&(c&16777248)!=0;E=zb(v[v[f+32>>2]>>2],v[f+36>>2]);F=v[g>>2];a:{c=v[a+1074308>>2];if(c>>>0>18874367){break a}e=!s;b=a+480192|0;d=1;while(1){b:{c=d&65535;if(c>>>0<=x[b>>1]){j=v[((c<<2)+a|0)+900380>>2];if(!j){break b}v[f+32>>2]=B(w[j+20|0],100)>>>6;v[f+16>>2]=100;G=j,H=v[Hb(f+32|0,f+16|0)>>2],t[G+20|0]=H;if(!(e|y[i>>2]<18350080)){break b}c=t[j+26|0];t[j+26|0]=((c>>31|1)+c|0)/2;if(!(e|y[i>>2]<18285314)){break b}NA(Gh(j,2),v[g>>2]);c=v[a+1074308>>2];c:{if(c>>>0<18284544){break c}if(c>>>0>18285135){break b}if(!w[j+34|0]){break c}if(!sj(w[j+31|0])){break c}Mb(h,2,1);if(y[i>>2]>18285135){break b}}if(!(w[j+24|0]|(w[j+23|0]|(w[j+19|0]|w[j+20|0])))){break b}Mb(h,1,1)}d:{if(!(v[a+480180>>2]&16777248)|y[i>>2]>18285313&s){break d}e=x[a+480190>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break d}d=B(b,104)+a|0;c=d+484419|0;if(!(w[c|0]|!(w[d+484421|0]|w[d+484420|0]))){t[c|0]=255}b=b+1|0;continue}}c=a+901404|0;d=xz(c);while(1){if((c|0)!=(d|0)){b=c;e=Wn(b);while(1){if((b|0)!=(e|0)){j=w[b|0];e:{f:{if((j-97&255)>>>0<=5){o=j-32|0;break f}if(!(j-88>>>0<2|j-120>>>0<2)){o=99;if((j|0)==75|(j|0)==107){break f}break e}o=122}t[b|0]=o}b=b+1|0;continue}break}c=c+32|0;continue}break}c=v[a+1074308>>2];break a}d=d+1|0;continue}}g:{h:{i:{if((c|0)==18874368|c>>>0>18874895){break i}if(!(v[a+480180>>2]&16777252)){break h}e=x[a+480192>>1]+1&65535;d=0;b=1;while(1){if((b|0)==(e|0)){if(!d){break i}Mb(h,3,1);c=v[i>>2]}else{g=v[((b<<2)+a|0)+900380>>2];if(!(!g|!w[g+31|0])){t[g+33|0]=13;d=1}b=b+1|0;continue}break}}if((c|0)==19005440|c>>>0>19006225){break g}}if(!(v[a+480180>>2]&16777248)){break g}Ab(f+32|0,h,0);if(!zb(v[v[f+32>>2]>>2],v[f+36>>2])){Ab(f+16|0,h,1);if(!zb(v[v[f+16>>2]>>2],v[f+20>>2])){break g}}c=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(c|0)){break g}e=v[((b<<2)+a|0)+900380>>2];if(!(!e|!w[e+19|0]|!(t[e+80|0]&1))){t[e+19|0]=0}b=b+1|0;continue}}j:{k:{l:{m:{n:{if(y[i>>2]>19007232){break n}b=a+906300|0;d=ck(b);while(1){if((b|0)==(d|0)){break n}c=f+16|0;e=b+80|0;nM(c,e);v[23516]=0;X(237,f+32|0,0,8,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break m}wb(f+16|0);c=f+32|0;wu(e,c);b=b+160|0;wb(c);continue}}o:{p:{q:{if(v[a+480180>>2]!=4){break q}d=v[i>>2];if(d>>>0<19007257){break o}if(d>>>0>19071235){break p}if(w[a+1074368|0]!=4){break q}oy(a,5)}d=v[i>>2]}if(d>>>0>19202054){break l}c=19202048;if((d|0)==19202048){break k}}j=x[a+480192>>1]+1&65535;c=1;while(1){if((c|0)==(j|0)){break l}m=v[((c<<2)+a|0)+900380>>2];r:{if(!m|!w[m+20|0]|!w[m+31|0]){break r}b=m+236|0;g=rq(b);while(1){if((b|0)!=(g|0)){e=x[b>>1];b=b+2|0;if(!e){continue}break r}break}t[m+20|0]=0}c=c+1|0;continue}}a=P()|0;O()|0;wb(f+16|0);S(a|0);L()}c=d;if(c>>>0>19267583){break j}}d=!s;e=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break j}g=v[((b<<2)+a|0)+900380>>2];s:{if(!g){break s}c=t[g+26|0];t[g+26|0]=((c>>31|1)+c|0)/2;c=v[i>>2];if(!(d|c>>>0<18350080)){break s}t[g+19|0]=w[g+19|0]+3>>>2}b=b+1|0;continue}}t:{if(c>>>0>19398673){break t}d=x[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break t}e=v[((e<<2)+a|0)+900380>>2];if(!e|w[e+65|0]==255){b=b+1|0;continue}else{Mb(h,94,1);c=v[i>>2]}break}}u:{if(c>>>0>19399427){break u}d=x[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break u}e=v[((e<<2)+a|0)+900380>>2];if(!e|w[e+36|0]>1){b=b+1|0;continue}else{Mb(h,101,1);c=v[i>>2]}break}}v:{if(c>>>0>19923027){break v}e=x[a+480190>>1];b=1;while(1){c=b&65535;if(c>>>0>e>>>0){break v}c=B(c,104)+a|0;if(!Vd(v[c+484380>>2],v[c+484400>>2])|!(w[c+484414|0]&20)){b=b+1|0;continue}else{Mb(h,116,1)}break}}c=hb-16|0;hb=c;u[f+12>>1]=0;v[f+8>>2]=a;Ab(c+8|0,a+1074312|0,0);G=f,H=zb(v[v[c+8>>2]>>2],v[c+12>>2]),t[G+14|0]=H;hb=c+16|0;c=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=c;c=hb-16|0;hb=c;p=a+484344|0;d=v[p+4>>2];e=v[p>>2];g=v[f+4>>2];b=v[f>>2];v[c>>2]=b;v[c+4>>2]=g;v[c+8>>2]=b;v[c+12>>2]=g;o=vf(e,d)-1&65535;e=hb-32|0;hb=e;A=v[c>>2];C=v[c+4>>2];w:{if(vf(v[p>>2],v[p+4>>2])>>>0<=o>>>0){break w}while(1){g=D&65535;if(g>>>0>o>>>0){break w}d=ag(v[p>>2],g);b=v[d>>2];if(Nb(b,v[d+4>>2])){b=Cb(b);j=Cb(v[ag(v[p>>2],g)+4>>2]);v[e+24>>2]=A;v[e+28>>2]=C;v[e+8>>2]=A;v[e+12>>2]=C;n=e+8|0;z=hb-16|0;hb=z;v[z+8>>2]=b;while(1){if(Nb(b,j)){q=hb-16|0;hb=q;m=x[n+4>>1];g=m+1|0;u[n+4>>1]=g;d=v[n>>2];u[n+4>>1]=x[d+480188>>1]>(g&65535)>>>0?g:0;x:{if($g(w[b|0])){break x}k=v[d+1074308>>2];y:{r=v[d+480180>>2];z:{A:{if((r|0)==2){if(k>>>0>18415615){break A}if(w[b+3|0]!=23){break z}sf(b+5|0,64);break z}if(r&16777248){B:{C:{if(k>>>0>=18285314){if(w[n+6|0]){break C}l=0;d=0;if(k>>>0>18874367){break B}}D:{switch(w[b+3|0]-20|0){case 3:sf(b+5|0,128);break C;case 0:break D;default:break C}}d=w[b+5|0];if((d|0)!=208){if((d|0)!=192){break C}t[b|0]=254;t[b+3|0]=0;break C}t[b+3|0]=0}E:{F:{G:{if(k>>>0>=18350080){if(w[n+6|0]){break G}l=0;d=0;if(k>>>0>18874367){break B}}d=w[b+3|0];if(d>>>0>29){break F}l=1;if(!(1<<d&536873152)){break F}break E}l=0;d=0;if(k>>>0>18874367){break B}d=w[b+3|0]}l=0}d=(d|0)==24|(d|0)==22}H:{if(!(d?1:l)){break H}d=w[b+5|0];g=d&15;if(!g|(g|0)==15){break H}d=d&240;if(!d|(d|0)==240){break H}t[b+5|0]=w[b+3|0]==24?d:g}I:{if((k|0)==19005440|k>>>0>19005699){break I}d=x[v[n>>2]+480192>>1];if(w[n+6|0]|(!d|d>>>0>=w[b+1|0])){break I}t[b+4|0]=0;t[b+2|0]=1}if(w[b+3|0]!=18|w[b+5|0]!=17){break A}if(k>>>0>19468801){break y}Ab(q+8|0,v[n>>2]+1074312|0,22);if(!zb(v[v[q+8>>2]>>2],v[q+12>>2])|v[v[n>>2]+480208>>2]&4){break A}t[b+5|0]=0;break A}if((r|0)!=4){break A}d=!w[n+6|0];J:{if((d|k>>>0<18285314)&k>>>0<18874368){break J}if(k>>>0>19137025){break y}if(w[b+3|0]!=23|w[b+5|0]<65){break J}t[b+3|0]=0}K:{L:{M:{if(!(d&k>>>0<18874368?0:k>>>0>=18415616)){l=w[b+3|0];d=w[b+2|0];if((l|0)!=10|(d|0)!=11){break M}l=0;t[b+3|0]=0;break K}if(k>>>0>18874639){break L}l=w[b+3|0];d=w[b+2|0]}if((d|0)!=11|(l|0)!=4){break K}g=w[b+4|0];if(!(g|w[n+6|0])){l=4;break K}l=4;d=w[b+5|0];if(!d){break K}t[b+2|0]=0;G=b,H=ju(d+(g<<4)|0),t[G+5|0]=H;break K}if(k>>>0>19007240){break y}l=w[b+3|0]}if(w[b+5|0]|(l|0)!=16){break A}t[b+3|0]=0}if(k>>>0>18874367){break y}}l=w[b+3|0];g=w[b+5|0]&240;N:{O:{if((l|0)!=28|(g|0)!=96){d=0}else{if(!w[n+6|0]|(r|0)!=4){break O}d=k>>>0<18350080}if(!(d|(l|0)==20&(g|0)==96)){break N}}d=B(m,-6)+b|0;while(1){if(b>>>0>d>>>0){if(!((w[d+3|0]|8)!=28|(w[d+5|0]&240)!=96)){t[d+3|0]=0}d=d+6|0;continue}break}l=w[b+3|0]}if((l|0)!=20|(g|0)!=224){break y}d=B(m,-6)+b|0;while(1){if(b>>>0<=d>>>0){break y}if(!(w[d+3|0]!=20|(w[d+5|0]&240)!=224)){t[d+3|0]=0}d=d+6|0;continue}}d=w[b+2|0];if(!((d|0)!=8|k>>>0>19333174|(k|0)==19333120)){g=w[b+4|0];m=w[b+3|0];if(!(!g|(m|0)!=7)){t[b+3|0]=11;break x}P:{Q:{switch(m-5|0){default:if((m|0)!=26){break x}break;case 1:break x;case 2:break P;case 0:break Q}}d=w[b+5|0];if(!(d&15)){t[b+2|0]=0;t[b+3|0]=5;t[b+5|0]=d|g&15;break x}R:{switch(m-5|0){case 1:break x;case 0:case 2:break P;default:break R}}if((m|0)!=26){break x}}t[b+2|0]=0;break x}if(!(w[b+3|0]|((r|0)==16777216|(d|0)!=15))){t[b+2|0]=0;t[b+3|0]=10;t[b+5|0]=w[b+4|0]<<3;break x}if(w[b+3|0]!=10|k>>>0>19922963|(d|0)!=15){break x}if(w[b+4|0]?w[b+5|0]:1){t[b+2|0]=0;break x}t[b+3|0]=0}hb=q+16|0;b=v[vk(z+8|0)>>2];continue}break}b=v[n+4>>2];v[e+16>>2]=v[n>>2];v[e+20>>2]=b;hb=z+16|0}D=D+1|0;continue}}v[f+32>>2]=A;v[f+36>>2]=C;hb=e+32|0;hb=c+16|0;S:{c=y[a+1074308>>2]<19267584;if(c&s){b=42048;while(1){if((b|0)==42392){break S}e=v[i>>2];c=v[b+4>>2];Mb(h,v[b>>2],e>>>0>=c>>>0|(e|0)==(c&-65536));b=b+8|0;continue}}if(!(c&((F|0)==4&E))){break S}b=42400;while(1){if((b|0)==42640){break S}Mb(h,v[b>>2],y[i>>2]>=y[b+4>>2]);b=b+8|0;continue}}T:{U:{c=v[a+480180>>2];if(c&16777248){b=42640;while(1){if((b|0)==42696){break U}d=v[i>>2];e=v[b+4>>2];c=e&-65536;if(!(d>>>0>=c>>>0&(d>>>0>=e>>>0|c>>>0>=d>>>0))){Lf(h,v[b>>2])}b=b+8|0;continue}}b=42768;d=42704;V:{switch(c-2|0){case 2:while(1){if((d|0)==42768){break U}if(y[i>>2]<y[d+4>>2]){Lf(h,v[d>>2])}d=d+8|0;continue};case 0:break V;default:break T}}while(1){if((b|0)==42856){break U}if(y[i>>2]<y[b+4>>2]){Lf(h,v[b>>2])}b=b+8|0;continue}}c=v[a+480180>>2]}W:{if((c|0)==4){b=v[i>>2];if(b>>>0>18415615){break W}Mb(h,98,1)}b=v[i>>2]}d=8;if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){c=b+77|0;Ab(f+32|0,h,c);Lf(Mb(h,b+86|0,zb(v[v[f+32>>2]>>2],v[f+36>>2])),c);b=b+1|0;continue}break}b=v[i>>2]}X:{if(b>>>0>=18284544){if(b>>>0>18874627){break X}d=6;if((b|0)==18874368){break X}}Mb(h,d,1)}c=v[a+1074308>>2];Y:{if(w[a+480208|0]&16){if(c>>>0<=19136511){Lf(h,7);break Y}if(!(v[a+480180>>2]&16777248)|c>>>0>19267583){break Y}Mb(h,7,1);break Y}if((c|0)==19922944|c>>>0>19922997){break Y}Lf(h,7)}Ab(f+32|0,h,31);Z:{if(!zb(v[v[f+32>>2]>>2],v[f+36>>2])){break Z}c=v[i>>2];if(c>>>0<19071234|c>>>0>19398722){break Z}e=x[a+480192>>1];b=1;while(1){c=b&65535;if(c>>>0>e>>>0){break Z}_:{d=v[((c<<2)+a|0)+900380>>2];if(!d){break _}c=w[d+65|0];if(!(w[d+60|0]&4)|(c|0)==255|c>>>0<=w[d- -64|0]){break _}Mb(h,97,1);break Z}b=b+1|0;continue}}d=v[a+480180>>2];$:{if(!(d&16777218)){break $}e=x[a+480190>>1];b=1;while(1){c=b&65535;if(c>>>0>e>>>0){break $}b=b+1|0;if(!(w[(B(c,104)+a|0)+484415|0]&2)){continue}break}aa:{ba:{ca:{if(!(!x[a+480192>>1]|(d|0)!=16777216)){b=v[i>>2];if(b>>>0<19398688){break ba}if(b>>>0>19464277){break ca}Mb(h,109,1)}b=v[i>>2]}if((b|0)==19922944|b>>>0>19922996){break aa}}Lf(h,111);b=v[i>>2]}c=v[a+480180>>2];if(!((c|0)!=2|b>>>0>19464191)){Mb(h,108,1);break $}if((c|0)==2){break $}Lf(h,108)}c=v[i>>2];da:{ea:{if(c>>>0<19333186){break ea}if(c>>>0<=19923013){if(!(v[a+480180>>2]&16777252)){break ea}b=a+906300|0;e=ck(b);while(1){if((b|0)!=(e|0)){fa:{if((w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24))!=1146637647|(w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24))!=-271958638){break fa}if((ad(v[b+4>>2],v[b+8>>2])|0)!=32){break fa}c=Fc(f+32|0,16949);wu(b+80|0,c);wb(c)}b=b+160|0;continue}break}c=v[i>>2]}if(c>>>0>19988488){break da}}if(!(v[a+480180>>2]&16777252)){break da}b=a+906300|0;c=ck(b);while(1){if((b|0)==(c|0)){break da}a=b;b=b+160|0;if(!zi(v[a+16>>2],v[a+20>>2])){continue}break}Mb(h,117,1)}hb=f+48|0}function oW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a:{n=Fh(b,13911);if(!n){break a}o=a+480192|0;b:while(1){if(!Ob(v[b>>2],v[b+8>>2],6)){break a}c:{f=zg(b);d:{if((f|0)==(Lm(13730)|0)){break d}c=w[21727]|w[21728]<<8|(w[21729]<<16|w[21730]<<24);if(!(f&1616928864)|f&-2139062144){break d}if((c|0)!=(f|0)){break c}}wg(b,4);break a}l=1;c=Ng(b);while(1){d=l&65535;if(d>>>0>x[o>>1]){continue b}d=v[((d<<2)+a|0)+900380>>2];if(d){e:{g=0;if((Lm(16852)|0)==(f|0)){Yb(b,c);break e}e=hb-48|0;hb=e;f:{if(!d){break f}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{switch(f-1349079874|0){default:if((f|0)==1095062094){break v}if((f|0)==1095126087){break s}if((f|0)==1129524782){break B}if((f|0)==1145263150){break Y}if((f|0)==1145979182){break X}if((f|0)==1179463214){break z}if((f|0)==1851469358){break F}if((f|0)==1179931728){break n}$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{if((f|0)!=1196830254){if((f|0)==1229341486){break U}if((f|0)==1229345326){break T}if((f|0)==1264266798){break G}if((f|0)==1296182830){break S}if((f|0)==1296248366){break Q}if((f|0)==1297100334){break R}if((f|0)==1297110852){break q}if((f|0)==1298747438){break D}if((f|0)==1313692462){break H}if((f|0)==1313751342){break Z}if((f|0)==1345203758){break ja}if((f|0)==1346711086){break l}if((f|0)==1346720334){break w}if((f|0)==1346722606){break J}if((f|0)==1346784327){break t}if((f|0)==1347175726){break da}if((f|0)==1347179310){break ea}if((f|0)==1347437358){break O}if((f|0)==1347441454){break P}if((f|0)==1347443502){break M}if((f|0)==1347628590){break W}if((f|0)==1347633710){break ca}if((f|0)==1347634478){break ba}if((f|0)==1347703884){break o}if((f|0)==1347831112){break y}if((f|0)==1347833672){break x}if((f|0)==1349076270){break k}if((f|0)==1349076315){break I}if((f|0)==1349078085){break $}if((f|0)==1349078099){break aa}if((f|0)==1349079131){break L}if((f|0)==1378758190){break p}if((f|0)==1381183022){break A}if((f|0)==1447374382){break m}if((f|0)==1447383630){break u}if((f|0)==1447385902){break K}if((f|0)==1447447623){break r}if((f|0)==1447839022){break ha}if((f|0)==1447842606){break ia}if((f|0)==1448106798){break N}if((f|0)==1448226350){break C}if((f|0)==1448291886){break V}if((f|0)==1448297006){break ga}if((f|0)==1448297774){break fa}if((f|0)!=1682320942){if((f|0)==1718508334){break E}if((f|0)!=1179594286|c>>>0>4){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=$u(b,c),v[p>>2]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+15|0]=q;break g}if(c>>>0>4){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=$u(b,c),v[p+4>>2]=q;break g}if(c>>>0>4){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=$u(b,c),v[p+8>>2]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+61|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+62|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+63|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d- -64|0,q=Ad(b,c),t[p|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+81|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+82|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+83|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+84|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+101|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+102|0]=q;break g;case 0:if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+103|0]=q;break g;case 3:break _;case 1:case 2:break f}}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+104|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+16|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+17|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+18|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+19|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+20|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+21|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+22|0]=q;break g}if(c>>>0>2){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=LC(b,c),u[p+28>>1]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+30|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+31|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=KC(b,c),t[p+26|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+27|0]=q;break g}Wd(e,b,c);i=hc(e+24|0,e);yb(e);j=Gh(d,0);h=v[j>>2];while(1){if(Qd(h,v[j+4>>2])>>>0<=g>>>0){yb(i);break g}v[23516]=0;k=T(195,i|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break j}h=v[j>>2];p=Bb(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}}Wd(e,b,c);i=hc(e+24|0,e);yb(e);j=Gh(d,1);h=v[j>>2];while(1){if(Qd(h,v[j+4>>2])>>>0<=g>>>0){yb(i);break g}v[23516]=0;k=T(195,i|0)|0;h=v[23516];v[23516]=0;if((h|0)!=1){h=v[j>>2];p=Bb(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Wd(e,b,c);i=hc(e+24|0,e);yb(e);j=Gh(d,2);h=v[j>>2];while(1){if(Qd(h,v[j+4>>2])>>>0<=g>>>0){yb(i);break g}v[23516]=0;k=T(195,i|0)|0;h=v[23516];v[23516]=0;if((h|0)!=1){h=v[j>>2];p=Bb(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Wd(e,b,c);i=hc(e+24|0,e);yb(e);j=Gh(d,0);h=v[j>>2];while(1){if(Qd(h,v[j+4>>2])>>>0<=g>>>0){yb(i);break g}v[23516]=0;k=T(196,i|0)|0;h=v[23516];v[23516]=0;if((h|0)!=1){h=v[j>>2];p=Bb(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Wd(e,b,c);i=hc(e+24|0,e);yb(e);j=Gh(d,1);h=v[j>>2];while(1){if(Qd(h,v[j+4>>2])>>>0<=g>>>0){yb(i);break g}v[23516]=0;k=T(196,i|0)|0;h=v[23516];v[23516]=0;if((h|0)!=1){h=v[j>>2];p=Bb(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Wd(e,b,c);i=hc(e+24|0,e);yb(e);j=Gh(d,2);h=v[j>>2];while(1){if(Qd(h,v[j+4>>2])>>>0<=g>>>0){yb(i);break g}v[23516]=0;k=T(196,i|0)|0;h=v[23516];v[23516]=0;if((h|0)!=1){h=v[j>>2];p=Bb(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>128){break f}h=d+108|0;Wd(e,b,c);i=hc(e+24|0,e);yb(e);while(1){if((g|0)==128){yb(i);break g}v[23516]=0;j=T(196,i|0)|0;k=v[23516];v[23516]=0;if((k|0)!=1){p=Ib(h,g),q=j,t[p|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>256){break f}h=d+236|0;Wd(e,b,c);i=hc(e+24|0,e);yb(e);while(1){if((g|0)==128){yb(i);break g}v[23516]=0;j=T(195,i|0)|0;k=v[23516];v[23516]=0;if((k|0)!=1){p=$b(h,g),q=j,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>32){break f}j=d+492|0;Wd(e,b,c);i=hc(e+24|0,e);yb(e);h=Kb(e);while(1){if((c|0)==(g|0)){break h}v[23516]=0;k=T(197,i|0)|0;m=v[23516];v[23516]=0;ka:{if((m|0)==1){break ka}v[23516]=0;Q(198,h|0,k|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break ka}g=g+1|0;continue}break}g=P()|0;O()|0;wb(h);break i}if(c>>>0>32){break f}j=d+524|0;Wd(e,b,c);i=hc(e+24|0,e);yb(e);h=Kb(e);la:{while(1){if((c|0)!=(g|0)){v[23516]=0;k=T(197,i|0)|0;m=v[23516];v[23516]=0;if((m|0)==1){break la}v[23516]=0;Q(198,h|0,k|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break la}g=g+1|0;continue}break}Ac(j,h);wb(h);yb(i);break g}g=P()|0;O()|0;wb(h);break i}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+34|0]=q;break g}if(c>>>0>2){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=LC(b,c),u[p+12>>1]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+23|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+24|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+25|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+35|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+36|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+105|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+85|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+65|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+100|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+80|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Ad(b,c),t[p+60|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=KC(b,c),t[p+33|0]=q;break g}g=1;i=Do(b,c);if(!Co(i)){break f}t[d+14|0]=i;break f}p=d,q=B(Zu(b,c),1e4)+(y[d+40>>2]%1e4|0)|0,v[p+40>>2]=q;break g}g=Zu(b,c);i=v[d+40>>2];v[d+40>>2]=i-((i>>>0)%1e4|0)+(g>>>0)%1e4;break g}v[e+24>>2]=240;p=e,q=Do(b,c),v[p>>2]=q;Mg(d+48|0,v[Hb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=Do(b,c),v[p>>2]=q;Mg(d+68|0,v[Hb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=Do(b,c),v[p>>2]=q;Mg(d+88|0,v[Hb(e+24|0,e)>>2]);break g}g=P()|0;O()|0}yb(i);S(g|0);L()}Ac(j,h);wb(h);yb(i)}g=1}hb=e+48|0;if(!g){Yb(b,c);break e}if((Lm(16857)|0)==(f|0)){e=w[d+15|0];t[d+15|0]=0;t[d+100|0]=w[d+100|0]&224|(e>>>5&4|e>>>6&1);t[d+60|0]=e>>>1&2|(e<<1&4|(w[d+60|0]&240|e&1));t[d+80|0]=w[d+80|0]&240|(e>>>4&2|(e>>>2&4|e>>>3&1))}}}l=l+1|0;continue}}}return n|0}function HV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=hb-304|0;hb=e;xc(b);if(Kq(b,17924)){o=Kb(e+288|0);v[23516]=0;f=Q(232,b|0,o|0)|0;g=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{if((g|0)!=1){if(!f){break a}v[23516]=0;f=Q(247,b|0,e+280|0)|0;g=v[23516];v[23516]=0;g:{if((g|0)==1){break g}if(!f){break a}if(!TB(w[e+280|0],w[e+281|0])){break a}f=Bc(SB(e+280|0),kb);g=v[b+8>>2];m=v[b>>2];v[23516]=0;f=W(154,m|0,g|0,f|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break g}if(!f){break a}if(!c){break b}v[23516]=0;R(248,a|0,4096);d=v[23516];v[23516]=0;if((d|0)==1){break g}v[23516]=0;R(249,a+1298308|0,o|0);d=v[23516];v[23516]=0;if((d|0)==1){break g}d=w[e+282|0];u[a+480188>>1]=32;u[a+480192>>1]=d;jh(a,1);v[23516]=0;d=Q(1,e+264|0,9505)|0;f=v[23516];v[23516]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){Gb(a+1298344|0,d);xb(d);v[23516]=0;d=Q(1,e+248|0,7053)|0;f=v[23516];v[23516]=0;if((f|0)==1){break p}Gb(a+1298356|0,d);xb(d);v[23516]=0;Y(250,e+48|0);d=v[23516];v[23516]=0;if((d|0)==1){break o}t[e+216|0]=w[e+281|0];v[23516]=0;t[e+8|0]=w[e+280|0];R(251,e+232|0,e+8|0);d=v[23516];v[23516]=0;if((d|0)==1){break n}v[23516]=0;X(252,e+96|0,e+48|0,e+216|0,e+232|0);d=v[23516];v[23516]=0;if((d|0)==1){break m}d=e+96|0;Gb(a+1298368|0,d);xb(d);xb(e+232|0);ac(e+48|0);v[a+1298404>>2]=5;if(w[e+280|0]<2){break i}u[e+96>>1]=8192;v[23516]=0;d=T(192,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break k}u[e+48>>1]=d;r=a,s=B(x[ie(e+96|0,e+48|0)>>1],1e4)>>>8|0,v[r+480204>>2]=s;v[23516]=0;t[e+96|0]=1;d=T(204,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break j}t[e+48|0]=d;r=a,s=w[ef(e+96|0,e+48|0)|0],v[r+480196>>2]=s;v[23516]=0;Q(186,b|0,3)|0;d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;d=T(192,b|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break h}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break l}b=P()|0;O()|0;xb(e+232|0)}ac(e+48|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+96|0]=32;v[23516]=0;d=T(204,b|0)|0;f=v[23516];v[23516]=0;q:{if((f|0)!=1){t[e+48|0]=d;r=a,s=B(w[ef(e+96|0,e+48|0)|0],1e4),v[r+480204>>2]=s;v[23516]=0;t[e+96|0]=1;d=T(204,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break q}t[e+48|0]=d;r=a,s=w[ef(e+96|0,e+48|0)|0],v[r+480196>>2]=s;v[23516]=0;d=T(204,b|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break h}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;m=Lb(e+232|0);p=e+96|12;n=Lb(e+216|0);h=a+480190|0;i=1;while(1){r:{s:{d=i&65535;if(d>>>0>x[a+480192>>1]){break s}v[23516]=0;f=W(253,a|0,d|0,0)|0;d=v[23516];v[23516]=0;t:{if((d|0)==1){break t}if(!f){break s}v[23516]=0;d=Q(242,b|0,f+492|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break t}if(!d){break s}v[23516]=0;k=T(204,b|0)|0;d=v[23516];v[23516]=0;u:{v:{w:{if((d|0)!=1){Rb(e+96|0,0,120);if(!k){break r}x:{if(w[e+280|0]){v[23516]=0;d=Q(254,b|0,e+96|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break w}if(!d){break r}if(w[e+280|0]){break x}}d=v[fc(e+88|0,p,96)>>2];v[23516]=0;X(163,e+48|0,b|0,d|0,v[e+92>>2]);d=v[23516];v[23516]=0;if((d|0)==1){break v}if(!v[e+52>>2]){break r}}g=f+236|0;d=0;break u}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){if((d|0)!=120){r=$b(g,d),s=(w[(e+96|0)+d|0]+x[h>>1]|0)+1|0,u[r>>1]=s;d=d+1|0;continue}break}v[23516]=0;d=f+48|0;U(255,e+8|0,d|0,b|0);g=v[23516];v[23516]=0;if((g|0)==1){break e}v[23516]=0;g=f+68|0;U(255,e+32|0,g|0,b|0);j=v[23516];v[23516]=0;if((j|0)==1){break e}v[23516]=0;j=f+88|0;U(255,e+80|0,j|0,b|0);l=v[23516];v[23516]=0;if((l|0)==1){break e}v[23516]=0;R(256,b|0,e+72|0);l=v[23516];v[23516]=0;if((l|0)==1){break f}v[f>>2]=(w[e+73|0]|w[e+74|0]<<8)&4095;l=w[e+73|0]|w[e+74|0]<<8;Bu(w[e+75|0]|w[e+76|0]<<8,d,0);Bu(w[e+75|0]|w[e+76|0]<<8,g,1);Bu(w[e+75|0]|w[e+76|0]<<8,j,2);r=e,s=Cb(v[d>>2]),v[r+48>>2]=s;l=l>>>12&3;q=Cb(v[f+52>>2]);while(1){d=v[e+48>>2];if(Nb(d,q)){t[e+44|0]=64;t[e+70|0]=((w[d+2|0]<<6)- -64>>>0)/127;r=d,s=w[Vb(e+44|0,e+70|0)|0],t[r+2|0]=s;Ie(e+48|0);continue}else{r=e,s=Cb(v[g>>2]),v[r+48>>2]=s;d=Cb(v[f+72>>2])}break}while(1){g=v[e+48>>2];if(Nb(g,d)){t[e+44|0]=64;t[e+70|0]=((w[g+2|0]<<6)+128>>>0)/255;r=g,s=w[Vb(e+44|0,e+70|0)|0],t[r+2|0]=s;Ie(e+48|0);continue}break}r=e,s=Cb(v[j>>2]),v[r+48>>2]=s;j=1<<l;l=Cb(v[f+92>>2]);while(1){d=v[e+48>>2];if(Nb(d,l)){g=d;d=t[d+2|0];d=rka(d^-128,d>>31^-1,j,0);f=kb;y:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break y}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}r=g,s=Dc(d,f)^128,t[r+2|0]=s;Ie(e+48|0);continue}else{f=x[h>>1]+1|0;u[e+70>>1]=f;d=0;f=f&65535;g=4e3-f|0;g=g>>>0>4e3?0:g;z:{A:{B:{while(1){if((d|0)==(k|0)){break A}if((d|0)==(g|0)){v[23516]=0;Q(186,b|0,20)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break A}b=P()|0;O()|0;break d}v[23516]=0;j=d+f|0;Q(242,b|0,((j<<5)+a|0)+946304|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break z}v[23516]=0;R(257,b|0,e+48|0);l=v[23516];v[23516]=0;C:{if((l|0)==1){break C}v[23516]=0;R(258,e+48|0,(B(j,104)+a|0)+484380|0);j=v[23516];v[23516]=0;if((j|0)==1){break C}v[23516]=0;u[e+44>>1]=w[e+72|0]|d<<8&32512|((w[e+67|0]&3)!=0)<<15;R(259,n|0,e+44|0);j=v[23516];v[23516]=0;if((j|0)==1){break B}d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[23516]=0;R(259,m|0,e+70|0);d=v[23516];v[23516]=0;if((d|0)!=1){v[e+48>>2]=3999;v[e+44>>2]=k+x[h>>1];r=h,s=v[od(e+48|0,e+44|0)>>2],u[r>>1]=s;break r}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}}}b=P()|0;O()|0;break d}d=Kb(e+96|0);v[23516]=0;f=Q(232,b|0,d|0)|0;g=v[23516];v[23516]=0;D:{E:{F:{G:{H:{if((g|0)!=1){I:{if(f){v[23516]=0;U(11,e+48|0,7,d|0);f=v[23516];v[23516]=0;if((f|0)==1){break I}f=e+48|0;Gb(a+1298320|0,f);xb(f)}wb(d);d=0;J:{while(1){if((d|0)==32){v[23516]=0;d=Q(260,b|0,e+32|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break G}if(!d){break F}d=v[e+32>>2];if(d>>>0<12){break H}f=v[b+8>>2];g=v[b>>2];v[23516]=0;d=W(154,g|0,f|0,d-11|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break G}if(d){break J}break H}f=(d<<5)+a|0;af(f+480280|0);v[23516]=0;R(233,b|0,f+480289|0);f=v[23516];v[23516]=0;if((f|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}d=v[e+32>>2]-11|0;v[e+80>>2]=d;h=Lb(e+96|0);v[23516]=0;U(236,b|0,h|0,d|0);d=v[23516];v[23516]=0;K:{if((d|0)!=1){v[e+48>>2]=50529027;d=e+48|0;r=e,s=B(v[Hb(e+80|0,d)>>2],85),v[r+72>>2]=s;g=Kb(d);v[e+8>>2]=v[e+36>>2];d=v[Hb(e+72|0,e+8|0)>>2];v[23516]=0;R(44,g|0,d|0);d=v[23516];v[23516]=0;L:{if((d|0)==1){break L}d=0;M:{while(1){f=v[e+80>>2];if(f>>>0<=d>>>0){break M}i=v[h>>2];k=w[Ib(i,d)|0];j=f;f=d+1|0;if(!((k|0)!=255|j-f>>>0<2)){f=t[Ib(i,f)|0];i=w[Ib(i,d+2|0)|0];r=e,s=uh(g),v[r+8>>2]=s;k=v[hj(e+24|0,e+8|0)>>2];v[23516]=0;X(239,g|0,k|0,i|0,f|0);f=v[23516];v[23516]=0;if((f|0)!=1){d=d+3|0;continue}break L}v[23516]=0;R(45,g|0,k<<24>>24);i=v[23516];v[23516]=0;d=f;if((i|0)!=1){continue}break}break L}v[23516]=0;X(237,e+8|0,5,7,g|0);d=v[23516];v[23516]=0;if((d|0)!=1){N:{f=e+8|0;d=yc(g,f);wb(f);f=Ic(d);i=Fb(d);v[23516]=0;da(238,a+1298332|0,f|0,i|0,74,0);f=v[23516];v[23516]=0;if((f|0)==1){break N}wb(d);dc(h);break H}}}b=P()|0;O()|0;wb(g);break K}b=P()|0;O()|0}dc(h);break d}}b=P()|0;O()|0;wb(d);break d}d=w[a+484376|0];f=v[a+484360>>2];v[23516]=0;U(240,Sb(f,d)|0,b|0,w[e+285|0]|w[e+286|0]<<8);d=v[23516];v[23516]=0;if((d|0)==1){break G}i=c&1;if(i){v[23516]=0;R(224,a+484344|0,w[e+283|0]|w[e+284|0]<<8);d=v[23516];v[23516]=0;if((d|0)==1){break G}}h=a+484344|0;f=b;d=0;while(1){O:{if((w[e+283|0]|w[e+284|0]<<8)>>>0>d>>>0){b=v[f+8>>2];g=v[f>>2];v[23516]=0;b=W(154,g|0,b|0,4)|0;g=v[23516];v[23516]=0;if((g|0)==1){break D}if(b){break O}}if(!(c&2)){break F}d=0;c=a+480190|0;while(1){b=x[c>>1];if(d>>>0>=b>>>0){d=0;f=a+480190|0;while(1){if(b>>>0<=d>>>0){break F}c=x[$b(v[n>>2],d)>>1];g=c&255;P:{if(!g){break P}h=v[m>>2];g=g-1&65535;if(Oc(h,v[m+4>>2])>>>0<=g>>>0){break P}j=b;b=x[$b(h,g)>>1]+(c>>>8&127)&65535;if(j>>>0<b>>>0){break P}b=B(b,104);g=b+a|0;c=g+484380|0;h=v[c>>2];if(!Vd(h,v[g+484400>>2])){break P}g=b;b=a+484380|0;g=g+b|0;i=x[g+34>>1];b=b+B(d+1|0,104)|0;v[b>>2]=h;u[b+34>>1]=x[b+34>>1]&65534|i&1;if(!Jg(b)){break P}pc(v[b+20>>2],v[g+20>>2],Fj(v[c>>2],x[c+34>>1]))}d=d+1|0;b=x[f>>1];continue}}b=x[$b(v[n>>2],d)>>1];if(b&255){d=d+1|0;continue}d=d+1|0;g=B(d,104)+a|0;b=Uc(e+96|0,u[g+484414>>1]&1?16:8,1,0,b<<16>>16>=0?0:6);v[23516]=0;W(218,b|0,g+484380|0,f|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){continue}break}b=P()|0;O()|0;break d}v[23516]=0;b=T(155,f|0)|0;g=v[23516];v[23516]=0;Q:{R:{S:{T:{if((g|0)!=1){v[23516]=0;U(188,e+48|0,f|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break T}b=e+48|0;g=hc(e+96|0,b);yb(b);if(!i){break R}v[23516]=0;b=T(204,g|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break Q}v[23516]=0;Q(186,g|0,1)|0;k=v[23516];v[23516]=0;if((k|0)==1){break Q}v[23516]=0;b=W(225,h|0,d&65535,b+1|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break Q}if(!b){break R}v[23516]=0;b=Q(234,g|0,e+48|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break E}if(!b){break S}b=v[h>>2];v[23516]=0;R(235,Xb(b,d)|0,e+48|0);b=v[23516];v[23516]=0;if((b|0)!=1){break S}break E}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=v[h>>2];v[23516]=0;U(241,Xb(b,d)|0,1,g|0);b=v[23516];v[23516]=0;if((b|0)==1){break E}}yb(g);d=d+1|0;continue}break}break E}b=P()|0;O()|0;break d}gd(n);gd(m);break b}b=P()|0;O()|0;yb(g);break d}b=P()|0;O()|0;break d}i=i+1|0;continue}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0}gd(n);gd(m)}wb(o);S(b|0);L()}d=1}wb(o)}hb=e+304|0;return d|0}function Fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=hb-368|0;hb=e;xc(b);g=e+344|0;f=WB(b,g);if(!f){Fu(g)}a:{b:{c:{d:{e:{if(!f){break e}if(!tU(e+344|0)){break e}if(!Ob(v[b>>2],v[b+8>>2],Bc(72,0))){break e}if(!c){d=1;break e}zd(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;g=w[e+353|0];u[a+480190>>1]=63;u[a+480188>>1]=g;f:{g:{while(1){if((g&65535)>>>0<=d>>>0){h:{d=1;i:{while(1){j:{g=d&65535;if(g>>>0>x[a+480190>>1]){$B(b,a+1298308|0);g=e+264|0;d=hb-16|0;hb=d;k:{if(!Ob(v[b>>2],v[b+8>>2],8)){t[d|0]=0;ci(g,8,d);break k}Tm(d+8|0,g);pd(d,b,v[d+8>>2],v[d+12>>2])}hb=d+16|0;n=Lb(e+248|0);g=x[e+354>>1];if(!g){break i}d=0;v[23516]=0;g=W(326,b|0,n|0,B(g,w[e+353|0])<<1)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break j}g=P()|0;O()|0;break a}f=(B(g,104)+a|0)+484380|0;jd(f,1);i=g+(e+272|0)|0;g=Je(b);t[i|0]=g;if(g<<24>>24>=0){A=f,C=rU(b)<<1,v[A>>2]=C}d=d+1|0;continue}break}if(!g){break f}}d=v[n>>2];ec(e+240|0,d,ad(d,v[n+4>>2])>>>1|0);l=Lb(e+224|0);v[23516]=0;R(327,l|0,x[e+356>>1]<<8);d=v[23516];v[23516]=0;if((d|0)==1){break h}d=0;l:{m:{n:{while(1){g=d&65535;d=x[e+356>>1];if(g>>>0>=d>>>0){break m}v[e+176>>2]=d-g;v[e+120>>2]=2e3;d=e+176|0;f=v[od(d,e+120|0)>>2];d=Lb(d);v[23516]=0;f=W(326,b|0,d|0,f<<8)|0;h=v[23516];v[23516]=0;if((h|0)==1){break l}if(!f){break n}f=cc(e+216|0,Cb(v[l+4>>2]));h=Cb(v[d>>2]);j=Cb(v[e+180>>2]);f=v[f>>2];v[23516]=0;X(328,l|0,f|0,h|0,j|0);f=v[23516];v[23516]=0;if((f|0)!=1){dc(d);d=g+2e3|0;continue}break}break c}dc(d);d=0;break g}oe(e+200|0,v[l>>2],v[l+4>>2]);Vg(e+208|0,v[e+200>>2],v[e+204>>2]);p=a+484376|0;d=w[p|0];g=v[a+484360>>2];v[23516]=0;R(329,Sb(g,d)|0,x[e+354>>1]);d=v[23516];v[23516]=0;if((d|0)==1){break d}q=a+484344|0;s=c&1;j=0;while(1){if(x[e+354>>1]<=j>>>0){h=c&2;g=1;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{while(1){c=g&65535;if(c>>>0>x[a+480190>>1]){break v}v[23516]=0;d=w[c+(e+272|0)|0];U(330,b|0,((c<<5)+a|0)+946304|0,d&63);f=v[23516];v[23516]=0;if((f|0)==1){break t}A:{B:{if(d<<24>>24<0){break B}v[23516]=0;d=T(331,b|0)|0;f=v[23516];v[23516]=0;C:{D:{E:{F:{G:{H:{I:{J:{if((f|0)==1){break J}c=B(c,104)+a|0;f=c+484392|0;v[f>>2]=d<<1;v[23516]=0;d=T(331,b|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break I}d=d<<1;if(d>>>0>=3){v[c+484396>>2]=d+v[f>>2];d=c+484414|0;u[d>>1]=x[d>>1]|8}v[23516]=0;d=T(204,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break s}t[e+40|0]=d;t[e+144|0]=64;A=c+484410|0,C=w[Vb(e+40|0,e+144|0)|0]<<2,u[A>>1]=C;v[23516]=0;d=T(204,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break J}t[c+484417|0]=d<<4;c=c+484380|0;lo(c);if(!v[c>>2]){break B}v[23516]=0;f=T(204,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break D}d=0;switch(f|0){case 4:case 5:break C;case 2:case 3:break F;case 1:break G;case 0:break H;default:break g}}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}if(h){f=Lb(e+40|0);j=v[b+8>>2];i=v[b>>2];k=v[c>>2];v[23516]=0;j=W(154,i|0,j|0,k|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break r}if(!j){break w}d=v[c>>2];v[23516]=0;U(332,b|0,f|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break r}A=e,C=Cb(v[f>>2]),v[A+144>>2]=C;j=Cb(v[e+44>>2]);while(1){d=v[e+144>>2];if(Nb(d,j)){i=d;d=w[d|0];t[i|0]=d<<7|(d^-1)<<24>>>25;He(e+144|0);continue}break}oe(e+168|0,v[f>>2],v[e+44>>2]);d=v[ce(e+160|0)>>2];v[23516]=0;d=ga(333,e+176|0,v[e+168>>2],v[e+172>>2],d|0,v[e+164>>2])|0;j=v[23516];v[23516]=0;K:{if((j|0)!=1){j=Uc(e+144|0,16,1,0,16);v[23516]=0;W(218,j|0,c|0,d|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break K}yb(d);dc(f);break B}g=P()|0;O()|0;break o}g=P()|0;O()|0;yb(d);break o}c=v[c>>2];break E}f=Lb(e+40|0);d=v[c>>2];v[23516]=0;U(334,e+144|0,b|0,d|0);d=v[23516];v[23516]=0;L:{M:{N:{if((d|0)!=1){d=e+144|0;j=Bm(f,d);dc(d);if(h){oe(e+112|0,v[j>>2],v[e+44>>2]);d=v[ce(e+104|0)>>2];v[23516]=0;d=ga(333,e+120|0,v[e+112>>2],v[e+116>>2],d|0,v[e+108>>2])|0;i=v[23516];v[23516]=0;if((i|0)==1){break N}i=Uc(e+144|0,8,1,0,2);v[23516]=0;W(218,i|0,c|0,d|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break M}yb(d)}dc(j);break B}g=V(30656)|0;if((O()|0)!=(ea(30656)|0)){break L}_(g|0)|0;d=0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)!=1){break u}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}g=P()|0;O()|0;yb(d)}dc(f);break b}if(h){d=Uc(e+40|0,(f|0)==2?8:16,1,0,0);v[23516]=0;W(218,d|0,c|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break B}g=P()|0;O()|0;break b}c=B(v[c>>2],f-1|0)}v[23516]=0;Q(186,b|0,c|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break B}}g=P()|0;O()|0;break b}j=Lb(e+40|0);d=v[c>>2];v[23516]=0;U(335,e+144|0,b|0,d|0);d=v[23516];v[23516]=0;O:{P:{if((d|0)!=1){i=e+144|0;d=Bm(j,i);dc(i);if(!h){break O}if((f|0)!=5){break P}A=e,C=Cb(v[d>>2]),v[A+144>>2]=C;k=Cb(v[e+44>>2]);while(1){i=v[e+144>>2];if(!Nb(i,k)){break P}m=i;i=w[i|0];t[m|0]=w[(i>>>7|0)+26529|0]^i;He(e+144|0);continue}}g=V(30656)|0;if((O()|0)!=(ea(30656)|0)){break x}_(g|0)|0;d=0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)!=1){break A}g=P()|0;O()|0;break x}oe(e+72|0,v[d>>2],v[e+44>>2]);i=v[ce(e- -64|0)>>2];v[23516]=0;i=ga(333,e+80|0,v[e+72>>2],v[e+76>>2],i|0,v[e+68>>2])|0;k=v[23516];v[23516]=0;if((k|0)==1){break z}f=(f|0)==5;f=Uc(e+144|0,f?16:8,1,0,f?16:1);v[23516]=0;W(218,f|0,c|0,i|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break y}yb(i)}dc(d)}g=g+1|0;continue}break}dc(j);break g}g=P()|0;O()|0;break x}g=P()|0;O()|0;yb(i)}dc(j);break b}dc(f);break g}Q:{R:{S:{T:{U:{V:{W:{d=x[e+358>>1]|w[e+360|0]<<16;if(d){c=Lb(e+144|0);v[23516]=0;b=W(326,b|0,c|0,d|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break q}if(!b){break U}oe(e+32|0,v[c>>2],v[c+4>>2]);b=ce(e+24|0);g=v[b+4>>2];b=v[b>>2];v[23516]=0;b=ga(333,e+40|0,v[e+32>>2],v[e+36>>2],b|0,g|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break W}v[23516]=0;X(336,a+1298332|0,b|0,d|0,1);d=v[23516];v[23516]=0;if((d|0)==1){break V}yb(b);dc(c)}v[23516]=0;Y(337,e+8|0);b=v[23516];v[23516]=0;if((b|0)==1){break T}v[23516]=0;U(212,e+144|0,e+8|0,w[e+352|0]);b=v[23516];v[23516]=0;if((b|0)==1){break S}b=e+144|0;Gb(a+1298344|0,b);xb(b);ac(e+8|0);v[23516]=0;b=Q(1,b|0,10115)|0;c=v[23516];v[23516]=0;if((c|0)==1){break R}Gb(a+1298356|0,b);xb(b);v[23516]=0;b=Q(1,e+8|0,5104)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Q}Gb(a+1298368|0,b);xb(b);v[a+1298404>>2]=10;d=1;break g}g=P()|0;O()|0;break p}g=P()|0;O()|0;yb(b);break p}dc(c);d=0;break g}g=P()|0;O()|0;break b}g=P()|0;O()|0;ac(e+8|0);break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}dc(f);break g}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break o}g=P()|0;O()|0}dc(c);break b}dc(f);break b}A=$b(v[Sb(v[a+484360>>2],w[p|0])>>2],j),C=j,u[A>>1]=C;X:{Y:{if(!s){break Y}v[23516]=0;r=j&65535;d=W(225,q|0,r|0,64)|0;g=v[23516];v[23516]=0;if((g|0)==1){break X}if(!d){break Y}f=x[a+480188>>1];i=0;while(1){d=f&65535;if(d>>>0<=i>>>0){break Y}d=$b(v[e+240>>2],B(d,j)+i|0);d=w[d|0]|w[d+1|0]<<8;Z:{if(d>>>0>=x[e+356>>1]){break Z}g=0;y=0-i|0;z=d<<8;d=Xb(v[q>>2],j);d=ed(v[d>>2],v[v[d+48>>2]+12>>2],0,i&65535);while(1){if((g|0)==64){break Z}uq(e+176|0,v[e+208>>2],v[e+212>>2],(g<<2)+z|0,4);f=v[e+176>>2];h=Ib(f,0);m=w[h|0]&63;t[d|0]=m?m+48|0:0;k=Ib(f,1);t[d+1|0]=w[k|0]<<2&60|w[h|0]>>>6;o=w[k|0];h=Ib(f,2);k=w[Ib(f,3)|0];f=w[h|0];h=k<<4|f>>>4;u[e+40>>1]=h;f=f<<2&60|o>>>6;_:{if(!(w[Ib(e+264|0,f>>>3|0)|0]>>>(f&7)&1)|!(h?1:f)){break _}t[d+5|0]=h;o=k>>>4|0;t[d+4|0]=o;$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{switch(f|0){case 0:case 1:case 2:case 32:case 33:case 34:Nf(d,f&15,h&255);if(!w[d+4|0]){break _}t[d+2|0]=f>>>0<32?3:4;break _;case 9:t[d+3|0]=10;t[d+5|0]=h>>>1;if(h>>>0<512){break _}t[d+2|0]=15;t[d+4|0]=k>>>5;break _;case 10:case 42:if(h>>>0>254){break ja}f=f&15;break;case 50:break aa;case 48:break ba;case 43:break ca;case 47:break da;case 17:case 18:case 26:case 27:break ea;case 22:case 25:case 28:case 29:case 30:break fa;case 16:case 19:case 20:case 21:case 23:case 31:break ga;case 13:break ha;case 11:case 15:break ia;case 3:case 4:case 5:case 6:case 7:case 12:break ka;default:break $}}Nf(d,f,h&255);break _}t[d+3|0]=19;t[d+5|0]=o|(f>>>0<32?16:32);if(k&15){t[d+2|0]=3;t[d+4|0]=(h&240)>>>4;break _}t[d+2|0]=4;t[d+4|0]=h&15;break _}t[d+3|0]=(f|0)==11?12:16;A=d,C=ju(h),t[A+5|0]=C;break _}t[d+3|0]=14;if((h&255)>>>0<64){break _}t[d+5|0]=0;break _}t[d+3|0]=19;t[d+5|0]=h&15|f<<4;break _}t[d+3|0]=19;u[e+120>>1]=15;A=d,C=w[Rc(e+40|0,e+120|0)|0]|f<<4,t[A+5|0]=C;break _}t[d+3|0]=19;if(h&255){t[d+5|0]=h&15|((f|0)==17?16:(f|0)==26?16:32);if(!(k&240)){break _}t[d+2|0]=f>>>0>25?6:5;break _}t[d+5|0]=o|(f>>>0>25?-80:-96);break _}if(!h){break $}t[d+3|0]=17;v[e+120>>2]=8;v[e+80>>2]=h+4;A=d,C=rg(v[Ne(e+120|0,e+80|0)>>2]/8|0),t[A+5|0]=C;break _}t[d+3|0]=14;k=B(y,6)+d|0;m=x[a+480188>>1];f=0;while(1){if((f|0)==(m|0)){break _}h=k+B(f,6)|0;if(!w[h+3|0]){t[h+3|0]=12;A=h,C=ju(r),t[A+5|0]=C}f=f+1|0;continue}}t[d+3|0]=9;f=h&7;if(f){t[d+5|0]=w[f+26521|0];break _}f=h>>>4|0;if((f|0)==128){break $}t[d+5|0]=f;if(!(h&2048)){t[d+5|0]=f^128;break _}t[d+5|0]=f^-1;break _}t[d+5|0]=0;t[d+3|0]=0;if(!m){t[d|0]=255;break _}t[d+3|0]=25;break _}t[d+3|0]=0}g=g+1|0;f=x[a+480188>>1];d=B(f,6)+d|0;continue}}i=i+1|0;continue}}j=j+1|0;continue}break}g=P()|0;O()|0;break b}break c}}else{kB(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;g=x[a+480188>>1];continue}break}g=P()|0;O()|0;break b}dc(l)}dc(n)}hb=e+368|0;return d|0}g=P()|0;O()|0;break b}g=P()|0;O()|0;dc(d)}dc(l)}dc(n);S(g|0);L()}function O4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=hb-32|0;hb=g;d=Fc(g+16|0,11636);h=Zg(c,d);wb(d);a:{b:{c:{d:{e:{if(h){Zk(a,v[b+24>>2]+1298356|0);break e}d=Fc(g+16|0,10974);h=Zg(c,d);wb(d);if(h){Zk(a,v[b+24>>2]+1298344|0);break e}d=Fc(g+16|0,11466);h=Zg(c,d);wb(d);if(h){Zk(a,v[b+24>>2]+1298392|0);break e}d=Fc(g+16|0,10966);h=Zg(c,d);wb(d);if(h){Zk(a,v[b+24>>2]+1298380|0);break e}d=Fc(g+16|0,8272);h=Zg(c,d);wb(d);if(h){c=g+16|0;d=v[v[b+24>>2]+480184>>2];b=32800;f:{g:{while(1){if((b|0)==32848){break g}if((d|0)!=v[b>>2]){b=b+12|0;continue}break}_m(c,0,v[b+8>>2]);break f}Kb(c)}v[23516]=0;R(1029,a|0,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break d}xb(g+16|0);break e}d=Fc(g+16|0,10951);h=Zg(c,d);wb(d);if(h){f=v[v[b+24>>2]+480184>>2];c=hb+-64|0;hb=c;b=32800;e=Xf(c+48|0);j=g+16|0;d=Kb(j);while(1){if((b|0)!=32848){if((f|0)==v[b>>2]){h=v[b+4>>2];v[23516]=0;h=Q(1,c+32|0,h|0)|0;i=v[23516];v[23516]=0;h:{i:{j:{k:{l:{m:{if((i|0)!=1){v[23516]=0;U(865,c+24|0,e|0,h|0);i=v[23516];v[23516]=0;if((i|0)==1){break k}if(!w[c+28|0]){break h}if(!oh(v[d+4>>2],w[d+11|0])){v[23516]=0;i=Q(1,c+8|0,17869)|0;k=v[23516];v[23516]=0;if((k|0)==1){break m}v[23516]=0;Q(96,d|0,i|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break l}xb(i)}v[23516]=0;Q(96,d|0,h|0)|0;i=v[23516];v[23516]=0;if((i|0)!=1){break h}b=P()|0;O()|0;break j}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;xb(i);break j}b=P()|0;O()|0}xb(h)}xb(d);VL(e);S(b|0);L()}xb(h)}b=b+12|0;continue}break}VL(e);hb=c- -64|0;v[23516]=0;R(1029,a|0,j|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(g+16|0);break e}c=P()|0;O()|0;xb(g+16|0);break a}d=Fc(g+16|0,8338);h=Zg(c,d);wb(d);if(h){Zk(a,v[b+24>>2]+1298368|0);break e}d=Fc(g+16|0,5623);h=Zg(c,d);wb(d);if(h){Zk(a,v[b+24>>2]+1298320|0);break e}d=Fc(g+16|0,12040);h=Zg(c,d);wb(d);if(h){c=g+16|0;yh(c,v[b+24>>2]+1298308|0);b=v[b+24>>2];v[23516]=0;U(1023,a|0,b|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){wb(g+16|0);break e}c=P()|0;O()|0;wb(g+16|0);break a}d=Fc(g+16|0,11409);h=Zg(c,d);wb(d);if(h){c=v[b+24>>2]+1298408|0;b=v[c+4>>2];n:{if(!nc(v[c>>2],b)){b=b-48|0;if(vd(v[b+12>>2])){break n}}Kb(a);break e}o=g+16|0;j=hb-144|0;hb=j;pc(j+96|0,b,44);e=v[b+44>>2];if(e){pc(j+44|0,b,44);h=hb-16|0;hb=h;b=Iw(v[j+64>>2]+1900|0,v[j+60>>2]+1|0,v[j+56>>2])-Iw(1970,1,1)|0;b=rka(b,b>>31,86400,0);c=B(v[j+52>>2],3600);b=b+c|0;d=kb+(c>>31)|0;d=b>>>0<c>>>0?d+1|0:d;c=B(v[j+48>>2],60);i=c;b=c+b|0;c=(c>>31)+d|0;c=b>>>0<i>>>0?c+1|0:c;d=v[j+44>>2];i=d;b=d+b|0;d=(d>>31)+c|0;c=Xl(h+8|0,b,b>>>0<i>>>0?d+1|0:d);b=v[c>>2];i=v[c+4>>2];hb=h+16|0;h=j+88|0;d=2147483647;m=se(+(e>>>0)/18.2);c=-1;o:{if(m>=0x8000000000000000){break o}d=-2147483648;c=0;if(m<=-0x8000000000000000){break o}if(D(m)<0x8000000000000000){d=D(m)>=1?~~(m>0?F(H(m*2.3283064365386963e-10),4294967295):I((m-+(~~m>>>0>>>0))*2.3283064365386963e-10))>>>0:0;c=~~m>>>0;break o}c=0}d=d+i|0;c=b+c|0;d=c>>>0<b>>>0?d+1|0:d;b=Xl(h,c,d);i=v[b+4>>2];h=v[b>>2];k=hb-16|0;hb=k;v[k+12>>2]=0;v[k+8>>2]=0;v[k+4>>2]=0;b=Iw(1970,1,1)+ska(h,i,86400,0)|0;f=b>>31;d=rka(b,f,1e4,0)+14780|0;c=kb;e=d;c=d>>>0<14780?c+1|0:c;l=ska(d,c,-14609700,-1)+b|0;d=f+kb|0;d=b>>>0>l>>>0?d+1|0:d;n=ska(e,c,365242500,0);l=n+l|0;d=kb+d|0;d=l>>>0<n>>>0?d+1|0:d;n=ska(e,c,-146097e4,-1);l=n+l|0;d=kb+d|0;d=l>>>0<n>>>0?d+1|0:d;c=ska(e,c,3652425,0);e=kb;n=e;p=l;l=rka(c,e,-365,-1);e=p+l|0;d=kb+d|0;d=e>>>0<l>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){d=n-!c|0;c=c-1|0;e=rka(c,d,-365,-1)+b|0;d=f+kb|0;d=b>>>0>e>>>0?d+1|0:d;b=e;e=(c|0)/-4|0;b=b+e|0;d=(e>>31)+d|0;d=b>>>0<e>>>0?d+1|0:d;e=b;b=(c|0)/100|0;f=b;e=e+b|0;b=(b>>31)+d|0;b=e>>>0<f>>>0?b+1|0:b;d=(c|0)/-400|0;f=d;e=d+e|0;d=(d>>31)+b|0;d=e>>>0<f>>>0?d+1|0:d}f=c;b=rka(e,d,100,0)+52|0;c=kb;b=ska(b,b>>>0<52?c+1|0:c,3060,0);c=b+2|0;d=(c|0)/12|0;v[k+12>>2]=f+d;v[k+8>>2]=(c+B(d,-12)|0)+1;b=rka(b,kb,306,0)+5|0;d=kb;b=ska(b,b>>>0<5?d+1|0:d,-10,-1)+e|0;v[k+4>>2]=b+1;v[j+136>>2]=0;v[j+128>>2]=0;v[j+132>>2]=0;v[j+120>>2]=0;v[j+124>>2]=0;v[j+116>>2]=v[k+12>>2]-1900;v[j+112>>2]=v[k+8>>2]-1;b=v[k+4>>2];q=j,r=tka(ska(h,i,3600,0),kb,24),v[q+104>>2]=r;v[j+108>>2]=b;b=ska(h,i,60,0);c=kb;q=j,r=tka(b,c,60),v[q+100>>2]=r;b=rka(b,c,-60,0)+h|0;v[j+96>>2]=b;hb=k+16|0}c=pc(j,j+96|0,44);b=hb-176|0;hb=b;h=Kb(b+160|0);v[23516]=0;d=Q(1,b+144|0,13511)|0;e=v[23516];v[23516]=0;p:{q:{r:{s:{t:{if((e|0)!=1){e=v[c+20>>2];if(!e){break q}v[23516]=0;v[b+112>>2]=e+1900;R(95,b+128|0,b+112|0);e=v[23516];v[23516]=0;if((e|0)!=1){v[23516]=0;i=Q(96,h|0,b+128|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break t}xb(b+128|0);f=v[c+16>>2];if(f>>>0>11){break q}v[23516]=0;e=Q(1,b+112|0,16896)|0;j=v[23516];v[23516]=0;u:{v:{w:{x:{y:{z:{if((j|0)!=1){v[23516]=0;v[b+80>>2]=f+1;R(97,b+96|0,b+80|0);f=v[23516];v[23516]=0;if((f|0)==1){break z}v[23516]=0;U(2,b+128|0,e|0,b+96|0);f=v[23516];v[23516]=0;if((f|0)==1){break y}v[23516]=0;i=Q(96,i|0,b+128|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break x}xb(b+128|0);xb(b+96|0);xb(e);if(v[c+12>>2]-32>>>0>=4294967265){break u}break q}a=P()|0;O()|0;break s}a=P()|0;O()|0;break v}a=P()|0;O()|0;break w}a=P()|0;O()|0;xb(b+128|0)}xb(b+96|0)}xb(e);break s}v[23516]=0;e=Q(1,b+96|0,16896)|0;f=v[23516];v[23516]=0;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((f|0)!=1){v[23516]=0;R(97,b+80|0,c+12|0);f=v[23516];v[23516]=0;if((f|0)==1){break Z}v[23516]=0;U(2,b+128|0,e|0,b+80|0);f=v[23516];v[23516]=0;if((f|0)==1){break Y}v[23516]=0;i=Q(96,i|0,b+128|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break X}xb(b+128|0);xb(b+80|0);xb(e);j=v[c>>2];e=v[c+8>>2];f=v[c+4>>2];if(!(j|(e|f))|e>>>0>23|f>>>0>59){break q}v[23516]=0;e=Q(1,b+128|0,13723)|0;f=v[23516];v[23516]=0;if((f|0)==1){break U}v[23516]=0;i=Q(96,i|0,e|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break T}xb(e);if(v[c+32>>2]>0){v[23516]=0;e=Q(1,b+80|0,15686)|0;f=v[23516];v[23516]=0;if((f|0)==1){break S}Gb(d,e);xb(e)}v[23516]=0;R(97,b+32|0,c+8|0);e=v[23516];v[23516]=0;if((e|0)==1){break R}v[23516]=0;e=Q(1,b+16|0,14732)|0;f=v[23516];v[23516]=0;if((f|0)==1){break Q}v[23516]=0;U(2,b+48|0,b+32|0,e|0);f=v[23516];v[23516]=0;if((f|0)==1){break P}v[23516]=0;R(97,b|0,c+4|0);f=v[23516];v[23516]=0;if((f|0)==1){break O}v[23516]=0;U(2,b- -64|0,b+48|0,b|0);f=v[23516];v[23516]=0;if((f|0)==1){break N}v[23516]=0;i=Q(96,i|0,b- -64|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break M}xb(b- -64|0);xb(b);xb(b+48|0);xb(e);xb(b+32|0);if(j>>>0<62){break H}v[23516]=0;U(98,o|0,i|0,d|0);e=v[23516];v[23516]=0;if((e|0)==1){break G}break p}a=P()|0;O()|0;break s}a=P()|0;O()|0;break V}a=P()|0;O()|0;break W}a=P()|0;O()|0;xb(b+128|0)}xb(b+80|0)}xb(e);break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;xb(e);break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;break K}a=P()|0;O()|0;break L}a=P()|0;O()|0;xb(b- -64|0)}xb(b)}xb(b+48|0)}xb(e)}xb(b+32|0);break s}v[23516]=0;e=Q(1,b+48|0,14732)|0;f=v[23516];v[23516]=0;if((f|0)==1){break F}v[23516]=0;R(97,b+32|0,c|0);f=v[23516];v[23516]=0;if((f|0)==1){break E}v[23516]=0;U(2,b- -64|0,e|0,b+32|0);f=v[23516];v[23516]=0;if((f|0)==1){break D}v[23516]=0;i=Q(96,i|0,b- -64|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break C}xb(b- -64|0);xb(b+32|0);xb(e);v[23516]=0;Q(96,i|0,d|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break q}}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;xb(b- -64|0)}xb(b+32|0)}xb(e);break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;xb(b+128|0)}xb(d)}xb(h);S(a|0);L()}Xc(o,h)}xb(d);xb(h);hb=b+176|0;hb=c+144|0;v[23516]=0;R(1029,a|0,o|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(g+16|0);break e}c=P()|0;O()|0;xb(g+16|0);break a}d=Fc(g+16|0,12241);h=Zg(c,d);wb(d);if(h){c=g+16|0;oP(c,v[b+24>>2]+1298332|0);_:{if(!Pe(c)){break _}d=v[v[b+24>>2]+480180>>2];$:{aa:{if((d|0)==33554432){break aa}c=1;if((d|0)==32){break $}if((d|0)==16384){break aa}if((d|0)==16777216){break $}}c=2}ba:{switch(c-1|0){case 0:v[23516]=0;R(1030,g|0,b|0);c=v[23516];v[23516]=0;if((c|0)!=1){yc(g+16|0,g);wb(g);break _}break b;case 1:break ba;default:break _}}if(Pe(g+16|0)){v[23516]=0;R(1031,g|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}yc(g+16|0,g);wb(g)}if(!Pe(g+16|0)){break _}v[23516]=0;R(1030,g|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}yc(g+16|0,g);wb(g)}b=v[b+24>>2];v[23516]=0;U(1023,a|0,b|0,g+16|0);a=v[23516];v[23516]=0;if((a|0)!=1){wb(g+16|0);break e}break b}d=Fc(g+16|0,5475);h=Zg(c,d);wb(d);if(h){c=g+16|0;oP(c,v[b+24>>2]+1298332|0);b=v[b+24>>2];v[23516]=0;U(1023,a|0,b|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){wb(g+16|0);break e}c=P()|0;O()|0;wb(g+16|0);break a}e=c;c=Fc(g+16|0,7295);d=Zg(e,c);wb(c);if(d){a=Kb(a);q=g,r=Cb(v[b+68>>2]),v[q+16>>2]=r;b=Cb(v[b+72>>2]);c=1;while(1){d=v[g+16>>2];if(!Nb(d,b)){break e}if(!(c&1)){v[23516]=0;Q(955,a|0,21721)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}}v[23516]=0;Q(820,a|0,d|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}gq(g+16|0);c=0;continue}}Fc(a,21751)}hb=g+32|0;return}c=P()|0;O()|0;xb(g+16|0);break a}c=P()|0;O()|0;wb(a);break a}c=P()|0;O()|0;wb(g+16|0)}S(c|0);L()}function DG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,D=0,E=0,F=0,G=0,H=C(0),I=0;e=hb-144|0;hb=e;d=Rb(e,0,144);v[d+76>>2]=-1;v[d+44>>2]=a;v[d+32>>2]=1134;v[d+84>>2]=a;x=c;a=0;h=hb-304|0;hb=h;a:{b:{c:{d:{if(v[d+4>>2]){break d}Pw(d);if(v[d+4>>2]){break d}break c}g=w[b|0];if(!g){break a}e:{f:{g:{h:{while(1){i:{c=g&255;j:{if(Nk(c)){while(1){g=b;b=b+1|0;if(Nk(w[g+1|0])){continue}break}li(d,0,0);while(1){b=v[d+4>>2];k:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break k}b=md(d)}if(Nk(b)){continue}break}b=v[d+4>>2];c=v[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;c=b>>31;i=b;e=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;f=b;b=i+b|0;i=c+e|0;m=b;n=b>>>0<f>>>0?i+1|0:i;break j}l:{m:{n:{if((c|0)==37){c=w[b+1|0];if((c|0)==42){break n}if((c|0)!=37){break m}}li(d,0,0);o:{if(w[b|0]==37){while(1){c=v[d+4>>2];p:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;g=w[c|0];break p}g=md(d)}if(Nk(g)){continue}break}b=b+1|0;break o}c=v[d+4>>2];if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;g=w[c|0];break o}g=md(d)}if(w[b|0]!=(g|0)){b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}if((g|0)>=0){break a}f=0;if(y){break a}break c}c=v[d+4>>2]-v[d+44>>2]|0;g=c>>31;f=c;c=n+v[d+124>>2]|0;e=m+v[d+120>>2]|0;c=e>>>0<m>>>0?c+1|0:c;i=e;e=f+e|0;f=c+g|0;m=e;n=e>>>0<i>>>0?f+1|0:f;g=b;break j}l=0;b=b+2|0;break l}if(!(!Zj(c)|w[b+2|0]!=36)){e=hb-16|0;v[e+12>>2]=x;c=c-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+x|0;v[e+8>>2]=c+4;l=v[c>>2];b=b+3|0;break l}l=v[x>>2];x=x+4|0;b=b+1|0}c=0;while(1){e=w[b|0];if(Zj(e)){b=b+1|0;c=(B(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){o=0;r=(l|0)!=0;e=w[b+1|0];b=b+1|0;a=0}g=b+1|0;k=3;f=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=w[b+1|0]==104;g=b?e:g;k=b?-2:-1;break q;case 43:e=b+2|0;b=w[b+1|0]==108;g=b?e:g;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;g=b}b=w[g|0];e=(b&47)==3;D=e?1:k;p=e?b|32:b;s:{if((p|0)==91){break s}t:{if((p|0)!=110){if((p|0)!=99){break t}c=(c|0)>1?c:1;break s}EG(l,D,m,n);break j}li(d,0,0);while(1){b=v[d+4>>2];u:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break u}b=md(d)}if(Nk(b)){continue}break}b=v[d+4>>2];e=v[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;f=b>>31;j=b;e=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;i=b;b=j+b|0;n=e+f|0;n=b>>>0<i>>>0?n+1|0:n;m=b}j=c;s=c>>31;li(d,c,s);b=v[d+4>>2];v:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;break v}if((md(d)|0)<0){break f}}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(p-88|0){default:b=p-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:GG(h+8|0,d,D,0);b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]!=(0-b|0)|v[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((p|16)==115){Rb(h+32|0,-1,257);t[h+32|0]=0;if((p|0)!=115){break x}t[h+65|0]=0;t[h+46|0]=0;u[h+42>>1]=0;u[h+44>>1]=0;break x}e=w[g+1|0];f=(e|0)==94;Rb(h+32|0,f,257);t[h+32|0]=0;b=f?g+2|0:g+1|0;B:{C:{D:{g=w[(f?2:1)+g|0];if((g|0)!=45){if((g|0)==93){break D}k=(e|0)!=94;break B}k=(e|0)!=94;t[h+78|0]=k;break C}k=(e|0)!=94;t[h+126|0]=k}b=b+1|0}g=b;while(1){e=w[g|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)==93){break x}break E}e=45;f=w[g+1|0];if(!f|(f|0)==93){break E}i=g+1|0;b=w[g-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;t[b+(h+32|0)|0]=k;e=w[i|0];if(e>>>0>b>>>0){continue}break}}g=i}t[(e+h|0)+33|0]=k;g=g+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}j=0;i=0;e=0;f=0;s=0;E=hb-16|0;hb=E;G:{if((b|0)==1){v[115992]=28;break G}while(1){c=v[d+4>>2];H:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break H}c=md(d)}if(Nk(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}s=(c|0)==45?-1:0;c=v[d+4>>2];if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break I}c=md(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=v[d+4>>2];O:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break O}c=md(d)}if((c&-33)==88){b=16;c=v[d+4>>2];P:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break P}c=md(d)}if(w[c+79457|0]<16){break M}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}li(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>w[c+79457|0]){break N}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}li(d,0,0);v[115992]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=B(b,10)+e|0;f=b>>>0<429496729;c=v[d+4>>2];Q:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break Q}c=md(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}j=b}R:{if(e>>>0>9){break R}k=rka(j,0,10,0);f=kb;b=e;while(1){c=v[d+4>>2];S:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break S}c=md(d)}e=c-48|0;q=e>>>0>9;j=b+k|0;i=j>>>0<b>>>0?f+1|0:f;if((i|0)==429496729&j>>>0>=2576980378|i>>>0>429496729|q){break R}k=rka(j,i,10,0);f=kb;b=e;if((f|0)==-1&k>>>0<=(b^-1)>>>0|(f|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){f=w[c+79457|0];if(f>>>0<b>>>0){while(1){e=B(b,e)+f|0;j=e>>>0<119304647;c=v[d+4>>2];T:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break T}c=md(d)}f=w[c+79457|0];if(j&f>>>0<b>>>0){continue}break}j=e}if(b>>>0<=f>>>0){break L}while(1){k=rka(j,i,b,0);e=kb;f=f&255;if((e|0)==-1&(f^-1)>>>0<k>>>0){break L}c=f+k|0;e=c>>>0<f>>>0?e+1|0:e;j=c;i=e;c=v[d+4>>2];U:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break U}c=md(d)}f=w[c+79457|0];if(b>>>0<=f>>>0){break L}rf(E,b,0,0,0,j,i,0,0);if(!(v[E+8>>2]|v[E+12>>2])){continue}break}break L}k=t[(B(b,23)>>>5&7)+79713|0];e=w[c+79457|0];if(e>>>0<b>>>0){while(1){f=f<<k|e;j=f>>>0<134217728;c=v[d+4>>2];V:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break V}c=md(d)}e=w[c+79457|0];if(j&e>>>0<b>>>0){continue}break}j=f}if(b>>>0<=e>>>0){break L}f=k;q=f&31;if((f&63)>>>0>=32){f=0;q=-1>>>q|0}else{f=-1>>>q|0;q=f|(1<<q)-1<<32-q}if(!f&j>>>0>q>>>0){break L}while(1){c=k&31;F=e&255;if((k&63)>>>0>=32){e=j<<c;c=0}else{e=(1<<c)-1&j>>>32-c|i<<c;c=j<<c}j=F|c;i=e;c=v[d+4>>2];W:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break W}c=md(d)}e=w[c+79457|0];if(b>>>0<=e>>>0){break L}if((f|0)==(i|0)&j>>>0<=q>>>0|f>>>0>i>>>0){continue}break}}if(w[c+79457|0]>=b>>>0){break K}while(1){c=v[d+4>>2];X:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break X}c=md(d)}if(w[c+79457|0]<b>>>0){continue}break}v[115992]=68;j=-1;i=-1;s=0}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=s;c=b^j;j=c-b|0;e=b>>31;i=(e^i)-((b>>>0>c>>>0)+e|0)|0}hb=E+16|0;b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]==(0-b|0)&v[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break g}if(!(!l|(p|0)!=112)){v[l>>2]=j;break w}EG(l,D,j,i);break w}if(!l){break w}b=v[h+16>>2];c=v[h+20>>2];e=v[h+8>>2];f=v[h+12>>2];Y:{switch(D|0){case 0:G=l,H=wF(e,f,b,c),z[G>>2]=H;break w;case 1:G=l,I=Mw(e,f,b,c),A[G>>3]=I;break w;case 2:break Y;default:break w}}v[l>>2]=e;v[l+4>>2]=f;v[l+8>>2]=b;v[l+12>>2]=c;break w}i=(p|0)==99;c=i?c+1|0:31;Z:{if((D|0)==1){e=l;if(r){e=Md(c<<2);if(!e){break h}}v[h+296>>2]=0;v[h+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=v[d+4>>2];$:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break $}e=md(d)}if(!w[(e+h|0)+33|0]){break _}t[h+27|0]=e;e=Lr(h+28|0,h+27|0,1,h+296|0);if((e|0)==-2){continue}o=0;if((e|0)==-1){break f}if(a){v[(b<<2)+a>>2]=v[h+28>>2];b=b+1|0}if(!((b|0)==(c|0)&r)){continue}break}f=1;b=c;c=b<<1|1;e=_r(a,c<<2);if(e){continue}break e}break}o=0;c=a;if(h+296|0?v[h+296>>2]:0){break f}break Z}if(r){b=0;e=Md(c);if(!e){break h}while(1){a=e;while(1){e=v[d+4>>2];aa:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break aa}e=md(d)}if(!w[(e+h|0)+33|0]){c=0;o=a;break Z}t[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}f=1;b=c;c=b<<1|1;e=_r(a,c);if(e){continue}break}o=a;a=0;break e}b=0;if(l){while(1){a=v[d+4>>2];ba:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ba}a=md(d)}if(w[(a+h|0)+33|0]){t[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;o=a;break Z}}}while(1){a=v[d+4>>2];ca:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ca}a=md(d)}if(w[(a+h|0)+33|0]){continue}break}a=0;o=0;c=0}e=v[d+4>>2];f=v[d+116>>2];if((f|0)>0|(f|0)>=0){e=e-1|0;v[d+4>>2]=e}f=e-v[d+44>>2]|0;k=f;e=f+v[d+120>>2]|0;f=v[d+124>>2]+(f>>31)|0;f=e>>>0<k>>>0?f+1|0:f;if(!(f|e)|((e|0)!=(j|0)|(f|0)!=(s|0))&(p|0)==99){break i}if(r){v[l>>2]=a}da:{if(i){break da}if(c){v[(b<<2)+c>>2]=0}if(!o){o=0;break da}t[b+o|0]=0}a=c}b=v[d+4>>2]-v[d+44>>2]|0;e=b>>31;i=b;c=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;c=b>>>0<m>>>0?c+1|0:c;f=b;b=i+b|0;e=c+e|0;m=b;n=b>>>0<f>>>0?e+1|0:e;y=((l|0)!=0)+y|0}b=g+1|0;g=w[g+1|0];if(g){continue}break a}break}a=c;break g}f=1;o=0;a=0;break e}f=r;break b}f=r}if(y){break b}}y=-1}if(!f){break a}Jb(o);Jb(a)}hb=h+304|0;hb=d+144|0;return y}function wea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;k=hb-208|0;hb=k;if(!wt(a)){e=k+48|0;pc(e,a,128);f=k+176|0;lf(f,e,128,2);e=k+192|0;Cc(e,f);Ac(b+492|0,e);wb(e)}u[c+34>>1]=x[c+34>>1]&65489;h=k+192|0;f=hb-32|0;hb=f;a:{b:{switch(w[a+128|0]-4|0){default:v[f+28>>2]=0;Yn(h,0,f+28|0);break a;case 0:case 4:break b}}t[f+28|0]=w[a+129|0];t[f+24|0]=100;e=f+24|0;g=w[Vb(f+28|0,e)|0];t[f+24|0]=w[a+130|0];t[f+20|0]=100;e=w[Vb(e,f+20|0)|0];v[f+28>>2]=e;c:{if(w[a+140|0]&16){j=Eb(w[a+150|0]|w[a+151|0]<<8);o=Eb(w[a+152|0]|w[a+153|0]<<8);l=v[c>>2];r=+(l>>>0)/6553600;g=sq(r*+((j|g<<16)>>>0));v[f+24>>2]=l-g;s=f,y=sq(r*+((o|e<<16)>>>0)),v[s+20>>2]=y;s=f,y=v[Hb(f+24|0,f+20|0)>>2],v[s+28>>2]=y;break c}j=v[c>>2];o=v[c+20>>2];if(!Vd(j,o)){break c}l=j>>>7|0;g=B(l,(g<<7>>>0)/100|0);v[f+24>>2]=j-g;v[f+20>>2]=B(l,(e<<7>>>0)/100|0);e=v[Hb(f+24|0,f+20|0)>>2];l=x[c+34>>1];j=B(Hd(l),j);d:{if(l&1){ec(f+8|0,o,j);o=v[f+8>>2];l=Hd(x[c+34>>1]);j=o+(B(l,e+g|0)<<1)|0;n=u[o+(B(g,l)<<1)>>1];l=0-l<<1;while(1){e:{f:{if(e){p=u[j>>1]-n|0;o=p>>31;if((o^p)-o>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;j=j+l|0;continue}break}break d}ec(f,o,j);o=v[f>>2];l=Hd(x[c+34>>1]);n=0-l|0;j=o+B(l,e+g|0)|0;l=t[o+B(g,l)|0];while(1){g:{h:{if(e){p=t[j|0]-l|0;o=p>>31;if((o^p)-o>>>0>=6){break h}}else{e=0}break g}e=e-1|0;j=j+n|0;continue}break}}v[f+28>>2]=e}Yn(h,g,f+28|0)}hb=f+32|0;o=gc(h);if(!(!v[o>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;e=v[k+192>>2];v[c+4>>2]=e;v[c+8>>2]=e+v[o>>2]}e=w[a+134|0];if((e-1&255)>>>0<=198){t[k+48|0]=e;t[k+176|0]=100;e=(w[Vb(k+48|0,k+176|0)|0]<<7>>>0)/100|0}else{e=128}t[k+47|0]=e;t[k+48|0]=64;e=k+47|0;f=k+48|0;s=c,y=w[ef(e,f)|0]>>>1|0,u[s+32>>1]=y;t[k+48|0]=64;s=b,y=w[Vb(e,f)|0],v[s+4>>2]=y;v[c+24>>2]=40460;sl(c,+t[a+139|0]/12+ +(0-w[a+143|0]|0)+ +t[a+138|0]/1536);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){Ij(b,127,1);Hj(b,0,1)}i:{if(!Vd(v[c>>2],v[c+20>>2])){break i}b=w[a+140|0];if(b&1){b=v[c>>2];e=v[c+20>>2];j:{if(!Vd(b,e)|b>>>0<2){break j}k:{l:{switch(yk(x[c+34>>1])-1|0){case 3:f=0;h=b>>>1|0;while(1){if((f|0)!=(h|0)){oc(e+(f<<2)|0,e+(b+(f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:f=0;h=b>>>1|0;while(1){if((f|0)!=(h|0)){dy(e+(f<<1)|0,e+(b+(f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}f=0;h=b>>>1|0;while(1){if((f|0)!=(h|0)){Bh(e+f|0,e+(b+(f^-1)|0)|0);f=f+1|0;continue}break}}rj(c,d)}b=w[a+140|0]}if(b&4){m:{e=v[c>>2];b=v[c+20>>2];if(!Vd(e,b)){break m}f=x[c+34>>1];e=B(Hd(f),e);n:{o:{switch(Qm(f)-1|0){case 1:f=0;while(1){if((e|0)!=(f|0)){h=b+(f<<1)|0;u[h>>1]=x[h>>1]^-1;f=f+1|0;continue}break};break n;case 0:break o;default:break m}}f=0;while(1){if((e|0)!=(f|0)){h=b+f|0;t[h|0]=w[h|0]^-1;f=f+1|0;continue}break}}rj(c,d)}}i=w[a+170|0]!=2|w[a+171|0]>100?i:w[a+172|0]<101;b=x[c+34>>1];if(!(!(w[a+141|0]?1:i|w[a+160|0]!=0)|b&1)){e=vt(v[c>>2],Hd(b)<<1&254);if(!e){break i}b=e;h=v[c>>2];g=x[c+34>>1];j=B(Hd(g),h);f=v[c+20>>2];g=Fj(h,g);h=hb-16|0;hb=h;v[h+12>>2]=j;uc(h+12|0,g);j=v[h+12>>2];while(1){if(j){u[b>>1]=t[f|0]<<8;f=f+1|0;b=b+2|0;j=j-1|0;continue}break}hb=h+16|0;u[c+34>>1]=x[c+34>>1]|1;bQ(c,e,v[c>>2],d)}p:{if(t[a+141|0]>=0){break p}ec(k+48|0,v[c+20>>2],B(v[c>>2],Hd(x[c+34>>1])));f=v[k+52>>2];e=v[k+48>>2];q:while(1){if((0-t[a+141|0]|0)<=(m|0)){break p}g=u[e>>1];h=$b(e,f);b=e;while(1)if((b|0)==(h|0)){m=m+1|0;continue q}else{g=hd(u[b>>1]-hd(g,1)|0,1);u[b>>1]=g;b=b+2|0;continue}}}r:{if(!i){break r}ec(k+48|0,v[c+20>>2],B(v[c>>2],Hd(x[c+34>>1])));i=v[k+52>>2];b=(i|0)/2|0;h=b>>31;n=b;b=w[a+172|0];g=w[a+171|0];e=g;f=0-(b>>>0<e>>>0)|0;b=b-e|0;e=f<<24|b>>>8;j=b<<24;f=n+j|0;b=e+h|0;b=Dc(ska(f,f>>>0<j>>>0?b+1|0:b,i,i>>31),kb);f=b;j=b>>31;b=g<<24;g=b;e=b>>31;b=v[k+48>>2];m=$b(b,i);while(1){if((b|0)==(m|0)){break r}i=u[b>>1];i=rka(g,e,i,i>>31)+838860800|0;h=kb;s=b,y=Dc(ska(i,i>>>0<838860800?h+1|0:h,1677721600,0),kb),u[s>>1]=y;b=b+2|0;e=e+j|0;i=f+g|0;e=i>>>0<f>>>0?e+1|0:e;g=i;continue}}s:{if(!w[a+160|0]){break s}ec(k+176|0,v[c+20>>2],B(v[c>>2],Hd(x[c+34>>1])));b=w[a+163|0];i=w[a+162|0];t:{if(w[a+161|0]<=1){f=0;e=v[k+180>>2];h=0;break t}f=v[k+180>>2];e=(f|0)/2|0;j=e>>31;g=e;e=w[a+164|0];h=0-(i>>>0>e>>>0)|0;e=e-i|0;m=e<<23;g=g+m|0;e=(h<<23|e>>>9)+j|0;f=Dc(ska(g,g>>>0<m>>>0?e+1|0:e,f,f>>31),kb);e=v[k+180>>2];h=(e|0)/2|0;j=h>>31;n=h;h=w[a+165|0];m=0-(b>>>0>h>>>0)|0;g=h-b|0;h=m<<23|g>>>9;m=g<<23;g=n+m|0;h=h+j|0;h=Dc(ska(g,g>>>0<m>>>0?h+1|0:h,e,e>>31),kb)}g=b<<23;i=i<<23;j=(k+48|0)+((w[a+160|0]&2)<<2)|0;m=0;b=v[k+176>>2];l=$b(b,e);e=0;while(1){if((b|0)==(l|0)){break s}n=(u[b>>1]>>1)-e|0;v[k+56>>2]=n;p=n;n=(i|0)/8388608|0;m=hd(B(p,n),8)+m|0;v[k+52>>2]=m;e=hd(B(m,n),6)+e|0;e=hd(hd(B(e,(g|0)/8388608|0),6)+e|0,2);v[k+48>>2]=e;s=b,y=$c(v[j>>2]),u[s>>1]=y;b=b+2|0;g=h+g|0;i=f+i|0;continue}}u:{if(t[a+141|0]<=0){break u}ec(k+48|0,v[c+20>>2],B(v[c>>2],Hd(x[c+34>>1])));m=0;f=v[k+52>>2];e=v[k+48>>2];v:while(1){if(t[a+141|0]<=(m|0)){break u}g=u[e>>1];i=$b(e,f);b=e;while(1)if((b|0)==(i|0)){m=m+1|0;continue v}else{g=((u[b>>1]<<1)+g|0)/3|0;u[b>>1]=g;b=b+2|0;continue}}}b=v[c+20>>2];f=x[c+34>>1];e=B(v[c>>2],Hd(f));w:{if(f&1){ec(k+32|0,b,e);j=hb-16|0;hb=j;b=v[k+32>>2];m=$b(b,v[k+36>>2]);l=hb-16|0;hb=l;v[l+12>>2]=b;q=j+8|0;f=Yn(q,b,l+12|0);x:{if((b|0)==(m|0)){break x}e=b+2|0;if((m|0)==(e|0)){break x}s=(jk(x[e>>1],x[v[f>>2]>>1])?0:4)+f|0,y=e,v[s>>2]=y;h=f+4|0;while(1){g=e;i=e+2|0;if((m|0)!=(i|0)){e=g+4|0;if((m|0)==(e|0)){v[l+12>>2]=m;e=x[g+2>>1];if(!jk(e,x[v[f>>2]>>1])){f=h;if(jk(e,x[v[f>>2]>>1])){break x}}v[f>>2]=i;break x}n=x[v[f>>2]>>1];p=x[e>>1];g=x[g+2>>1];y:{if(jk(p,g)){if(jk(p,n)){v[f>>2]=e}if(jk(g,x[v[h>>2]>>1])){continue}break y}if(jk(g,n)){v[f>>2]=i}i=e;if(jk(p,x[v[h>>2]>>1])){continue}}v[h>>2]=i;continue}break}v[l+12>>2]=g}hb=l+16|0;v[j+4>>2]=0-u[v[j+8>>2]>>1];s=j,y=u[v[gc(q)>>2]>>1],v[s>>2]=y;z:{e=v[Ne(j+4|0,j)>>2];if((e|0)>32766|!e){break z}while(1){if((b|0)==(m|0)){break z}u[b>>1]=(B(u[b>>1],32767)|0)/(e|0);b=b+2|0;continue}}break w}ec(k+24|0,b,e);j=hb-16|0;hb=j;b=v[k+24>>2];m=Ib(b,v[k+28>>2]);l=hb-16|0;hb=l;v[l+12>>2]=b;q=j+8|0;f=Yn(q,b,l+12|0);A:{if((b|0)==(m|0)){break A}e=b+1|0;if((m|0)==(e|0)){break A}s=(jl(w[e|0],w[v[f>>2]])?0:4)+f|0,y=e,v[s>>2]=y;h=f+4|0;while(1){g=e;i=e+1|0;if((m|0)!=(i|0)){e=g+2|0;if((m|0)==(e|0)){v[l+12>>2]=m;e=w[g+1|0];if(!jl(e,w[v[f>>2]])){f=h;if(jl(e,w[v[f>>2]])){break A}}v[f>>2]=i;break A}n=w[v[f>>2]];p=w[e|0];g=w[g+1|0];B:{if(jl(p,g)){if(jl(p,n)){v[f>>2]=e}if(jl(g,w[v[h>>2]])){continue}break B}if(jl(g,n)){v[f>>2]=i}i=e;if(jl(p,w[v[h>>2]])){continue}}v[h>>2]=i;continue}break}v[l+12>>2]=g}hb=l+16|0;v[j+4>>2]=0-t[v[j+8>>2]];s=j,y=t[v[gc(q)>>2]],v[s>>2]=y;C:{e=v[Ne(j+4|0,j)>>2];if((e|0)>126|!e){break C}while(1){if((b|0)==(m|0)){break C}t[b|0]=(B(t[b|0],127)|0)/(e|0);b=b+1|0;continue}}}hb=j+16|0;D:{if((w[a+134|0]-101&255)>>>0>98){break D}f=x[c+34>>1];e=B(v[c>>2],Hd(f));b=v[c+20>>2];if(f&1){i=k+16|0;v[i>>2]=b;s=i,y=st(b,b+(e<<1)|0),v[s+4>>2]=y;b=(3276800-(w[a+134|0]<<14)|0)/100|0;h=0-b|0;f=32768-b|0;e=v[i>>2];g=$b(e,v[i+4>>2]);while(1){if((e|0)!=(g|0)){i=u[e>>1];E:{if((i|0)>(b|0)){n=f+((B(b,i-b|0)|0)/(f|0)|0)|0;break E}n=((B(b,b+i|0)|0)/(f|0)|0)-f|0;if((h|0)>(i|0)){break E}n=(B(f,i)|0)/(b|0)|0}s=e,y=$c(n),u[s>>1]=y;e=e+2|0;continue}break}break D}i=ln(k+8|0,b,b+e|0);e=v[i>>2];b=(3276800-(w[a+134|0]<<14)|0)/100|0;h=0-b|0;f=32768-b|0;g=Ib(e,v[i+4>>2]);while(1){if((e|0)!=(g|0)){i=t[e|0]<<8;F:{if((i|0)>(b|0)){n=f+((B(b,i-b|0)|0)/(f|0)|0)|0;break F}n=((B(b,b+i|0)|0)/(f|0)|0)-f|0;if((h|0)>(i|0)){break F}n=(B(f,i)|0)/(b|0)|0}s=e,y=ZR((n|0)/256|0),t[s|0]=y;e=e+1|0;continue}break}}aQ(c);if(w[a+128|0]!=8){break i}b=w[a+131|0];if(!b){break i}e=v[o>>2];if(!e){break i}s=Bb(c+68|0,0),y=v[k+192>>2]+B(e,b+1|0)|0,v[s>>2]=y;b=v[k+192>>2];v[c+12>>2]=b;v[c+16>>2]=b+v[o>>2];h=v[o>>2];i=w[a+131|0];if(h>>>0>268435456/(i>>>0)>>>0){break i}f=v[c>>2];e=B(h,i);if(f>>>0>268435456-e>>>0){break i}f=e+f|0;e=yk(x[c+34>>1]);j=vt(f,e);if(!j){break i}g=b+B(h,i+1|0)|0;v[c>>2]=f;b=j;j=v[c+20>>2];i=v[k+192>>2];h=pc(b,j,B(e,i+v[o>>2]|0));m=j+B(e,i)|0;a=w[a+131|0];b=0;while(1){if((a|0)==(b|0)){pc(h+B(e,g)|0,j+B(e,i+v[o>>2]|0)|0,B(e,f-g|0));bQ(c,h,f,d)}else{b=b+1|0;l=v[o>>2];pc(h+B(e,i+B(b,l)|0)|0,m,B(e,l));continue}break}}hb=k+208|0}function $9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=hb-784|0;hb=d;xc(b);a:{b:{c:{d:{e:{f:{if(!di(b,d+776|0)){break f}if(!NL(v[d+776>>2],v[d+780>>2])){break f}if(!oA(b,d+768|0)){break f}g=v[d+768>>2];if(!ML(g)){break f}f=1313423693;if((g|0)!=1179012417){f=1414090313;if((g|0)!=538987841){break f}}m=he(d+744|0,b);j=Lb(d+728|0);g:{h:{i:{j:{k:{l:{m:{if(!c){v[23516]=0;X(871,d+136|0,m|0,((g|0)==1179012417?1:2)|0,f|0);b=v[23516];v[23516]=0;if((b|0)!=1){break m}a=P()|0;O()|0;break a}v[23516]=0;U(872,d+136|0,m|0,((g|0)==1179012417?1:2)|0);b=v[23516];v[23516]=0;if((b|0)==1){break l}}b=d+136|0;Dt(j,b);Ud(b);v[23516]=0;U(873,d+704|0,j|0,f|0);b=v[23516];v[23516]=0;if((b|0)!=1){v[23516]=0;b=T(176,v[d+704>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break k}e=0;if(!b){break g}v[23516]=0;b=Q(874,d+704|0,d+624|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break k}if(!b){break g}b=w[d+689|0];if(!b){break g}v[23516]=0;e=W(154,v[d+704>>2],v[d+712>>2],b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break k}if(!c|e^1){break g}v[23516]=0;R(248,a|0,8388608);b=v[23516];v[23516]=0;if((b|0)==1){break k}v[a+480208>>2]=w[d+688|0]<<4&16^28;u[d+136>>1]=w[d+689|0];u[d+496>>1]=127;p=a,q=x[Rc(d+136|0,d+496|0)>>1],u[p+480188>>1]=q;v[a+480196>>2]=w[d+690|0];v[a+480204>>2]=B(w[d+691|0],1e4);v[a+480200>>2]=w[d+696|0]<<1;v[23516]=0;Q(134,a+1298344|0,((g|0)==1179012417?17067:17033)|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break k}v[23516]=0;b=Q(1,d+608|0,13295)|0;e=v[23516];v[23516]=0;if((e|0)==1){break i}Gb(a+1298356|0,b);xb(b);v[a+1298404>>2]=5;b=d+496|0;Vz(b,2,d+624|0);v[23516]=0;R(221,d+136|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break j}k=(g|0)!=1179012417;b=d+136|0;yc(a+1298308|0,b);wb(b);l=(g|0)==1179012417;b=0;while(1){n:{o:{p:{if(x[a+480188>>1]<=b>>>0){b=Cb(v[j>>2]);f=Cb(v[j+4>>2]);e=hb-16|0;hb=e;v[e+8>>2]=b;while(1){q:{if(!Nb(b,f)){break q}if(IU(1380209231,v[b>>2],v[b+4>>2])){break q}b=v[Em(e+8|0)>>2];continue}break}hb=e+16|0;if(Nb(b,Cb(v[j+4>>2]))){break p}break h}f=(b<<5)+a|0;h=f+480280|0;af(h);v[23516]=0;e=T(204,d+704|0)|0;n=v[23516];v[23516]=0;r:{s:{if((n|0)!=1){if(l){break r}if(e>>>0<129){break s}break o}a=P()|0;O()|0;break b}u[f+480284>>1]=e<<1;break n}if(e<<24>>24<0){break o}v[d+136>>2]=e<<2;v[d+496>>2]=256;p=f+480284|0,q=v[od(d+136|0,d+496|0)>>2],u[p>>1]=q;break n}v[23516]=0;U(873,d+136|0,j|0,1380209231);b=v[23516];v[23516]=0;t:{if((b|0)!=1){v[23516]=0;b=T(204,d+136|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break t}e=w[a+484376|0];f=v[a+484360>>2];v[23516]=0;da(347,Sb(f,e)|0,d+136|0,b+1&255,255,254);b=v[23516];v[23516]=0;if((b|0)==1){break t}yb(d+136|0);break h}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+136|0);break b}v[h>>2]=1024}b=b+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}u:{if(!(c&1)){break u}u[d+56>>1]=0;v[23516]=0;U(875,d+560|0,j|0,1414807888);b=v[23516];v[23516]=0;if((b|0)==1){break c}b=v[d+564>>2];e=v[d+560>>2];v[23516]=0;f=a+484344|0;R(224,f|0,wf(e,b)&65535);b=v[23516];v[23516]=0;v:{if((b|0)!=1){p=d,q=Cb(v[d+560>>2]),v[p+88>>2]=q;l=Cb(v[d+564>>2]);w:{x:{y:{z:{A:{while(1){b=v[d+88>>2];if(!Nb(b,l)){k=a+484348|0;b=0;break w}b=he(d+136|0,b);v[23516]=0;e=T(204,b|0)|0;h=v[23516];v[23516]=0;if((h|0)!=1){v[23516]=0;u[d+480>>1]=e;e=T(155,b|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break A}v[23516]=0;U(188,d+496|0,b|0,e|0);e=v[23516];v[23516]=0;if((e|0)==1){break z}e=hc(d+584|0,d+496|0);v[23516]=0;h=v[e+12>>2];v[d+8>>2]=v[e+8>>2];v[d+12>>2]=h;v[d+16>>2]=v[e+16>>2];h=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=h;X(876,d|0,x[d+480>>1],k|0,a|0);e=v[23516];v[23516]=0;if((e|0)==1){break y}yb(d+496|0);p=d,q=x[ie(d+56|0,d+480|0)>>1],u[p+56>>1]=q;yb(b);Jf(d+88|0);continue}break}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;yb(d+496|0)}yb(b);break v}while(1){e=b&65535;if(e>>>0>=x[d+56>>1]){Nc(d+560|0);break u}B:{if(!te(v[a+484344>>2],v[k>>2],e)){v[23516]=0;W(225,f|0,e|0,64)|0;e=v[23516];v[23516]=0;if((e|0)==1){break B}}b=b+1|0;continue}break}a=P()|0;O()|0;break v}a=P()|0;O()|0}Nc(d+560|0);break b}C:{if((g|0)==1179012417){v[23516]=0;U(875,d+88|0,j|0,1414745673);b=v[23516];v[23516]=0;if((b|0)==1){break d}p=d,q=Cb(v[d+88>>2]),v[p+120>>2]=q;f=c&2;k=d+504|0;l=Cb(v[d+92>>2]);g=a+480190|0;while(1){b=v[d+120>>2];if(!Nb(b,l)){Nc(d+88|0);break C}c=he(d+560|0,b);v[23516]=0;b=Q(877,c|0,d+136|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){D:{if(!b){break D}b=w[d+137|0];if((b|0)==255){break D}v[23516]=0;e=W(253,a|0,b+1|0,0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break e}if(!e){break D}h=x[g>>1];b=0;v[23516]=0;U(878,d+136|0,e|0,h|0);e=v[23516];v[23516]=0;if((e|0)==1){break e}while(1){if(w[d+166|0]<=b>>>0){break D}E:{if(!Yh(x[g>>1])){break E}v[23516]=0;e=Q(879,c|0,d+496|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break e}if(!e){break E}e=x[g>>1]+1|0;u[g>>1]=e;if(v[d+496>>2]!=1347240275){break E}h=d+480|0;Gi(h,2,k);v[23516]=0;R(221,d+56|0,h|0);h=v[23516];v[23516]=0;F:{if((h|0)!=1){e=e&65535;h=d+56|0;Ac(((e<<5)+a|0)+946304|0,h);wb(h);v[23516]=0;e=(B(e,104)+a|0)+484380|0;U(880,d+496|0,d+136|0,e|0);h=v[23516];v[23516]=0;if((h|0)==1){break e}if(!f){break F}h=d+56|0;LL(h,x[d+534>>1]);v[23516]=0;W(218,h|0,e|0,c|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break E}break e}break e}h=x[e+34>>1];e=v[e>>2];v[23516]=0;Q(186,c|0,Fj(e,h)|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break e}}b=b+1|0;continue}}yb(c);Jf(d+120|0);continue}break}break e}v[23516]=0;U(875,d+480|0,j|0,1179011410);b=v[23516];v[23516]=0;if((b|0)!=1){p=d,q=Cb(v[d+480>>2]),v[p+472>>2]=q;k=c&2;l=d+496|4;h=Cb(v[d+484>>2]);e=a+480190|0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{while(1){b=v[d+472>>2];if(!Nb(b,h)){Nc(d+480|0);break C}c=he(d+560|0,b);v[23516]=0;b=T(155,c|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break P}Q:{R:{if((b|0)!=538986817){break R}v[23516]=0;b=Q(881,c|0,d+464|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break O}if(!(b&v[d+464>>2]==1414745673)){break R}v[23516]=0;b=Q(882,c|0,d+136|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break N}if(!b){break R}b=w[d+141|0];if((b|0)==255){break R}v[23516]=0;b=W(253,a|0,b+1|0,0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break M}if(!b){break R}g=x[e>>1];v[23516]=0;U(883,d+136|0,b|0,g|0);b=v[23516];v[23516]=0;if((b|0)==1){break M}v[23516]=0;U(872,d+496|0,c|0,2);b=v[23516];v[23516]=0;if((b|0)==1){break Q}v[23516]=0;U(875,d+120|0,d+496|0,1179011410);b=v[23516];v[23516]=0;if((b|0)==1){break L}Ud(d+496|0);p=d,q=Cb(v[d+120>>2]),v[p+112>>2]=q;n=Cb(v[d+124>>2]);S:{T:{while(1){b=v[d+112>>2];if(!Nb(b,n)){break S}b=he(d+88|0,b);v[23516]=0;g=T(155,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break K}U:{V:{if((g|0)!=538989377){break V}g=x[e>>1];if(!Yh(g)){break V}f=x[d+460>>1];u[d+460>>1]=f-1;if(!f){yb(b);break S}i=g+1|0;u[e>>1]=i;v[23516]=0;g=Q(881,b|0,d+80|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break J}if(!(g&v[d+80>>2]==1347240275)){break T}v[23516]=0;U(188,d+496|0,b|0,v[d+84>>2]);g=v[23516];v[23516]=0;W:{if((g|0)!=1){f=d+496|0;g=hc(d+56|0,f);yb(f);v[23516]=0;f=Q(884,g|0,f|0)|0;o=v[23516];v[23516]=0;if((o|0)==1){break U}if(f){break W}yb(g);yb(b);break S}a=P()|0;O()|0;break H}f=d+24|0;Ke(f,2,l);v[23516]=0;R(221,d+40|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break I}f=i&65535;i=d+40|0;Ac(((f<<5)+a|0)+946304|0,i);wb(i);v[23516]=0;f=(B(f,104)+a|0)+484380|0;U(885,d+496|0,d+136|0,f|0);i=v[23516];v[23516]=0;if((i|0)==1){break U}X:{if(!k){break X}v[23516]=0;Q(153,g|0,v[d+496>>2]+4|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break U}i=d+40|0;LL(i,x[d+536>>1]);v[23516]=0;W(218,i|0,f|0,g|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break X}break I}yb(g)}yb(b);Jf(d+112|0);continue}break}break I}yb(b)}Nc(d+120|0)}yb(c);Jf(d+472|0);continue}break}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;Ud(d+496|0);break G}a=P()|0;O()|0;break H}a=P()|0;O()|0;break H}a=P()|0;O()|0;yb(g)}yb(b);Nc(d+120|0)}yb(c);Nc(d+480|0);break b}a=P()|0;O()|0;break b}e=1}yb(d+704|0);Ud(j);yb(m)}hb=d+784|0;return e|0}a=P()|0;O()|0;yb(c);Nc(d+88|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}yb(d+704|0)}Ud(j);yb(m);S(a|0);L()}function $s(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=hb-32|0;hb=h;v[h+28>>2]=c;a:{if((c|0)<=0){break a}k=v[b+656>>2];if(!(!k|v[a+480180>>2]!=16777216)){m=v[k+44>>2]!=0}i=v[b+104>>2];b:{c:{d:{if(!k){j=c;break d}if((c|0)>128){break c}j=c-1|0;l=x[$b(k+236|0,j)>>1];e:{if((l-1&65535)>>>0<=3998){i=(B(l,104)+a|0)+484380|0;break e}Ab(h+16|0,a+1074312|0,43);if(!zb(v[v[h+16>>2]>>2],v[h+20>>2])){break e}if(!lj(v[b+656>>2])){break a}}j=w[Ib(k+108|0,j)|0];v[h+28>>2]=j}if(j>>>0<121){break b}c=j}f:{if(!(v[a+480180>>2]&16777248?(c|0)!=255:0)){Kn(a,b);if(d){break f}Ab(h+16|0,a+1074312|0,100);if(!zb(v[v[h+16>>2]>>2],v[h+20>>2])|!(w[a+480208|0]&4)|!w[b+789|0]){break f}v[b+88>>2]=v[b+88>>2]&-6145;break f}if(!x[a+480192>>1]){break f}v[b+88>>2]=v[b+88>>2]|4096}g:{if((c|0)!=254){break g}d=v[b+88>>2];c=a+480180|0;if(!(!(d&512)|v[c>>2]!=2)){v[b+88>>2]=d|2048;break g}v[b+88>>2]=d|2101248;h:{if(v[c>>2]&16777248){if(!x[a+480192>>1]){break h}Ab(h+16|0,a+1074312|0,50);if(zb(v[v[h+16>>2]>>2],v[h+20>>2])){break h}}v[b+688>>2]=0}Ab(h+16|0,a+1074312|0,50);if(zb(v[v[h+16>>2]>>2],v[h+20>>2])){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}Ab(h+16|0,a+1074312|0,20);if(!zb(v[v[h+16>>2]>>2],v[h+20>>2])){break a}t[b+797|0]=0;t[b+802|0]=0;break a}i:{j:{k:{if(m){if(d){l=w[b+797|0];if(l){break k}}v[b+708>>2]=0}if(d){break j}if(!(!(v[a+480180>>2]&1048588)|!i)){u[b+770>>1]=t[i+36|0];u[b+772>>1]=t[i+37|0]}if(i){Ab(h+16|0,a+1074312|0,24);l=0;o=1;if(!zb(v[v[h+16>>2]>>2],v[h+20>>2])){break i}v[b+704>>2]=v[i+24>>2];break i}i=0;l=0;break i}l=B((v[v[k+44>>2]+36>>2]<<16>>16)+1|0,(j<<16>>16)-(l<<16>>16)|0)-v[b+852>>2]|0;v[b+708>>2]=l;v[b+852>>2]=0-l}o=(i|0)!=0;l=1;if(zi(v[b+8>>2],v[b+12>>2])){break i}l=a+1074312|0;Ab(h+16|0,l,54);l:{if(!zb(v[v[h+16>>2]>>2],v[h+20>>2])){break l}if(lj(v[b+656>>2])){Ab(h+8|0,l,117);if(!zb(v[v[h+8>>2]>>2],v[h+12>>2])){break l}}v[b+700>>2]=0;break a}Ab(h+16|0,l,39);l=(zb(v[v[h+16>>2]>>2],v[h+20>>2])^-1)&d}m:{if(Am(v[a+480180>>2])){v[h+28>>2]=u[b+770>>1]+j;me(h+28|0,12,131);break m}vR(h+28|0)}j=a+1074312|0;Ab(h+16|0,j,34);n:{if(zb(v[v[h+16>>2]>>2],v[h+20>>2])){d=Cm(c);break n}d=v[h+28>>2]}t[b+797|0]=d;t[b+851|0]=w[b+851|0]&183|64;if(!(v[a+480180>>2]&16777250?0:l)){t[b+803|0]=0}d=_g(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;Ab(h+16|0,j,48);if(zb(v[v[h+16>>2]>>2],v[h+20>>2])){nN(a,b,k,i)}Ab(h+16|0,j,115);if(!(!zb(v[v[h+16>>2]>>2],v[h+20>>2])|!k|!w[k+26|0])){if(!x[b+784>>1]){u[b+784>>1]=x[b+692>>1]+1}mN(b+692|0,c,w[k+26|0],w[k+27|0])}o:{if(e^1|l){break o}v[b+776>>2]=0;v[b+780>>2]=0;if(!k){break o}Ab(h+16|0,j,29);if(zb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+798|0]=w[k+16|0]}if(!(w[k+60|0]&8)){kj(b+724|0)}if(!(w[k+80|0]&8)){kj(b+732|0)}if(!(w[k+100|0]&8)){kj(b+740|0)}if(w[k+20|0]){c=Zs(Jn(a));n=w[k+20|0];Ab(h+16|0,j,28);n=((B(c,n)<<16>>16)/64<<16)+65536>>16;p:{if(zb(v[v[h+16>>2]>>2],v[h+20>>2])){c=v[b+752>>2];break p}c=(v[b+688>>2]+1|0)/2|0}u[b+776>>1]=(B(c,n)|0)/199}q:{if(!w[k+19|0]){break q}q=b,r=(B(Zs(Jn(a)),w[k+19|0])<<16>>16)/32|0,u[q+778>>1]=r;Ab(h+16|0,j,28);if(zb(v[v[h+16>>2]>>2],v[h+20>>2])|x[b+784>>1]){break q}u[b+784>>1]=x[b+692>>1]+1}c=w[k+23|0];if(c){n=Zs(Jn(a));p=w[b+837|0];t[b+796|0]=p+1;u[b+780>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[k+24|0];if(!c){break o}n=Zs(Jn(a));p=w[b+838|0];t[b+795|0]=p+1;u[b+782>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!o){break a}c=0;r:{s:{if(!d){break s}if(!(v[b+700>>2]?l:0)){v[b+700>>2]=d}t:{u:{if(!m){if(!l){Ab(h+16|0,j,69);if(zb(v[v[h+16>>2]>>2],v[h+20>>2])){break u}Ab(h+8|0,j,46);if(zb(v[v[h+8>>2]>>2],v[h+12>>2])|v[a+480180>>2]==1){break u}}v[b+708>>2]=d;t[b+851|0]=w[b+851|0]&239}if(!l){break u}if(v[b+76>>2]|w[a+480180|0]&2){break t}}v[b+104>>2]=i;d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;v:{w:{if(!(v[a+480208>>2]&2097152)){Ab(h+16|0,j,96);if(!zb(v[v[h+16>>2]>>2],v[h+20>>2])){break w}}if(w[b+789|0]){break w}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Hb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break v}v[b+660>>2]=0}m=x[i+34>>1];d=m&1023;o=d|v[b+88>>2]&-525056;v[b+88>>2]=o;x:{y:{if(m&8){v[b+80>>2]=v[i+12>>2];m=v[i+16>>2];v[b+88>>2]=(d&16?o|4:o&-524295)|2;v[b+84>>2]=m;if(y[b+76>>2]>m>>>0){break y}break x}if(!(d&2)){break x}v[b+80>>2]=v[i+4>>2];m=v[i+8>>2];v[b+84>>2]=m;if(y[b+76>>2]<=m>>>0){break x}}v[b+76>>2]=m}Ab(h+16|0,j,83);if(!(!zb(v[v[h+16>>2]>>2],v[h+20>>2])|v[b+80>>2])){d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d}d=v[b+88>>2];z:{if(!(d&128)){break z}i=v[b+76>>2];if(!i){break z}v[b+4>>2]=i-1;v[b+88>>2]=d|128}A:{if(w[b+822|0]>3){break A}Ab(h+16|0,j,21);B:{C:{D:{if(!zb(v[v[h+16>>2]>>2],v[h+20>>2])){i=v[a+480180>>2];if(!(i&16777248)){break D}m=16;if(v[a+480208>>2]&4){break C}break B}i=v[a+480180>>2]}m=32;if((i|0)==16){break B}}if(i&67633152){break A}m=0}t[b+819|0]=m}Ab(h+16|0,j,21);if(zb(v[v[h+16>>2]>>2],v[h+20>>2])|w[b+825|0]>3){break t}t[b+820|0]=0}i=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){d=v[b+80>>2];v[b>>2]=i;v[b+4>>2]=d}if(!l){break s}c=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break s}d=1;if(!(w[a+480208|0]&8)){break r}d=1;if(!w[b+789|0]){break r}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){km(b);Ab(h+16|0,j,21);if(!zb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}E:{if(!c){i=w[b+789|0];break E}i=w[b+789|0];if(!(w[a+480208|0]&8)){break E}d=1;if(!(i&255)){break r}}if(!(i&255?0:v[a+480180>>2]&1048580)){v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}d=c}Ab(h+16|0,j,40);F:{G:{if(zb(v[v[h+16>>2]>>2],v[h+20>>2])){if(d){if(!(!(w[a+480208|0]&8)|!w[b+789|0])){v[b+88>>2]=v[b+88>>2]&-4196353;i=1;break F}v[b+88>>2]=v[b+88>>2]&-4194305;i=1;break F}c=v[b+88>>2]&-4196353;break G}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;i=1;if(d){break F}}u[b+842>>1]=65535;v[b+88>>2]=c&-6326273|2097152;Ab(h+16|0,j,23);H:{if(zb(v[v[h+16>>2]>>2],v[h+20>>2])){break H}Ab(h+8|0,j,22);if(zb(v[v[h+8>>2]>>2],v[h+12>>2])){break H}Ab(h+16|0,j,52);if(zb(v[v[h+16>>2]>>2],v[h+20>>2])){break H}Ab(h+8|0,j,71);if(zb(v[v[h+8>>2]>>2],v[h+12>>2])){break H}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;I:{J:{if(k){i=1;d=w[k+22|0];K:{if(!zf(d)){i=!(c>>>13|0);break K}q=b,r=Sq(d),t[q+838|0]=r}c=w[k+21|0];if(zf(c)){q=b,r=Sq(c),t[q+837|0]=r;break J}if(i){break J}c=(i|0)!=0;break I}v[b+776>>2]=0;v[b+780>>2]=0;c=!c;break I}c=1;d=w[k+25|0];if((d|0)==255){break I}t[b+845|0]=d}L:{if(w[b+837|0]>=127){Ab(h+16|0,j,36);if(!zb(v[v[h+16>>2]>>2],v[h+20>>2])){break L}}if(!c){break L}if((Rp(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break L}c=v[a+1298300>>2];if(!vd(c)|(g|0)==65535){break L}Vp(c,g,w[b+837|0]>>>1|0,1)}i=0;if(!(w[b+89|0]&2)){break F}if(!vd(v[a+1298300>>2])|(g|0)==65535){break F}Ab(h+16|0,j,111);if(zb(v[v[h+16>>2]>>2],v[h+20>>2])){fk(v[a+1298300>>2],g);break F}Ab(h+16|0,j,110);if(!zb(v[v[h+16>>2]>>2],v[h+20>>2])){break F}hz(v[a+1298300>>2],g,0,1,0)}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}M:{N:{if(w[a+24618|0]&16?c&1024:0){break N}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break N}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break M}}if(f){break M}v[b+700>>2]=0}if(i){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}hb=h+32|0}function mX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0;e=hb-1456|0;hb=e;xc(b);Ro(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!jr(b,e+1432|0)){break n}if(!OD(e+1432|0)){break n}if(!c){j=1;break n}if(!ir(v[b>>2],x[e+1450>>1]|x[e+1452>>1]<<16)){break n}if(!ir(v[b>>2],(x[e+1450>>1]|x[e+1452>>1]<<16)+(x[e+1444>>1]<<2)|0)){break n}Bv(a);z=e,A=Av(),v[z+56>>2]=A;c=e+56|0;zv(Rj(v[a+4>>2])+32|0,c);hr(c);l=v[Rj(v[a+4>>2])+32>>2];v[e+1428>>2]=x[e+1446>>1]|x[e+1448>>1]<<16;z=e,A=nh(v[b>>2]),v[z+1168>>2]=A;v[e+1128>>2]=214748364;d=e+1168|0;z=e,A=B(v[Hb(d,e+1128|0)>>2],20),v[z+56>>2]=A;hn(l,v[Hb(e+1428|0,c)>>2]);Rb(d,0,256);r=Lb(e+1152|0);o:{while(1){j=x[e+1444>>1]<=s>>>0;if(!j){v[23516]=0;c=Q(153,b|0,(x[e+1450>>1]|x[e+1452>>1]<<16)+(s<<2)|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break m}if(!c){break o}c=v[b+8>>2];d=v[b>>2];v[23516]=0;c=W(154,d|0,c|0,4)|0;d=v[23516];v[23516]=0;if((d|0)==1){break m}if(!c){break o}v[23516]=0;c=T(155,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break l}v[23516]=0;d=Q(153,b|0,c|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break l}if(!d){break o}v[23516]=0;d=Q(156,b|0,e+1128|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break k}if(!d){break o}v[23516]=0;d=W(157,b|0,r|0,x[e+1140>>1])|0;g=v[23516];v[23516]=0;if((g|0)==1){break k}if(!d){break o}g=v[r>>2];f=v[b>>2];v[23516]=0;d=x[e+1140>>1];f=T(158,f|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break j}h=c+20|0;if(f>>>0<=h+(d<<3)>>>0){break o}c=d?g:0;g=x[e+1140>>1];f=h+(g<<3)|0;d=0;h=x[e+1142>>1];p:{if(!(h&1)){while(1){if(d>>>0>=g>>>0){break p}if(!c){break o}g=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23516]=0;g=fa(159,h|0,g|0,l|0,v[e+1428>>2])|0;h=v[23516];v[23516]=0;if((h|0)==1){break i}if(!g){break o}v[23516]=0;g=Q(153,b|0,f|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break i}if(!g){break o}g=v[fc(e+1120|0,Ib(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))>>2];v[23516]=0;X(160,e+56|0,b|0,g|0,v[e+1124>>2]);g=v[23516];v[23516]=0;if((g|0)==1){break h}if(v[e+60>>2]!=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))){break o}d=d+1|0;c=c+8|0;g=x[e+1140>>1];continue}}q:{r:{s:{t:{u:{if(h&4){if(!c){break o}d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23516]=0;d=fa(159,g|0,d|0,l|0,v[e+1428>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break g}if(!d){break o}m=Ib(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));k=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!k){break o}v[23516]=0;g=x[e+1146>>1];d=Q(153,b|0,f+x[e+1144>>1]|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break f}if(!d){break o}d=v[b+8>>2];f=v[b>>2];v[23516]=0;d=W(154,f|0,d|0,v[e+1132>>2]-x[e+1144>>1]|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break f}if(!d){break o}v[23516]=0;U(161,e+32|0,b|0,v[e+1132>>2]-x[e+1144>>1]|0);d=v[23516];v[23516]=0;if((d|0)==1){break b}d=e+32|0;f=gr(e+56|0,d);yb(d);q=0;n=0;v:{w:{x:{while(1){h=0;y:{while(1){if(x[e+1140>>1]<=(n&65535)>>>0){break x}v[23516]=0;d=Q(162,f|0,g+1|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break y}i=g&15;o=x[(i<<1)+26144>>1];z:{A:{if(o>>>0<=d>>>0){v[23516]=0;i=w[i+26192|0];p=Q(162,f|0,i|0)|0;u=v[23516];v[23516]=0;if((u|0)==1){break y}d=p+(d-o<<i)|0;if((d|0)!=(g|0)){g=d&15;break z}v[23516]=0;d=Q(162,f|0,4)|0;i=v[23516];v[23516]=0;if((i|0)==1){break y}if((d|0)==15){v[23516]=0;i=Q(162,f|0,1)|0;d=v[23516];v[23516]=0;if((d|0)==1){break y}d=65535;if(!i){break A}yb(f);break p}d=d+65520|0}if(d>>>0>65535){break z}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;p=h+m|0;i=x[e+1142>>1];B:{if(i&2){q=d+q|0;d=q;break B}d=i&512?d:d^32768}o=d>>>8|0;i=i&1024;t[p+1|0]=i?d:o;t[p|0]=i?o:d;h=h+2|0}if(h>>>0<k>>>0){continue}break}n=n+1|0;if(n>>>0>=x[e+1140>>1]){break r}d=(n<<3)+c|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);k=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);v[23516]=0;h=fa(159,h|0,k|0,l|0,v[e+1428>>2])|0;k=v[23516];v[23516]=0;if((k|0)==1){break y}if(!h){break t}k=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!k){break u}m=Ib(v[l>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}j=V(30656)|0;if((O()|0)!=(ea(30656)|0)){break v}_(j|0)|0;v[23516]=0;Z(18);c=v[23516];v[23516]=0;if((c|0)==1){break w}}yb(f);break p}j=P()|0;O()|0}yb(f);break a}if(!c){break o}d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23516]=0;d=fa(159,g|0,d|0,l|0,v[e+1428>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break e}if(!d){break o}q=Ib(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));if(x[e+1144>>1]>256){break o}m=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);g=x[e+1146>>1];v[23516]=0;d=Q(153,b|0,f|0)|0;f=v[23516];v[23516]=0;C:{D:{if((f|0)!=1){if(!d){break o}d=v[fc(e+24|0,e+1168|0,x[e+1144>>1])>>2];v[23516]=0;X(163,e+56|0,b|0,d|0,v[e+28>>2]);d=v[23516];v[23516]=0;if((d|0)==1){break D}d=x[e+1144>>1];if(d>>>0>y[e+60>>2]){break o}f=v[b+8>>2];h=v[b>>2];v[23516]=0;d=W(154,h|0,f|0,v[e+1132>>2]-d|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break C}}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}if(!d){break o}v[23516]=0;U(161,e+32|0,b|0,v[e+1132>>2]-x[e+1144>>1]|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}d=e+32|0;f=gr(e+56|0,d);yb(d);k=0;n=0;E:{F:{G:{while(1){h=0;H:{while(1){if(x[e+1140>>1]<=(k&65535)>>>0){break G}v[23516]=0;d=Q(162,f|0,g+1|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break H}i=g&7;o=w[i+26176|0];I:{J:{if(o>>>0<=d>>>0){v[23516]=0;i=w[i+26184|0];p=Q(162,f|0,i|0)|0;u=v[23516];v[23516]=0;if((u|0)==1){break H}d=p+(d-o<<i)|0;if((d|0)!=(g|0)){g=d&7;break I}v[23516]=0;d=Q(162,f|0,3)|0;i=v[23516];v[23516]=0;if((i|0)==1){break H}if((d|0)==7){v[23516]=0;i=Q(162,f|0,1)|0;d=v[23516];v[23516]=0;if((d|0)==1){break H}d=255;if(!i){break J}yb(f);break p}d=d+248|0}if(d>>>0>255){break I}}d=w[(e+1168|0)+d|0];i=d+n|0;p=d;d=x[e+1142>>1]&2;t[h+q|0]=d?i:p;n=d?i:n;h=h+1|0}if(h>>>0<m>>>0){continue}break}k=k+1|0;if(k>>>0>=x[e+1140>>1]){break q}d=(k<<3)+c|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);v[23516]=0;h=fa(159,h|0,m|0,l|0,v[e+1428>>2])|0;m=v[23516];v[23516]=0;if((m|0)==1){break H}if(!h){break s}m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);q=Ib(v[l>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}j=V(30656)|0;if((O()|0)!=(ea(30656)|0)){break E}_(j|0)|0;v[23516]=0;Z(18);c=v[23516];v[23516]=0;if((c|0)==1){break F}}yb(f);break p}j=P()|0;O()|0}yb(f);break a}yb(f);break o}yb(f);break o}yb(f);break o}yb(f);break p}yb(f)}s=s+1|0;continue}break}oe(e+8|0,v[l>>2],v[l+4>>2]);Vg(e+16|0,v[e+8>>2],v[e+12>>2]);b=ce(e);c=v[b+4>>2];b=v[b>>2];v[23516]=0;b=ga(164,e+56|0,v[e+16>>2],v[e+20>>2],b|0,c|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}cd(Rj(v[a+4>>2])+12|0,b);yb(b)}be(r)}hb=e+1456|0;return j|0}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0}be(r);S(j|0);L()}function WP(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;l=hb-336|0;hb=l;m=i&65535;p=d;q=e&65535;s=(e^i)&-2147483648;k=h;z=i>>>16&32767;A=e>>>16&32767;a:{b:{if(z-32767>>>0>4294934529&A-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){o=d;s=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;s=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;s=2147450880;break a}s=s|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));o=b?0:o;s=b?2147450880:s;b=0;c=0;break a}if(!(f|h|(e|g))){s=s|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(p|q);h=d<<6;j=E(d?b:p)+32|0;b=E(d?c:q);b=h+((b|0)==32?j:b)|0;Hf(l+320|0,i,c,p,q,b-15|0);n=16-b|0;p=v[l+328>>2];q=v[l+332>>2];c=v[l+324>>2];b=v[l+320>>2]}if(e>>>0>65535){break b}d=!(k|m);e=d<<6;h=E(d?f:k)+32|0;d=E(d?g:m);d=e+((d|0)==32?h:d)|0;Hf(l+304|0,f,g,k,m,d-15|0);n=(d+n|0)-16|0;k=v[l+312>>2];m=v[l+316>>2];f=v[l+304>>2];g=v[l+308>>2]}e=m|65536;B=e;C=k;d=k;k=e<<15|d>>>17;d=d<<15|g>>>17;h=0-d|0;e=k;i=1963258675-(e+((d|0)!=0)|0)|0;rf(l+288|0,d,e,0,0,h,i,0,0);j=v[l+296>>2];rf(l+272|0,0-j|0,0-(v[l+300>>2]+((j|0)!=0)|0)|0,0,0,h,i,0,0);h=v[l+280>>2];i=h<<1|v[l+276>>2]>>>31;h=v[l+284>>2]<<1|h>>>31;rf(l+256|0,i,h,0,0,d,e,0,0);j=h;h=v[l+264>>2];rf(l+240|0,i,j,0,0,0-h|0,0-(v[l+268>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+248>>2];i=h<<1|v[l+244>>2]>>>31;h=v[l+252>>2]<<1|h>>>31;rf(l+224|0,i,h,0,0,d,e,0,0);j=h;h=v[l+232>>2];rf(l+208|0,i,j,0,0,0-h|0,0-(v[l+236>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+216>>2];i=h<<1|v[l+212>>2]>>>31;h=v[l+220>>2]<<1|h>>>31;rf(l+192|0,i,h,0,0,d,e,0,0);e=h;h=v[l+200>>2];rf(l+176|0,i,e,0,0,0-h|0,0-(v[l+204>>2]+((h|0)!=0)|0)|0,0,0);i=d;h=v[l+184>>2];d=h<<1|v[l+180>>2]>>>31;e=d-1|0;h=(v[l+188>>2]<<1|h>>>31)-!d|0;rf(l+160|0,i,k,0,0,e,h,0,0);d=f;j=g<<15|d>>>17;rf(l+144|0,d<<15,j,0,0,e,h,0,0);k=v[l+172>>2];m=v[l+160>>2];D=v[l+152>>2];d=m+D|0;i=v[l+164>>2];j=i+v[l+156>>2]|0;j=d>>>0<D>>>0?j+1|0:j;m=(i|0)==(j|0)&d>>>0<m>>>0|i>>>0>j>>>0;i=m+v[l+168>>2]|0;k=i>>>0<m>>>0?k+1|0:k;m=!j&d>>>0>1|(j|0)!=0;i=m+i|0;k=i>>>0<m>>>0?k+1|0:k;rf(l+112|0,e,h,0,0,0-i|0,0-(((i|0)!=0)+k|0)|0,0,0);rf(l+128|0,1-d|0,0-((d>>>0>1)+j|0)|0,0,0,e,h,0,0);J=(A-z|0)+n|0;e=v[l+116>>2];x=e;d=v[l+112>>2];j=e<<1|d>>>31;m=d<<1;n=j;d=j;h=v[l+140>>2];u=h;e=v[l+136>>2];j=h<<1|e>>>31;i=e<<1|v[l+132>>2]>>>31;h=i+m|0;j=d+j|0;j=h>>>0<i>>>0?j+1|0:j;i=h;e=j;j=j-(h>>>0<13927)|0;r=j;k=q|65536;M=k;D=p;j=p;k=k<<1|j>>>31;p=j<<1|c>>>31;d=0;j=d|k;q=j;w=rka(r,d,j,0);d=kb;t=d;j=b;d=c<<1|j>>>31;z=j<<1;A=d;h=h-13927|0;j=(e|0)==(r|0)&h>>>0<i>>>0|e>>>0>r>>>0;e=(e|0)==(n|0)&i>>>0<m>>>0|e>>>0<n>>>0;d=v[l+120>>2];k=v[l+124>>2]<<1|d>>>31;i=d<<1;m=j;n=e;e=u>>>31|0;d=e+(x>>>31|i)|0;j=k;j=d>>>0<e>>>0?j+1|0:j;e=d;d=n+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;k=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;F=k-!e|0;G=0;i=rka(A,o,F,G);e=i+w|0;k=kb+t|0;k=e>>>0<i>>>0?k+1|0:k;m=(k|0)==(t|0)&e>>>0<w>>>0|k>>>0<t>>>0;w=d;i=rka(d,0,p,0);d=i+e|0;j=kb+k|0;j=d>>>0<i>>>0?j+1|0:j;n=d;i=j;e=(j|0)==(k|0)&d>>>0<e>>>0|j>>>0<k>>>0;d=m+e|0;k=0;k=d>>>0<e>>>0?1:k;e=rka(q,o,F,G);d=e+d|0;j=kb+k|0;u=d;d=d>>>0<e>>>0?j+1|0:j;m=rka(q,o,w,o);k=kb;x=rka(F,G,p,o);e=x+m|0;j=kb+k|0;j=e>>>0<x>>>0?j+1|0:j;x=e;e=j;j=(k|0)==(j|0)&m>>>0>x>>>0|j>>>0<k>>>0;m=u+e|0;d=d+j|0;j=m;m=j>>>0<e>>>0?d+1|0:d;u=j;e=0;d=e+n|0;j=i+x|0;j=d>>>0<e>>>0?j+1|0:j;e=j;k=(j|0)==(i|0)&d>>>0<n>>>0|i>>>0>j>>>0;i=u+k|0;j=m;u=i;i=i>>>0<k>>>0?j+1|0:j;n=d;m=e;x=h;h=rka(h,0,p,o);e=kb;t=rka(r,o,A,o);d=t+h|0;j=kb+e|0;j=d>>>0<t>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;H=u;t=e;I=z&-2;k=rka(w,o,I,0);e=k+d|0;j=kb+j|0;j=e>>>0<k>>>0?j+1|0:j;u=e;k=e;e=j;h=(j|0)==(h|0)&d>>>0>k>>>0|h>>>0>j>>>0;d=t+h|0;k=0;k=d>>>0<h>>>0?1:k;j=d;h=n+d|0;d=k+m|0;d=h>>>0<j>>>0?d+1|0:d;t=h;j=h;h=d;k=(d|0)==(m|0)&j>>>0<n>>>0|d>>>0<m>>>0;d=H+k|0;j=i;N=d;n=d>>>0<k>>>0?j+1|0:j;K=rka(q,o,x,o);H=kb;i=rka(F,G,I,o);d=i+K|0;j=kb+H|0;j=d>>>0<i>>>0?j+1|0:j;F=d;k=rka(r,o,p,o);i=d+k|0;m=j;d=j+kb|0;d=i>>>0<k>>>0?d+1|0:d;L=i;j=rka(A,o,w,o);i=i+j|0;k=kb+d|0;G=i;k=i>>>0<j>>>0?k+1|0:k;i=k;w=0;O=(d|0)==(k|0)&G>>>0<L>>>0|d>>>0>k>>>0;j=(d|0)==(m|0)&F>>>0>L>>>0|d>>>0<m>>>0;d=j+((m|0)==(H|0)&F>>>0<K>>>0|m>>>0<H>>>0)|0;k=0;d=O+d|0;m=i|0;k=m+t|0;j=(d|w)+h|0;w=k;d=k;j=d>>>0<m>>>0?j+1|0:j;m=j;h=(h|0)==(j|0)&d>>>0<t>>>0|h>>>0>j>>>0;d=h+N|0;j=n;H=d;h=d>>>0<h>>>0?j+1|0:j;t=rka(r,o,I,o);r=kb;k=rka(A,o,x,o);d=k+t|0;j=kb+r|0;j=d>>>0<k>>>0?j+1|0:j;n=0;k=(j|0)==(r|0)&d>>>0<t>>>0|j>>>0<r>>>0;r=j;d=j+u|0;j=(k|n)+e|0;n=d;j=d>>>0<r>>>0?j+1|0:j;u=(e|0)==(j|0)&d>>>0<u>>>0|e>>>0>j>>>0;i=0;e=i+d|0;d=j;k=G+d|0;k=e>>>0<i>>>0?k+1|0:k;e=(d|0)==(k|0)&e>>>0<n>>>0|d>>>0>k>>>0;d=u+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+w|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<w>>>0|j>>>0<m>>>0;i=j+H|0;k=h;h=i;k=h>>>0<j>>>0?k+1|0:k;i=k;c:{if((k|0)==131071|k>>>0<131071){rf(l+80|0,d,e,h,i,f,g,C,B);j=b<<17;b=0;c=v[l+88>>2];n=b-c|0;k=v[l+80>>2];m=v[l+84>>2];D=(k|m)!=0;r=n-D|0;n=(j-(v[l+92>>2]+(b>>>0<c>>>0)|0)|0)-(n>>>0<D>>>0)|0;b=k;k=0-k|0;m=0-(((b|0)!=0)+m|0)|0;b=J+16382|0;break c}k=h<<31;d=(e&1)<<31|d>>>1;e=e>>>1|k;h=(i&1)<<31|h>>>1;i=i>>>1|0;rf(l+96|0,d,e,h,i,f,g,C,B);q=0;m=v[l+104>>2];n=q-m|0;k=v[l+96>>2];p=v[l+100>>2];z=(k|p)!=0;r=n-z|0;n=((b<<16)-(v[l+108>>2]+(m>>>0>q>>>0)|0)|0)-(n>>>0<z>>>0)|0;j=k;k=0-j|0;m=0-(((j|0)!=0)+p|0)|0;z=b;A=c;p=D;q=M;b=J+16383|0}if((b|0)>=32767){s=s|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=r;j=n<<1|c>>>31;r=c<<1|m>>>31;n=j;p=h;q=i&65535|b<<16;j=m<<1|k>>>31;b=k<<1;break d}if((b|0)<=-113){b=0;c=0;break a}vm(l- -64|0,d,e,h,i,1-b|0);Hf(l+48|0,z,A,p,q,b+112|0);d=v[l+64>>2];e=v[l+68>>2];p=v[l+72>>2];q=v[l+76>>2];rf(l+32|0,f,g,C,B,d,e,p,q);c=v[l+40>>2];i=c<<1;c=v[l+44>>2]<<1|c>>>31;b=v[l+56>>2];h=v[l+36>>2];n=h>>>31|i;i=b-n|0;n=v[l+60>>2]-((b>>>0<n>>>0)+c|0)|0;c=v[l+32>>2];k=h<<1|c>>>31;c=c<<1;j=v[l+52>>2];b=v[l+48>>2];h=(k|0)==(j|0)&c>>>0>b>>>0|j>>>0<k>>>0;r=i-h|0;n=n-(h>>>0>i>>>0)|0;h=b;b=h-c|0;j=j-((c>>>0>h>>>0)+k|0)|0}rf(l+16|0,f,g,C,B,3,0,0,0);rf(l,f,g,C,B,5,0,0,0);h=d;m=p;p=d&1;c=b+p|0;d=0;k=j+d|0;k=b>>>0>c>>>0?k+1|0:k;i=c;c=k;g=(k|0)==(g|0)&i>>>0>f>>>0|g>>>0<k>>>0;d=(d|0)==(k|0)&i>>>0<p>>>0|d>>>0>k>>>0;b=d+r|0;j=n;j=b>>>0<d>>>0?j+1|0:j;f=b;d=b;b=j;g=(d|0)==(C|0)&(j|0)==(B|0)?g:(B|0)==(j|0)&d>>>0>C>>>0|j>>>0>B>>>0;d=h+g|0;k=e;k=d>>>0<g>>>0?k+1|0:k;g=(e|0)==(k|0)&d>>>0<h>>>0|e>>>0>k>>>0;e=m+g|0;j=q;j=e>>>0<g>>>0?j+1|0:j;g=e;e=d;m=g;d=v[l+20>>2];h=(d|0)==(c|0)&y[l+16>>2]<i>>>0|c>>>0>d>>>0;d=v[l+28>>2];g=v[l+24>>2];h=j>>>0<2147418112&((f|0)==(g|0)&(b|0)==(d|0)?h:(d|0)==(b|0)&g>>>0<f>>>0|b>>>0>d>>>0);g=e+h|0;d=k;d=g>>>0<h>>>0?d+1|0:d;h=(d|0)==(k|0)&e>>>0>g>>>0|d>>>0<k>>>0;e=m+h|0;k=e>>>0<h>>>0?j+1|0:j;h=e;e=v[l+4>>2];i=(e|0)==(c|0)&y[l>>2]<i>>>0|c>>>0>e>>>0;c=v[l+12>>2];e=v[l+8>>2];c=k>>>0<2147418112&((e|0)==(f|0)&(b|0)==(c|0)?i:(c|0)==(b|0)&e>>>0<f>>>0|b>>>0>c>>>0);b=c+g|0;j=b>>>0<c>>>0?d+1|0:d;c=j;f=(d|0)==(j|0)&b>>>0<g>>>0|d>>>0>j>>>0;e=h+f|0;d=k;o=e|o;s=s|(e>>>0<f>>>0?d+1|0:d)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=s;hb=l+336|0}function Qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=hb+-64|0;hb=e;xc(a);a:{b:{if(b>>>0<=2){G=e,H=Je(a),t[G+56|0]=H;Yb(a,2);G=e,H=Ng(a),u[G+58>>1]=H;G=e,H=zg(a),v[G+60>>2]=H;break b}oo(a,e+56|0);if(b>>>0>5){break a}}t[e+57|0]=0}c:{m=d+484344|0;A=Bd(x[e+58>>1],1,1024);l=qB(m,A);if((l|0)==65535){break c}b=Xb(v[d+484344>>2],l);g=xf(v[b>>2],v[v[b+48>>2]+12>>2],0);f=x[d+480188>>1];u[e>>1]=f-1;u[e+40>>1]=w[e+56|0];C=x[Rc(e,e+40|0)>>1];j=C+1|0;b=j&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){t[c+13|0]=w[e+57|0]>>>4;b=w[c+12|0];t[e|0]=0;b=(b|0)!=0;p=qu(e+40|0,j,e);D=d+480188|0;d:while(1){if((k|0)==(A|0)){dc(p);break c}e:{d=Ib(v[p>>2],0);f=w[d|0];f:{g:{if(!f){v[23516]=0;d=T(204,a|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}d=d<<24>>24;if((d|0)<0){v[23516]=0;f=T(204,a|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break e}G=Ib(v[p>>2],0),H=f,t[G|0]=H}t[e|0]=0;h:{i:{d=d&63;if(!d){break i}v[23516]=0;j=T(204,a|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break h}t[e|0]=j;j:{k:{switch(d-1|0){case 0:t[c+12|0]=0;t[e+36|0]=1;G=c,H=w[ef(e+36|0,e)|0],t[G+14|0]=H;t[c+15|0]=0;break j;case 1:if(!j){break i}t[c+15|0]=j;t[c+12|0]=1;b=w[c+13|0];if(!b){break j}t[c+14|0]=B(B(b,j),15);break j;case 2:t[c+13|0]=j>>>4;if(j>>>0>=16){b=w[c+12|0];j=0;v[e+36>>2]=0;v[e+32>>2]=0;n=0;if(!b){break f}break g}j=0;t[c+12|0]=0;v[e+36>>2]=0;v[e+32>>2]=0;n=0;if(!(b&1)){break f}break g;case 3:n=0;v[e+36>>2]=0;v[e+32>>2]=0;if(b&1){break g}break f;case 5:if(!j){break i}d=(w[c+12|0]?15:14)+c|0;b=w[d|0];t[d|0]=b>>>0<256-j>>>0?b+j|0:-1;break j;case 6:break k;default:break i}}if(!j){break i}d=(w[c+12|0]?15:14)+c|0;b=w[d|0];t[d|0]=b>>>0>j+1>>>0?b-j|0:1}j=0;v[e+36>>2]=0;v[e+32>>2]=0;break g}j=0;v[e+36>>2]=0;v[e+32>>2]=0;n=0;if(!(b&1)){break f}break g}break e}t[d|0]=f-1;j=0;v[e+36>>2]=0;v[e+32>>2]=0;n=0;if(!(b&1)){break f}}b=w[c+13|0];d=w[c+12|0];if(d){n=0;if(!b){break f}}l:{if(d){v[e>>2]=1;v[e+24>>2]=B(b,w[c+15|0])<<1;d=v[Ne(e,e+24|0)>>2];break l}d=B(w[c+14|0],30)+30|0}b=255;h=0;while(1){m:{if(!b){b=0;break m}f=B(b,d);h=(f|0)/48|0;if(f-1536>>>0<10752){break m}b=b-1|0;continue}break}v[e+36>>2]=b;v[e+32>>2]=h;me(e+32|0,32,255);n=1;v[e>>2]=1;G=c,H=v[Ne(e,e+36|0)>>2],t[G+16|0]=H}s=k-1|0;y=1;b=Xb(v[m>>2],l);b=ed(v[b>>2],v[v[b+48>>2]+12>>2],k,1);while(1){g=y&65535;if(g>>>0>C>>>0){if(n){ve(Xb(v[m>>2],l),Eh(no(Se(Le(e,17,w[e+32|0]),k),0)));ve(Xb(v[m>>2],l),Eh(Se(Le(e,16,w[e+36|0]),k)))}if(j&240){ve(Xb(v[m>>2],l),QU(Se(Le(e,20,j>>>4|224),k)))}b=j&15;if(b){ve(Xb(v[m>>2],l),QU(Se(Le(e,20,Bd((B(b,w[c+16|0])>>>0)/15&255,1,15)|96),k)))}k=k+1|0;b=0;continue d}n:{o:{p:{q:{r:{d=Ib(v[p>>2],g);f=w[d|0];if(!f){v[23516]=0;h=T(204,a|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}if(h&128){v[23516]=0;d=T(204,a|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}G=Ib(v[p>>2],g),H=d,t[G|0]=H}E=1;if(h&64){v[23516]=0;d=T(204,a|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}t[b+1|0]=d;E=!d}if(!(h&32)){f=w[b|0];break r}v[23516]=0;f=T(204,a|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}t[b|0]=f;if((f-1&255)>>>0<=107){d=Cm(f+24|0);t[b|0]=d;G=Ed(v[c>>2],g),H=d,t[G+1|0]=H;f=w[b|0];break o}if((f+127&255)>>>0<=107){d=Cm((f&127)+24|0);G=Ed(v[c>>2],g),H=d,t[G|0]=H;t[b|0]=0;break q}if((f|0)!=255){break r}f=254;break p}t[d|0]=f-1;break n}if(f&255){break o}}if(!w[b+1|0]){f=0;break o}f=w[Ed(v[c>>2],g)+1|0];t[b+1|0]=0}t[b|0]=f}if(Wc(f)){G=Ed(v[c>>2],g),H=0,t[G+5|0]=H}t[e+23|0]=0;t[e+22|0]=0;if(h&16){t[b+2|0]=1;v[23516]=0;d=T(204,a|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}t[b+4|0]=d+2>>>2}f=0;q=0;o=0;s:{if(!(h&8)){break s}v[23516]=0;d=T(204,a|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break e}v[23516]=0;o=T(204,a|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break e}t:{switch(d-1|0){case 0:t[b|0]=254;break s;case 1:t[b|0]=255;break s;case 2:d=Ed(v[c>>2],g);t[b|0]=w[d+1|0];t[d+5|0]=0;break s;case 3:d=pu(o,w[c+16|0]);o=d?d|-48:0;q=d?20:0;if(w[b|0]){break s}d=Ed(v[c>>2],g);t[b|0]=w[d+1|0];t[d+5|0]=0;break s;case 4:t[e|0]=1;G=e,H=pu(o,w[c+16|0]),t[G+24|0]=H;o=w[ef(e,e+24|0)|0];G=Ed(v[c>>2],g),H=0,t[G+5|0]=H;q=15;break s;case 5:case 6:case 7:case 8:u:{if(!k){break u}if((d|0)==w[Ed(v[c>>2],g)+4|0]){break u}if(!ve(Xb(v[m>>2],l),Dm(no(Se(Le(e,20,(d+122|160)&255),s),g)))){break u}G=Ed(v[c>>2],g),H=d,t[G+4|0]=H}d=Ed(v[c>>2],g);if(!w[b|0]){t[b|0]=w[d+1|0]}t[d+5|0]=0;q=10;break s;case 9:break t;default:break s}}i=Ed(v[c>>2],g);d=w[i+5|0];t[i+5|0]=d^1;o=d?-98:-97;q=20}v:{w:{x:{if(!(h&4)){break x}v[23516]=0;i=T(204,a|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}v[23516]=0;d=T(204,a|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}t[e+23|0]=d;F=1;f=1;y:{switch(i-1|0){case 0:pB(e,d<<24>>24<<3,128);d=w[b|0];if(Wc(d)){G=b,H=Cm(d+v[e>>2]|0),t[G|0]=H}t[e+23|0]=w[e+4|0]^128;f=35;break x;case 1:d=pu(d,w[c+16|0]);t[e+23|0]=d;if(!d){break w}t[e+23|0]=d|208;f=20;break v;case 3:case 4:G=e,H=PU(d,w[c+16|0],1),t[G+23|0]=H;f=(i|0)==4?2:3;break v;case 5:if(!w[b|0]){G=b,H=w[Ed(v[c>>2],g)|0],t[G|0]=H;d=w[e+23|0]}G=e,H=PU(d&255,w[c+16|0],0),t[G+23|0]=H;f=4;break v;case 6:G=b,H=Cm(d+25|0),t[G|0]=H;t[e+23|0]=255;f=4;break v;case 7:case 8:case 9:z:{if(!k){break z}if((i|0)==w[Ed(v[c>>2],g)+2|0]){break z}if(!ve(Xb(v[m>>2],l),Dm(no(Se(Le(e,20,(i-8|48)&255),s),g)))){break z}G=Ed(v[c>>2],g),H=i,t[G+2|0]=H}G=e,H=oB(w[e+23|0],w[c+16|0]),t[G+23|0]=H;f=5;break v;case 10:G=e,H=OU(d,w[c+16|0]),t[G+23|0]=H;f=18;break v;case 11:d=pu(d,w[c+16|0]);t[e+23|0]=d;if(d){t[e+23|0]=d|192;f=20;break v}t[b|0]=254;break w;case 2:break v;default:break y}}f=0}F=0;break v}f=0}i=0;z=1;A:{if(h&2){v[23516]=0;d=T(204,a|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break e}v[23516]=0;r=T(204,a|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break e}t[e+22|0]=r;i=9;z=0;h=0;B:{switch(d-1|0){case 0:case 1:h=1;G=e,H=NU(r,w[c+16|0],(d|0)==1),t[G+22|0]=H;i=11;break A;case 2:G=e,H=OU(r,w[c+16|0]),t[G+22|0]=H;h=1;i=18;break A;case 3:case 4:case 5:C:{if(!k){break C}if((d|0)==w[Ed(v[c>>2],g)+3|0]){break C}if(!ve(Xb(v[m>>2],l),Dm(no(Se(Le(e,20,(d-4|64)&255),s),g)))){break C}G=Ed(v[c>>2],g),H=d,t[G+3|0]=H}G=e,H=oB(r,w[c+16|0]),t[G+22|0]=H;h=1;i=8;break A;case 7:case 8:G=e,H=NU(r,w[c+16|0],(d|0)==8),t[G+22|0]=H;h=1;i=29;break A;case 9:G=e,H=oB(r,w[c+16|0]),t[G+22|0]=H;h=1;i=27;break A;case 6:break A;default:break B}}z=1;i=0}h=0}if(F){MU(b,k,x[D>>1],f,e+23|0)}if(h){MU(b,k,x[D>>1],i,e+22|0)}D:{E:{F:{G:{H:{if(!E){break H}if(!Wc(w[b|0])){break H}if(!f){break G}if(!z|(f|0)==4){break H}t[e+22|0]=255;i=4}d=b+2|0;if(w[b+2|0]!=1){break D}if(f){break F}t[e+23|0]=w[b+4|0];f=13;break E}t[e+23|0]=255;d=b+2|0;f=4;if(w[b+2|0]!=1){break D}}if(i){break D}t[e+22|0]=w[b+4|0];i=13}t[d|0]=0}g=sg(e);to(e+24|0,g,f,w[e+23|0],i,w[e+22|0]);I:{if(w[d|0]){break I}f=w[e+2|0];if(!f){break I}t[b+2|0]=f;t[b+4|0]=w[e+4|0]}h=w[e+3|0];J:{if(q){to(e+24|0,g,h&255,w[e+5|0],q,o&255);K:{if(w[d|0]){break K}d=w[e+2|0];if(!d){break K}t[b+2|0]=d;t[b+4|0]=w[e+4|0]}h=w[e+3|0];break J}if(!(h&255)){break n}}t[b+3|0]=h;t[b+5|0]=w[e+5|0]}b=b+6|0;y=y+1|0;continue}}break}a=P()|0;O()|0;dc(p);S(a|0);L()}else{t[g+B(b,6)|0]=254;b=b+1|0;continue}}hb=e- -64|0;return l|0}function Uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=hb-304|0;hb=e;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if(!TU(b,e+232|0)){break p}if(!UU(e+232|0)){break p}if(!c){d=1;break p}zd(a,131072);d=hb-16|0;hb=d;i=e+136|0;f=vc(d,3913);Xc(i,f);xb(f);hb=d+16|0;v[23516]=0;U(308,e+184|0,i|0,e+232|4);d=v[23516];v[23516]=0;q:{if((d|0)!=1){d=e+184|0;Gb(a+1298344|0,d);xb(d);i=e+136|0;ac(i);f=vc(d,11114);Gb(a+1298356|0,f);xb(f);v[a+1298404>>2]=5;CB(i,3,e+245|0);Cc(d,i);yc(a+1298308|0,d);wb(d);f=e+112|0;Aj(f,3,e+275|0);Cc(i,f);v[23516]=0;U(11,d|0,5,i|0);d=v[23516];v[23516]=0;if((d|0)==1){break b}d=e+184|0;Gb(a+1298320|0,d);xb(d);wb(e+136|0);d=po(d);o=d,p=Bd(w[e+295|0],1,31),v[o+12>>2]=p;o=d,p=Bd(w[e+296|0],1,12)-1|0,v[o+16>>2]=p;v[d+20>>2]=w[e+297|0];i=a+1298408|0;Gc(i);tB(i,d);g=e+144|0;i=Lb(e+168|0);r:{s:{t:{while(1){d=v[b+8>>2];f=v[b>>2];v[23516]=0;d=W(154,f|0,d|0,8)|0;f=v[23516];v[23516]=0;u:{v:{w:{x:{y:{if((f|0)!=1){if(!d){break r}v[23516]=0;R(309,b|0,e+72|0);d=v[23516];v[23516]=0;if((d|0)==1){break y}d=v[e+76>>2];z:{l=w[e+236|0];switch(l-3|0){case 1:break x;case 0:break z;default:break w}}f=2;if(v[e+72>>2]!=1431389523){break v}break u}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}f=4;if(v[e+72>>2]!=1431389523){break v}break u}f=0;if(l>>>0>7){break u}}d=v[e+72>>2]==1146113363?-1:d;f=0}l=v[e+76>>2];v[e+136>>2]=v[e+72>>2];v[e+140>>2]=l;v[23516]=0;U(188,e+112|0,b|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break t}hc(g,e+112|0);v[23516]=0;R(310,i|0,e+136|0);d=v[23516];v[23516]=0;if((d|0)==1){break s}yd(e+136|0);yb(e+112|0);v[23516]=0;Q(186,b|0,f|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){continue}break}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;yd(e+136|0);yb(e+112|0);break c}v[23516]=0;l=T(172,e+136|0)|0;b=v[23516];v[23516]=0;A:{B:{C:{if((b|0)!=1){v[23516]=0;U(311,e+112|0,i|0,1431389523);b=v[23516];v[23516]=0;if((b|0)==1){break C}d=e+112|0;b=cd(l,d);yb(d);u[e+110>>1]=0;u[e+108>>1]=65534;if(w[e+236|0]<3){break A}v[23516]=0;d=T(192,b|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break B}break e}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}u[e+110>>1]=d;if(w[e+236|0]<4){break A}v[23516]=0;d=T(192,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}u[e+108>>1]=w[e+236|0]==4?d?d:-2:d}d=w[a+484376|0];f=v[a+484360>>2];v[23516]=0;g=T(200,b|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break e}v[23516]=0;U(240,Sb(f,d)|0,b|0,g>>>1|0);d=v[23516];v[23516]=0;if((d|0)==1){break e}d=Sb(v[a+484360>>2],w[a+484376|0]);d=sB(v[d>>2],v[d+4>>2]);Bf(e+110|0,d);Bf(e+108|0,d);v[23516]=0;U(311,e+112|0,i|0,1414807888);d=v[23516];v[23516]=0;if((d|0)==1){break h}d=e+112|0;b=cd(b,d);yb(d);d=v[b>>2];v[23516]=0;d=T(176,d|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}if(!(c&1)|d^1){break q}v[23516]=0;R(312,b|0,e+8|0);d=v[23516];v[23516]=0;if((d|0)==1){break i}o=a+480188|0,p=Bd(w[e+10|0],1,32)+1|0,u[o>>1]=p;v[23516]=0;d=Q(217,e+96|0,x[e+8>>1])|0;f=v[23516];v[23516]=0;if((f|0)==1){break j}o=e,p=Cb(v[d>>2]),v[o+48>>2]=p;g=Cb(v[d+4>>2]);D:{E:{while(1){h=v[e+48>>2];if(!Nb(h,g)){f=x[a+480188>>1];v[23516]=0;f=Q(313,e+112|0,f|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){g=a+484376|0;h=Sb(v[a+484360>>2],w[g|0]);h=ul(v[h>>2],v[h+4>>2]);v[23516]=0;k=a+484344|0;R(224,k|0,h|0);h=v[23516];v[23516]=0;if((h|0)==1){break g}g=Sb(v[a+484360>>2],w[g|0]);o=e,p=Cb(v[g>>2]),v[o+72>>2]=p;h=Cb(v[g+4>>2]);F:{while(1){G:{g=v[e+72>>2];if(!Nb(g,h)){g=w[a+484376|0];h=v[a+484360>>2];v[23516]=0;j=Sb(h,g);h=x[e+108>>1];g=Q(314,j|0,h|0)|0;j=v[23516];v[23516]=0;if((j|0)!=1){break G}break g}j=v[d>>2];n=wf(j,v[d+4>>2]);m=x[g>>1];if(n>>>0>m>>>0){v[23516]=0;j=fa(315,Kg(j,m)|0,w[e+236|0],f|0,a|0)|0;m=v[23516];v[23516]=0;if((m|0)==1){break F}u[g>>1]=j}Qe(e+72|0);continue}break}H:{if(!g){break H}g=Sb(v[a+484360>>2],w[a+484376|0]);j=x[e+110>>1];if(!j){if(sB(v[g>>2],v[g+4>>2])>>>0<=h>>>0){break H}}g=Xb(v[k>>2],x[$b(v[g>>2],h)>>1]);ve(g,Dm(Se(Le(e+72|0,12,j&255),v[g+12>>2]-1|0)))}Ah(f);Nc(d);break q}break g}b=P()|0;O()|0;break f}v[23516]=0;f=w[e+236|0]<3?9:8;Q(186,b|0,f-4|0)|0;k=v[23516];v[23516]=0;if((k|0)!=1){v[23516]=0;k=T(155,b|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break E}wg(b,f);v[23516]=0;U(188,e+72|0,b|0,f+k|0);f=v[23516];v[23516]=0;if((f|0)==1){break D}j=h;f=e+72|0;h=hc(e+112|0,f);cd(j,h);yb(h);yb(f);Jf(e+48|0);continue}break}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;ac(e+136|0);break a}v[23516]=0;U(311,e+72|0,i|0,1196641603);d=v[23516];v[23516]=0;if((d|0)==1){break n}d=e+72|0;b=cd(b,d);yb(d);d=v[b>>2];v[23516]=0;d=T(176,d|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}if(d){v[23516]=0;Q(186,b|0,1)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}v[23516]=0;d=T(200,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}v[23516]=0;da(316,a+1298332|0,b|0,d|0,40,0);d=v[23516];v[23516]=0;if((d|0)==1){break e}}v[23516]=0;U(311,e+72|0,i|0,1146113363);d=v[23516];v[23516]=0;if((d|0)==1){break k}v[23516]=0;U(311,e+48|0,i|0,1229999443);d=v[23516];v[23516]=0;if((d|0)==1){break o}d=e+48|0;b=cd(b,d);yb(d);v[23516]=0;d=T(204,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break m}h=a+480190|0;u[h>>1]=d;k=!(c&2);f=1;I:{while(1){J:{c=f&65535;if(c>>>0>(d&65535)>>>0){break I}d=30;K:{L:{M:{if(w[e+236|0]>=2){v[23516]=0;d=T(204,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break M}}v[23516]=0;U(317,b|0,((c<<5)+a|0)+946304|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break M}v[23516]=0;R(318,b|0,e+32|0);d=v[23516];v[23516]=0;if((d|0)==1){break L}v[23516]=0;g=B(c,104)+a|0;j=g+484380|0;R(319,e+32|0,j|0);c=v[23516];v[23516]=0;if((c|0)==1){break L}d=w[e+236|0];if(d>>>0>=8){v[23516]=0;R(320,b|0,g+484423|0);c=v[23516];v[23516]=0;if((c|0)==1){break L}d=w[e+236|0]}v[23516]=0;Q(186,b|0,((d&255)>>>0>1?6:2)|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break L}v[23516]=0;c=T(155,e+72|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;U(188,e+8|0,e+72|0,c|0);c=v[23516];v[23516]=0;if((c|0)!=1){break K}}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}d=e+8|0;c=hc(e+48|0,d);yb(d);d=v[c>>2];v[23516]=0;d=T(176,d|0)|0;m=v[23516];v[23516]=0;if((m|0)!=1){N:{if(k|d^1){break N}d=Uc(e+8|0,u[g+484414>>1]&1?16:8,1,0,(w[e+47|0]&12)==4?7:0);v[23516]=0;W(218,d|0,j|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break N}break J}yb(c);f=f+1|0;d=x[h>>1];continue}}break}b=P()|0;O()|0;yb(c);break l}$f(a);v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;v[23516]=0;d=1;W(267,a+1074312|0,114,1)|0;a=v[23516];v[23516]=0;if((a|0)==1){break m}yb(e+72|0);yb(b);Ud(i)}hb=e+304|0;return d|0}b=P()|0;O()|0;break l}b=P()|0;O()|0;break d}b=P()|0;O()|0}yb(e+72|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;Ah(f)}Nc(d);break d}b=P()|0;O()|0}yb(l)}Ud(i);break a}b=P()|0;O()|0;wb(e+136|0)}S(b|0);L()}function Jfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0;d=hb-1344|0;hb=d;xc(b);f=hb-16|0;hb=f;pR(f+8|0,d+232|0);e=v[f+12>>2];jc(f,v[b>>2],v[b+8>>2],v[f+8>>2],e);j=v[f+4>>2];if((j|0)==(e|0)){Yb(b,v[f+12>>2])}hb=f+16|0;a:{if((e|0)!=(j|0)){break a}if(!rR(d+232|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(qR(v[d+1336>>2]),kb))){break a}if(!c){m=1;break a}xc(b);b=he(d+232|0,b);v[23516]=0;R(631,d+216|0,b|0);f=v[23516];v[23516]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((f|0)!=1){yb(b);v[23516]=0;U(632,d+200|0,d+216|0,1196314451);b=v[23516];v[23516]=0;if((b|0)==1){break i}v[23516]=0;U(632,d+184|0,d+216|0,1280331091);b=v[23516];v[23516]=0;if((b|0)==1){break h}if(nc(v[d+200>>2],v[d+204>>2])){break b}if(!nc(v[d+184>>2],v[d+188>>2])){break g}break b}c=P()|0;O()|0;yb(b);break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}v[23516]=0;R(248,a|0,1);b=v[23516];v[23516]=0;j:{k:{l:{m:{n:{if((b|0)!=1){$f(a);v[a+480188>>2]=4;v[a+480208>>2]=25231360;D=d,E=Cb(v[d+184>>2]),v[D+48>>2]=E;g=c&2;m=Cb(v[d+188>>2]);f=a+480190|0;o:{p:{while(1){e=v[d+48>>2];if(!Nb(e,m)){break p}b=x[f>>1];if(!Yh(b)){break p}b=b+1|0;u[f>>1]=b;v[23516]=0;b=B(b&65535,104)+a|0;j=b+484380|0;R(280,j|0,1);i=v[23516];v[23516]=0;q:{r:{if((i|0)!=1){v[23516]=0;i=Q(633,e|0,d+232|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break r}if(!i){break c}if(Ft(d+232|0)){break q}break c}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[23516]=0;i=Q(53,d+168|0,d+232|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break o}Ac(((x[f>>1]<<5)+a|0)+946304|0,i);wb(i);i=v[d+268>>2];v[j>>2]=i;v[b+484388>>2]=i;v[b+484384>>2]=v[d+264>>2];i=b+484414|0;u[i>>1]=x[i>>1]|2;u[b+484410>>1]=255;s:{if(g){b=Uc(d+16|0,8,1,0,0);v[23516]=0;W(218,b|0,j|0,e|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break s}}Jf(d+48|0);continue}break}c=P()|0;O()|0;break j}D=d,E=Cb(v[d+200>>2]),v[D+160>>2]=E;q=a+484344|0;A=c&1;s=a+484360|0;C=Cb(v[d+204>>2]);l=a+484376|0;p=a+480190|0;y=a+484380|0;z=a+946304|0;c=1;m=1;while(1){t:{u:{v:{w:{x:{y:{b=v[d+160>>2];if(!Nb(b,C)){break y}if(!(c&1)){v[23516]=0;c=T(275,s|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break x}if(!c){break y}}Gc(Sb(v[a+484360>>2],w[l|0]));v[23516]=0;c=Q(634,b|0,d+232|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break w}if(!(c&!x[d+1318>>1])|v[d+1320>>2]-5>>>0<4294967292){break c}c=w[l|0];f=v[a+484360>>2];v[23516]=0;U(5,d+48|0,5,d+232|0);e=v[23516];v[23516]=0;if((e|0)==1){break k}v[23516]=0;R(276,Sb(f,c)|0,d+48|0);c=v[23516];v[23516]=0;if((c|0)==1){break l}xb(d+48|0);z:{if(A){v[23516]=0;U(188,d+48|0,b|0,v[d+1328>>2]);b=v[23516];v[23516]=0;if((b|0)==1){break m}b=d+48|0;hc(d+136|0,b);break z}v[23516]=0;b=T(172,d+112|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break n}c=zD(d+48|0,b);hc(d+136|0,c);yb(c)}yb(b);Rb(d+48|0,0,64);c=1;A:{B:{C:{while(1){if((c|0)==32){break C}b=(B(c,34)+d|0)+198|0;f=b+32|0;Mm(d,f);D:{E:{if(!w[v[d>>2]]){break E}e=w[b- -64|0];if(e>>>0>15){break B}b=w[b+65|0];if(b>>>0>64){break B}if(!Ft(f)){break B}j=b<<2;i=e<<4;f=0;b=1;F:{while(1){g=b&65535;e=x[p>>1];if(g>>>0>e>>>0){break F}v[23516]=0;U(533,d+16|0,v[d>>2],v[d+4>>2]);e=v[23516];v[23516]=0;if((e|0)==1){break D}e=hb-16|0;hb=e;k=d+16|0;Be(e+8|0,k);nR(e,((g<<5)+a|0)+946304|0);h=v[e+8>>2];r=v[e>>2];n=v[e+12>>2];o=v[e+4>>2];if((n|0)==(o|0)){h=(VS(h,n,r,o)|0)!=0}else{h=1}hb=e+16|0;wb(k);G:{H:{if(h){break H}D=$b(d+48|0,c),E=b,u[D>>1]=E;e=B(g,104)+a|0;g=e+484410|0;h=x[g>>1];if((h|0)==255){break G}f=b;if(w[e+484417|0]!=(i&255)){break H}if((h|0)==(j|0)){break G}}b=b+1|0;continue}break}t[e+484417|0]=i;u[g>>1]=j;break E}f=f&65535;if(!f){break E}if(!Yh(e)){break E}b=e+1|0;u[p>>1]=b;D=$b(d+48|0,c),E=b,u[D>>1]=E;b=B(x[p>>1],104)+y|0;um(b);e=B(f,104)+y|0;g=_n(b,e);u[b+30>>1]=j;t[b+37|0]=i;gS(g,e);f=(f<<5)+z|0;e=v[f+4>>2];b=(x[p>>1]<<5)+z|0;v[b>>2]=v[f>>2];v[b+4>>2]=e;e=v[f+28>>2];v[b+24>>2]=v[f+24>>2];v[b+28>>2]=e;e=v[f+20>>2];v[b+16>>2]=v[f+16>>2];v[b+20>>2]=e;e=v[f+12>>2];v[b+8>>2]=v[f+8>>2];v[b+12>>2]=e}c=c+1|0;continue}break}break v}i=0;v[d+40>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;e=64;j=65535;r=x[d+1320>>1];f=0;I:while(1){J:{if(f){break J}v[23516]=0;b=W(154,v[d+136>>2],v[d+144>>2],1)|0;c=v[23516];v[23516]=0;if((c|0)==1){break A}if(b){break J}b=j;break u}e=e+1|0;if(e>>>0>=64){v[23516]=0;j=Q(366,q|0,64)|0;b=v[23516];v[23516]=0;if((b|0)==1){break A}b=65535;if((j|0)==65535){break u}b=w[l|0];c=v[a+484360>>2];e=0;v[23516]=0;R(531,Sb(c,b)|0,j|0);b=v[23516];v[23516]=0;if((b|0)==1){break A}}b=0;c=Xb(v[q>>2],j&65535);c=ed(v[c>>2],v[v[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(r|0)){continue I}g=(d+16|0)+B(b,7)|0;h=w[g+6|0];K:{if(h){t[g+6|0]=h-1;h=w[g+4|0]|w[g+5|0]<<8;t[c+4|0]=h;t[c+5|0]=h>>>8;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[c|0]=g;t[c+1|0]=g>>>8;t[c+2|0]=g>>>16;t[c+3|0]=g>>>24;f=f-1|0;break K}v[23516]=0;h=W(154,v[d+136>>2],v[d+144>>2],1)|0;k=v[23516];v[23516]=0;if((k|0)==1){break v}if(!h){break K}if(v[d+144>>2]==v[d+1324>>2]){i=Sb(v[a+484360>>2],w[l|0]);Te(i,sB(v[i>>2],v[i+4>>2]));i=e}v[23516]=0;h=T(204,d+136|0)|0;k=v[23516];v[23516]=0;L:{if((k|0)!=1){h=h<<24>>24;if((h|0)>=0){break L}h=h&127;t[g+6|0]=h;k=w[g+4|0]|w[g+5|0]<<8;t[c+4|0]=k;t[c+5|0]=k>>>8;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[c|0]=g;t[c+1|0]=g>>>8;t[c+2|0]=g>>>16;t[c+3|0]=g>>>24;f=f+h|0;break K}break v}if((h-1&255)>>>0<=35){t[c|0]=h+48}v[23516]=0;h=T(204,d+136|0)|0;k=v[23516];v[23516]=0;M:{N:{if((k|0)!=1){D=c,E=w[$b(d+48|0,h&31)|0],t[D+1|0]=E;if(!(h&128)){break N}t[c+3|0]=w[g+3|0];t[c+5|0]=w[g+5|0];break M}break v}v[23516]=0;R(263,d|0,d+136|0);h=v[23516];v[23516]=0;O:{if((h|0)!=1){h=w[d|0];if(h>>>0>19){break M}n=h<<1;o=w[n+27120|0];t[c+3|0]=o;k=w[Kc(d)|0];t[c+5|0]=k;if((o|0)!=16|k>>>0<32){break O}t[c+3|0]=17;break M}break v}if(819137>>>h&1){break M}t[c+5|0]=w[n+27121|0]|k&15}h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[g|0]=h;t[g+1|0]=h>>>8;t[g+2|0]=h>>>16;t[g+3|0]=h>>>24;h=w[c+4|0]|w[c+5|0]<<8;t[g+4|0]=h;t[g+5|0]=h>>>8}c=c+6|0;b=b+1|0;continue}}}m=0;break t}break v}Dj(s,0);v[23516]=0;b=Q(1,d+232|0,6470)|0;c=v[23516];v[23516]=0;P:{if((c|0)!=1){Gb(a+1298344|0,b);xb(b);v[23516]=0;b=Q(1,d+48|0,6772)|0;c=v[23516];v[23516]=0;if((c|0)==1){break P}Gb(a+1298356|0,b);xb(b);v[a+1298404>>2]=5;m=1;break b}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;yb(d+136|0);break j}Q:{if(!i&e>>>0>62){break Q}b=b&65535;if((b|0)==65535){break Q}ve(Xb(v[q>>2],b),Eh(Se(Le(d,14,i&255),e)))}c=32}yb(d+136|0);if(c>>>0<32){break b}Jf(d+160|0);c=0;continue}}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;xb(d+48|0);break j}c=P()|0;O()|0}Nc(d+184|0)}Nc(d+200|0)}Ud(d+216|0)}S(c|0);L()}m=0}Nc(d+184|0);Nc(d+200|0);Ud(d+216|0)}hb=d+1344|0;return m|0}function hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=hb-336|0;hb=d;a:{if(!Zc(b,1080)){break a}if(!eo(b,d+332|0)){break a}zd(a,1);m=WR(d+312|0);if(!VR(d+332|0,m)){break a}f=x[m+10>>1];if(!f|f>>>0>127){break a}if(!c){g=1;break a}r=a+480188|0;u[r>>1]=f;p=w[m+14|0];E=w[m+13|0];h=w[m+12|0];F=1;if(!le(d+332|0,27050)){F=le(d+332|0,27055)}if(w[m+15|0]){Mb(a+1074312|0,5,1);f=x[a+480188>>1]}g=d+332|0;s=le(g,16824);e=1;if(!le(g,17588)){e=le(d+332|0,13625)}z=(f&65535)==8&(E|0)!=0;Zc(b,0);GA(b,a+1298308|0,20);u[a+480190>>1]=31;l=(h|0)!=0;q=a+480188|0;g=1;f=s;while(1)if((g|0)==32){b:{c:{d:{e:{f:{g:{N=v[m+4>>2];if(N>>>0>=G>>>0){h=d+176|0;QR(b,h);Zc(b,x[m+8>>1]);g=w[d+177|0];e=128;j=a+484376|0;Aq(Sb(v[a+484360>>2],w[j|0]),h|2,128);h=!g&f;k=h?k:0;f=w[d+176|0];h:{if(f>>>0>128){break h}e=f;if(f){break h}f=v[Sb(v[a+484360>>2],w[a+484376|0])>>2];g=128;while(1){e=g;if(e>>>0<2){e=1;break h}g=e-1|0;if(!x[$b(f,g)>>1]){continue}break}}o=PR(b,Sb(v[a+484360>>2],w[j|0]),e&65535,i,r,k,0);H=1;i:{if(!(h&x[a+480188>>1]==8)){H=(p|0)!=0;break i}v[m>>2]=11299}j:{if(!z){break j}f=Sb(v[a+484360>>2],w[a+484376|0]);aa=d,ba=Cb(v[f>>2]),v[aa+160>>2]=ba;h=Cb(v[f+4>>2]);while(1){f=v[d+160>>2];if(!Nb(f,h)){break j}u[f>>1]=x[f>>1]>>>1;Qe(d+160|0);continue}}f=a+484376|0;Te(Sb(v[a+484360>>2],w[f|0]),w[d+177|0]);Q=e-1|0;e=w[d+177|0];k:{if((Q&65535)>>>0>=e>>>0){g=x[r>>1];if((e|0)!=120|(g|0)!=4){break k}}Te(Sb(v[a+484360>>2],w[f|0]),0);g=x[a+480188>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;k=0;v[a+480208>>2]=0;aa=a,ba=Wb(256/((g&65535)>>>0)|0,32,128),v[aa+480228>>2]=ba;jh(a,0);t[d+175|0]=0;l:{if(l&1){p=1;e=1;break l}p=1;e=0;l=0;h=s;m:while(1){n:{q=0;if(o>>>0<=(l&65535)>>>0){break n}g=0;while(1)if((g|0)==256){l=l+1|0;continue m}else{f=d+144|0;j=sg(d+160|0);tu(f,b,j);i=Kc(f);n=YA(w[j|0]);o:{p:{q:{r:{j=w[d+144|0];if((j-7&255)>>>0<3){h=0;break r}f=w[i|0];if(!((j|0)!=14|f>>>0<=1)){h=0;break q}if(!((j|0)==15&(f&255)>>>0>31)){h=n?h:0;if((j|0)!=13){break r}q=q+1|0;if((q&65535)>>>0<2){break o}}h=0;break o}if((j|0)==8){break p}if((j|0)!=14){break o}f=w[i|0]}if((f&240)!=128){break o}t[d+80|0]=f<<4;aa=d,ba=w[ef(d+175|0,d+80|0)|0],t[aa+175|0]=ba;break o}aa=d,ba=w[ef(d+175|0,i)|0],t[aa+175|0]=ba;f=t[i|0];if((f|0)>=0){k=1;break o}e=(f|0)!=-92&f>>>0>4294967183|e}p=n&p;g=g+1|0;continue}}break}f=k^-1;k=0;k=(e|f)&1?k:w[d+175|0]>47;e=h&1}j=e;Zc(b,x[m+8>>1]);e=x[a+480188>>1];n=a+484344|0;I=o+z&65535;vg(n,I);R=z?4:e;o=a+1074312|0;_=k^1;$=c&1;l=0;k=0;s:{t:{u:{while(1){if((l|0)==(I|0)){break t}v:{if(z){e=(l&65534)>>>1|0;f=l&1;if(!f){if(!kh(n,e,64)){break t}}g=Xb(v[n>>2],e);e=f<<2;break v}if(!kh(n,l&65535,64)){break t}g=Xb(v[n>>2],l);e=0}h=0;q=ed(v[g>>2],v[v[g+48>>2]+12>>2],0,e);if(!$){J=0;K=0;break s}e=x[r>>1];t[d+80|0]=0;f=e;e=d+80|0;C=qu(d+160|0,f,e);f=x[r>>1];v[23516]=0;t[d+80|0]=0;D=W(589,d+144|0,f|0,e|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){M=0;w:{x:while(1){y:{if((M|0)==64){break w}g=0;f=0;T=0;while(1){if((g|0)==(R|0)){M=M+1|0;J=f&T|J;q=B(x[r>>1],6)+q|0;continue x}v[23516]=0;h=B(g,6)+q|0;U(590,d+80|0,b|0,h|0);e=v[23516];v[23516]=0;if((e|0)!=1){e=w[d+80|0];y=Kc(d+80|0);i=w[y|0];if(e|i){z:{if(!(!E|(e&255)!=14)){e=0;t[y|0]=0;t[d+80|0]=0;i=w[y|0];break z}if(!E|(e&255)!=15|(i&255)>>>0<32){break z}i=31;t[y|0]=31;e=w[d+80|0]}Nf(h,e&255,i&255)}e=1;A:{B:{C:{D:{E:{i=w[h+3|0];switch(i-14|0){case 2:break A;case 0:break D;case 3:break E;default:break C}}k=w[h+5|0]<100|k;T=1;break B}if(!j){break B}t[h+5|0]=0;break B}if(!((i|0)!=9|_)){e=w[h+5|0];if((e|0)==164){t[h+3|0]=20;t[h+5|0]=145;break B}aa=h,ba=rg(e<<1),t[aa+5|0]=ba;break B}if((i|0)!=19){break B}e=w[h+5|0];if(e>>>0>15){break B}i=e&1;e=!i;y=!i;i=V&1;V=(i|0)==(e|0)?V:y;K=((e|0)!=(i|0))+K|0}e=f}F:{if(!w[h|0]){f=w[h+1|0];if(!f|z){break F}i=w[Ib(v[C>>2],g)|0];if(!i|(f|0)==(i|0)){break F}i=Ib(v[D>>2],g);f=w[i|0]+1|0;t[i|0]=f;if((f&255)>>>0<4){break F}v[23516]=0;W(267,o|0,85,1)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break F}break y}aa=Ib(v[D>>2],g),ba=0,t[aa|0]=ba}f=w[h+1|0];if(f){aa=Ib(v[C>>2],g),ba=f,t[aa|0]=ba}g=g+1|0;f=e;continue}break}}break}f=P()|0;O()|0;dc(D);break u}dc(D);dc(C);l=l+1|0;continue}break}f=P()|0;O()|0}dc(C);break b}h=k}G:{H:{I:{if((p^-1|X)&1){break I}J:{if(le(d+332|0,16824)){break J}if(le(d+332|0,17593)){break J}if(!le(d+332|0,13615)){break I}}v[a+480208>>2]=v[a+480208>>2]|2162688;e=Mb(Mb(Mb(o,85,1),91,1),92,1);K:{if(w[d+175|0]>47){break K}e=Mb(e,84,1);if(w[d+177|0]==127){break K}Mb(e,83,1)}if(!(p&1)){break G}break H}if(p&1){break H}if(s^1|w[d+177|0]!=127|(Q&65535)>>>0>128){break G}v[m>>2]=8523;break G}if((K|0)>6|H){break G}v[a+480208>>2]=v[a+480208>>2]|8388608}if((s|H)==1){Mb(o,89,1)}if(F){Mb(o,84,1)}L:{if(!(c&2)){break L}Zc(b,x[m+8>>1]+(B(I,R)<<8)|0);f=(p&s^1|Y)&1;g=1;while(1){if((g|0)==32){break L}k=B(g,104)+a|0;c=k+484380|0;e=v[c>>2];if(e){i=2;if(!F){i=OR(b,13931)?10:0;e=v[c>>2]}j=Uc(d+160|0,8,1,0,i);e=IA(j,e)+v[b+8>>2]|0;if(!f){aa=c,ba=v[Vc(c,k+484388|0)>>2],v[aa>>2]=ba}ug(j,c,b);Zc(b,e)}g=g+1|0;continue}}M:{if((h&s^-1|J)&1){break M}b=NR(d+120|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;b=d+160|0;Jt(b,a,0,d+24|0);Z=A[v[d+160>>2]>>3];Ci(b);if(!(Z>=480)){break M}c=Mb(o,5,1);b=MR(d+96|0,Z);e=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=e;e=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=d+160|0;Jt(b,a,0,d);e=w[v[d+160>>2]+26|0];Ci(b);if(e){Lf(c,5);break M}v[m>>2]=17176}b=d+332|0;e=b;f=gc(b);c=b;while(1){if((e|0)!=(f|0)){h=w[e|0];t[c|0]=h>>>0>32?h:32;c=c+1|0;e=e+1|0;continue}break}Qf(d+80|0,16929);v[23516]=0;b=W(591,d+48|0,b|0,f|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break g}v[23516]=0;U(11,d- -64|0,1,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break f}v[23516]=0;U(143,d+160|0,d+80|0,d- -64|0);c=v[23516];v[23516]=0;if((c|0)==1){break e}c=d+160|0;Gb(a+1298344|0,c);xb(c);xb(d- -64|0);wb(b);ac(d+80|0);b=vc(c,12354);Gb(a+1298356|0,b);xb(b);b=v[m>>2];if(b){Hl(a+1298368|0,b)}v[a+1298404>>2]=14}g=G>>>0<=N>>>0;break a}f=P()|0;O()|0;break c}f=P()|0;O()|0;break d}f=P()|0;O()|0;xb(d- -64|0)}wb(b)}ac(d+80|0)}S(f|0);L()}else{j=B(g,104)+a|0;h=j+484380|0;o=cA(b,d+176|0,h,((g<<5)+a|0)+946304|0,x[q>>1]==4);h=v[h>>2];N:{if(e){t[j+484417|0]=0-(w[d+200|0]<<3);break N}l=h>>>0<65536&l}j=Eb(x[d+198>>1]);O:{if(j){X=!Eb(x[d+204>>1])|X;break O}Y=w[d+201|0]==64|Y}n=f&1;f=0;P:{if(!n){break P}k=(j<<1)+k|0;n=w[d+200|0];f=!n;if(n|!j){break P}f=w[d+201|0]==64}G=o+G|0;i=h+i|0;g=g+1|0;continue}}hb=d+336|0;return g|0}function W6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=0,u=0,x=C(0),y=C(0),A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=C(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=C(0),Z=0,_=0,$=C(0);a:{if(!w[a+5046|0]){break a}g=z[a+4268>>2];pK(a);if(g==z[a+4268>>2]){break a}wx(a)}b:{if(!w[a+5045|0]){break b}if(!ai(a+44|0)){break b}i=v[a+44>>2];p=Ec(i,0);q=Ec(i,1);i=v[a+56>>2];l=Ec(i,0);m=Ec(i,1);c:{if(!(!w[a+5044|0]|(!d|w[a+4264|0]&2))){z[l>>2]=z[a+5036>>2];z[m>>2]=z[a+5040>>2];t[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;u=a+4864|0;U=a+4504|0;V=a+4960|0;W=a+4868|0;X=a+4892|0;D=a+4628|0;E=a+4604|0;Q=a+4916|0;F=a+4532|0;G=a+4508|0;H=a+4772|0;I=a+4748|0;R=a+4940|0;J=a+4676|0;K=a+4652|0;L=a+4724|0;M=a+4700|0;S=a+4844|0;N=a+4580|0;O=a+4556|0;T=a+4820|0;d:{while(1){if(!r){break d}g=z[p>>2];g=C(C(C(z[a+5008>>2]-g)*z[a+4276>>2])+g);z[a+5008>>2]=g;_=Lc(v[a+4864>>2],v[W>>2],v[a+4880>>2]),$=g,z[_>>2]=$;g=z[q>>2];g=C(C(C(z[a+5012>>2]-g)*z[a+4276>>2])+g);z[a+5012>>2]=g;_=Lc(v[a+4888>>2],v[X>>2],v[a+4904>>2]),$=g,z[_>>2]=$;g=C(C(C(C(C(Rh(u,v[a+4356>>2])*C(.6800000071525574))+C(Rh(u,v[a+4360>>2])*C(-.5)))-C(Rh(u,v[a+4364>>2])*C(.6200000047683716)))+C(Rh(u,v[a+4368>>2])*C(-.5)))-C(Rh(u,v[a+4372>>2])*C(.6200000047683716)));if(t[a+4264|0]&1){e=g;g=C(z[Lc(v[a+4816>>2],v[T>>2],v[a+4836>>2])>>2]+C(e*C(.6180340051651001)));_=Lc(v[a+4816>>2],v[T>>2],v[a+4832>>2]),$=C(e-C(g*C(.6180340051651001))),z[_>>2]=$}x=z[a+4280>>2];_=a,$=C(Rh(u,v[a+4352>>2])+z[a+5020>>2]),z[_+5020>>2]=$;e=C(Rh(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=e;f=z[a+5020>>2];h=C(C(C(z[a+4980>>2]-z[Lc(v[a+4624>>2],v[D>>2],v[a+4644>>2])>>2])*z[a+4444>>2])+z[Lc(v[a+4624>>2],v[D>>2],v[a+4644>>2])>>2]);z[a+4980>>2]=h;P=C(h*z[a+4440>>2]);k=C(e*C(.7070000171661377));j=C(f*C(-.7070000171661377));f=C(k+j);h=z[a+4272>>2];e=C(P+C(f*h));_=Lc(v[a+4624>>2],v[D>>2],v[a+4640>>2]),$=C(f-C(h*e)),z[_>>2]=$;f=C(C(C(z[a+4976>>2]-z[Lc(v[a+4600>>2],v[E>>2],v[a+4620>>2])>>2])*z[a+4436>>2])+z[Lc(v[a+4600>>2],v[E>>2],v[a+4620>>2])>>2]);z[a+4976>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4432>>2])+C(e*h));_=Lc(v[a+4600>>2],v[E>>2],v[a+4616>>2]),$=C(e-C(h*f)),z[_>>2]=$;y=C(C(e*C(-.15000000596046448))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){e=C(C(C(z[a+4972>>2]-z[Lc(v[a+4576>>2],v[N>>2],v[a+4596>>2])>>2])*z[a+4428>>2])+z[Lc(v[a+4576>>2],v[N>>2],v[a+4596>>2])>>2]);z[a+4972>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4424>>2])+C(f*h));_=Lc(v[a+4576>>2],v[N>>2],v[a+4592>>2]),$=C(f-C(h*e)),z[_>>2]=$;f=C(C(C(z[a+4968>>2]-z[Lc(v[a+4552>>2],v[O>>2],v[a+4572>>2])>>2])*z[a+4420>>2])+z[Lc(v[a+4552>>2],v[O>>2],v[a+4572>>2])>>2]);z[a+4968>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4416>>2])+C(e*h));_=Lc(v[a+4552>>2],v[O>>2],v[a+4568>>2]),$=C(e-C(h*f)),z[_>>2]=$;y=C(C(C(e*C(.3499999940395355))+y)+C(f*C(-.3799999952316284)))}_=Lc(v[a+4912>>2],v[Q>>2],v[a+4928>>2]),$=f,z[_>>2]=$;e=C(z[Lc(v[a+4912>>2],v[Q>>2],v[a+4932>>2])>>2]*z[a+4496>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-e)*z[a+4500>>2])+e;e=C(C(C(z[a+4964>>2]-z[Lc(v[a+4528>>2],v[F>>2],v[a+4548>>2])>>2])*z[a+4412>>2])+z[Lc(v[a+4528>>2],v[F>>2],v[a+4548>>2])>>2]);z[a+4964>>2]=e;f=z[a+5028>>2];o=z[a+4272>>2];h=C(C(f*o)+C(e*z[a+4408>>2]));_=Lc(v[a+4528>>2],v[F>>2],v[a+4544>>2]),$=C(f-C(o*h)),z[_>>2]=$;e=C(C(C(z[a+4960>>2]-z[Lc(v[a+4504>>2],v[G>>2],v[a+4524>>2])>>2])*z[a+4404>>2])+z[Lc(v[a+4504>>2],v[G>>2],v[a+4524>>2])>>2]);z[a+4960>>2]=e;f=C(e*z[a+4400>>2]);e=z[a+4272>>2];o=C(f+C(h*e));_=Lc(v[a+4504>>2],v[G>>2],v[a+4520>>2]),$=C(h-C(e*o)),z[_>>2]=$;z[a+5020>>2]=o;e=C(C(C(C(C(Rh(s,v[a+4380>>2])*C(.7070000171661377))+C(Rh(s,v[a+4384>>2])*C(-.6000000238418579)))-C(Rh(s,v[a+4388>>2])*C(.5)))+C(Rh(s,v[a+4392>>2])*C(-.6000000238418579)))-C(Rh(s,v[a+4396>>2])*C(.5)));if(t[a+4264|0]&1){f=e;e=C(z[Lc(v[a+4840>>2],v[S>>2],v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));_=Lc(v[a+4840>>2],v[S>>2],v[a+4856>>2]),$=C(f-C(e*C(.6180340051651001))),z[_>>2]=$}Y=z[a+4280>>2];f=C(C(C(z[a+5004>>2]-z[Lc(v[a+4768>>2],v[H>>2],v[a+4788>>2])>>2])*z[a+4492>>2])+z[Lc(v[a+4768>>2],v[H>>2],v[a+4788>>2])>>2]);z[a+5004>>2]=f;P=C(f*z[a+4488>>2]);f=C(j-k);j=z[a+4272>>2];k=C(P+C(f*j));_=Lc(v[a+4768>>2],v[H>>2],v[a+4784>>2]),$=C(f-C(j*k)),z[_>>2]=$;f=C(C(C(z[a+5e3>>2]-z[Lc(v[a+4744>>2],v[I>>2],v[a+4764>>2])>>2])*z[a+4484>>2])+z[Lc(v[a+4744>>2],v[I>>2],v[a+4764>>2])>>2]);z[a+5e3>>2]=f;j=z[a+4272>>2];f=C(C(f*z[a+4480>>2])+C(k*j));_=Lc(v[a+4744>>2],v[I>>2],v[a+4760>>2]),$=C(k-C(j*f)),z[_>>2]=$;k=C(C(C(h*C(.3799999952316284))+C(k*C(-.15000000596046448)))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){h=C(C(C(z[a+4996>>2]-z[Lc(v[a+4720>>2],v[L>>2],v[a+4740>>2])>>2])*z[a+4476>>2])+z[Lc(v[a+4720>>2],v[L>>2],v[a+4740>>2])>>2]);z[a+4996>>2]=h;j=z[a+4272>>2];h=C(C(h*z[a+4472>>2])+C(f*j));_=Lc(v[a+4720>>2],v[L>>2],v[a+4736>>2]),$=C(f-C(j*h)),z[_>>2]=$;f=C(C(C(z[a+4992>>2]-z[Lc(v[a+4696>>2],v[M>>2],v[a+4716>>2])>>2])*z[a+4468>>2])+z[Lc(v[a+4696>>2],v[M>>2],v[a+4716>>2])>>2]);z[a+4992>>2]=f;j=z[a+4272>>2];f=C(C(f*z[a+4464>>2])+C(h*j));_=Lc(v[a+4696>>2],v[M>>2],v[a+4712>>2]),$=C(h-C(j*f)),z[_>>2]=$;k=C(C(C(h*C(.3499999940395355))+k)+C(f*C(-.3799999952316284)))}Z=q+4|0;n=p+4|0;h=C(g*x);y=C(y-C(o*C(.3799999952316284)));o=C(e*Y);_=Lc(v[a+4936>>2],v[R>>2],v[a+4952>>2]),$=f,z[_>>2]=$;g=C(z[Lc(v[a+4936>>2],v[R>>2],v[a+4956>>2])>>2]*z[a+4496>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-g)*z[a+4500>>2])+g;g=C(C(C(z[a+4988>>2]-z[Lc(v[a+4672>>2],v[J>>2],v[a+4692>>2])>>2])*z[a+4460>>2])+z[Lc(v[a+4672>>2],v[J>>2],v[a+4692>>2])>>2]);z[a+4988>>2]=g;e=z[a+5032>>2];f=z[a+4272>>2];g=C(C(e*f)+C(g*z[a+4456>>2]));_=Lc(v[a+4672>>2],v[J>>2],v[a+4688>>2]),$=C(e-C(f*g)),z[_>>2]=$;f=z[a+4284>>2];e=C(C(C(z[a+4984>>2]-z[Lc(v[a+4648>>2],v[K>>2],v[a+4668>>2])>>2])*z[a+4452>>2])+z[Lc(v[a+4648>>2],v[K>>2],v[a+4668>>2])>>2]);z[a+4984>>2]=e;x=z[a+4272>>2];e=C(C(e*z[a+4448>>2])+C(g*x));_=Lc(v[a+4648>>2],v[K>>2],v[a+4664>>2]),$=C(g-C(x*e)),z[_>>2]=$;z[a+5024>>2]=e;e=C(-e);x=z[a+4288>>2];i=U;e:{f:{while(1){if((i|0)==(V|0)){g:{e=C(o+C(C(C(e*C(.3799999952316284))+k)*x));g=C(h+C(C(C(g*C(.3799999952316284))+y)*f));if(!(w[a+4264|0]&2)){break g}p=n;n=Z;break f}}else{A=v[i+16>>2];B=A-1|0;v[i+16>>2]=B;if((A|0)<=0){v[i+16>>2]=B+v[i+12>>2]}A=v[i+20>>2];B=A-1|0;v[i+20>>2]=B;if((A|0)<=0){v[i+20>>2]=B+v[i+12>>2]}i=i+24|0;continue}break}z[l>>2]=C(g+z[a+5036>>2])*C(.5);z[m>>2]=C(e+z[a+5040>>2])*C(.5);z[a+5040>>2]=e;z[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;z[l>>2]=g;z[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}t[a+5044|0]=1}n=a;a=v[a+56>>2];si(n,b,c,Ec(a,0),Ec(a,1),d)}}function pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=hb-288|0;hb=g;e=hb-128|0;hb=e;f=he(g+104|0,c);v[23516]=0;n=T(172,f+20|0)|0;c=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){v[23516]=0;p=T(172,f+40|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break B}v[23516]=0;q=T(172,f+60|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break A}v[23516]=0;i=T(172,f+80|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break z}v[23516]=0;o=T(172,f+100|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break y}v[23516]=0;k=T(172,f+120|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break x}j=Lb(f+140|0);xc(f);v[f+172>>2]=1873739776;u[f+176>>1]=0;v[23516]=0;d=Q(789,f|0,e+112|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break w}if(!d){break n}d=v[e+112>>2];if((d|0)!=1414744396&(d|0)!=1179011410){break n}c=v[e+120>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}t[f+176|0]=(d|0)==1414744396;v[23516]=0;U(790,e+96|0,f|0,2);c=v[23516];v[23516]=0;if((c|0)==1){break v}h=v[e+96>>2];C:{if(Cq(h,v[e+100>>2])>>>0<4){break C}c=Vx(h,1);d=v[c+4>>2];c=v[c>>2];Zh(e+40|0,c,d);if(v[e+40>>2]!=1635017060){break C}Zh(e- -64|0,c,d);if(!(t[e+68|0]&1)){break C}c=Vx(h,2);Zh(e+24|0,v[c>>2],v[c+4>>2]);if(v[e+28>>2]){break C}c=Vx(h,3);Zh(e+88|0,v[c>>2],v[c+4>>2]);if(v[e+88>>2]){break C}v[23516]=0;Q(153,f|0,12)|0;c=v[23516];v[23516]=0;if((c|0)==1){break u}v[23516]=0;U(790,e+40|0,f|0,1);c=v[23516];v[23516]=0;if((c|0)==1){break t}c=e+40|0;Dt(e+96|0,c);Ud(c)}v[23516]=0;U(791,e- -64|0,e+96|0,544501094);c=v[23516];v[23516]=0;if((c|0)==1){break s}v[23516]=0;d=Q(792,e- -64|0,f+156|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break k}if(!d){break o}d=x[f+156>>1];if((d|0)!=1){break q}v[23516]=0;d=T(200,e- -64|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break r}break k}d=P()|0;O()|0;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}if((d|0)==4){v[23516]=0;h=T(195,e- -64|0)|0;c=v[23516];v[23516]=0;D:{if((c|0)!=1){v[23516]=0;d=T(195,e- -64|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break D}if((h|0)!=2|(d|0)!=1){break p}t[f+177|0]=1;break p}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=x[f+156>>1]}if((d&65535)!=65534){break p}v[23516]=0;d=Q(793,e- -64|0,e+40|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break l}if(!d){break o}c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;c=v[e+52>>2];v[e+8>>2]=v[e+48>>2];v[e+12>>2]=c;c=e+24|0;v[c>>2]=w[e+8|0]|w[e+9|0]<<8|(w[e+10|0]<<16|w[e+11|0]<<24);u[c+4>>1]=w[e+12|0]|w[e+13|0]<<8;u[c+6>>1]=w[e+14|0]|w[e+15|0]<<8;r=c,s=pA(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24),w[e+20|0]|w[e+21|0]<<8|(w[e+22|0]<<16|w[e+23|0]<<24)),v[r+8>>2]=s;v[c+12>>2]=kb;u[f+172>>1]=v[c>>2]}v[23516]=0;U(791,e+40|0,e+96|0,1635017060);c=v[23516];v[23516]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=e+40|0;m=cd(n,c);yb(c);c=v[m>>2];v[23516]=0;d=T(176,c|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break k}if(!d){v[23516]=0;U(791,e+40|0,e+96|0,544039792);c=v[23516];v[23516]=0;if((c|0)==1){break J}c=e+40|0;cd(m,c);yb(c)}v[23516]=0;U(791,e+40|0,e+96|0,1952670054);c=v[23516];v[23516]=0;if((c|0)==1){break I}v[23516]=0;d=T(155,e+40|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break H}v[f+152>>2]=d;yb(e+40|0);if(v[f+152>>2]?x[f+156>>1]==17:0){break E}h=x[f+158>>1];d=QL(h,x[f+170>>1]);if(!d){break E}c=x[f+168>>1];if((c>>>0)/(h>>>0)>>>0<d<<1>>>0?c:0){break G}c=v[m>>2];v[23516]=0;d=T(158,c|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break k}c=QL(x[f+158>>1],x[f+170>>1]);break F}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;yb(e+40|0);break j}c=v[m>>2];v[23516]=0;d=T(158,c|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break k}c=x[f+168>>1]}v[f+152>>2]=(d>>>0)/((c&65535)>>>0)}v[23516]=0;d=Q(794,f|0,e+96|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break k}u[f+174>>1]=d;v[23516]=0;R(795,f|0,e+96|0);c=v[23516];v[23516]=0;if((c|0)==1){break k}v[23516]=0;U(791,e+40|0,e+96|0,1886221175);c=v[23516];v[23516]=0;if((c|0)==1){break m}c=e+40|0;cd(o,c);yb(c)}yb(e- -64|0);Ud(e+96|0)}hb=e+128|0;break a}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0}yb(e- -64|0)}Ud(e+96|0)}Ud(j);yb(k)}yb(o)}yb(i)}yb(q)}yb(p)}yb(n)}yb(f);S(d|0);L()}c=v[f+20>>2];v[23516]=0;d=T(730,c|0)|0;c=v[23516];v[23516]=0;K:{L:{if((c|0)!=1){M:{if(!d|(x[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=x[f+170>>1];P:{if(!c){if((hk(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((hk(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}d=hk(f);c=30416;while(1){Q:{R:{if((c|0)!=30440){if((d|0)!=v[c>>2]){break R}}else{c=30440}break Q}c=c+4|0;continue}break}if((c|0)==30440){break M}bt(a,b);v[23516]=0;d=Q(53,g+88|0,21751)|0;c=v[23516];v[23516]=0;S:{T:{U:{V:{W:{if((c|0)!=1){h=Ac(((b<<5)+a|0)+946304|0,d);wb(d);v[23516]=0;d=B(b,104)+a|0;i=d+484380|0;R(280,i|0,0);c=v[23516];v[23516]=0;if((c|0)==1){break W}v[i>>2]=v[f+152>>2];v[d+484404>>2]=v[f+160>>2];c=v[a+1298404>>2];v[23516]=0;X(731,f|0,i|0,c|0,h|0);c=v[23516];v[23516]=0;if((c|0)==1){break W}he(g- -64|0,f+20|0);d=x[f+158>>1];j=Uc(g+56|0,8,d>>>0>1?2:1,0,0);c=hk(f);if((c|0)!=17|d>>>0>2){break U}uc(i,268435456);c=B(b,104)+a|0;b=c+484414|0;u[b>>1]=x[b>>1]&65470|((d|0)==2)<<6|1;if(Jg(i)){break V}break S}l=P()|0;O()|0;break K}l=P()|0;O()|0;break K}j=v[c+484400>>2];h=v[i>>2];k=he(g+32|0,g- -64|0);d=x[f+158>>1];c=x[f+168>>1];v[23516]=0;b=v[k+12>>2];v[g+16>>2]=v[k+8>>2];v[g+20>>2]=b;v[g+24>>2]=v[k+16>>2];b=v[k+4>>2];v[g+8>>2]=v[k>>2];v[g+12>>2]=b;da(732,j|0,h|0,g+8|0,c|0,d|0);b=v[23516];v[23516]=0;if((b|0)==1){break L}rj(i,a);break T}if((c|0)==85){v[23516]=0;c=W(568,a|0,b|0,g- -64|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(FP(x[f+156>>1])){break Z}_:{if(!Sd(w[f+177|0])){break _}if((hk(f)|0)!=1|x[f+170>>1]!=32|x[f+168>>1]!=d<<2){break _}nd(j,32);b=12;break Y}if((hk(f)|0)!=1|x[f+170>>1]!=24|x[f+168>>1]!=d<<2){break Z}nd(j,32);b=13;break Y}if((hk(f)&65534)!=6){break X}nd(j,16);b=(hk(f)|0)==6?17:16}cg(j,b);v[23516]=0;W(218,j|0,i|0,g- -64|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break T}break L}d=x[f+170>>1];c=(d-1>>>3|0)-1|0;b=c<<3;h=b&31;nd(j,(c>>>0<7?(b&63)>>>0>=32?4196360>>>h|0:((1<<h)-1&4196360)<<32-h|136321040>>>h:8)&255);if(d>>>0<9){cg(j,1)}if((hk(f)|0)==3){cg(j,3)}v[23516]=0;W(218,j|0,i|0,g- -64|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break L}}tz(i,v[a+480180>>2]);rj(i,a);l=1}yb(g- -64|0)}EP(f);hb=g+288|0;return l|0}l=P()|0;O()|0;break K}l=P()|0;O()|0;yb(g- -64|0)}EP(f);S(l|0);L()}function GI(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=hb-272|0;hb=h;a:{b:{if(g){kf(h+256|0,f,32);v[23516]=0;W(536,h+240|0,f|0,32)|0;k=v[23516];v[23516]=0;if((k|0)!=1){break b}f=P()|0;O()|0;break a}Kb(h+256|0);Kb(h+240|0)}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(gs(c)){k=v[b+24>>2];i=v[k+484344>>2];if(te(i,v[k+484348>>2],c&65535)){break o}}v[23516]=0;U(1108,a|0,h+256|0,h+240|0);a=v[23516];v[23516]=0;if((a|0)!=1){break n}f=P()|0;O()|0;break c}c=Xb(i,c);if(!(!((e|0)<0|v[c+12>>2]<=(d|0)|(d|0)<0)&x[k+480188>>1]>e>>>0)){v[23516]=0;U(1108,a|0,h+256|0,h+240|0);a=v[23516];v[23516]=0;if((a|0)!=1){break n}f=P()|0;O()|0;break c}c=ed(v[c>>2],v[v[c+48>>2]+12>>2],d,e&65535);_f(h+256|0);_f(h+240|0);p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{d=w[c|0];if(!Wc(d)){if(!Gp(d)){break F}}e=w[c+1|0];k=v[b+24>>2];v[23516]=0;X(1109,h+208|0,k|0,d|0,e|0);d=v[23516];v[23516]=0;e=1;if((d|0)==1){break D}v[23516]=0;R(1029,h+224|0,h+208|0);d=v[23516];v[23516]=0;if((d|0)!=1){break E}f=P()|0;O()|0;break A}e=0;v[23516]=0;Q(53,h+224|0,16862)|0;d=v[23516];v[23516]=0;if((d|0)==1){break C}}v[23516]=0;k=Q(820,h+256|0,h+224|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break B}wb(h+224|0);if(e){xb(h+208|0)}e=9987;d=w[c|0];if(!Wc(d)){e=Gp(d)?10297:16862}v[23516]=0;d=Q(53,h+224|0,e|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break z}v[23516]=0;e=Q(820,h+240|0,d|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break y}wb(d);if(f-6>>>0>4294967290){break q}v[23516]=0;d=Q(53,h+192|0,17922)|0;i=v[23516];v[23516]=0;if((i|0)==1){break x}v[23516]=0;i=Q(820,k|0,d|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break w}wb(d);v[23516]=0;d=Q(53,h+176|0,17922)|0;l=v[23516];v[23516]=0;if((l|0)==1){break v}v[23516]=0;l=Q(820,e|0,d|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break u}wb(d);d=c+1|0;G:{if(w[c+1|0]){v[23516]=0;R(553,h+160|0,d|0);j=v[23516];v[23516]=0;if((j|0)!=1){break G}break d}v[23516]=0;Q(53,h+160|0,16867)|0;j=v[23516];v[23516]=0;if((j|0)==1){break d}}v[23516]=0;j=Q(820,i|0,h+160|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break t}i=h+160|0;wb(i);d=w[d|0];v[23516]=0;d=Q(53,i|0,(d?10791:16867)|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break s}v[23516]=0;l=Q(820,l|0,d|0)|0;i=v[23516];v[23516]=0;if((i|0)!=1){break r}f=P()|0;O()|0;wb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;wb(h+224|0);if(!e){break c}}xb(h+208|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;wb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;wb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;wb(d);break c}f=P()|0;O()|0;wb(h+160|0);break c}f=P()|0;O()|0;break c}wb(d);if(f-9>>>0>4294967287){break q}H:{I:{J:{K:{L:{M:{N:{i=$g(w[c|0]);O:{if(i){v[23516]=0;m=Q(53,h+128|0,17922)|0;d=v[23516];v[23516]=0;if((d|0)==1){break N}d=w[c+4|0];n=w[c+2|0];v[23516]=0;o=h,p=ek(n,d)&255,v[o+96>>2]=p;R(552,h+112|0,h+96|0);d=v[23516];v[23516]=0;if((d|0)==1){break M}d=0;v[23516]=0;U(985,h+144|0,m|0,h+112|0);m=v[23516];v[23516]=0;if((m|0)!=1){break O}f=P()|0;O()|0;break f}d=w[c+2|0];if(d){d=HL(v[v[v[b+24>>2]+8>>2]+88>>2],d);v[23516]=0;d=W(536,h+128|0,1,d|0)|0;m=v[23516];v[23516]=0;if((m|0)==1){break J}v[23516]=0;R(553,h+112|0,c+4|0);m=v[23516];v[23516]=0;if((m|0)==1){break L}v[23516]=0;U(985,h+144|0,d|0,h+112|0);m=v[23516];v[23516]=0;d=1;if((m|0)!=1){break O}f=P()|0;O()|0;break i}d=0;v[23516]=0;Q(53,h+144|0,16866)|0;m=v[23516];v[23516]=0;if((m|0)==1){break j}}v[23516]=0;j=Q(820,j|0,h+144|0)|0;m=v[23516];v[23516]=0;if((m|0)==1){break K}wb(h+144|0);if(d){wb(h+112|0);wb(h+128|0)}if(i){wb(h+112|0);wb(h+128|0)}d=5491;if(!$g(w[c|0])){d=w[c+2|0]?5487:16866}v[23516]=0;d=Q(53,h+144|0,d|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break I}v[23516]=0;i=Q(820,l|0,d|0)|0;l=v[23516];v[23516]=0;if((l|0)!=1){break H}f=P()|0;O()|0;wb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break e}f=P()|0;O()|0;break h}f=P()|0;O()|0;wb(h+144|0);if(d){break i}break g}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}wb(d);if(f-13>>>0>4294967283){break q}v[23516]=0;d=Q(53,h+96|0,17922)|0;l=v[23516];v[23516]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){v[23516]=0;l=Q(820,j|0,d|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break Z}wb(d);v[23516]=0;d=Q(53,h+80|0,17922)|0;j=v[23516];v[23516]=0;if((j|0)==1){break Y}v[23516]=0;i=Q(820,i|0,d|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break X}wb(d);_:{if($g(w[c|0])){d=w[c+5|0];j=w[c+3|0];b=0;v[23516]=0;o=h,p=ek(j,d)&4095,v[o+16>>2]=p;R(1110,h- -64|0,h+16|0);d=v[23516];v[23516]=0;if((d|0)!=1){break _}f=P()|0;O()|0;break c}d=w[c+3|0];if(d){b=GL(v[v[v[b+24>>2]+8>>2]+84>>2],d);v[23516]=0;b=W(536,h+48|0,1,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break W}v[23516]=0;R(553,h+32|0,c+5|0);d=v[23516];v[23516]=0;if((d|0)==1){break V}v[23516]=0;U(985,h- -64|0,b|0,h+32|0);d=v[23516];v[23516]=0;b=1;if((d|0)!=1){break _}f=P()|0;O()|0;break S}b=0;v[23516]=0;Q(53,h- -64|0,16862)|0;d=v[23516];v[23516]=0;if((d|0)==1){break U}}v[23516]=0;Q(820,l|0,h- -64|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break T}wb(h- -64|0);if(b){wb(h+32|0);wb(h+48|0)}b=11134;if(!$g(w[c|0])){b=w[c+3|0]?11134:16862}v[23516]=0;b=Q(53,h- -64|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break Q}v[23516]=0;Q(820,i|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break P}f=P()|0;O()|0;wb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;wb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;wb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break R}f=P()|0;O()|0;break c}f=P()|0;O()|0;wb(h- -64|0);if(!b){break c}}wb(h+32|0)}wb(h+48|0);break c}f=P()|0;O()|0;break c}wb(b);if(!f){break p}}$:{aa:{ba:{ca:{b=Fb(k);da:{if(b>>>0>f>>>0){v[23516]=0;X(128,h+16|0,k|0,0,f|0);b=v[23516];v[23516]=0;if((b|0)!=1){b=h+16|0;yc(k,b);wb(b);break da}f=P()|0;O()|0;break c}if(!g){break da}v[23516]=0;b=W(536,h+16|0,f-b|0,32)|0;c=v[23516];v[23516]=0;if((c|0)==1){break ca}v[23516]=0;Q(820,k|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break ba}wb(b)}b=Fb(e);if(b>>>0<=f>>>0){break $}v[23516]=0;X(128,h|0,e|0,0,f|0);b=v[23516];v[23516]=0;if((b|0)==1){break aa}yc(e,h);wb(h);break p}f=P()|0;O()|0;break c}f=P()|0;O()|0;wb(b);break c}f=P()|0;O()|0;break c}if(!g){break p}v[23516]=0;b=W(536,h|0,f-b|0,32)|0;c=v[23516];v[23516]=0;if((c|0)==1){break m}v[23516]=0;Q(820,e|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break l}wb(b)}v[23516]=0;U(1108,a|0,k|0,e|0);a=v[23516];v[23516]=0;if((a|0)==1){break k}}wb(h+240|0);wb(h+256|0);hb=h+272|0;return}f=P()|0;O()|0;break c}f=P()|0;O()|0;wb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}wb(h+112|0)}wb(h+128|0)}if(!i){break c}}wb(h+112|0)}wb(h+128|0);break c}f=P()|0;O()|0}wb(h+240|0)}wb(h+256|0);S(f|0);L()}function J_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=hb-560|0;hb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=1175;k=l+96|0;s=pe(l+136|0,l+144|0,k);b=v[s>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;y=Kb(k);o=Kb(l+80|0);p=Kb(l- -64|0);q=Kb(l+48|0);u=Kb(l+32|0);v[23516]=0;na(1184,c|0,d|0,l+120|0,l+116|0,l+112|0,y|0,o|0,p|0,q|0,l+28|0);c=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){v[j>>2]=v[i>>2];z=e&512;A=z>>>9|0;c=v[l+28>>2];while(1){g:{h:{i:{j:{k:{if((r|0)==4){break k}v[23516]=0;d=Q(1158,a|0,l+552|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}if(!d){break k}l:{m:{n:{o:{p:{q:{switch(t[(l+120|0)+r|0]){case 1:if((r|0)==3){break h}d=v[a>>2];v[23516]=0;d=T(1160,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}v[23516]=0;d=W(1185,h|0,8192,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}if(d){v[23516]=0;R(1186,l+16|0,a|0);d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;R(47,u|0,v[l+16>>2]);d=v[23516];v[23516]=0;if((d|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break g;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break h}}if((r|0)==3){break h}}while(1){v[23516]=0;d=Q(1158,a|0,l+552|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}if(!d){break h}d=v[a>>2];v[23516]=0;d=T(1160,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}v[23516]=0;d=W(1185,h|0,8192,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}if(!d){break h}v[23516]=0;R(1186,l+16|0,a|0);d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;R(47,u|0,v[l+16>>2]);d=v[23516];v[23516]=0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;break a}d=Fb(p);k=Fb(q);if((d|0)==(0-k|0)){break h}e=v[a>>2];if(!(k?d:0)){if(d){v[23516]=0;d=T(1160,e|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}if((d|0)!=v[wc(p)>>2]){break l}v[23516]=0;T(1162,a|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}n=Fb(p)>>>0>1?p:n;break h}v[23516]=0;d=T(1160,e|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}if((d|0)!=v[wc(q)>>2]){break h}v[23516]=0;T(1162,a|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}t[g|0]=1;n=Fb(q)>>>0>1?q:n;break h}v[23516]=0;d=T(1160,e|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}if((d|0)==v[wc(p)>>2]){v[23516]=0;T(1162,a|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}n=Fb(p)>>>0>1?p:n;break h}d=v[a>>2];v[23516]=0;d=T(1160,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}if((d|0)==v[wc(q)>>2]){v[23516]=0;T(1162,a|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}t[g|0]=1;n=Fb(q)>>>0>1?q:n;break h}v[f>>2]=v[f>>2]|4;a=0;break g}if(!(r>>>0<2|n|((r|0)==2&w[l+123|0]!=0|A))){n=0;break h}e=cc(l+16|0,ge(o));r:{s:{if(!r|w[(l+r|0)+119|0]>1){break s}while(1){t:{d=Lk(o);k=v[e>>2];if(!Nb(k,d)){break t}d=v[k>>2];v[23516]=0;d=W(1185,h|0,8192,d|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break r}if(!d){break t}Ie(e);continue}break}d=ge(o);d=Nt(v[e>>2],d);if(Fb(u)>>>0>=d>>>0){k=qm(Lk(u),0-d|0);m=Lk(u);x=ge(o);d=hb-16|0;hb=d;v[d>>2]=x;v[d+8>>2]=k;while(1){u:{x=Nb(k,m);if(!x){break u}if(!nc(v[k>>2],v[v[d>>2]>>2])){break u}k=Ie(d+8|0);Ie(d);k=v[k>>2];continue}break}hb=d+16|0;if(x^1){break s}}B=e,C=v[cc(l+8|0,ge(o))>>2],v[B>>2]=C}v[l+8>>2]=v[e>>2];v:{while(1){d=Lk(o);if(!Nb(v[l+8>>2],d)){break v}v[23516]=0;d=Q(1158,a|0,l+552|0)|0;e=v[23516];v[23516]=0;w:{if((e|0)==1){break w}if(!d){break v}d=v[a>>2];v[23516]=0;d=T(1160,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break w}if((d|0)!=v[v[l+8>>2]>>2]){break v}v[23516]=0;T(1162,a|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break d}Ie(l+8|0);continue}break}break d}if(!z){break h}d=Lk(o);if(!Nb(v[l+8>>2],d)){break h}v[f>>2]=v[f>>2]|4;a=0;break g}break d}d=0;m=v[l+112>>2];x:{while(1){y:{v[23516]=0;e=Q(1158,a|0,l+552|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break y}if(!e){break x}e=v[a>>2];v[23516]=0;e=T(1160,e|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break f}v[23516]=0;k=W(1185,h|0,2048,e|0)|0;x=v[23516];v[23516]=0;if((x|0)==1){break f}z:{if(k){k=v[j>>2];if((k|0)==v[l+548>>2]){v[23516]=0;U(1187,i|0,j|0,l+548|0);k=v[23516];v[23516]=0;if((k|0)==1){break f}k=v[j>>2]}v[j>>2]=k+4;v[k>>2]=e;d=d+1|0;break z}if(!Fb(y)|!d|(e|0)!=(m|0)){break x}if(v[l+128>>2]==(b|0)){v[23516]=0;U(1181,s|0,l+132|0,l+128|0);b=v[23516];v[23516]=0;if((b|0)==1){break f}b=v[l+132>>2]}e=b+4|0;v[l+132>>2]=e;v[b>>2]=d;b=e;d=0}v[23516]=0;T(1162,a|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[s>>2]==(b|0)){break j}if(v[l+128>>2]==(b|0)){v[23516]=0;U(1181,s|0,l+132|0,l+128|0);b=v[23516];v[23516]=0;if((b|0)==1){break e}b=v[l+132>>2]}e=b+4|0;v[l+132>>2]=e;v[b>>2]=d;break i}t[g|0]=1;break h}v[l+28>>2]=c;A:{if(!n){break A}c=1;while(1){if(Fb(n)>>>0<=c>>>0){break A}v[23516]=0;d=Q(1159,a|0,l+552|0)|0;e=v[23516];v[23516]=0;B:{if((e|0)==1){break B}C:{if(!d){d=v[a>>2];v[23516]=0;d=T(1160,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break B}if((d|0)==v[oj(n,c)>>2]){break C}}v[f>>2]=v[f>>2]|4;a=0;break g}v[23516]=0;T(1162,a|0)|0;d=v[23516];v[23516]=0;c=c+1|0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;c=v[s>>2];if((c|0)==(b|0)){break g}a=0;v[l+16>>2]=0;Cf(y,c,b,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break g}a=1;break g}e=b}D:{if((c|0)<=0){break D}v[23516]=0;b=Q(1159,a|0,l+552|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}E:{if(!b){b=v[a>>2];v[23516]=0;b=T(1160,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}if((b|0)==v[l+116>>2]){break E}}v[l+28>>2]=c;v[f>>2]=v[f>>2]|4;a=0;break g}v[23516]=0;b=T(1162,a|0)|0;k=v[23516];v[23516]=0;d=c;if((k|0)==1){break e}while(1){if((d|0)<=0){c=0;break D}v[23516]=0;k=Q(1159,b|0,l+552|0)|0;m=v[23516];v[23516]=0;F:{if((m|0)==1){break F}G:{if(!k){k=v[b>>2];v[23516]=0;k=T(1160,k|0)|0;m=v[23516];v[23516]=0;if((m|0)==1){break F}v[23516]=0;k=W(1185,h|0,2048,k|0)|0;m=v[23516];v[23516]=0;if((m|0)==1){break F}if(k){break G}}v[l+28>>2]=d;v[f>>2]=v[f>>2]|4;a=0;break g}if(v[j>>2]==v[l+548>>2]){v[23516]=0;U(1187,i|0,j|0,l+548|0);k=v[23516];v[23516]=0;if((k|0)==1){break F}}k=v[b>>2];v[23516]=0;k=T(1160,k|0)|0;m=v[23516];v[23516]=0;if((m|0)==1){break F}m=v[j>>2];v[j>>2]=m+4;v[m>>2]=k;v[23516]=0;T(1162,b|0)|0;k=v[23516];v[23516]=0;d=d-1|0;if((k|0)!=1){continue}}break}break d}if(v[j>>2]!=v[i>>2]){b=e;break h}v[l+28>>2]=c;v[f>>2]=v[f>>2]|4;a=0;break g}r=r+1|0;continue}break}Yc(u);Yc(q);Yc(p);Yc(o);wb(y);Sc(s);hb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;v[l+28>>2]=c;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Yc(u);Yc(q);Yc(p);Yc(o);wb(y);Sc(s);S(a|0);L()}function xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=hb-304|0;hb=d;xc(b);a:{b:{c:{d:{if(!Et(b,d+208|0)){break d}if(!jR(d+208|0)){break d}if(!Ob(v[b>>2],v[b+8>>2],Bc(iR(d+208|0),kb))){break d}if(!c){g=1;break d}if(!Zc(b,w[d+212|0])){break d}zd(a,268435456);$f(a);v[a+480208>>2]=4;Mb(a+1074312|0,114,1);f=d+88|0;i=vc(f,15416);Gb(a+1298344|0,i);xb(i);i=vc(f,10301);Gb(a+1298356|0,i);xb(i);v[a+1298404>>2]=5;i=d+16|0;lf(i,d+208|6,48,3);Cc(f,i);yc(a+1298308|0,f);wb(f);f=w[d+262|0];u[a+480188>>1]=f+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];while(1){if((e|0)==(f|0)){e:{u[a+480190>>1]=w[d+300|0];i=x[d+302>>1];f=Lb(d+192|0);f:{g:{if(i){v[23516]=0;R(649,f|0,i|0);e=v[23516];v[23516]=0;if((e|0)==1){break g}xA(f,i)}break f}a=P()|0;O()|0;lc(f);S(a|0);L()}v[23516]=0;i=f;U(644,b|0,f|0,x[d+302>>1]);f=v[23516];v[23516]=0;if((f|0)==1){break b}z=Lb(d+176|0);r=Lb(d+160|0);v[23516]=0;W(417,b|0,z|0,w[d+301|0])|0;f=v[23516];v[23516]=0;if((f|0)==1){break c}v[23516]=0;W(417,b|0,r|0,w[d+300|0])|0;f=v[23516];v[23516]=0;if((f|0)==1){break c}p=c&2;s=d+126|0;n=d+88|6;f=0;h:{while(1){e=f;if(e>>>0>=w[d+300|0]){g=1;if(!(c&1)){break e}v[d+68>>2]=0;q=a+484376|0;Gc(Sb(v[a+484360>>2],w[q|0]));F=d,G=Cb(v[i>>2]),v[F+64>>2]=G;y=a+484344|0;A=Cb(v[i+4>>2]);C=a+484348|0;break h}v[23516]=0;f=e+1|0;h=B(f,104)+a|0;k=h+484380|0;R(280,k|0,0);g=v[23516];v[23516]=0;i:{if((g|0)!=1){g=Bb(v[r>>2],e);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);if(!g){continue}v[23516]=0;g=Q(153,b|0,g|0)|0;j=v[23516];v[23516]=0;j:{if((j|0)==1){break j}if(!g){continue}v[23516]=0;g=Q(645,b|0,d+88|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break j}if(!g){continue}g=d+72|0;Ke(g,2,n);v[23516]=0;R(221,d+16|0,g|0);g=v[23516];v[23516]=0;if((g|0)==1){break c}g=d+16|0;Ac(((f<<5)+a|0)+946304|0,g);wb(g);j=d+72|0;ok(j,2,s);v[23516]=0;R(221,g|0,j|0);g=v[23516];v[23516]=0;if((g|0)==1){break c}g=d+16|0;xe(h+484423|0,g);wb(g);g=w[d+138|0];if(g>>>0<=15){u[h+484408>>1]=B(g,17);g=h+484414|0;u[g>>1]=x[g>>1]|32}t[d+16|0]=w[d+139|0];t[d+72|0]=64;F=h+484412|0,G=w[Vb(d+16|0,d+72|0)|0],u[F>>1]=G;v[h+484404>>2]=w[d+141|0]|w[d+142|0]<<8;m=h+484384|0;g=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);v[m>>2]=g;q=h+484388|0;j=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[q>>2]=j;y=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);v[k>>2]=y;l=w[d+140|0];if(l&1){g=g>>>1|0;v[m>>2]=g;j=j>>>1|0;v[q>>2]=j;v[k>>2]=y>>>1}k:{if(g>>>0>=j>>>0){break k}h=h+484414|0;g=x[h>>1];u[h>>1]=g|2;if(!(l&2)){break k}u[h>>1]=g|6}wk(k);if(!p){continue}e=Bb(v[r>>2],e);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[23516]=0;Q(153,b|0,e+w[d+92|0]|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break i}}break c}break c}e=Uc(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[23516]=0;W(218,e|0,k|0,b|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){continue}break}break c}while(1){l:{m:{k=v[d+64>>2];if(!Nb(k,A)){b=v[d+68>>2];c=b&63;if(!c){break m}f=w[a+484376|0];e=v[a+484360>>2];v[23516]=0;b=b>>>6|0;f=Q(314,Sb(e,f)|0,b&65535)|0;e=v[23516];v[23516]=0;if((e|0)!=1){if(!f){break m}b=x[$b(v[Sb(v[a+484360>>2],w[a+484376|0])>>2],b&65535)>>1];f=v[a+484344>>2];v[23516]=0;R(646,Xb(f,b)|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break m}}break c}c=w[k+3|0];if(w[k+2|0]>w[d+262|0]|c>>>0>=w[d+301|0]){break l}c=Bb(v[z>>2],c);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23516]=0;c=Q(153,b|0,c|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break c}if(!c){break l}v[23516]=0;R(647,b|0,d+88|0);c=v[23516];v[23516]=0;if((c|0)==1){break c}e=w[d+92|0];if(!e){break l}f=w[k|0]|w[k+1|0]<<8;t[d+16|0]=w[d+93|0];t[d+72|0]=w[d+262|0]-w[k+2|0];j=w[Vb(d+16|0,d+72|0)|0];v[d+60>>2]=e+f;F=d,G=v[Vc(d+68|0,d+60|0)>>2],v[F+68>>2]=G;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;c=f&63;p=f>>>6|0;s=0;while(1){if((e&255)>>>0<=s>>>0){break l}e=Sb(v[a+484360>>2],w[q|0]);h=c>>>0>63;p=h+p|0;f=p&65535;if(Oc(v[e>>2],v[e+4>>2])>>>0<=f>>>0){v[23516]=0;R(329,e|0,p+1&65535);e=v[23516];v[23516]=0;if((e|0)==1){break c}v[23516]=0;n=Q(366,y|0,64)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}e=Sb(v[a+484360>>2],w[q|0]);F=$b(v[e>>2],f),G=n,u[F>>1]=G}m=v[a+484344>>2];o=v[C>>2];n=x[$b(v[e>>2],f)>>1];if(!te(m,o,n)){break l}f=0;e=Xb(m,n);m=h?0:c;e=ed(v[e>>2],v[v[e+48>>2]+12>>2],m,w[k+2|0]);n:{while(1){if((f|0)==(j|0)){c=w[d+93|0];if(c>>>0<=j>>>0){break n}v[23516]=0;Q(186,b|0,B(c-j|0,5)|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break n}break c}v[23516]=0;R(648,d+72|0,b|0);c=v[23516];v[23516]=0;if((c|0)!=1){c=d+72|0;h=Kc(c);D=Re(c);l=Ji(c);E=gc(c);c=w[d+72|0];o=c-1&255;o:{if(o>>>0<=142){c=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[e|0]=c;t[(d+16|0)+f|0]=c;break o}t[e|0]=0}c=w[h|0];t[e+2|0]=1;t[e+1|0]=c;c=w[D|0];p:{if((c|0)!=255){t[e+4|0]=c;break p}t[e+2|0]=0}c=w[l|0];q:{if(c>>>0>22){break q}t[e+3|0]=w[c+27168|0];h=w[E|0];t[e+5|0]=h;c=e+5|0;r:{switch(w[l|0]-4|0){case 3:t[c|0]=h&3|64;break q;case 4:t[c|0]=h&3|48;break q;case 7:l=v[i>>2];if(sc(l,v[i+4>>2])>>>0<=h>>>0){break q}o=c;c=Bb(l,h);c=w[c|0]|w[c+1|0]<<8;t[o|0]=c>>>6;h=Xb(v[a+484344>>2],n);h=ed(v[h>>2],v[v[h+48>>2]+12>>2],m,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break q;case 8:o=c;c=v[d+60>>2];t[o|0]=c>>>6;h=Xb(v[a+484344>>2],n);h=ed(v[h>>2],v[v[h+48>>2]+12>>2],m,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break q;case 10:t[c|0]=h&15|128;break q;case 12:t[d+15|0]=15;F=c,G=w[Vb(c,d+15|0)|0]|208,t[F|0]=G;break q;case 13:t[d+15|0]=15;F=c,G=w[Vb(c,d+15|0)|0]|192,t[F|0]=G;break q;case 14:t[d+15|0]=15;F=c,G=w[Vb(c,d+15|0)|0]|224,t[F|0]=G;break q;case 0:case 16:case 17:if(!(h&15)){break q}l=h&240;if(!l|(l|0)==240){break q}t[c|0]=h|15;break q;case 9:case 18:break r;default:break q}}if(o>>>0<143){break q}t[e|0]=w[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}c=m+1|0;s=s+1|0;e=w[d+92|0];continue}}a=Sb(v[a+484360>>2],w[a+484376|0]);F=d,G=Cb(v[a>>2]),v[F+88>>2]=G;b=Cb(v[a+4>>2]);c=65535;while(1){a=v[d+88>>2];if(!Nb(a,b)){break e}if(x[a>>1]==65535){s:{if((c&65535)!=65535){break s}v[23516]=0;c=Q(366,y|0,64)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break s}break c}u[a>>1]=c}Qe(d+88|0);continue}}Ie(d- -64|0);continue}}}else{u[((e<<5)+a|0)+480284>>1]=B(w[(d+e|0)+268|0],17);e=e+1|0;continue}break}lc(r);lc(z);lc(i)}hb=d+304|0;return g|0}a=P()|0;O()|0;lc(r);lc(z);break a}a=P()|0;O()|0}lc(i);S(a|0);L()}function Q_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=hb-560|0;hb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=1175;k=l+104|0;r=pe(l+136|0,l+144|0,k);b=v[r>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;u=Kb(k);o=Kb(l+88|0);p=Kb(l+72|0);q=Kb(l+56|0);s=Kb(l+40|0);v[23516]=0;na(1178,c|0,d|0,l+120|0,l+119|0,l+118|0,u|0,o|0,p|0,q|0,l+36|0);c=v[23516];v[23516]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;k=v[l+36>>2];x=h;h=0;while(1){f:{g:{h:{i:{j:{if((h|0)==4){break j}v[23516]=0;c=Q(1142,a|0,l+552|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}if(!c){break j}k:{l:{m:{n:{o:{p:{switch(t[(l+120|0)+h|0]){case 1:if((h|0)==3){break g}c=v[a>>2];v[23516]=0;c=T(1144,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}if(qh(v[x+8>>2],8192,c)){v[23516]=0;R(1179,l+24|0,a|0);c=v[23516];v[23516]=0;if((c|0)!=1){v[23516]=0;R(45,s|0,t[l+24|0]);c=v[23516];v[23516]=0;if((c|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break g}}if((h|0)==3){break g}}while(1){v[23516]=0;c=Q(1142,a|0,l+552|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}if(!c){break g}c=v[a>>2];v[23516]=0;c=T(1144,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}if(!qh(v[x+8>>2],8192,c)){break g}v[23516]=0;R(1179,l+24|0,a|0);c=v[23516];v[23516]=0;if((c|0)!=1){v[23516]=0;R(45,s|0,t[l+24|0]);c=v[23516];v[23516]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}c=Fb(p);e=Fb(q);if((c|0)==(0-e|0)){break g}d=v[a>>2];if(!(e?c:0)){if(c){v[23516]=0;c=T(1144,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}if(w[Jc(p,0)|0]!=(c&255)){break k}v[23516]=0;T(1146,a|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}m=Fb(p)>>>0>1?p:m;break g}v[23516]=0;c=T(1144,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}if(w[Jc(q,0)|0]!=(c&255)){break g}v[23516]=0;T(1146,a|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}t[g|0]=1;m=Fb(q)>>>0>1?q:m;break g}v[23516]=0;c=T(1144,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}if(w[Jc(p,0)|0]==(c&255)){v[23516]=0;T(1146,a|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}m=Fb(p)>>>0>1?p:m;break g}c=v[a>>2];v[23516]=0;c=T(1144,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}if(w[Jc(q,0)|0]==(c&255)){v[23516]=0;T(1146,a|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}t[g|0]=1;m=Fb(q)>>>0>1?q:m;break g}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(h>>>0<2|m|((h|0)==2&w[l+123|0]!=0|z))){m=0;break g}B=l,C=ge(o),v[B+16>>2]=C;d=hj(l+24|0,l+16|0);q:{if(!h|w[(h+l|0)+119|0]>1){break q}while(1){r:{B=l,C=uh(o),v[B+16>>2]=C;if(!mj(d,l+16|0)){break r}if(!qh(v[x+8>>2],8192,t[v[d>>2]])){break r}He(d);continue}break}B=l,C=ge(o),v[B+16>>2]=C;c=En(d,l+16|0);if(Fb(s)>>>0>=c>>>0){B=l,C=uh(s),v[B+16>>2]=C;e=Bp(l+16|0,0-c|0);n=uh(s);A=ge(o);c=hb-32|0;hb=c;v[c+16>>2]=n;v[c+24>>2]=e;v[c+8>>2]=A;while(1){e=mj(c+24|0,c+16|0);if(!(!e|w[v[c+24>>2]]!=w[v[c+8>>2]])){He(c+24|0);He(c+8|0);continue}break}hb=c+32|0;if(e^1){break q}}B=l,C=ge(o),v[B+8>>2]=C;B=d,C=v[hj(l+16|0,l+8|0)>>2],v[B>>2]=C}v[l+16>>2]=v[d>>2];s:{t:{while(1){B=l,C=uh(o),v[B+8>>2]=C;if(!mj(l+16|0,l+8|0)){break s}v[23516]=0;c=Q(1142,a|0,l+552|0)|0;d=v[23516];v[23516]=0;u:{if((d|0)==1){break u}if(!c){break s}c=v[a>>2];v[23516]=0;c=T(1144,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break u}if(w[v[l+16>>2]]!=(c&255)){break s}v[23516]=0;T(1146,a|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break t}He(l+16|0);continue}break}a=P()|0;O()|0;v[l+36>>2]=k;break a}a=P()|0;O()|0;v[l+36>>2]=k;break a}if(!y){break g}B=l,C=uh(o),v[B+8>>2]=C;if(!mj(l+16|0,l+8|0)){break g}v[f>>2]=v[f>>2]|4;a=0;break f}d=0;n=w[l+118|0];v:{while(1){w:{v[23516]=0;c=Q(1142,a|0,l+552|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break w}if(!c){break v}c=v[a>>2];v[23516]=0;c=T(1144,c|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break e}x:{if(qh(v[x+8>>2],2048,c)){e=v[j>>2];if((e|0)==v[l+548>>2]){v[23516]=0;U(1180,i|0,j|0,l+548|0);e=v[23516];v[23516]=0;if((e|0)==1){break e}e=v[j>>2]}v[j>>2]=e+1;t[e|0]=c;d=d+1|0;break x}if(!Fb(u)|!d|(n|0)!=(c&255)){break v}if(v[l+128>>2]==(b|0)){v[23516]=0;U(1181,r|0,l+132|0,l+128|0);b=v[23516];v[23516]=0;if((b|0)==1){break e}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[23516]=0;T(1146,a|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[r>>2]==(b|0)){break i}if(v[l+128>>2]==(b|0)){v[23516]=0;U(1181,r|0,l+132|0,l+128|0);b=v[23516];v[23516]=0;if((b|0)==1){break d}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;break h}t[g|0]=1;break g}v[l+36>>2]=k;y:{if(!m){break y}c=1;while(1){if(Fb(m)>>>0<=c>>>0){break y}v[23516]=0;d=Q(1143,a|0,l+552|0)|0;e=v[23516];v[23516]=0;z:{if((e|0)==1){break z}A:{if(!d){d=v[a>>2];v[23516]=0;d=T(1144,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break z}if(w[gg(m,c)|0]==(d&255)){break A}}v[f>>2]=v[f>>2]|4;a=0;break f}v[23516]=0;T(1146,a|0)|0;d=v[23516];v[23516]=0;c=c+1|0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;c=v[r>>2];if((c|0)==(b|0)){break f}a=0;v[l+24>>2]=0;Cf(u,c,b,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break f}a=1;break f}c=b}B:{if((k|0)<=0){break B}v[23516]=0;b=Q(1143,a|0,l+552|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break d}C:{if(!b){b=v[a>>2];v[23516]=0;b=T(1144,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break d}if(w[l+119|0]==(b&255)){break C}}v[l+36>>2]=k;v[f>>2]=v[f>>2]|4;a=0;break f}v[23516]=0;b=T(1146,a|0)|0;e=v[23516];v[23516]=0;d=k;if((e|0)==1){break d}while(1){if((d|0)<=0){k=0;break B}v[23516]=0;e=Q(1143,b|0,l+552|0)|0;n=v[23516];v[23516]=0;D:{if((n|0)==1){break D}E:{if(!e){e=v[b>>2];v[23516]=0;e=T(1144,e|0)|0;n=v[23516];v[23516]=0;if((n|0)==1){break D}if(qh(v[x+8>>2],2048,e)){break E}}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[23516]=0;U(1180,i|0,j|0,l+548|0);e=v[23516];v[23516]=0;if((e|0)==1){break D}}e=v[b>>2];v[23516]=0;e=T(1144,e|0)|0;n=v[23516];v[23516]=0;if((n|0)==1){break D}n=v[j>>2];v[j>>2]=n+1;t[n|0]=e;v[23516]=0;T(1146,b|0)|0;e=v[23516];v[23516]=0;d=d-1|0;if((e|0)!=1){continue}}break}a=P()|0;O()|0;v[l+36>>2]=k;break a}if(v[j>>2]!=v[i>>2]){b=c;break g}v[l+36>>2]=k;v[f>>2]=v[f>>2]|4;a=0;break f}h=h+1|0;continue}break}wb(s);wb(q);wb(p);wb(o);wb(u);Sc(r);hb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}wb(s);wb(q);wb(p);wb(o);wb(u);Sc(r);S(a|0);L()}function tN(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=C(0),S=C(0),T=0,U=0,V=0,W=C(0),X=0;m=hb-48|0;hb=m;t[m+40|0]=0;h=b+223848|0;j=m+40|0;Oi(h,vh(e,yi(e,Wn(e),j))+1|0);oe(j,v[h>>2],v[b+223852>>2]);h=hb-16|0;hb=h;t[h+15|0]=0;fc(m+32|0,e,vh(e,yi(e,Wn(e),h+15|0)));hb=h+16|0;G=v[m+32>>2];H=v[m+36>>2];i=hb-16|0;hb=i;I=a+906300|0;s=a+1074312|0;n=B(c,872)+b|0;J=n+1415|0;K=n+1304|0;L=n+1392|0;D=n+1368|0;E=n+1364|0;M=n+1336|0;N=n+1308|0;O=n+1300|0;P=n+1280|0;Q=n+1402|0;p=n+1466|0;R=C(w[p|0]);S=C(f>>>0);F=n+616|0;l=v[n+1272>>2];T=a+480188|0;k=1;r=255;while(1){if((o|0)!=(H|0)&y[j+4>>2]>g>>>0){e=w[Ib(G,o)|0];h=e-48|0;a:{b:{c:{if((h&255)>>>0<=9){break c}if((e-65&255)>>>0<=5){h=e-55|0;break c}d:{e:{f:{switch(e-97|0){case 2:g:{e=Fl(a,b,c,3,0)-1|0;if((e&255)>>>0>249){break g}e=v[Id(I,e)>>2];if(!e){break g}e=Cy(e,47672,44728);if(!e){break g}h=lb[v[v[e>>2]+192>>2]](e,F,c)|0;e=(h|0)!=255;h=e?h:0;if(e|!l){break c}break d}if(l){break d}h=0;break c;case 21:Ab(i+8|0,s,28);h:{if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){Ab(i,s,1);e=0;if(!zb(v[v[i>>2]>>2],v[i+4>>2])){break h}}e=u[L>>1]}h=B(v[D>>2],v[E>>2]);e=B(v[a+1074456>>2],e+v[K>>2]|0);e=Wb((Dc(ska(rka(h,h>>31,e,e>>31),kb,1048576,0),kb)|0)/2|0,1,127);break e;case 20:e=B(v[D>>2],v[E>>2]);h=e;A=e>>31;e=B(v[a+1074456>>2],v[M>>2]);e=Wb((Dc(ska(rka(h,A,e,e>>31),kb,67108864,0),kb)|0)/2|0,1,127);break e;case 23:v[i+8>>2]=v[N>>2]/2;v[i>>2]=127;e=v[od(i+8|0,i)>>2];break e;case 24:v[i+8>>2]=v[O>>2]/2;v[i>>2]=127;e=v[od(i+8|0,i)>>2];break e;case 0:e=0;if(!l){break e}h=x[l+28>>1];if(!h){break e}e=h-1>>>7&127;break e;case 1:e=0;if(!l){break e}h=x[l+28>>1];if(!h){break e}e=h-1&127;break e;case 14:e=v[P>>2]>>>8|0;break e;case 7:e=(x[T>>1]<=c>>>0?w[Q|0]-1|0:c)&127;break e;case 12:e=w[n+704|0]>>>7|0;break e;case 15:e=0;if(!l){break e}h=w[l+30|0];if(!h){break e}e=h-1&127;break e;case 25:i:{if(!d|t[p|0]<0){break i}j:{if(g>>>0<3){break j}e=v[j>>2];if(w[Ib(e,g-3|0)|0]!=240){break j}if(w[Ib(e,g-2|0)|0]>239){break i}}q=Lp(b,R,S);k:{if(q<C(4294967296)&q>=C(0)){e=~~q>>>0;break k}e=0}t[p|0]=e;r=128;break e}r=(r&255)==255?f:r;e=f;break e;case 18:l:{if(!g){h=0;break l}e=v[j>>2];h=g;while(1){h=h-1|0;A=Ib(e,h);if(!h){break l}if(w[A|0]!=240){continue}break}}if(g-h>>>0<5){break a}A=v[j>>2];if(w[Ib(A,h)|0]!=240){break a}h=h+5|0;e=0;while(1){if((g|0)!=(h|0)){e=w[Ib(A,h)|0]+e|0;h=h+1|0;continue}break};e=0-e&127;break e;case 13:break f;default:break a}}e=w[J|0];e=Wc(e)?e-1|0:0}h=((k^-1)&1)+g|0;U=Ib(v[j>>2],h),V=e,t[U|0]=V;g=h+1|0;k=1;break b}e=x[F+786>>1];h=(e?e-1|0:c)&15;e=w[l+31|0];if((e|0)!=17){h=sj(e)?e-1&15:0}}e=Ib(v[j>>2],g);m:{if(k){t[e|0]=h;break m}t[e|0]=w[e|0]<<4|h;g=g+1|0}k=(k^-1)&1}}o=o+1|0;continue}else{if(r<<24>>24>=0){t[p|0]=r}ec(i+8|0,v[j>>2],((k^-1)&1)+g|0);e=v[i+12>>2];v[j>>2]=v[i+8>>2];v[j+4>>2]=e;hb=i+16|0}break}p=v[m+44>>2];h=0;n:while(1){n=0;while(1){e=h;o:{p:{q:{r:{while(1){if(y[m+44>>2]<=e>>>0){break o}f=v[m+40>>2];k=Ib(f,e);g=t[k|0];if((g|0)==-16){g=e;if(p-g>>>0>=4){h=4;if((w[Ib(f,e+1|0)|0]&254)==240){break p}}s:{while(1){g=g+1|0;if(p>>>0<=g>>>0){break s}if(w[Ib(f,g)|0]!=247){continue}break}h=(g-e|0)+1|0;if(h){break p}}U=Ib(f,p),V=247,t[U|0]=V;p=p+1|0;h=p-e|0;break q}if((g|0)<0){break r}if(n&255){e=e-1|0;U=Ib(f,e),V=n,t[U|0]=V;continue}break}h=h+1|0;continue n}U=m,V=rP(g&255),v[U+16>>2]=V;v[m+28>>2]=p-e;h=v[Hb(m+16|0,m+28|0)>>2]}if(!h){break o}f=v[m+40>>2];k=Ib(f,e)}r=w[k|0];uq(m+16|0,f,v[m+44>>2],e,h);f=v[fc(m+8|0,v[m+16>>2],v[m+20>>2])>>2];k=hb-32|0;hb=k;i=v[m+12>>2];t:{if(!i){break t}j=Sd(w[b+223884|0]);u:{l=Ib(f,0);g=w[l|0]-250|0;if(g>>>0>5|!(1<<g&37)){break u}o=x[a+480188>>1];g=0;while(1){if((g|0)==(o|0)){break u}s=(B(g,872)+b|0)+1453|0;t[s|0]=127;t[s+1|0]=0;g=g+1|0;continue}}v:{if((i|0)!=4|w[l|0]!=240){break v}g=w[Ib(f,1)|0];if((g&254)!=240){break v}i=(B(c,872)+b|0)+616|0;l=Ib(f,2);o=w[Ib(f,3)|0];f=o<<24>>24;w:{x:{y:{z:{A:{B:{l=w[l|0];switch(l|0){case 3:break y;case 2:break z;case 1:break A;case 0:break B;default:break x}}if((g|0)==241|(f|0)<0){break x}g=B(c,872)+b|0;l=g+1453|0;if(d){f=dh(Lp(b,C(w[l|0]),C((f&255)>>>0)))}t[l|0]=f;t[g+1412|0]=0;f=Rp(a,i,!(v[g+704>>2]&32768),256);if((f|0)<0|!(w[g+705|0]&2)){break t}g=v[a+1298300>>2];if(j|vd(g)^1){break t}Vp(g,c,f>>>2&255,1);break t}if((g|0)==241|(f|0)<0){break x}g=B(c,872)+b|0;j=g+1454|0;if(d){f=dh(Lp(b,C(w[j|0]),C((f&255)>>>0)))}t[j|0]=f;t[g+1411|0]=0;Rp(a,i,!(v[g+704>>2]&32768),256);break t}if((g|0)==241){break w}if(f>>>0>31){break t}g=B(c,872)+b|0;t[g+1461|0]=(f&240)>>>4;Rp(a,i,!(v[g+704>>2]&32768),256);break t}if((g|0)==241){break w}g=(f|0)<0;f=Fl(a,b,c,3,0)-1|0;if(g|(f&255)>>>0>249){break t}t[k+24|0]=f;g=Id(a+906300|0,f&255);f=v[g>>2];if(!f){break t}q=C(C(127-o|0)/C(127));if(j){j=0;i=hb-16|0;hb=i;U=i,V=xj(k+24|0),v[U>>2]=V;f=hb-16|0;hb=f;l=b+223860|0;o=By(l,f+12|0,w[k+24|0]);g=v[o>>2];if(!g){g=hb-16|0;hb=g;j=gc(l);s=gh(f,tc(24),hh(g+8|0,j));j=v[s>>2];D=w[v[i>>2]];v[j+20>>2]=0;t[j+16|0]=D;U=gc(s),V=1,t[U+4|0]=V;hb=g+16|0;Hg(l,v[f+12>>2],o,v[f>>2]);g=_d(f);mk(f);j=1}Gg(i+8|0,v[cc(f,g)>>2],j);hb=f+16|0;f=sd(v[i+8>>2]);hb=i+16|0;z[f+4>>2]=q;break t}if(!d){Ss(v[f+20>>2],q);break t}Ss(v[f+20>>2],Lp(b,z[g+144>>2],q));break t}if(l&128){break w}if((g|0)!=241){break t}}o=Fl(a,b,c,3,0)-1|0;if((f|0)<0|(o&255)>>>0>249){break t}i=v[Id(a+906300|0,o&255)>>2];if(!i){break t}g=(g|0)==241?l+128|0:l&127;q=C(C((f&255)>>>0)/C(127));if(j){U=JN(b+223872|0,_M(k+24|0,o,g)),W=q,z[U>>2]=W;break t}f=v[i>>2];if(!d){lb[v[f+44>>2]](i,g,q);break t}V=i,X=g,W=Lp(b,C(lb[v[f+48>>2]](i,g)),q),U=v[v[i>>2]+44>>2],lb[U](V|0,X|0,C(W));break t}if(j){break t}j=x[a+480188>>1];C:{if(j>>>0>c>>>0){g=c+1|0;break C}g=x[(B(c,872)+b|0)+1402>>1];if(!g){break t}}if(w[(B(c,872)+b|0)+707|0]&4|j>>>0<(g&65535)>>>0){break t}g=Fl(a,b,c,3,0)-1|0;if((g&255)>>>0>249){break t}g=v[Id(a+906300|0,g)>>2];if(!g){break t}j=w[l|0];if((j|0)==240){Vg(k+16|0,f,i);f=v[v[g>>2]+72>>2];i=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=i;lb[f|0](g,k)|0;break t}U=k,X=rP(j),v[U+24>>2]=X;v[k+12>>2]=i;i=k+24|0;j=v[Hb(i,k+12|0)>>2];v[k+24>>2]=0;pc(i,f,j);lb[v[v[g>>2]+68>>2]](g,v[k+24>>2])|0}hb=k+32|0;n=r>>>0<240?r:n;h=e+h|0;continue}break}break}hb=m+48|0}
function gW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=hb-224|0;hb=e;xc(b);a:{b:{c:{d:{if(!rC(b,e+176|0)){break d}if(!uC(e+176|0)){break d}if(!c){n=1;break d}zd(a,2048);$f(a);d=hb-16|0;hb=d;f=e+8|0;h=vc(d,3947);Xc(f,h);xb(h);hb=d+16|0;v[23516]=0;U(212,e+80|0,f|0,w[e+179|0]);d=v[23516];v[23516]=0;e:{f:{g:{h:{i:{j:{k:{if((d|0)!=1){d=e+80|0;Gb(a+1298344|0,d);xb(d);f=e+8|0;ac(f);h=vc(d,11118);Gb(a+1298356|0,h);xb(h);v[a+1298404>>2]=5;h=a+480188|0;u[h>>1]=w[e+216|0];u[a+480190>>1]=w[e+212|0];Ke(f,2,e+176|4);Cc(d,f);yc(a+1298308|0,d);wb(d);d=w[e+179|0];l:{if(d>>>0>=9){if(d>>>0>=11){f=(d|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break l}h=_u(b);m:{if((h|0)==100){v[((d<<5)+a|0)+480280>>2]=256;break m}v[e+80>>2]=(h<<1)+128;v[e+8>>2]=0;v[e+160>>2]=256;s=((d<<5)+a|0)+480284|0,y=v[Gj(e+80|0,e+8|0,e+160|0)>>2],u[s>>1]=y}d=d+1|0;continue}}f=e+80|0;d=hb-16|0;hb=d;n:{if(!Ob(v[b>>2],v[b+8>>2],16)){fC(f);break n}Pu(d+8|0,f);pd(d,b,v[d+8>>2],v[d+12>>2])}hb=d+16|0;d=0;while(1){if((d|0)==16){break l}u[((d<<5)+a|0)+480284>>1]=t[(e+80|0)+d|0]&1?64:192;d=d+1|0;continue}}u[h>>1]=4;wg(b,1);jh(a,1)}o:{if(w[e+179|0]>=13){d=e+80|0;Tu(d,b);f=Kc(d);d=w[e+80|0];if(d>>>0<=31){t[e+80|0]=125;d=125}v[a+480204>>2]=B(d,1e4);v[a+480196>>2]=w[f|0];break o}v[a+480196>>2]=6;v[a+480204>>2]=125e4}tg(Sb(v[a+484360>>2],w[a+484376|0]),w[e+213|0]);l=Lb(e+160|0);f=w[e+179|0];q=v[b+8>>2]+((f>>>0>13)<<1)|0;d=0;p:{if(f>>>0<14){break p}v[23516]=0;R(213,l|0,w[e+213|0]);f=v[23516];v[23516]=0;if((f|0)!=1){break p}d=P()|0;O()|0;break b}q:{r:{s:{while(1){t:{if(w[e+213|0]<=d>>>0){d=0;if(w[e+179|0]!=10){break s}m=v[b+8>>2];k=a+480190|0;d=1;while(1){j=x[k>>1];if(j>>>0<(d&65535)>>>0){break t}v[23516]=0;f=Q(214,b|0,e+80|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break r}if(f){f=0;u:{if(w[e+212|0]<(w[e+126|0]|w[e+127|0]<<8|(w[e+128|0]<<16|w[e+129|0]<<24))>>>0|w[e+80|0]>1){break u}h=w[e+130|0]|w[e+131|0]<<8|(w[e+132|0]<<16|w[e+133|0]<<24);if(h>>>0>1048576|w[e+136|0]>64|h>>>0<(w[e+137|0]|w[e+138|0]<<8|(w[e+139|0]<<16|w[e+140|0]<<24))>>>0){break u}f=h>>>0>=(w[e+141|0]|w[e+142|0]<<8|(w[e+143|0]<<16|w[e+144|0]<<24))>>>0}if(!f){break t}}d=d+1|0;continue}}s=$b(v[Sb(v[a+484360>>2],w[a+484376|0])>>2],d),y=d,u[s>>1]=y;if(w[e+179|0]>=14){v[23516]=0;f=T(192,b|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break q}s=$b(v[l>>2],d),y=f,u[s>>1]=y}f=x[a+480188>>1];v[23516]=0;Q(186,b|0,f<<1)|0;f=v[23516];v[23516]=0;if((f|0)==1){break q}d=d+1|0;continue}break}v[23516]=0;Q(153,b|0,m|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break c}d=j>>>0>=(d&65535)>>>0}j=a+480190|0;f=x[j>>1];v[23516]=0;v[e+80>>2]=0;m=W(215,e- -64|0,f|0,e+80|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break k}n=d?59:65;k=e+80|1;f=1;v:{while(1){h=f&65535;if(h>>>0>x[j>>1]){h=Lb(e+48|0);v[23516]=0;n=W(216,b|0,h|0,x[e+214>>1])|0;d=v[23516];v[23516]=0;w:{if((d|0)!=1){if(!n){break e}d=0;k=0;f=v[h>>2];if(!nc(f,v[h+4>>2])){f=Cb(f);g=Cb(v[h+4>>2]);k=hb-16|0;hb=k;x:{if(!Nb(f,g)){break x}v[k+8>>2]=f;while(1){j=v[Qe(k+8|0)>>2];if(!Nb(j,g)){break x}f=xk(w[f|0]|w[f+1|0]<<8,w[j|0]|w[j+1|0]<<8)?j:f;continue}}hb=k+16|0;k=w[f|0]|w[f+1|0]<<8}v[23516]=0;j=Q(217,e+32|0,k|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break w}y:{while(1){if((d|0)==(k|0)){if(!(c&2)){break j}i=Uc(e+80|0,8,1,0,1);o=a+480190|0;f=x[o>>1];g=1;z:{A:while(1){p=g&65535;if(p>>>0>(f&65535)>>>0){break j}d=v[b+8>>2];f=v[b>>2];v[23516]=0;d=W(154,f|0,d|0,1)|0;f=v[23516];v[23516]=0;if((f|0)==1){break z}if(!d){break j}r=v[b+8>>2];d=0;while(1){f=x[o>>1];if(f>>>0<=d>>>0){g=g+1|0;continue A}if((p|0)!=v[Bb(v[m>>2],d)>>2]){d=d+1|0;continue}v[23516]=0;Q(153,b|0,r|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){v[23516]=0;d=d+1|0;W(218,i|0,(B(d,104)+a|0)+484380|0,b|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){continue}}break}break}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}v[23516]=0;f=T(192,b|0)|0;g=v[23516];v[23516]=0;B:{if((g|0)==1){break B}v[23516]=0;Q(186,b|0,1)|0;g=v[23516];v[23516]=0;if((g|0)==1){break B}if(f){v[23516]=0;U(188,e+8|0,b|0,B(f,3)+(w[e+179|0]==1?3:0)|0);f=v[23516];v[23516]=0;if((f|0)==1){break y}g=e+8|0;f=hc(e+80|0,g);cd(Kg(v[j>>2],d),f);yb(f);yb(g)}d=d+1|0;continue}break}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}C:{D:{if(w[e+179|0]<=9){v[23516]=0;R(219,b|0,e+80|0);g=v[23516];v[23516]=0;E:{F:{if((g|0)==1){break F}v[23516]=0;R(220,e+80|0,(B(h,104)+a|0)+484380|0);g=v[23516];v[23516]=0;if((g|0)==1){break F}g=e+48|0;Ke(g,2,k);v[23516]=0;R(221,e+8|0,g|0);g=v[23516];v[23516]=0;if((g|0)==1){break E}break D}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}v[23516]=0;U(222,b|0,e+80|0,n|0);g=v[23516];v[23516]=0;if((g|0)==1){break C}v[23516]=0;U(223,e+80|0,(B(h,104)+a|0)+484380|0,d|0);g=v[23516];v[23516]=0;if((g|0)==1){break C}g=e+48|0;Ke(g,2,k);v[23516]=0;R(221,e+8|0,g|0);g=v[23516];v[23516]=0;if((g|0)==1){break v}}g=e+8|0;Ac(((h<<5)+a|0)+946304|0,g);wb(g);s=Bb(v[m>>2],h-1|0),y=x[e+126>>1]|x[e+128>>1]<<16,v[s>>2]=y;f=f+1|0;continue}break}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;ac(e+8|0);break a}d=P()|0;O()|0;break b}if(!(c&1)){break f}v[23516]=0;g=a+484344|0;R(224,g|0,w[e+213|0]);c=v[23516];v[23516]=0;G:{if((c|0)!=1){f=a+480188|0;a=0;while(1){H:{if(w[e+213|0]<=a>>>0){break f}d=64;c=v[l>>2];if(Oc(c,v[l+4>>2])>>>0>a>>>0){d=x[$b(c,a)>>1]}v[23516]=0;c=W(225,g|0,a&65535,d&65535)|0;d=v[23516];v[23516]=0;if((d|0)==1){break G}I:{if(c){c=x[f>>1];v[23516]=0;Q(153,b|0,B(((w[e+179|0]>13)<<1)+(c<<1)|0,a)+q|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break G}c=Lb(e+80|0);d=x[f>>1];v[23516]=0;i=W(216,b|0,c|0,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break I}d=0;J:{if(!i){break J}while(1){if(x[f>>1]<=d>>>0){break J}K:{i=$b(v[c>>2],d);i=w[i|0]|w[i+1|0]<<8;if(!i|i>>>0>x[e+214>>1]){break K}i=$b(v[h>>2],i-1|0);i=(w[i|0]|w[i+1|0]<<8)-1&65535;if(i>>>0>=k>>>0){break K}o=v[g>>2];p=v[j>>2];v[23516]=0;U(226,Xb(o,a)|0,d&65535,Kg(p,i)|0);i=v[23516];v[23516]=0;if((i|0)!=1){break K}break H}d=d+1|0;continue}}gd(c)}a=a+1|0;continue}}break}d=P()|0;O()|0;gd(c);break i}d=P()|0;O()|0;break i}d=P()|0;O()|0}Nc(j)}gd(h)}lc(m);break b}Nc(j)}gd(h);lc(m);gd(l)}hb=e+224|0;return n|0}d=P()|0;O()|0}gd(l)}S(d|0);L()}function Pp(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;g=hb-16|0;hb=g;i=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:i;s=v[b+752>>2];k=w[b+802|0];a:{if(!k){Ab(g+8|0,a+1074312|0,11);if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}}b:{c:{if(!i){break c}if(!Wc(k)){break c}d:{l=k-1|0;k=$b(i+236|0,l);if(x[k>>1]){break d}Ab(g+8|0,a+1074312|0,43);if(!zb(v[v[g+8>>2]>>2],v[g+12>>2])){break d}if(sj(w[i+31|0])){break d}v[b+656>>2]=i;break a}if(w[Ib(i+108|0,l)|0]>120){break a}k=x[k>>1];l=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}l=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(k>>>0>250){break a}Ab(g+8|0,a+1074312|0,43);if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){if(i){l=0;if(sj(w[i+31|0])){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}l=0}k=v[b+104>>2];n=(k|0)!=0&(k|0)!=(l|0);j=v[b+656>>2];p=!i|v[a+480180>>2]!=16777216?p:v[i+44>>2]!=0;q=d^1;h=(j|0)!=(i|0);if((q|h|n)==1){u[b+774>>1]=0}r=!n;if(!(r|(h|!(d&p)))){break a}e:{if(!(d&n)){break e}k=a+1074312|0;Ab(g+8|0,k,32);if(!(!zb(v[v[g+8>>2]>>2],v[g+12>>2])|!(w[a+480208|0]&8))){l=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:l}m=v[a+480180>>2];f:{if(!(i?h|!(m&1048580):1)|(m|0)==268435456){break f}if((m|0)==1){if(zi(v[b+8>>2],v[b+12>>2])){break f}}Ab(g+8|0,k,79);if(!zb(v[v[g+8>>2]>>2],v[g+12>>2])){break e}if(!zi(v[b+8>>2],v[b+12>>2])){break e}}o=1}g:{if(!v[b+16>>2]|(!n|(h|!x[a+480192>>1]))){break g}Ab(g+8|0,a+1074312|0,87);if(!zb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}o=Wc(w[b+788|0])^1|o}h:{i:{j:{k:{l:{if(zi(v[b+8>>2],v[b+12>>2])|!(v[a+480180>>2]&16777248)){break l}if(i){if(sj(w[i+31|0])){break l}}k=1;break k}if(!(h|n)){break j}k=(j|0)!=(i|0)}if(!d){break i}Ab(g+8|0,a+1074312|0,61);if(!zb(v[v[g+8>>2]>>2],v[g+12>>2])){break i}j=v[b+656>>2];if(!j){j=0;m=0;h=v[b+104>>2];if(!h){break i}break h}h=v[b+104>>2];m=0;break h}k=0}v[b+656>>2]=i;j=i;m=k;h=l}m:{n:{o:{if(!e){break o}p:{if(w[a+480180|0]&3){if(h){if(Vd(v[h>>2],v[h+20>>2])){break p}}if(!lj(j)){break o}}if(!h){break n}}if(u[h+34>>1]<0){break o}v[b+688>>2]=x[h+30>>1]}i=(h|0)!=0;if(!(n&o)|!h){break m}Ab(g+8|0,a+1074312|0,85);if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){u[b+772>>1]=t[h+37|0]}i=1;if(v[a+480180>>2]!=2){break m}if(!Vd(v[h>>2],v[h+20>>2])){break m}v[b+704>>2]=v[h+24>>2];break m}if(!(!j|!w[j+34|0])){k=v[b+688>>2];if(j){k=v[j+4>>2]<<2}v[b+688>>2]=k;i=0;break m}i=0;v[b+688>>2]=0}if(o){break a}t[b+803|0]=0;q:{if(!j){break q}Ab(g+8|0,a+1074312|0,29);if(!(z=1,A=(zb(v[v[g+8>>2]>>2],v[g+12>>2])^-1)&i,C=w[j+34|0]|m,C?z:A)){break q}t[b+798|0]=w[j+16|0]}l=64;v[b+752>>2]=64;if(h){l=x[h+32>>1];v[b+752>>2]=l}if(j){v[b+752>>2]=B(v[j+4>>2],l)>>>6}r:{if(!(v[a+480180>>2]&1048580?e:1)){break r}Ab(g+8|0,a+1074312|0,48);if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){break r}nN(a,b,j,h)}s:{t:{u:{if(!f){break u}f=a+1074312|0;Ab(g+8|0,f,19);v:{w:{x:{y:{z:{A:{B:{C:{if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){if(!v[b+76>>2]){e=1;break B}if(!(!c|q)){e=(w[a+480208|0]&8)>>>3|0;if(e){break B}break C}e=0;if(c){break C}break B}c=v[a+480180>>2]&17301536;e=1;D:{if(!d|!c){break D}c=1;e=1;if(w[a+480208|0]&8){break D}e=1;if(!v[b+76>>2]){break D}e=0;if(!(w[b+89|0]&16)){break D}e=!v[b+696>>2]}if(!j|(!c|m)){break z}if(!e){break y}c=v[b+88>>2];e=c&6144;break A}if(d){break B}if(!(w[b+89|0]&24)){e=0;break B}e=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|m){break z}if(!e){break y}c=v[b+88>>2];e=c&2048}v[b+88>>2]=c|2097152;if(!j){break v}if(e){break w}if(!(w[j+60|0]&8)){kj(b+724|0)}if(!(w[j+80|0]&8)){kj(b+732|0)}if(w[j+100|0]&8){break v}kj(b+740|0);break v}if(e){break x}}if(j){if(t[j+60|0]&1){break u}Ab(g+8|0,f,32);if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){kj(b+724|0);break u}km(b);break u}c=0;if(!h){break t}break s}v[b+88>>2]=v[b+88>>2]|2097152;if(!j){break v}}km(b)}Ab(g+8|0,f,21);if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){break u}t[b+818|0]=0;v[b+756>>2]=0}c=0;if(h){break s}if(!j){break t}c=1;if(sj(w[j+31|0])){break s}}v[b+752>>2]=0;v[b+104>>2]=0;break a}E:{F:{G:{H:{I:{if(!(!d|(i^1|v[b+104>>2]!=(h|0)))){d=v[a+480180>>2];if(v[b+76>>2]?d&16777250:0){break a}if((d|0)!=4){break I}Ab(g+8|0,a+1074312|0,40);if(!zb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+789|0]){break I}d=v[b+88>>2];break H}v[b+88>>2]=v[b+88>>2]&-6145;e=a+1074312|0;Ab(g+8|0,e,18);J:{if(z=zb(v[v[g+8>>2]>>2],v[g+12>>2]),A=1,C=v[a+480180>>2]&16777248,C?z:A){f=-640;if(!(v[b+104>>2]!=(h|0)|m)){break J}}f=-768}v[b+88>>2]=f&v[b+88>>2];K:{if(!j){break K}t[b+730|0]=w[j+60|0];t[b+738|0]=w[j+80|0];t[b+746|0]=w[j+100|0];L:{if((w[j+100|0]&17)!=17){break L}Ab(g+8|0,e,36);if(zb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+837|0]){break L}t[b+837|0]=127}e=w[j+21|0];if(zf(e)){z=b,A=Sq(e),t[z+837|0]=A}e=w[j+22|0];if(!zf(e)){break K}z=b,A=Sq(e),t[z+838|0]=A}if(c){break G}if(!d){break E}break F}d=v[b+88>>2]&-6145}v[b+88>>2]=d&-640;if(!c){break F}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break E}c=a+1074312|0;Ab(g+8|0,c,54);if(!zb(v[v[g+8>>2]>>2],v[g+12>>2])){Ab(g,c,39);if(!zb(v[v[g>>2]>>2],v[g+4>>2])){break E}}v[b+8>>2]=0;v[b+12>>2]=0}M:{if(w[b+788|0]!=255){break M}Ab(g+8|0,a+1074312|0,100);if(!zb(v[v[g+8>>2]>>2],v[g+12>>2])|(!(v[a+480208>>2]&4)|r)){break M}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[h+30>>1];if(!(w[h+34|0]&32)){break a}Yp(b,x[h+28>>1],a);break a}v[b+104>>2]=h;v[b+76>>2]=v[h>>2];v[b+80>>2]=v[h+4>>2];v[b+84>>2]=v[h+8>>2];e=a+1074312|0;Ab(g+8|0,e,83);if(!(!zb(v[v[g+8>>2]>>2],v[g+12>>2])|v[b+80>>2])){v[b+84>>2]=v[h>>2]}v[b+88>>2]=v[b+88>>2]|x[h+34>>1]&1023;Ab(g+8|0,e,21);if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){t[b+818|0]=0;v[b+756>>2]=0}N:{O:{if(p){v[b+704>>2]=v[h+24>>2];t[b+851|0]=w[b+851|0]|64;c=0;break O}if(!(n|q)){d=v[a+480180>>2];if(d&5){break N}}v[b+704>>2]=v[h+24>>2];c=t[h+37|0]}u[b+772>>1]=c;d=v[a+480180>>2]}if(Am(d)){c=t[h+36|0]}else{c=0}u[b+770>>1]=c;Ab(g+8|0,e,69);if(!(zb(v[v[g+8>>2]>>2],v[g+12>>2])|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;i=v[b+88>>2];if(i&8){v[b+80>>2]=v[h+12>>2];v[b+84>>2]=v[h+16>>2];i=i>>>2&4|i|2;v[b+88>>2]=i}P:{if(!(i&2)){i=v[b+76>>2];break P}i=v[b+76>>2];c=v[b+84>>2];if(i>>>0<=c>>>0){break P}v[b+76>>2]=c;i=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<i>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}hb=g+16|0}function bja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;e=hb-272|0;hb=e;xc(b);d=hb-16|0;hb=d;i=e+112|0;YT(d+8|0,i);g=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],g);h=v[d+4>>2];if((h|0)==(g|0)){Yb(b,v[d+12>>2])}hb=d+16|0;d=(g|0)==(h|0);if(!d){XT(i)}a:{if(!d){break a}if(!ZT(e+112|0)){break a}if(!c){f=1;break a}zd(a,v[(x[e+228>>1]<<2)+26560>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+48|0;f=vc(d,13139);Gb(a+1298344|0,f);xb(f);f=vc(d,10332);Gb(a+1298356|0,f);xb(f);f=hb-16|0;hb=f;g=e+8|0;i=vc(f,4392);Xc(g,i);xb(i);hb=f+16|0;v[23516]=0;X(231,d|0,g|0,w[e+191|0],e+188|0);d=v[23516];v[23516]=0;b:{if((d|0)!=1){d=e+48|0;Gb(a+1298368|0,d);xb(d);f=e+8|0;ac(f);Hl(a+1298392|0,(x[e+228>>1]<<2)+26608|0);Hl(a+1298380|0,v[(x[e+228>>1]<<2)+26656>>2]);v[a+1298404>>2]=5;Ke(f,2,e+112|4);Cc(d,f);yc(a+1298308|0,d);wb(d);Ke(f,2,e+148|0);Cc(d,f);c:{if(qq(d,9769)){v[23516]=0;U(11,e+8|0,5,e+48|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}d=e+8|0;Gb(a+1298320|0,d);xb(d)}wb(e+48|0);u[a+480188>>1]=32;d=0;d:{while(1){if((d|0)!=32){g=(d<<5)+a|0;i=g+480280|0;af(i);f=w[(d+e|0)+193|0];e:{if(f>>>0<=15){v[e+48>>2]=f<<4|8;v[e+8>>2]=256;y=g+480284|0,z=v[od(e+48|0,e+8|0)>>2],u[y>>1]=z;break e}if((f|0)!=16){if((f|0)!=255){break e}u[a+480188>>1]=d;break d}u[g+480284>>1]=128;v[i>>2]=256}d=d+1|0;continue}break}d=x[a+480188>>1]}f=0;if(!(d&65535)){break a}v[e+48>>2]=w[e+225|0]<<2;v[e+8>>2]=256;y=a,z=v[Hb(e+48|0,e+8|0)>>2],v[y+480200>>2]=z;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if(Zc(b,x[e+230>>1]|x[e+232>>1]<<16)){ko(Sb(v[a+484360>>2],w[a+484376|0]),b,w[e+234|0]+1|0,255,254)}if(!Zc(b,v[e+240>>2])){break a}l=a+480190|0;d=w[e+248|0]+1|0;u[l>>1]=d;m=e+80|0;n=a+480180|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(d&65535)>>>0){break g}d=hb-16|0;hb=d;g=e+48|0;ec(d+8|0,g,62);f=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],f);h=v[d+4>>2];if((h|0)==(f|0)){Yb(b,v[d+12>>2])}hb=d+16|0;d=(f|0)==(h|0);if(!d){Rb(g,0,62)}if(!d){break g}d=0;f=B(j,104)+a|0;k=f+484380|0;jd(k,0);h=e+32|0;Ke(h,2,e+48|0);g=e+8|0;Cc(g,h);Ac(((j<<5)+a|0)+946304|0,g);wb(g);ok(h,2,m);Cc(g,h);xe(f+484423|0,g);wb(g);g=x[e+106>>1];v[f+484404>>2]=g;if(!Am(v[n>>2])){break f}while(1){if((d|0)==16){break f}if((g|0)==x[(d<<1)+26704>>1]){t[f+484417|0]=d<<4;break f}else{d=d+1|0;continue}}}h:{if(!(c&2)){break h}if(!Zc(b,v[e+244>>2])){break h}d=1;f=a+480190|0;while(1){g=d&65535;if(g>>>0>x[f>>1]){break h}g=B(g,104)+a|0;ug(Uc(e+48|0,u[g+484414>>1]&1?16:8,1,0,1),g+484380|0,b);d=d+1|0;continue}}n=a+484344|0;vg(n,w[e+239|0]+1|0);f=pq(a);d=hb-16|0;hb=d;v[d+12>>2]=0;Ps(d+12|0,f);k=v[d+12>>2];hb=d+16|0;Zc(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));p=c&1;q=a+480188|0;r=a+480180|0;j=0;m=1;i:{j:{k:{while(1){if(w[e+239|0]<j>>>0){if(v[a+480180>>2]==1){break k}c=v[a+480208>>2]&-8454145;break j}l:{d=Ng(b);if(d>>>0>=3){c=e+8|0;Wd(c,b,d-2|0);h=hc(e+48|0,c);yb(c);m:{if(!p){break m}c=v[h>>2];v[23516]=0;c=T(176,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break l}if(!c){break m}v[23516]=0;c=W(225,n|0,j&65535,64)|0;d=v[23516];v[23516]=0;if((d|0)==1){break l}l=0;if(!c){break m}while(1){if((l|0)==64){break m}c=Xb(v[n>>2],j);s=xf(v[c>>2],v[v[c+48>>2]+12>>2],l);n:{o:while(1){v[23516]=0;c=T(204,h|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=x[q>>1]){break n}f=B(d,6)+s|0;if(c&32){v[23516]=0;R(263,e+8|0,h|0);d=v[23516];v[23516]=0;if((d|0)==1){break i}g=Kc(e+8|0);d=w[e+8|0];if(d){d=(d&127)-1|0;t[e+8|0]=d;d=(B((d&240)>>>4|0,12)+(d&15)|0)+13|0;t[f|0]=d;m=YA(d)&m}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){c=v[h>>2];v[23516]=0;c=W(154,c|0,v[e+56>>2],2)|0;d=v[23516];v[23516]=0;if((d|0)==1){break i}if(!c){continue o}o=w[f+5|0];c=w[f+3|0];v[23516]=0;R(263,e+8|0,h|0);d=v[23516];v[23516]=0;if((d|0)!=1){i=w[Kc(e+8|0)|0];t[g|0]=i;d=w[(w[e+8|0]&31)+26736|0];t[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(i>>>0<224){break r}d=223;if(v[r>>2]!=1){break s}break r;case 11:t[e+32|0]=64;y=g,z=w[Vb(g,e+32|0)|0],t[y|0]=z;if(!WT(v[k+88>>2])){break r}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=o;d=c;break q;case 17:u:{switch(((i&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[g|0]=i&15|224;break p;case 1:t[f+3|0]=3;t[g|0]=i&15|224;break p;default:break u}}if(eu(v[k+84>>2],19)){break r}Iu(f);break r;case 13:d=v[k+84>>2];if(eu(d,15)){break r}if(!eu(d,19)){break r}t[f+3|0]=19;t[g|0]=i&15|144;break p;case 18:d=145;if((i|0)==1){break s}if((i&240)==128){if(eu(v[k+84>>2],20)){break r}t[f+3|0]=19;break p}t[f+3|0]=0;break p;case 4:case 5:break t;default:break q}}d=i&240;if(!d){break r}}t[g|0]=d}d=w[f+3|0]}if((d&255)!=20){break p}d=w[g|0];if(w[f+2|0]|(d&240)!=128){break p}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=o}if(!(w[e+8|0]&32)){continue o}continue}break}break}break i}l=l+1|0;continue}}yb(h)}j=j+1|0;continue}break}break i}c=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?m&1?8454144:0:0)}v[a+480208>>2]=c;f=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break a}if(!Zc(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break a}lB(a+1298332|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4);break a}d=P()|0;O()|0;yb(h);break b}u[f+484412>>1]=64;g=w[e+93|0]|w[e+94|0]<<8|(w[e+95|0]<<16|w[e+96|0]<<24);v[k>>2]=g;d=w[e+105|0];if(d&2){h=f+484414|0;u[h>>1]=x[h>>1]|1;v[k>>2]=g>>>1}v[f+484384>>2]=w[e+97|0]|w[e+98|0]<<8|(w[e+99|0]<<16|w[e+100|0]<<24);v[f+484388>>2]=(w[e+101|0]|w[e+102|0]<<8|(w[e+103|0]<<16|w[e+104|0]<<24))-1;if(d&1){g=f+484414|0;u[g>>1]=x[g>>1]|2}v:{w:{if(!(d&4)){break w}g=w[e+108|0];if((g|0)==255){break w}t[e+8|0]=g;t[e+32|0]=64;y=f+484410|0,z=w[Vb(e+8|0,e+32|0)|0]<<2,u[y>>1]=z;break v}g=f+484414|0;u[g>>1]=x[g>>1]|32768}x:{if(d&8){d=f+484414|0;g=x[d>>1]|32;u[d>>1]=g;j=f+484408|0;f=w[e+109|0];if(f>>>0<=15){v[e+32>>2]=256;v[e+8>>2]=f<<4|8;h=v[od(e+8|0,e+32|0)>>2]}else{h=128}u[j>>1]=h;u[d>>1]=g&65279|((f|0)==16)<<8;break x}u[f+484408>>1]=128}i=i+1|0;d=x[l>>1];continue}}d=P()|0;O()|0;wb(e+48|0);break b}d=P()|0;O()|0;ac(e+8|0)}S(d|0);L()}hb=e+272|0;return f|0}function Aaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=hb+-64|0;hb=i;d=v[b>>2];v[23516]=0;d=T(176,d|0)|0;h=v[23516];v[23516]=0;a:{b:{c:{d:{if((h|0)==1){break d}e:{f:{if(d){h=Lb(i+48|0);g:{h:{i:{if(c&16){break i}v[23516]=0;g=(c|0)!=0;f=W(842,h|0,b|0,g|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}d=4;j:{if(f){break j}v[23516]=0;f=W(843,h|0,b|0,g|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}d=5;if(f){break j}v[23516]=0;f=W(844,h|0,b|0,g|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}d=6;if(f){break j}f=0;v[23516]=0;g=W(845,h|0,b|0,g|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}d=3;if(!g){break i}}if(!c){d=1;break h}f=v[h>>2];if(!nc(f,v[h+4>>2])){jv(b,f+12|0)}f=d}d=0;if(c&32){break h}d=31728;k:{while(1){e=d;if((d|0)!=32268){j=v[e+8>>2];g=(j>>1)+a|0;d=v[e+4>>2];d=j&1?v[v[g>>2]+d>>2]:d;v[23516]=0;g=W(d|0,g|0,b|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}d=e+12|0;if(!g){continue}break k}break}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){d=(e|0)!=32268;e=0;break h}if(!(v[a+480184>>2]|!f)){v[a+480184>>2]=f}v[23516]=0;e=1;R(785,a+1298264|0,1);f=v[23516];v[23516]=0;d=1;if((f|0)==1){break g}}pM(h);if(e){break f}break a}break c}v[23516]=0;R(248,a|0,0);d=v[23516];v[23516]=0;if((d|0)==1){break d}v[23516]=0;R(785,a+1298264|0,1);d=v[23516];v[23516]=0;if((d|0)==1){break d}v[a+1074304>>2]=19988497}d=0;while(1){if((d|0)==127){d=1;while(1){e=d&65535;if(e>>>0>x[a+480190>>1]){e=0;h=a+480180|0;d=0;l:{while(1){f=d&65535;if(f>>>0>x[a+480192>>1]){m:{u[a+480192>>1]=e;d=a+480204|0;if(y[a+480204>>2]>=1e4){break m}v[d>>2]=125e4;break l}}else{f=v[((f<<2)+a|0)+900380>>2];if(f){g=v[h>>2];uc(f,65536);uc(f+4|0,64);uc(f+8|0,256);Bf(f+28|0,16384);sf(f+30|0,128);sf(f+31|0,17);if(w[f+16|0]>=4){t[f+16|0]=0}if(w[f+17|0]>=5){t[f+17|0]=0}if(w[f+18|0]>=3){t[f+18|0]=0}sf(f+19|0,64);sf(f+20|0,100);e=224;j=t[f+26|0];n:{if((j|0)>=-32){e=32;if((j|0)<33){break n}}t[f+26|0]=e}sf(f+23|0,64);sf(f+24|0,64);vz(f+48|0,64);vz(f+68|0,64);vz(f+88|0,(g|0)==4096?255:64);g=f+108|0;e=0;while(1){o:{if((e|0)==128){if(!Co(w[f+14|0])){t[f+14|0]=5}if(w[f+34|0]>=251){t[f+34|0]=0}break o}j=Ib(g,e);if((w[j|0]-121&255)>>>0<=135){t[j|0]=e+1}e=e+1|0;continue}break}e=d}d=d+1|0;continue}break}uc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}e=a+480216|0;f=a+480220|0;d=v[a+480216>>2];if(!(d|w[a+480224|0]!=2)){v[e>>2]=1;d=1}if(y[a+480220>>2]<d>>>0){v[f>>2]=d}uc(e,65536);uc(f,65536);uc(a+480200|0,256);p:{d=a+480248|0;if(!nc(v[d>>2],v[a+480252>>2])){e=v[e>>2];v[23516]=0;R(846,d|0,e|0);d=v[23516];v[23516]=0;if((d|0)==1){break p}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];e=v[a+480220>>2];d=a+1074408|0;v[d>>2]=v[a+480216>>2];v[d+4>>2]=e;v[a+1074456>>2]=v[a+480200>>2];Ny(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;if(Am(v[a+480180>>2])){v[23516]=0;Q(268,a+1074312|0,7)|0;d=v[23516];v[23516]=0;if((d|0)==1){break p}}u[a+480276>>1]=0;Hp(a);o=i,p=Cb(v[a+484360>>2]),v[o+48>>2]=p;e=Cb(v[a+484364>>2]);while(1){d=v[i+48>>2];if(!Nb(d,e)){q:{r:{j=v[a+480180>>2];if(j){Ps(a+8|0,pq(a));if(v[a+1074308>>2]){v[23516]=0;Y(847,a|0);d=v[23516];v[23516]=0;if((d|0)==1){break p}}h=Lb(i+48|0);s:{if((c&12)!=12){break s}l=a+906300|0;m=a+1298464|0;d=0;t:{u:{v:{w:{x:{y:{while(1){if((d|0)==250){break s}z:{e=Id(l,d);k=e+16|0;A:{if(!zi(v[k>>2],v[e+20>>2])){break A}v[23516]=0;R(848,e|0,a|0);c=v[23516];v[23516]=0;B:{if((c|0)!=1){c=v[e>>2];if(!c){break B}e=v[e+148>>2];f=v[v[c>>2]+56>>2];v[23516]=0;R(f|0,c|0,e|0);c=v[23516];v[23516]=0;if((c|0)!=1){break A}}a=P()|0;O()|0;break q}f=Cb(v[h>>2]);n=Cb(v[h+4>>2]);g=hb-16|0;hb=g;v[g+8>>2]=f;while(1){C:{if(!Nb(f,n)){break C}c=v[f>>2];if((w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))==(w[e+20|0]|w[e+21|0]<<8|(w[e+22|0]<<16|w[e+23|0]<<24))){c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))}else{c=0}if(c){break C}f=v[Ie(g+8|0)>>2];continue}break}hb=g+16|0;if(Nb(f,Cb(v[h+4>>2]))){break A}v[23516]=0;v[i+32>>2]=k;R(849,h|0,i+32|0);c=v[23516];v[23516]=0;if((c|0)==1){break z}v[23516]=0;c=Q(1,i+16|0,17798)|0;f=v[23516];v[23516]=0;if((f|0)==1){break y}v[23516]=0;R(850,i|0,e|0);e=v[23516];v[23516]=0;if((e|0)==1){break x}v[23516]=0;U(2,i+32|0,c|0,i|0);e=v[23516];v[23516]=0;if((e|0)==1){break w}e=v[m>>2];v[23516]=0;U(384,e|0,2,i+32|0);e=v[23516];v[23516]=0;if((e|0)==1){break v}xb(i+32|0);xb(i);xb(c)}d=d+1|0;continue}break}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;break u}a=P()|0;O()|0;xb(i+32|0)}xb(i)}xb(c);break q}c=w[a+1074368|0];v[23516]=0;R(851,a|0,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break r}lc(h)}d=(j|0)!=0;break a}a=P()|0;O()|0}lc(h);break b}v[23516]=0;Y(852,d|0);f=v[23516];v[23516]=0;if((f|0)!=1){if(Oc(v[d>>2],v[d+4>>2])>>>0<=x[d+28>>1]){Te(d,0)}pz(i+48|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}f=B(e,104)+a|0;e=f+484380|0;D:{if(Vd(v[e>>2],v[f+484400>>2])){rj(e,a);break D}h=f+484414|0;g=x[h>>1];if(g&16384){break D}v[e>>2]=0;v[e+4>>2]=0;v[e+16>>2]=0;v[e+8>>2]=0;v[e+12>>2]=0;u[h>>1]=g&65505}e=f+484412|0;if(x[e>>1]>=65){u[e>>1]=64}E:{F:{if(!(w[f+484415|0]&2)){break F}if(!gk(v[a+1298300>>2])){break F}v[23516]=0;Y(853,a|0);e=v[23516];v[23516]=0;if((e|0)==1){break E}}d=d+1|0;continue}break}a=P()|0;O()|0;break b}e=(d<<5)+a|0;Bf(e+480286|0,64);f=e+480284|0;if(x[f>>1]>=257){u[f>>1]=128}e=e+480288|0;if(w[e|0]>=251){t[e|0]=0}Vn((B(d,872)+a|0)+1074992|0,a,d&65535,134217728);d=d+1|0;continue}}break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;pM(h)}yb(b);S(a|0);L()}yb(b);hb=i- -64|0;return d|0}function c1(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0;n=hb-560|0;hb=n;v[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){x=1;A=5299;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){x=1;A=5302;break a}x=e&1;A=x?5305:5300;F=!x}b:{if((g&2146435072)==2146435072){d=x+3|0;Df(a,32,c,d,e&-65537);of(a,A,x);f=f&32;of(a,b!=b?f?9997:13875:f?11106:14241,3);Df(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c;break b}z=n+16|0;c:{d:{e:{b=zH(b,n+44|0);b=b+b;if(b!=0){g=v[n+44>>2];v[n+44>>2]=g-1;u=f|32;if((u|0)!=97){break e}break c}u=f|32;if((u|0)==97){break c}l=v[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;v[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}r=(n+48|0)+((l|0)<0?0:288)|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}v[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=r;break f}k=r;d=l;while(1){d=(d|0)<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){q=v[g>>2];p=d&31;C=i;if((d&63)>>>0>=32){i=q<<p;q=0}else{i=(1<<p)-1&q>>>32-p;q=q<<p}p=C+q|0;i=i+E|0;i=p>>>0<q>>>0?i+1|0:i;i=uka(p,i,1e9,0);q=rka(i,kb,-1e9,0)+p|0;v[g>>2]=q;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[n+44>>2]-d|0;v[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){y=((m+25>>>0)/9|0)+1|0;p=(u|0)==102;while(1){d=0-d|0;i=(d|0)<9?d:9;h:{if(g>>>0<=k>>>0){h=v[k>>2];break h}q=1e9>>>i|0;E=-1<<i^-1;d=0;h=k;while(1){C=d;d=v[h>>2];v[h>>2]=C+(d>>>i|0);d=B(q,d&E);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0}d=i+v[n+44>>2]|0;v[n+44>>2]=d;k=(!h<<2)+k|0;h=p?r:k;g=g-h>>2>(y|0)?h+(y<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=(m-((u|0)==102?0:d)|0)-((u|0)==103&(m|0)!=0)|0;if((h|0)<(B(g-r>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(p<<2)|0)-4048|0;h=10;i=i+B(p,-9)|0;if((i|0)<=7){while(1){h=B(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=v[l>>2];y=(p>>>0)/(h>>>0)|0;i=B(y,h);q=l+4|0;j:{if((i|0)==(p|0)&(q|0)==(g|0)){break j}p=p-i|0;k:{if(!(y&1)){b=9007199254740992;if(!(t[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}s=(g|0)==(q|0)?1:1.5;q=h>>>1|0;s=p>>>0<q>>>0?.5:(q|0)==(p|0)?s:1.5;if(!(w[A|0]!=45|F)){s=-s;b=-b}v[l>>2]=i;if(b+s==b){break j}d=h+i|0;v[l>>2]=d;if(d>>>0>=1e9){while(1){v[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[l>>2]+1|0;v[l>>2]=d;if(d>>>0>999999999){continue}break}}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!v[g>>2]){continue}}break}l:{if((u|0)!=103){l=e&8;break l}g=m?m:1;l=(g|0)>(d|0)&(d|0)>-5;m=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=v[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=B(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=B(h-r>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}i=-1;u=l|m;if(((u?2147483645:2147483646)|0)<(m|0)){break b}p=(((u|0)!=0)+m|0)+1|0;q=f&-33;n:{if((q|0)==70){if((2147483647-p|0)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=tn((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((z-g|0)<2){continue}break}}y=g-2|0;t[y|0]=f;t[g-1|0]=(d|0)<0?45:43;g=z-y|0;if((g|0)>(2147483647-p|0)){break b}}d=g+p|0;if((d|0)>(x^2147483647)){break b}f=d+x|0;Df(a,32,c,f,e);of(a,A,x);Df(a,48,c,f,e^65536);o:{p:{q:{if((q|0)==70){g=n+16|0;d=g|8;l=g|9;i=k>>>0>r>>>0?r:k;k=i;while(1){g=tn(v[k>>2],0,l);r:{if((i|0)!=(k|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}t[n+24|0]=48;g=d}of(a,g,l-g|0);k=k+4|0;if(r>>>0>=k>>>0){continue}break}if(u){of(a,16868,1)}if((m|0)<=0|h>>>0<=k>>>0){break q}while(1){g=tn(v[k>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}of(a,g,(m|0)<9?m:9);g=m-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;g=n+16|0;d=g|8;r=g|9;h=k;while(1){g=tn(v[h>>2],0,r);if((r|0)==(g|0)){t[n+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}of(a,g,1);g=g+1|0;if(!(l|m)){break t}of(a,16868,1)}C=g;g=r-g|0;of(a,C,(g|0)>(m|0)?m:g);m=m-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}Df(a,48,m+18|0,18,0);of(a,y,z-y|0);break o}g=m}Df(a,48,g+9|0,9,0)}Df(a,32,c,f,e^8192);i=(c|0)<(f|0)?f:c;break b}m=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;s=16;while(1){s=s*16;g=g-1|0;if(g){continue}break}if(w[m|0]==45){b=-(s+(-b-s));break u}b=b+s-s}l=x|2;k=f&32;h=v[n+44>>2];g=h>>31;g=tn((g^h)-g|0,0,z);if((z|0)==(g|0)){t[n+15|0]=48;g=n+15|0}r=g-2|0;t[r|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=n+16|0;while(1){f=h;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=k|w[g+77344|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-r|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(n+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(n+16|0)|0;g=k}d=g+f|0;Df(a,32,c,d,e);of(a,m,l);Df(a,48,c,d,e^65536);of(a,n+16|0,k);Df(a,48,g-k|0,0,0);of(a,r,p);Df(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c}hb=n+560|0;return i|0}function ffa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-272|0;hb=e;xc(b);d=hb-16|0;hb=d;f=e+120|0;XQ(d+8|0,f);g=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],g);h=v[d+4>>2];if((h|0)==(g|0)){Yb(b,v[d+12>>2])}hb=d+16|0;d=(g|0)==(h|0);if(!d){WQ(f)}a:{b:{if(!d){break b}if(!YQ(e+120|0)){break b}if(!c){i=1;break b}zd(a,4194304);d=e+32|0;g=vc(d,17135);Gb(a+1298344|0,g);xb(g);g=vc(d,10156);Gb(a+1298356|0,g);xb(g);v[a+1298404>>2]=5;n=a,o=Bd(x[e+198>>1],x[e+200>>1],127),u[n+480188>>1]=o;g=w[e+189|0];v[a+480228>>2]=(g|0)==255?48:g;v[a+480196>>2]=w[e+187|0];v[a+480204>>2]=B(w[e+188|0],1e4);g=e+96|0;lf(g,e+120|4,59,3);Cc(d,g);yc(a+1298308|0,d);wb(d);d=x[e+202>>1]|x[e+204>>1]<<16;c:{if(d>>>0<5){break c}if(!Zc(b,d-4|0)){break c}if(!Fh(b,14341)){break c}ko(Sb(v[a+484360>>2],w[a+484376|0]),b,x[e+192>>1],65535,65535)}d:{d=x[e+206>>1]|x[e+208>>1]<<16;if(d>>>0<5){break d}if(!Zc(b,d-4|0)){break d}if(!Fh(b,13870)){break d}d=0;while(1){if((d|0)==32){break d}g=(d<<5)+a|0;af(g+480280|0);n=g+480284|0,o=((((Je(b)^-1)&15)<<8|8)>>>0)/15|0,u[n>>1]=o;d=d+1|0;continue}}d=x[e+214>>1]|x[e+216>>1]<<16;e:{if(d>>>0<5){break e}if(!Zc(b,d-4|0)){break e}if(!Fh(b,14198)){break e}d=e+32|0;Wd(d,b,x[e+196>>1]<<6);k=c&2;h=a+480190|0;g=hc(e+96|0,d);yb(d);j=e+45|0;d=0;f:{while(1){if(x[e+196>>1]<=(d&65535)>>>0){break f}v[23516]=0;f=Q(675,g|0,e+32|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break a}if(!f){break f}f=w[e+77|0]|w[e+78|0]<<8;u[e+30>>1]=f;g:{h:{if((f-1&65535)>>>0>3998){break h}f=B(f,104)+a|0;i=f+484380|0;if(Vd(v[i>>2],v[f+484400>>2])){break h}n=h,o=x[ie(h,e+30|0)>>1],u[n>>1]=o;v[23516]=0;R(676,e+32|0,i|0);f=v[23516];v[23516]=0;if((f|0)==1){break g}LT(e,1,j);v[23516]=0;R(221,e+16|0,e|0);f=v[23516];v[23516]=0;if((f|0)==1){break a}f=e+16|0;Ac(((x[e+30>>1]<<5)+a|0)+946304|0,f);wb(f);if(!k){break h}v[23516]=0;Q(153,b|0,w[e+69|0]|w[e+70|0]<<8|(w[e+71|0]<<16|w[e+72|0]<<24))|0;f=v[23516];v[23516]=0;if((f|0)==1){break g}i=1;l=e+16|0;f=w[e+79|0];m=Uc(l,f&4?16:8,1,0,0);i:{j:{if(f&8){break j}i=2;if(f&16){break j}if(f&127){break i}}cg(m,i)}v[23516]=0;W(218,l|0,(B(x[e+30>>1],104)+a|0)+484380|0,b|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){break h}break a}d=d+1|0;continue}break}break a}yb(g)}i=1;if(!(c&1)){break b}k:{c=x[e+210>>1]|x[e+212>>1]<<16;if(c>>>0<5){break k}if(!Zc(b,c-4|0)){break k}if(!Fh(b,13720)){break k}k=a+484344|0;vg(k,x[e+194>>1]);f=0;while(1){if(x[e+194>>1]<=f>>>0){break k}if(!oA(b,e+16|0)){break k}l:{d=x[e+16>>1];if(d>>>0>3){c=e+96|0;Wd(c,b,(d+15&131056)-4|0);g=hc(e+32|0,c);yb(c);v[23516]=0;c=W(225,k|0,f&65535,w[e+18|0])|0;d=v[23516];v[23516]=0;if((d|0)==1){break l}h=0;m:{if(!c){break m}while(1){n:{c=v[g>>2];v[23516]=0;d=W(154,c|0,v[e+40>>2],1)|0;c=v[23516];v[23516]=0;o:{if((c|0)!=1){c=w[e+18|0];if(!(d&c>>>0>(h&255)>>>0)){break n}v[23516]=0;d=T(204,g|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}if(d){break o}h=h+1|0;continue}break a}c=v[a+484344>>2];u[e+96>>1]=d&31;u[e>>1]=x[a+480188>>1]-1;c=Xb(c,f);c=ed(v[c>>2],v[v[c+48>>2]+12>>2],h,x[Rc(e+96|0,e)>>1]);if(d&128){v[23516]=0;R(263,e+96|0,g|0);j=v[23516];v[23516]=0;if((j|0)==1){break a}t[c|0]=w[e+96|0]+36;n=c,o=w[Kc(e+96|0)|0],t[n+1|0]=o}if(d&64){t[c+2|0]=1;v[23516]=0;j=T(204,g|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break a}t[e+96|0]=j;t[e|0]=64;n=c,o=w[Vb(e+96|0,e)|0],t[n+4|0]=o}if(!(d&32)){continue}v[23516]=0;R(263,e+96|0,g|0);d=v[23516];v[23516]=0;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{if((d|0)!=1){d=w[Kc(e+96|0)|0];t[c+5|0]=d;switch(w[e+96|0]-1|0){case 71:break q;case 70:break r;case 69:break s;case 60:break t;case 59:break u;case 52:break v;case 51:break w;case 50:break x;case 49:break y;case 42:break z;case 41:break A;case 40:break B;case 39:break C;case 30:break D;case 29:break E;case 22:break F;case 21:break G;case 20:break H;case 19:break I;case 16:break J;case 15:break K;case 14:break L;case 13:break M;case 12:break N;case 11:break O;case 10:break P;case 9:break Q;case 3:break R;case 2:break S;case 1:break T;case 0:break U;default:break p}}break a}t[c+3|0]=11;t[c+5|0]=d<<4|15;continue}t[c+3|0]=11;t[c+5|0]=d<<4;continue}t[c+3|0]=11;t[c+5|0]=d|240;continue}t[c+3|0]=11;t[c+5|0]=d&15;continue}t[c+3|0]=2;t[c+5|0]=d|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=d|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=d|16;continue}t[c+3|0]=6;t[c+5|0]=d<<4;continue}t[c+3|0]=6;t[c+5|0]=d&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=d|48;continue}t[c+3|0]=7;t[c+5|0]=d<<4;continue}t[c+3|0]=7;t[c+5|0]=d&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=d|64;continue}t[c+3|0]=10;v[23516]=0;d=T(204,g|0)|0;j=v[23516];v[23516]=0;if((j|0)!=1){t[c+5|0]=d;v[23516]=0;Q(186,g|0,1)|0;c=v[23516];v[23516]=0;if((c|0)!=1){continue}}break a}t[c+3|0]=15;t[c+5|0]=d&15;continue}t[c+3|0]=20;t[c+5|0]=d|192;continue}t[c+3|0]=20;t[c+5|0]=d|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=d|176;continue}t[c+3|0]=20;t[c+5|0]=d|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=d&15|32;continue}t[c+3|0]=20;t[c+5|0]=d&15|128;continue}t[c+3|0]=0;continue}break}if((c|0)==64){break m}ve(Xb(v[k>>2],f),Eh(Se(Le(e+96|0,14,0),c-1|0)))}yb(g)}f=f+1|0;continue}break}break a}c=x[e+218>>1]|x[e+220>>1]<<16;if(!c){break b}Zc(b,c);lB(a+1298332|0,b,Ng(b),4)}hb=e+272|0;return i|0}a=P()|0;O()|0;yb(g);S(a|0);L()}function Wia(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;k=hb-128|0;hb=k;t[k+127|0]=d;a:{if(!c|(e|0)<0&c>>>0>=176){break a}t[b+5|0]=d;t[k+8|0]=15;l=k+127|0;p=k+8|0;j=p;o=w[Vb(l,j)|0];t[k+8|0]=14;l=w[Vb(l,j)|0];v[k+8>>2]=d+31>>>5;v[k+120>>2]=14;r=k+120|0;n=v[od(j,r)>>2];v[k+8>>2]=d+127>>>7;v[k+120>>2]=14;q=c&15;j=q<<8|d;p=od(p,r);b:{switch((c>>>4|0)-2|0){case 0:t[b+2|0]=1;t[b+4|0]=j>>>2;break a;case 1:t[b+2|0]=1;if(!j){t[b+4|0]=0;break a}s=b,y=rg(WA(j)>>>2|0),t[s+4|0]=y;break a;case 2:t[b+3|0]=9;t[b+5|0]=j>>>4;break a;case 3:t[b+3|0]=23;t[b+5|0]=j+1>>>5;break a;case 4:t[b+3|0]=23;if(j){a=rg(WA(j)>>>5|0)}else{a=0}t[b+5|0]=a;break a;case 5:t[b+5|0]=q;t[b+3|0]=15;break a;case 6:t[b+3|0]=15;if((e|0)>=0){if(w[b+2|0]){break a}t[b+2|0]=2;s=b,y=Dc(((q<<6|7)>>>0)/15|0,0),t[s+4|0]=y;break a}t[b+2|0]=1;t[b+5|0]=q;t[b+4|0]=d+3>>>2;break a;case 7:t[b+3|0]=10;c:{if((e|0)>5){break c}if(!j){t[b+5|0]=1;break a}c=nq(a,f,g);if(!c){break c}a=Fi(a,c);c=x[a+34>>1];if(c&1){j=j>>>1|0;v[k+120>>2]=j}if(!(c&2)){break c}c=v[a>>2];if(c>>>0>=j<<8>>>0){break c}v[k+120>>2]=v[a+4>>2]+8>>>8;uc(k+120|0,c-1>>>8|0);j=v[k+120>>2]}t[b+5|0]=j;if(w[b+2|0]|j>>>0<256){break a}t[b+2|0]=15;v[k+116>>2]=j>>>8;VA(k+8|0);v[k+112>>2]=9;s=b,y=v[Hb(k+116|0,k+112|0)>>2],t[s+4|0]=y;break a;default:break b}}j=v[p>>2];d:{switch(c-160|0){default:e:{switch(c-1|0){case 0:case 1:case 2:case 3:case 6:case 10:case 14:Nf(b,c,d);f:{switch(w[b+3|0]-16|0){case 1:v[h>>2]=B(w[b+5|0],1e4);break a;case 0:break f;default:break a}}a=w[b+5|0];if(!a){break a}v[i>>2]=a;break a;case 4:t[b+3|0]=4;if(w[b+2|0]){break a}t[b+4|0]=0;t[b+2|0]=8;break a;case 5:t[b+3|0]=5;if(w[b+2|0]){break a}t[b+4|0]=0;t[b+2|0]=11;break a;case 7:if(!Wc(w[b|0])|!d){break a}t[b+3|0]=35;t[b+5|0]=(d>>>1&120|128)-(d<<3&120);e=a+480192|0;if(x[e>>1]){break a}u[k+8>>1]=255;c=x[Rc(a+480190|0,k+8|0)>>1];u[e>>1]=c;b=1;while(1){d=b&65535;if(d>>>0>(c&65535)>>>0){break a}c=Cu(a,d,d);if(c){t[c+33|0]=2;d=(d<<5)+a|0;f=d+946304|0;g=v[f+4>>2];v[c+492>>2]=v[f>>2];v[c+496>>2]=g;f=d+946312|0;g=v[f+4>>2];v[c+500>>2]=v[f>>2];v[c+504>>2]=g;f=d+946320|0;g=v[f+4>>2];v[c+508>>2]=v[f>>2];v[c+512>>2]=g;d=d+946328|0;f=v[d+4>>2];v[c+516>>2]=v[d>>2];v[c+520>>2]=f;Ij(c,127,1);Hj(c,0,1)}b=b+1|0;c=x[e>>1];continue};case 8:t[b+3|0]=19;t[b+5|0]=o|208;break a;case 9:t[b+3|0]=25;break a;case 11:if(d>>>0>2){break a}t[b+3|0]=19;t[b+5|0]=d|64;break a;case 12:t[b+3|0]=14;break a;case 13:if(d>>>0>2){break a}t[b+3|0]=19;t[b+5|0]=d|112;break a;case 15:t[b+3|0]=1;break a;case 16:case 17:t[b+3|0]=19;t[b+5|0]=l|c<<4;break a;case 18:t[b+3|0]=15;break a;case 19:t[b+3|0]=11;t[b+5|0]=l<<4;break a;case 20:t[b+5|0]=l;t[b+3|0]=11;break a;case 23:t[b+3|0]=6;t[b+5|0]=l<<4;break a;case 24:t[b+5|0]=l;t[b+3|0]=6;break a;case 27:t[b+3|0]=7;t[b+5|0]=l<<4;break a;case 28:break e;default:break a}}t[b+5|0]=l;t[b+3|0]=7;break a;case 0:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n<<4;break a;case 1:if(!d){break a}t[b+5|0]=n;t[b+3|0]=24;break a;case 4:t[b+3|0]=11;t[b+5|0]=l<<4|15;break a;case 5:t[b+3|0]=11;t[b+5|0]=l|240;break a;case 6:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n<<4|15;break a;case 7:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n|240;break a;case 8:if(!d){break a}t[b+3|0]=16;v[i>>2]=d;break a;case 9:if((e|0)>5){break a}a=v[h>>2];if(a>>>0<1e4){break a}t[b+3|0]=17;m=122925/(+(a>>>0)/1e4)+ +((d<<1)-256|0);s=b,y=nk(245850/(m+m)),t[s+5|0]=y;break a;case 10:t[b+3|0]=19;t[b+5|0]=o|224;break a;case 12:t[b+3|0]=28;t[b+5|0]=o|16;break a;case 13:t[b+3|0]=28;t[b+5|0]=o|32;break a;case 14:t[b+3|0]=29;t[b+5|0]=l<<3&240;break a;case 15:t[b+3|0]=29;t[b+5|0]=(l&254)>>>1;break a;case 16:t[b+3|0]=18;break a;case 17:t[b+3|0]=19;t[b+5|0]=o|176;break a;case 18:case 19:t[b+3|0]=20;t[b+5|0]=d?120:119;break a;case 20:t[b+3|0]=20;t[b+5|0]=d?125:123;break a;case 21:t[b+3|0]=20;t[b+5|0]=d?122:121;break a;case 22:t[b+3|0]=20;t[b+5|0]=d?126:123;break a;case 26:t[b+3|0]=10;t[b+5|0]=d+15>>>4;break a;case 27:t[b+5|0]=1;t[b+3|0]=10;break a;case 30:case 31:if(!d|(!g|!f)){break a}o=v[h>>2];if(o>>>0<1e4){break a}l=v[i>>2];if(!l){break a}i=nq(a,f,g);if(!i){break a}j=Fi(a,i);n=x[j+34>>1];g:{if(!(n&2)){i=v[j>>2];break g}i=v[j+8>>2]-((e|0)<6?v[j+4>>2]:0)|0;if(!(n&4)){break g}i=i<<((e|0)>5)}if(!i|(e|0)<6&i>>>0<1024){break a}n=v[j+24>>2];if(!n){break a}h:{if(x[a+480192>>1]<g>>>0){break h}a=v[((g<<2)+a|0)+900380>>2];if(!a){break h}m=+(w[Ib(a+108|0,f-1|0)|0]-f|0)}a=(c|0)==190;m=ni(m/12+(a?(e|0)<6?+t[j+37|0]/-1536:-0:-0))*+(n>>>0);if(a){t[b+3|0]=17;a=nk(m*.5*(+(B(d,l)>>>0)*2.5)/+(i>>>0));t[b+5|0]=a;v[h>>2]=B(a,1e4);break a}m=du(tK(+(i>>>0)/m/(+(B(d,l)>>>0)*2.5/(+(o>>>0)/1e4)))*12+61,1,120);i:{if(m<4294967296&m>=0){a=~~m>>>0;break i}a=0}c=Wc(w[b|0]);t[b|0]=a;m=(m-H(m))*64+128;j:{if(m<4294967296&m>=0){a=~~m>>>0;break j}a=0}t[b+5|0]=a;if((a|0)!=128){t[b+3|0]=35}if(c){break a}if(!w[b+2|0]){t[b+4|0]=9;t[b+2|0]=11;break a}t[b+5|0]=255;t[b+3|0]=4;break a;case 32:a=d>>>4|0;if(a-1>>>0>1){break a}t[b+3|0]=20;t[b+5|0]=a-99;break a;case 34:t[b+3|0]=21;t[b+5|0]=d<<2;break a;case 35:t[b+3|0]=21;s=b,y=rg(WA(d<<4)>>>6|0),t[s+5|0]=y;break a;case 36:case 38:t[b+3|0]=22;t[b+5|0]=j<<4;break a;case 37:case 39:t[b+5|0]=j;t[b+3|0]=22;break a;case 40:t[b+3|0]=22;t[b+5|0]=l<<4|15;break a;case 2:case 3:case 11:case 23:case 24:case 25:case 28:case 29:case 33:break a;case 41:break d}}t[b+3|0]=22;t[b+5|0]=l|240}hb=k+128|0}function oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=hb-208|0;hb=d;xc(c);a:{if(!mo(c,d+192|0)){break a}if(Qb(d+192|0,13901,4)){break a}f=d+200|0;if(Qb(f,14274,4)){if(Qb(f,14378,4)){break a}}e=hb-32|0;hb=e;i=d+176|0;g=Lb(i);b:{c:{d:{e:{f:{while(1){h=v[c+8>>2];j=v[c>>2];v[23516]=0;h=W(154,j|0,h|0,8)|0;j=v[23516];v[23516]=0;if((j|0)==1){break d}if(!h){break e}v[23516]=0;R(807,e|0,c|0);h=v[23516];v[23516]=0;if((h|0)!=1){v[23516]=0;R(808,g|0,e|0);h=v[23516];v[23516]=0;if((h|0)==1){break f}yd(e);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;yd(e);break c}hb=e+32|0;break b}a=P()|0;O()|0}Ud(g);S(a|0);L()}v[23516]=0;U(733,d+152|0,i|0,1129270605);c=v[23516];v[23516]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){v[23516]=0;c=Q(734,d+152|0,d+128|0)|0;e=v[23516];v[23516]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!_b(x[d+130>>1]|x[d+132>>1]<<16)){break g}if((Eb(x[d+128>>1])-3&65535)>>>0<65534){break g}if((Eb(x[d+134>>1])-65&65535)>>>0<65472){break g}v[d+124>>2]=1162760014;c=1;if(!Qb(f,14378,4)){v[23516]=0;c=Q(618,d+152|0,d+124|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break o}if(!c){break g}c=v[d+124>>2]!=1936684916}v[23516]=0;U(733,d+104|0,d+176|0,1397968452);e=v[23516];v[23516]=0;p:{q:{if((e|0)!=1){v[23516]=0;k=Q(735,d+104|0,d+96|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break p}if(k){break q}break h}c=P()|0;O()|0;break j}f=((Eb(x[d+134>>1])-1|0)/8|0)-1|0;g=f<<3;e=g&31;g=Uc(d+88|0,(f>>>0<7?(g&63)>>>0>=32?4196360>>>e|0:((1<<e)-1&4196360)<<32-e|136321040>>>e:8)&255,(Eb(x[d+128>>1])|0)==2?2:1,c,0);c=v[d+124>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}cg(g,3);break r}cg(g,17);nd(g,16);break r}cg(g,16);nd(g,16);break r}cg(g,1)}c=v[d+96>>2];v[23516]=0;c=W(154,v[d+104>>2],v[d+112>>2],_b(c)|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break l}if(c){c=v[d+96>>2];v[23516]=0;Q(186,d+104|0,_b(c)|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break l}}bt(a,b);v[23516]=0;c=B(b,104)+a|0;i=c+484380|0;R(280,i|0,0);e=v[23516];v[23516]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}r=i,s=_b(x[d+130>>1]|x[d+132>>1]<<16),v[r>>2]=s;j=c+484404|0;c=w[d+138|0]|w[d+139|0]<<8|(w[d+140|0]<<16|w[d+141|0]<<24);f=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);h=30-w[d+137|0]|0;e=0;while(1){c=f;if(h&255){f=c>>>1|0;h=h-1|0;e=c;continue}break}v[j>>2]=c+(e&1);v[23516]=0;W(218,g|0,i|0,d+104|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break D}v[23516]=0;U(733,d- -64|0,d+176|0,1296126539);c=v[23516];v[23516]=0;if((c|0)==1){break C}v[23516]=0;c=T(176,v[d+64>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break B}if(!c){break u}v[23516]=0;U(733,d+16|0,d+176|0,1229869908);c=v[23516];v[23516]=0;if((c|0)==1){break A}v[23516]=0;c=Q(736,d+16|0,d+40|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break z}yb(d+16|0);if(!c){break u}v[23516]=0;f=T(274,d- -64|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break y}e=Lb(d+16|0);v[23516]=0;R(737,e|0,f|0);c=v[23516];v[23516]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}v[23516]=0;g=Q(738,d- -64|0,d|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break w}if(!g){break x}v[23516]=0;R(739,e|0,d|0);g=v[23516];v[23516]=0;if((g|0)==1){break w}v[23516]=0;g=w[d+6|0];Q(186,d- -64|0,((g^-1)&1)+g|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break m}c=P()|0;O()|0;break m}c=P()|0;O()|0;yb(d+16|0);break m}c=P()|0;O()|0;break m}c=Eb(x[d+48>>1]);if(c){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]&65511|((c|0)==2)<<4|8}c=Eb(x[d+54>>1]);if(c){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]&65529|((c|0)==2?4:2)|2}r=d,s=Cb(v[e>>2]),v[r>>2]=s;c=B(b,104)+a|0;g=c+484388|0;h=c+484384|0;j=c+484396|0;l=c+484392|0;m=Cb(v[e+4>>2]);n=x[d+50>>1];o=x[d+52>>1];p=x[d+56>>1];q=x[d+58>>1];while(1){c=v[d>>2];if(!Nb(c,m)){break v}f=Eb(w[c|0]|w[c+1|0]<<8);if((f|0)==(Eb(n)|0)){r=l,s=_b(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Eb(w[c|0]|w[c+1|0]<<8)}if((Eb(o)|0)==(f|0)){r=j,s=_b(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Eb(w[c|0]|w[c+1|0]<<8)}if((Eb(p)|0)==(f|0)){r=h,s=_b(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Eb(w[c|0]|w[c+1|0]<<8)}if((f|0)==(Eb(q)|0)){r=g,s=_b(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s}v[d>>2]=v[d>>2]+7;continue}}c=P()|0;O()|0;UN(e);break m}wk(i);UN(e)}v[23516]=0;U(733,d+16|0,d+176|0,1312902469);c=v[23516];v[23516]=0;if((c|0)==1){break n}v[23516]=0;c=T(176,v[d+16>>2])|0;e=v[23516];v[23516]=0;E:{if((e|0)==1){break E}F:{if(c){v[23516]=0;c=T(158,v[d+16>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break E}v[23516]=0;U(317,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break F}break E}v[23516]=0;c=Q(53,d|0,21751)|0;e=v[23516];v[23516]=0;if((e|0)==1){break E}Ac(((b<<5)+a|0)+946304|0,c);wb(c)}tz(i,v[a+480180>>2]);rj(i,a);yb(d+16|0);yb(d- -64|0);break h}c=P()|0;O()|0;yb(d+16|0);break m}c=P()|0;O()|0;break k}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break m}c=P()|0;O()|0;break i}yb(d- -64|0);break k}c=P()|0;O()|0}yb(d+104|0)}yb(d+152|0)}Ud(d+176|0);S(c|0);L()}yb(d+104|0)}yb(d+152|0);Ud(d+176|0)}hb=d+208|0;return k|0}function Rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=hb-224|0;hb=e;xc(b);a:{if(!It(b,e+160|0)){break a}if(!zQ(e+160|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(yQ(e+160|0),kb))){break a}if(!c){d=1;break a}zd(a,256);f=e+144|0;Aj(f,2,e+160|0);d=e+48|0;Cc(d,f);yc(a+1298308|0,d);wb(d);f=x[e+210>>1];v[a+480260>>2]=64;v[a+480264>>2]=32767;u[a+480188>>1]=4;u[a+480190>>1]=f;Mb(a+1074312|0,107,1);f=w[e+203|0];f=f?f:96;k=Nz(f);v[a+480196>>2]=f>>>4;v[a+480204>>2]=k;t[e+48|0]=64;A=a,C=w[Vb(e+202|0,d)|0]<<2,v[A+480200>>2]=C;d=0;b:{c:{d:{e:{f:{g:{while(1){if((d|0)==4){h:{k=Lb(e+144|0);m=Lb(e+128|0);v[23516]=0;Q(153,b|0,x[e+192>>1]<<4)|0;d=v[23516];v[23516]=0;i:{if((d|0)==1){break i}v[23516]=0;W(216,b|0,k|0,x[e+208>>1])|0;d=v[23516];v[23516]=0;if((d|0)==1){break i}v[23516]=0;Q(153,b|0,x[e+194>>1]<<4)|0;d=v[23516];v[23516]=0;if((d|0)==1){break i}v[23516]=0;W(216,b|0,m|0,x[e+210>>1])|0;d=v[23516];v[23516]=0;if((d|0)==1){break i}v[23516]=0;Q(153,b|0,(x[e+196>>1]<<4)+32|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break i}d=a+484376|0;f=w[d|0];i=v[a+484360>>2];v[23516]=0;R(329,Sb(i,f)|0,x[e+212>>1]);f=v[23516];v[23516]=0;if((f|0)==1){break i}d=Sb(v[a+484360>>2],w[d|0]);A=e,C=Cb(v[d>>2]),v[A+48>>2]=C;d=Cb(v[d+4>>2]);j:{while(1){f=v[e+48>>2];if(!Nb(f,d)){d=0;if(!BQ(Sb(v[a+484360>>2],w[a+484376|0]))){break b}i=c&2;j=e+48|1;d=1;break j}v[23516]=0;i=T(204,b|0)|0;j=v[23516];v[23516]=0;k:{if((j|0)==1){break k}u[f>>1]=i;v[23516]=0;Q(186,b|0,4)|0;f=v[23516];v[23516]=0;if((f|0)==1){break k}Qe(e+48|0);continue}break}d=P()|0;O()|0;break c}l:{m:{n:{o:{while(1){f=d&65535;if(f>>>0>x[e+210>>1]){break l}g=$b(v[m>>2],f-1|0);g=w[g|0]|w[g+1|0]<<8;v[23516]=0;g=Q(153,b|0,g<<4)|0;h=v[23516];v[23516]=0;p:{if((h|0)!=1){if(g){break p}d=0;break b}d=P()|0;O()|0;break c}v[23516]=0;Q(684,b|0,e+48|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break o}v[23516]=0;g=(B(f,104)+a|0)+484380|0;U(685,e+48|0,g|0,0);h=v[23516];v[23516]=0;if((h|0)==1){break o}h=e+16|0;ok(h,2,j);v[23516]=0;R(221,e+32|0,h|0);h=v[23516];v[23516]=0;if((h|0)==1){break n}h=((f<<5)+a|0)+946304|0;f=e+32|0;Ac(h,f);wb(f);q:{r:{if(!i|!v[e+64>>2]){break r}f=OQ(e+48|0);v[23516]=0;f=Q(153,b|0,f|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break m}if(!f){break r}f=e+32|0;NQ(f,w[e+78|0],w[e+79|0],1);v[23516]=0;W(218,f|0,g|0,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break q}}d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}t[e+15|0]=1;d=v[k>>2];s:{if(nc(d,v[k+4>>2])|x[e+188>>1]==26){break s}f=w[d|0]|w[d+1|0]<<8;d=0;v[23516]=0;f=Q(153,b|0,f<<4)|0;i=v[23516];v[23516]=0;if((i|0)==1){break h}if(!f){break b}v[23516]=0;d=T(192,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break h}if((d|0)!=x[e+188>>1]){break s}t[e+15|0]=0}n=c&1;if(n){v[23516]=0;R(224,a+484344|0,x[e+208>>1]);c=v[23516];v[23516]=0;if((c|0)==1){break h}}h=a+484344|0;c=e+48|0;p=c|5;q=c|4;r=c|2;s=c|1;y=a+480188|0;f=0;while(1){t:{if(!n|x[e+208>>1]<=f>>>0){break t}v[23516]=0;c=W(225,h|0,f&65535,64)|0;d=v[23516];v[23516]=0;if((d|0)==1){break g}if(!c){break t}c=$b(v[k>>2],f);c=w[c|0]|w[c+1|0]<<8;v[23516]=0;c=Q(153,b|0,c<<4)|0;d=v[23516];v[23516]=0;if((d|0)==1){break g}d=0;if(!c){break b}if(!w[e+15|0]){v[23516]=0;c=T(192,b|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break g}if(c>>>0>2112){break b}}u[e+16>>1]=65535;v[e+32>>2]=63;u:while(1){c=Xb(v[h>>2],f);z=xf(v[c>>2],v[v[c+48>>2]+12>>2],d);v:while(1){c=d;while(1){if(c>>>0<=63){v[23516]=0;i=T(204,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break f}if(!i){d=64;if(c>>>0>62){continue v}d=c+1|0;continue u}d=i&31;j=B(d,6)+z|0;l=sg(e+48|0);g=d>>>0<x[y>>1];o=g?j:l;if(i&32){v[23516]=0;R(263,e|0,b|0);d=v[23516];v[23516]=0;w:{x:{y:{if((d|0)!=1){l=Kc(e);d=w[e|0];if(d>>>0>239){break y}d=MQ((B(d>>>4|0,12)+(d&15)|0)+37|0);break x}d=P()|0;O()|0;break c}z:{switch(d-254|0){case 0:break x;case 1:break z;default:break w}}d=0}t[o|0]=d}t[(g?j+1|0:s)|0]=w[l|0]}if(i&64){v[23516]=0;d=T(204,b|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break e}t[e|0]=d;t[(g?j+2|0:r)|0]=1;t[e+14|0]=64;A=g?j+4|0:q,C=w[Vb(e,e+14|0)|0],t[A|0]=C}if(!(i&128)){continue}v[23516]=0;R(263,e|0,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break d}A=g?j+5|0:p,C=w[Kc(e)|0],t[A|0]=C;AQ(o,w[e|0],c,255,e+16|0,e+32|0);continue}break}break}break}c=x[e+16>>1];if((c|0)!=65535){ve(Xb(v[h>>2],f),Dm(Se(Le(e+48|0,12,c&255),v[e+32>>2])))}f=f+1|0;continue}break}v[23516]=0;b=Q(1,e+48|0,6091)|0;c=v[23516];v[23516]=0;A:{B:{C:{if((c|0)!=1){Gb(a+1298344|0,b);xb(b);v[23516]=0;b=Q(1,e+32|0,5277)|0;c=v[23516];v[23516]=0;if((c|0)==1){break C}Gb(a+1298356|0,b);xb(b);v[a+1298404>>2]=5;v[23516]=0;R(687,e|0,4408);b=v[23516];v[23516]=0;if((b|0)==1){break B}v[23516]=0;U(308,e+16|0,e|0,e+15|0);b=v[23516];v[23516]=0;if((b|0)==1){break A}b=a+1298368|0;a=e+16|0;Gb(b,a);xb(a);ac(e);d=1;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;ac(e);break c}d=P()|0;O()|0;break c}}else{f=(d<<5)+a|0;af(f+480280|0);u[f+480284>>1]=d&1?64:192;d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0}gd(m);gd(k);S(d|0);L()}gd(m);gd(k)}hb=e+224|0;return d|0}function xH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0,E=0,F=0;i=hb-80|0;hb=i;v[i+76>>2]=b;D=i+55|0;s=i+56|0;b=0;a:{b:{c:{d:{e:while(1){if((2147483647-o|0)<(b|0)){break d}o=b+o|0;f:{g:{h:{k=v[i+76>>2];b=k;h=w[b|0];if(h){while(1){i:{h=h&255;j:{if(!h){h=b;break j}if((h|0)!=37){break i}h=b;while(1){if(w[b+1|0]!=37){break j}j=b+2|0;v[i+76>>2]=j;h=h+1|0;l=w[b+2|0];b=j;if((l|0)==37){continue}break}}b=h-k|0;C=2147483647-o|0;if((b|0)>(C|0)){break d}if(a){of(a,k,b)}if(b){continue e}r=-1;h=1;b=v[i+76>>2];j=t[b+1|0];if(!(!Zj(j)|w[b+2|0]!=36)){r=j-48|0;y=1;h=3}b=h+b|0;v[i+76>>2]=b;p=0;m=t[b|0];j=m-32|0;k:{if(j>>>0>31){h=b;break k}h=b;j=1<<j;if(!(j&75913)){break k}while(1){h=b+1|0;v[i+76>>2]=h;p=j|p;m=t[b+1|0];j=m-32|0;if(j>>>0>=32){break k}b=h;j=1<<j;if(j&75913){continue}break}}l:{if((m|0)==42){b=t[h+1|0];m:{if(!(!Zj(b)|w[h+2|0]!=36)){v[((b<<2)+e|0)-192>>2]=10;m=h+3|0;q=v[((t[h+1|0]<<3)+d|0)-384>>2];y=1;break m}if(y){break h}m=h+1|0;if(!a){v[i+76>>2]=m;y=0;q=0;break l}b=v[c>>2];v[c>>2]=b+4;q=v[b>>2];y=0}v[i+76>>2]=m;if((q|0)>=0){break l}q=0-q|0;p=p|8192;break l}q=wH(i+76|0);if((q|0)<0){break d}m=v[i+76>>2]}b=0;l=-1;n:{if(w[m|0]!=46){j=m;h=0;break n}if(w[m+1|0]==42){h=t[m+2|0];o:{if(!(!Zj(h)|w[m+3|0]!=36)){v[((h<<2)+e|0)-192>>2]=10;j=m+4|0;l=v[((t[m+2|0]<<3)+d|0)-384>>2];break o}if(y){break h}j=m+2|0;l=0;if(!a){break o}h=v[c>>2];v[c>>2]=h+4;l=v[h>>2]}v[i+76>>2]=j;h=(l^-1)>>>31|0;break n}v[i+76>>2]=m+1;l=wH(i+76|0);j=v[i+76>>2];h=1}z=h;while(1){n=b;h=28;x=j;if(t[j|0]-123>>>0<4294967238){break c}j=x+1|0;v[i+76>>2]=j;b=w[(t[x|0]+B(n,58)|0)+76815|0];if(b-1>>>0<8){continue}break}p:{q:{if((b|0)!=27){if(!b){break c}if((r|0)>=0){v[(r<<2)+e>>2]=b;b=(r<<3)+d|0;h=v[b+4>>2];v[i+64>>2]=v[b>>2];v[i+68>>2]=h;break q}if(!a){break f}vH(i- -64|0,b,c,g);break p}if((r|0)>=0){break c}}b=0;if(!a){continue e}}m=p&-65537;j=p&8192?m:p;p=0;r=5289;h=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{b=t[x|0];b=n?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(b-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((b|0)==83){break w}break g}n=v[i+64>>2];k=v[i+68>>2];r=5289;break z}b=0;I:{switch(n&255){case 0:v[v[i+64>>2]>>2]=o;continue e;case 1:v[v[i+64>>2]>>2]=o;continue e;case 2:h=v[i+64>>2];v[h>>2]=o;v[h+4>>2]=o>>31;continue e;case 3:u[v[i+64>>2]>>1]=o;continue e;case 4:t[v[i+64>>2]]=o;continue e;case 6:v[v[i+64>>2]>>2]=o;continue e;case 7:break I;default:continue e}}h=v[i+64>>2];v[h>>2]=o;v[h+4>>2]=o>>31;continue e}l=l>>>0>8?l:8;j=j|8;b=120}m=s;E=b&32;n=v[i+64>>2];k=v[i+68>>2];if(n|k){while(1){m=m-1|0;t[m|0]=E|w[(n&15)+77344|0];F=!k&n>>>0>15|(k|0)!=0;x=k;k=k>>>4|0;n=(x&15)<<28|n>>>4;if(F){continue}break}}k=m;if(!(j&8)|!(v[i+64>>2]|v[i+68>>2])){break y}r=(b>>>4|0)+5289|0;p=2;break y}b=s;n=v[i+64>>2];k=v[i+68>>2];if(n|k){while(1){b=b-1|0;t[b|0]=n&7|48;x=!k&n>>>0>7|(k|0)!=0;m=k;k=m>>>3|0;n=(m&7)<<29|n>>>3;if(x){continue}break}}k=b;if(!(j&8)){break y}b=s-k|0;l=(b|0)<(l|0)?l:b+1|0;break y}b=v[i+68>>2];k=b;n=v[i+64>>2];if((b|0)<0){k=0-(k+((n|0)!=0)|0)|0;n=0-n|0;v[i+64>>2]=n;v[i+68>>2]=k;p=1;r=5289;break z}if(j&2048){p=1;r=5290;break z}p=j&1;r=p?5291:5289}k=tn(n,k,s)}if((l|0)<0?z:0){break d}j=z?j&-65537:j;m=v[i+64>>2];b=v[i+68>>2];if(!((m|b)!=0|l)){k=s;h=k;l=0;break g}b=!(b|m)+(s-k|0)|0;l=(b|0)<(l|0)?l:b;break g}b=v[i+64>>2];k=b?b:17169;b=k;h=l>>>0<2147483647?l:2147483647;j=Js(b,0,h);b=j?j-b|0:h;h=b+k|0;if((l|0)>=0){j=m;l=b;break g}j=m;l=b;if(w[h|0]){break d}break g}if(l){h=v[i+64>>2];break u}b=0;Df(a,32,q,0,j);break t}v[i+12>>2]=0;v[i+8>>2]=v[i+64>>2];h=i+8|0;v[i+64>>2]=h;l=-1}b=0;J:{while(1){k=v[h>>2];if(!k){break J}k=uH(i+4|0,k);m=(k|0)<0;if(!(m|k>>>0>l-b>>>0)){h=h+4|0;b=b+k|0;if(l>>>0>b>>>0){continue}break J}break}if(m){break b}}h=61;if((b|0)<0){break c}Df(a,32,q,b,j);if(!b){b=0;break t}k=0;h=v[i+64>>2];while(1){l=v[h>>2];if(!l){break t}l=uH(i+4|0,l);k=l+k|0;if(k>>>0>b>>>0){break t}of(a,i+4|0,l);h=h+4|0;if(b>>>0>k>>>0){continue}break}}Df(a,32,q,b,j^8192);b=(b|0)<(q|0)?q:b;continue e}if((l|0)<0?z:0){break d}h=61;b=lb[f|0](a,A[i+64>>3],q,l,j,b)|0;if((b|0)>=0){continue e}break c}t[i+55|0]=v[i+64>>2];l=1;k=D;j=m;break g}j=b+1|0;v[i+76>>2]=j;h=w[b+1|0];b=j;continue}}if(a){break a}if(!y){break f}b=1;while(1){a=v[(b<<2)+e>>2];if(a){vH((b<<3)+d|0,a,c,g);o=1;b=b+1|0;if((b|0)!=10){continue}break a}break}o=1;if(b>>>0>=10){break a}h=0;while(1){if(h){break h}b=b+1|0;if((b|0)==10){break a}h=v[(b<<2)+e>>2];continue}}h=28;break c}m=h-k|0;n=(l|0)>(m|0)?l:m;if((n|0)>(2147483647-p|0)){break d}h=61;l=n+p|0;b=(l|0)<(q|0)?q:l;if((C|0)<(b|0)){break c}Df(a,32,b,l,j);of(a,r,p);Df(a,48,b,l,j^65536);Df(a,48,n,m,0);of(a,k,m);Df(a,32,b,l,j^8192);continue}break}o=0;break a}h=61}v[115992]=h}o=-1}hb=i+80|0;return o}function bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=hb-224|0;hb=f;if(Fh(b,13916)){if(d){t[d|0]=1}k=a+480204|0;n=a+480216|0;o=a+480220|0;p=a+480224|0;l=a+1074368|0;s=a+480228|0;z=a+480232|0;q=a+480200|0;m=a+480268|0;A=a+1298320|0;C=a+480248|0;D=Zt(a+1074312|0);E=a+480180|0;F=a+484376|0;G=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Ob(v[b>>2],v[b+8>>2],7)){break a}e=zg(b);g=Ng(b);if((e|0)==(w[21727]|w[21728]<<8|(w[21729]<<16|w[21730]<<24))){wg(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Ob(v[b>>2],v[b+8>>2],g)){break a}d=f+176|0;Wd(d,b,g);h=hc(f+200|0,d);yb(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=z;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=n;if((e|0)==1380991534){break s}d=o;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=s;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}v[23516]=0;U(448,h|0,g|0,f+176|0);d=v[23516];v[23516]=0;if((d|0)==1){break i}v[k>>2]=B(v[f+176>>2],1e4)+(y[k>>2]%1e4|0);break j}v[23516]=0;U(448,h|0,g|0,f+176|0);d=v[23516];v[23516]=0;if((d|0)!=1){d=v[k>>2];v[k>>2]=d-((d>>>0)%1e4|0)+y[f+176>>2]%1e4;break j}e=P()|0;O()|0;break b}if(c){break j}v[23516]=0;u[f+176>>1]=0;U(449,h|0,g|0,f+176|0);d=v[23516];v[23516]=0;if((d|0)!=1){H=a,I=Bd(x[f+176>>1],x[a+480188>>1],127),u[H+480188>>1]=I;break j}e=P()|0;O()|0;break b}v[23516]=0;U(450,h|0,g|0,l|0);d=v[23516];v[23516]=0;if((d|0)!=1){break j}break c}v[23516]=0;v[f+176>>2]=0;U(448,h|0,g|0,f+176|0);d=v[23516];v[23516]=0;if((d|0)!=1){v[a+1074304>>2]=v[f+176>>2];break j}e=P()|0;O()|0;break b}v[23516]=0;v[f+176>>2]=0;U(448,h|0,g|0,f+176|0);d=v[23516];v[23516]=0;if((d|0)==1){break h}d=v[f+176>>2];if(!d){break j}v[a+1074308>>2]=d;break j}d=q}v[23516]=0;U(448,h|0,g|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}break j}if(v[E>>2]==4){break j}v[23516]=0;U(449,h|0,g|0,f+176|0);d=v[23516];v[23516]=0;if((d|0)!=1){Te(Sb(v[a+484360>>2],w[F|0]),x[f+176>>1]);break j}e=P()|0;O()|0;break b}v[23516]=0;U(451,h|0,g|0,m|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}if(Co(w[m|0])){break j}t[m|0]=5;break j}d=Kb(f+176|0);e=v[h>>2];v[23516]=0;e=T(158,e|0)|0;g=v[23516];v[23516]=0;x:{if((g|0)==1){break x}v[23516]=0;U(452,h|0,d|0,e|0);e=v[23516];v[23516]=0;if((e|0)==1){break x}v[23516]=0;U(11,f+160|0,0,d|0);e=v[23516];v[23516]=0;if((e|0)==1){break x}e=f+160|0;Gb(A,e);xb(e);wb(d);break j}e=P()|0;O()|0;wb(d);break b}if(g&1|g>>>0>126){break j}d=64;u[f+176>>1]=(g>>>1|0)- -64;u[f+160>>1]=127;e=x[Rc(f+176|0,f+160|0)>>1];i=e>>>0>64?e:64;while(1){if((d|0)==(i|0)){break j}v[23516]=0;R(263,f+176|0,h|0);e=v[23516];v[23516]=0;if((e|0)==1){break g}e=w[f+176|0];y:{if((e|0)==255){break y}j=w[Kc(f+176|0)|0];g=(d<<5)+a|0;r=g+480284|0;u[r>>1]=128;u[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;v[g>>2]=j;e=e&127;if(e>>>0<65){u[r>>1]=e<<2;break y}if((e|0)!=100){break y}v[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}v[23516]=0;d=T(192,h|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break f}if(!d|d>>>0>x[G>>1]){break j}d=(B(d,104)+a|0)+484448|0;g=gT(d);while(1){if((d|0)==(g|0)){break j}e=v[h>>2];v[23516]=0;i=W(154,e|0,v[f+208>>2],4)|0;e=v[23516];v[23516]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}v[23516]=0;e=T(155,h|0)|0;i=v[23516];v[23516]=0;if((i|0)!=1){break z}}e=P()|0;O()|0;break b}v[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}v[23516]=0;R(453,f|0,h|0);d=v[23516];v[23516]=0;A:{B:{C:{D:{if((d|0)!=1){v[23516]=0;U(454,f+176|0,v[f>>2],v[f+4>>2]);d=v[23516];v[23516]=0;if((d|0)==1){break D}v[23516]=0;d=Q(87,f+16|0,f+176|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break C}wb(f+176|0);dc(f);e=v[h>>2];v[23516]=0;e=T(158,e|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break A}v[23516]=0;U(455,d|0,C|0,e|0);e=v[23516];v[23516]=0;if((e|0)==1){break A}pf(d);break j}e=P()|0;O()|0;break b}e=P()|0;O()|0;break B}e=P()|0;O()|0;wb(f+176|0)}dc(f);break b}e=P()|0;O()|0;pf(d);break b}e=0;g=Zt(D);E:while(1){d=v[h>>2];v[23516]=0;d=W(154,d|0,v[f+208>>2],1)|0;i=v[23516];v[23516]=0;if((i|0)==1){break d}if(!(d&e>>>0<118)){break j}v[23516]=0;i=T(204,h|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>117){break F}v[23516]=0;W(267,g|0,e|0,1)|0;j=v[23516];v[23516]=0;if((j|0)!=1){break F}e=P()|0;O()|0;break b}e=e+1|0;d=d+1|0;continue}}}v[23516]=0;U(456,h|0,g|0,p|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}}yb(h);continue}break}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}yb(h);S(e|0);L()}b=v[a+8>>2];Ko(k,B(v[b+20>>2],1e4),B(v[b+24>>2],1e4));if(w[a+480224|0]>=3){t[p|0]=0}if(w[l|0]>=6){t[l|0]=0}uc(q,256);uc(n,65536);uc(o,65536)}hb=f+224|0}function wia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;e=hb-1360|0;hb=e;xc(b);h=hb-16|0;hb=h;j=e+784|0;rT(h+8|0,j);i=v[h+12>>2];jc(h,v[b>>2],v[b+8>>2],v[h+8>>2],i);l=v[h+4>>2];if((l|0)==(i|0)){Yb(b,v[h+12>>2])}hb=h+16|0;h=(i|0)==(l|0);if(!h){qT(j)}a:{if(!h){break a}if(!uT(e+784|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(sT(x[e+818>>1],x[e+820>>1]),kb))){break a}if(!c){d=1;break a}q=wh(e+776|0);b:{while(1){if((d|0)!=32){h=(d<<5)+a|0;i=h+480280|0;af(i);j=(e+784|0)+(d<<4)|0;u[h+480284>>1]=((w[j+78|0]<<8&65280)>>>0)/255;m=e+512|0;ok(m,1,j- -64|0);l=e+112|0;Cc(l,m);wl(h+480289|0,l);wb(l);c:{d:{switch(w[j+79|0]){case 0:k=f+1|0;break c;case 1:v[i>>2]=1024;k=d+1|0;break c;case 2:break d;default:break b}}v[i>>2]=1024;h=e+112|0;Pc(h,q,d);fo(h)}f=f+1|0;d=d+1|0;continue}break}zd(a,33554432);u[a+480188>>1]=k&255;d=e+112|0;f=vc(d,6776);Gb(a+1298344|0,f);xb(f);d=vc(d,11110);Gb(a+1298356|0,d);xb(d);v[a+1298404>>2]=5;e:{if(w[e+863|0]){break e}d=1;f=1;while(1){if((d|0)==16){while(1){if((f|0)==16){break e}d=((f<<5)+a|0)+480280|0;v[d>>2]=v[d>>2]&-1025;f=f+1|0;continue}}h=d<<4;d=d+1|0;if(w[(e+h|0)+863|0]==1){continue}break}}d=e+512|0;Ke(d,1,e+784|0);f=e+112|0;Cc(f,d);yc(a+1298308|0,f);wb(f);v[a+480208>>2]=v[a+480208>>2]&-17|x[e+822>>1]<<4&16;v[a+480196>>2]=w[e+832|0];v[a+480204>>2]=B(w[e+833|0],1e4);v[a+480200>>2]=w[e+834|0]<<2;v[a+480228>>2]=w[e+835|0];f=x[e+820>>1];u[a+480190>>1]=0;u[a+480192>>1]=f;Uu(b,d);Mq(Sb(v[a+484360>>2],w[a+484376|0]),d,x[e+816>>1],65535,255);o=c&1;if(o){vg(a+484344|0,x[e+818>>1])}m=a+484344|0;s=a+480188|0;f:{while(1){g:{if(x[e+818>>1]<=g>>>0){l=c&2;q=e+108|0;m=a+480192|0;h=1;c=0;h:while(1){if(x[m>>1]<=(c&65535)>>>0){d=32;break b}c=c+1|0;f=Cu(a,c&65535,0);i=!f;d=hb-16|0;hb=d;k=e+112|0;ec(d+8|0,k,384);g=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],g);j=v[d+4>>2];if((j|0)==(g|0)){Yb(b,v[d+12>>2])}hb=d+16|0;d=(g|0)==(j|0);if(!d){Rb(k,0,384)}if(!d|i){continue}k=h&65535;g=hb-32|0;hb=g;i=e+112|0;Ke(g,1,i);d=g+16|0;Cc(d,g);Ac(f+492|0,d);wb(d);i:{if(!(w[i+378|0]|w[i+379|0]<<8)){break i}j=f+236|0;d=0;while(1){v[g+16>>2]=120;v[g>>2]=116;if(y[Hb(g+16|0,g)>>2]<=d>>>0){break i}z=$b(j,d+12|0),A=k+w[(d+i|0)+32|0]|0,u[z>>1]=A;d=d+1|0;continue}}d=w[i+376|0]|w[i+377|0]<<8;t[f+33|0]=1;v[f>>2]=d;OA(i,f+48|0,0);OA(i,f+68|0,1);OA(i,f+88|0,2);d=w[f+100|0];if(d&1){t[f+100|0]=d|16}if(!(v[f>>2]|t[f+60|0]&1)){v[f>>2]=32767}hb=g+32|0;d=0;while(1){f=x[e+490>>1];if(f>>>0<=d>>>0){h=f+h|0;continue h}wU(b,e+48|0);j:{k:{if(Qb(q,15634,4)){break k}f=d+h|0;k=f&65535;if(k>>>0>3999){break k}u[a+480190>>1]=f;i=hb-32|0;hb=i;j=B(k,104)+a|0;f=j+484380|0;jd(f,0);_h(i,1,e+48|0);g=i+16|0;Cc(g,i);xe(f+43|0,g);wb(g);p=w[e+64|0]|w[e+65|0]<<8|(w[e+66|0]<<16|w[e+67|0]<<24);v[f>>2]=p;n=w[e+68|0]|w[e+69|0]<<8|(w[e+70|0]<<16|w[e+71|0]<<24);v[f+4>>2]=n;o=w[e+72|0]|w[e+73|0]<<8|(w[e+74|0]<<16|w[e+75|0]<<24);v[f+8>>2]=o;v[f+24>>2]=w[e+76|0]|w[e+77|0]<<8|(w[e+78|0]<<16|w[e+79|0]<<24);u[f+30>>1]=w[e+80|0]<<2;u[f+28>>1]=w[e+81|0];g=w[e+96|0];if(g&1){u[f+34>>1]=x[f+34>>1]|2;g=w[e+96|0]}if(g&2){u[f+34>>1]=x[f+34>>1]|4;g=w[e+96|0]}if(g&4){v[f+8>>2]=o>>>1;v[f+4>>2]=n>>>1;v[f>>2]=p>>>1;u[f+34>>1]=x[f+34>>1]|1;g=w[e+96|0]}if(g&8){u[f+34>>1]=x[f+34>>1]|32}hb=i+32|0;g=hb-16|0;hb=g;cv(g+8|0,j+484423|0);i=e+24|0;Tq(i,v[g+8>>2],v[g+12>>2]);hb=g+16|0;Ac(((k<<5)+a|0)+946304|0,i);wb(i);g=v[e+64>>2];if(!g){break k}Wd(e,b,g);g=hc(e+24|0,e);yb(e);if(l){i=Uc(e,u[j+484414>>1]&1?16:8,1,0,0);v[23516]=0;W(218,i|0,f|0,g|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break j}}yb(g)}d=d+1|0;continue}break}break}a=P()|0;O()|0;yb(g);break f}f=Ng(b);p=Ng(b);d=e+48|0;Wd(d,b,f-4|0);j=hc(e+112|0,d);yb(d);l:{m:{if(!o){break m}v[23516]=0;d=W(225,m|0,g&65535,p|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break l}if(!d){break m}k=0;i=sg(e+24|0);while(1){if(k>>>0>=p>>>0){break m}v[23516]=0;l=T(204,j|0)|0;d=v[23516];v[23516]=0;n:{if((d|0)!=1){if(l){break n}k=k+1|0;continue}break g}f=i;n=l&31;if(n>>>0<x[s>>1]){d=Xb(v[m>>2],g);f=ed(v[d>>2],v[v[d+48>>2]+12>>2],k,n)}if(l&32){v[23516]=0;R(263,e+48|0,j|0);d=v[23516];v[23516]=0;if((d|0)==1){break g}h=w[e+48|0];t[f|0]=h;z=f,A=w[Kc(e+48|0)|0],t[z+1|0]=A;o:{p:{if((h|0)==160){d=255;break p}if((h|0)==255){d=0;break p}d=0;h=(B(h>>>4|0,12)+(h&15)|0)+13|0;if(pT(h)){break o}}h=d}t[f|0]=h}d=l&192;q:{if(!d){break q}if((d|0)==192){v[23516]=0;R(356,e+48|0,j|0);d=v[23516];v[23516]=0;if((d|0)!=1){d=e+48|0;h=Kc(d);l=Re(d);d=Ji(d);PA(e,w[e+48|0],w[h|0]);h=Kc(e);r=e+504|0;PA(r,w[l|0],w[d|0]);to(e+496|0,f,w[e|0],w[h|0],w[e+504|0],w[Kc(r)|0]);break q}break g}v[23516]=0;R(263,e+48|0,j|0);d=v[23516];v[23516]=0;r:{s:{if((d|0)!=1){PA(e,w[e+48|0],w[Kc(e+48|0)|0]);h=w[Kc(e)|0];d=w[e|0];if((d|0)!=13){break s}t[f+2|0]=1;d=f+4|0;break r}break g}t[f+3|0]=d;d=f+5|0}t[d|0]=h}Pc(e+48|0,q,n);if(!zb(v[v[e+48>>2]>>2],v[e+52>>2])){continue}if(!mV(w[f+3|0],w[f+5|0])){continue}t[f+3|0]=0;continue}}yb(j);g=g+1|0;continue}}break}a=P()|0;O()|0;yb(j)}S(a|0);L()}d=d>>>0>31}hb=e+1360|0;return d|0}function fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;e=hb-1824|0;hb=e;xc(b);d=hb-16|0;hb=d;j=e+1224|0;HR(d+8|0,j);f=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],f);i=v[d+4>>2];if((i|0)==(f|0)){Yb(b,v[d+12>>2])}hb=d+16|0;d=(f|0)==(i|0);if(!d){GR(j)}a:{if(!d){break a}if(!IR(e+1224|0)){break a}if(!bA(b,16,0)){break a}v[e+1216>>2]=v[e+1240>>2];d=v[e+1228>>2];v[e+1200>>2]=v[e+1224>>2];v[e+1204>>2]=d;d=e+1232|0;f=v[d+4>>2];v[e+1208>>2]=v[d>>2];v[e+1212>>2]=f;zd(a,1);Mb(Mb(Lf(a+1074312|0,83),84,1),85,1);u[a+480188>>1]=4;v[e+1196>>2]=0;u[a+480190>>1]=15;Zc(b,20);i=a+480188|0;g=1;n=1;while(1){b:{if((g|0)==16){d=e+1064|0;QR(b,d);f=a+484360|0;j=a+484376|0;Aq(Sb(v[f>>2],w[j|0]),d|2,128);g=0;m=PR(b,Sb(v[f>>2],w[j|0]),w[e+1064|0],k,i,0,1);if(!(w[e+1064|0]?1:w[e+1065|0]|m>>>0>1)){break a}if($e(b)+65536>>>0<(m<<10)+k>>>0){break a}if(c){break b}g=1;break a}f=B(g,104)+a|0;j=f+484380|0;d=((g<<5)+a|0)+946304|0;cA(b,e+24|0,j,d,1);m=v[j>>2];c:{if(!w[Ib(d,0)|0]){break c}d:{if(Qb(d,16870,3)){if(Qb(d,16874,3)){break d}}if(w[Ib(d,5)|0]==58){break c}}n=0}d=Eb(x[e+52>>1]);if(d>>>0>=2){l=d<<1;d=Eb(x[e+50>>1]);v[f+484388>>2]=l+d;v[f+484384>>2]=d;wk(j)}e:{if(Eb(x[e+46>>1])>>>0<=4999){if(Eb(x[e+50>>1])>>>0<1e4){break e}}v[e+1064>>2]=5;z=e,A=v[Ne(e+1196|0,e+1064|0)>>2],v[z+1196>>2]=A}k=k+m|0;g=g+1|0;continue}break}g=w[e+1065|0];if(!g){t[e+1065|0]=120;g=120}f:{if(!Qb(e+1200|0,15028,6)){t[e+1065|0]=120;v[a+480204>>2]=125e4;break f}v[a+480204>>2]=125e4;if((g|0)==120){break f}z=a,A=Oe(1773447.5/(+(240-g|0)*122)*1e4),v[z+480204>>2]=A;if(v[e+1196>>2]>=2){v[e+24>>2]=n?4:5;z=e,A=v[Ne(e+1196|0,e+24|0)>>2],v[z+1196>>2]=A;break f}v[e+24>>2]=n?1:2;z=e,A=v[Ne(e+1196|0,e+24|0)>>2],v[z+1196>>2]=A}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;f=e+1048|0;Aj(f,3,e+1200|0);d=e+24|0;Cc(d,f);yc(a+1298308|0,d);wb(d);jh(a,0);r=v[b+8>>2];s=a+484376|0;while(1){g:{h:{if((p&65535)>>>0<m>>>0){d=Sb(v[a+484360>>2],w[s|0]);d=Nb(Xz(Cb(v[d>>2]),Cb(v[d+4>>2]),p),Cb(v[d+4>>2]));FR(b,e+24|0);if(d){h=$z(e+24|0,0)+h|0;if(h>>>0>512){break h}}k=0;d=0;j=0;i:while(1){if((j|0)==64){break g}g=0;y=Gd(e+24|0,j);while(1){f=d;if((g|0)==4){j=j+1|0;continue i}else{o=Bb(y,g);l=w[Ib(o,2)|0]&15;i=w[Ib(o,3)|0];d=0;j:{if(!(f&255)){break j}if(Qb(o,27060,4)){break j}d=f+1|0;if((d&255)>>>0<33){break j}v[e+1196>>2]=6}k:{l:{m:{switch(l-1|0){case 0:case 1:f=v[e+1196>>2];if((f|0)==1&i>>>0>=32){break l}l=(l|0)!=1;if(!(l|!i|i>>>0>2)){v[e+1048>>2]=2;z=e,A=v[Ne(e+1196|0,e+1048|0)>>2],v[z+1196>>2]=A;break k}if(l|(i|0)!=55&(i|0)!=71){break k}if((f|0)<=2){break l}break k;case 10:v[e+1196>>2]=6;break k;case 11:case 12:case 13:v[e+1048>>2]=2;z=e,A=v[Ne(e+1196|0,e+1048|0)>>2],v[z+1196>>2]=A;if((l|0)!=13){break k}k=((i|j)!=0)+k|0;d=1;break k;case 14:break m;default:break k}}v[e+1048>>2]=3;z=e,A=v[Ne(e+1196|0,e+1048|0)>>2],v[z+1196>>2]=A;break k}v[e+1196>>2]=n}g=g+1|0;continue}}}}if(!(v[e+1196>>2]!=6|m+32>>>0>=q>>>0)){v[e+1196>>2]=5}Zc(b,r);o=c&1;if(o){vg(a+484344|0,m)}l=a+484344|0;k=0;while(1){if((k|0)==(m|0)){g=21751;d=v[e+1196>>2];if(d>>>0<7){g=v[(d<<2)+27072>>2]}d=e+24|0;f=vc(d,8333);Gb(a+1298344|0,f);xb(f);d=vc(d,10775);Gb(a+1298356|0,d);xb(d);Hl(a+1298368|0,g);v[a+1298404>>2]=14;if(!(c&2)){break h}g=1;while(1){if((g|0)==16){break h}c=B(g,104)+a|0;d=c+484384|0;Yb(b,v[d>>2]);f=v[d>>2];v[d>>2]=0;d=c+484380|0;v[d>>2]=v[d>>2]-f;c=c+484388|0;v[c>>2]=v[c>>2]-f;c=e+24|0;Uc(c,8,1,1,0);ug(c,d,b);g=g+1|0;continue}}FR(b,e+24|0);n:{if(!o){break n}if(!kh(l,k&65535,64)){break n}j=0;v[e+1048>>2]=0;o:while(1){if((j|0)==64){break n}g=0;d=Xb(v[l>>2],k);q=ed(v[d>>2],v[v[d+48>>2]+12>>2],j,0);r=Gd(e+24|0,j);while(1)if((g|0)==4){j=j+1|0;continue o}else{d=Bb(r,g);d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+4>>2]=d;v[e+8>>2]=d;h=e+16|0;d=q+B(g,6)|0;gu(h,e+4|0,d);f=w[e+16|0];i=Kc(h);h=w[i|0];if(!((f|0)!=14?h:0)){t[(e+1048|0)+g|0]=0}n=(e+1048|0)+g|0;p:{if(f|h){q:{h=w[n|0];if(h){r:{if(h>>>0>=16){t[d+2|0]=3;h=h>>>4|0;break r}t[d+2|0]=4}t[d+4|0]=h;f=w[e+16|0]}s:{t:{u:{v:{switch((f&255)-12|0){case 1:h=v[e+1196>>2];if((h|0)!=6){t[e+16|0]=10;break t}t[i|0]=0;break u;case 0:t[i|0]=w[i|0]&127;break u;case 2:h=w[i|0];if(h>>>0<=1){f=14;if(v[e+1196>>2]>3){break s}}t[e+16|0]=10;t[n|0]=w[i|0];break u;case 3:break v;default:break u}}t[i|0]=w[i|0]&15}h=v[e+1196>>2]}if((h|0)<2){break q}h=w[i|0];f=w[e+16|0]}Nf(d,f,h&255);break p}f=w[i|0];t[d+5|0]=f;w:{switch(w[e+16|0]){case 0:if(w[i|0]<=2){t[d+3|0]=0;break p}t[d+3|0]=1;break p;case 1:t[d+3|0]=1;break p;case 2:h=f&15;if(h){t[d+3|0]=2;t[d+5|0]=h;break p}if(f>>>0<16){break p}t[d+3|0]=3;t[d+5|0]=(f&240)>>>4;break p;default:break w}}t[d+3|0]=0;break p}t[n|0]=0}g=g+1|0;continue}}}k=k+1|0;continue}}g=(p&65535)>>>0>=m>>>0;break a}if((k-1&255)>>>0<2){v[e+1196>>2]=6}p=p+1|0;q=(k&255)+q|0;continue}}hb=e+1824|0;return g|0}function Vea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=hb-352|0;hb=d;Zc(b,60);f=15;a:{if(!Fh(b,14226)){Zc(b,124);f=31;if(!Fh(b,15489)){break a}}zd(a,536870912);u[a+480190>>1]=f;xc(b);b:{while(1){if(x[a+480190>>1]>g>>>0){e=uo(b);v[(d+224|0)+(g<<2)>>2]=e;g=g+1|0;if(e>>>0<=131072){continue}break b}break}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;g=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;jh(a,1);Yb(b,4);e=Ej(b);if(e>>>0<178){break a}p=a,q=Oe(1776930/+(e>>>0)*1e4),v[p+480204>>2]=q;Yb(b,14);f=0;n=1;c:while(1){m=n&65535;if(m>>>0<=x[a+480190>>1]){LR(b,d+56|0);g=v[((m<<2)+d|0)+220>>2];l=hb-16|0;hb=l;h=(B(m,104)+a|0)+484380|0;jd(h,1);v[h>>2]=g;t[h+37|0]=w[d+80|0]<<4;t[l+15|0]=w[d+81|0];t[l+14|0]=64;p=h,q=w[Vb(l+15|0,l+14|0)|0]<<2,u[p+30>>1]=q;d:{if(!g){break d}e=Eb(w[d+84|0]|w[d+85|0]<<8);j=Eb(w[d+82|0]|w[d+83|0]<<8);v[h+4>>2]=j;e=(e<<1)+j|0;v[h+8>>2]=e;if(g>>>0<=j>>>0){j=g-1|0;v[h+4>>2]=j}if(e>>>0>g>>>0){v[h+8>>2]=g;e=g}if(!(!(e>>>0<4|e>>>0<j>>>0)&e-j>>>0>3)){v[h+4>>2]=0;v[h+8>>2]=0;break d}if(e>>>0<=j>>>0){break d}u[h+34>>1]=x[h+34>>1]|2}hb=l+16|0;g=0;while(1)if((g|0)==22){if(f>>>0>127){break b}e=d+192|0;xl(e,3,d+56|0);g=d+208|0;Cc(g,e);Ac(((m<<5)+a|0)+946304|0,g);n=n+1|0;wb(g);continue c}else{e=(d+56|0)+g|0;if((w[e|0]-1&255)>>>0<=30){t[e|0]=32;f=f+1|0}g=g+1|0;continue}}break}l=1;e:{f:{g:{f=a+946336|0;g=Fc(d+56|0,14093);if(!HQ(f,g)){v[23516]=0;e=Q(53,d+208|0,14104)|0;h=v[23516];v[23516]=0;if((h|0)==1){break g}l=HQ(f,e);wb(e)}wb(g);g=0;e=d+56|0;f=KR(b,e);if(!f){Zz(e)}if(!f){break a}e=w[d+56|0];if(!KQ(e)){break a}if(!c){break e}u[d+54>>1]=0;while(1)if((e|0)==(g|0)){g=a+484360|0;f=a+484376|0;i=Sb(v[g>>2],w[f|0]);h=w[d+57|0];Te(i,e>>>0>h>>>0?h:0);Aq(Sb(v[g>>2],w[f|0]),d+56|2,w[d+56|0]);if(x[a+480190>>1]==31){Yb(b,4)}v[d+48>>2]=0;v[d+44>>2]=0;v[d+40>>2]=0;t[d+39|0]=0;m=c&1;if(m){vg(a+484344|0,x[d+54>>1])}n=a+484344|0;h=0;while(1){h:{i:{j:{if(x[d+54>>1]<=h>>>0){if(!(c&2)){break j}g=1;while(1){f=x[a+480190>>1];c=g&65535;if(f>>>0<c>>>0){break i}c=(B(c,104)+a|0)+484380|0;if(v[c>>2]){ug(Uc(d+192|0,8,1,0,0),c,b)}g=g+1|0;continue}}k:{if(m){j=0;if(kh(n,h&65535,64)){break k}}Yb(b,1024);break h}l:while(1){if((j|0)==64){break h}g=0;e=Xb(v[n>>2],h);o=ed(v[e>>2],v[v[e+48>>2]+12>>2],j,0);while(1)if((g|0)==4){j=j+1|0;continue l}else{f=d+192|0;Km(f,b);e=B(g,6)+o|0;m:{n:{o:{p:{if(w[Ib(f,0)|0]!=255){break p}t[(d+48|0)+g|0]=0;t[(d+40|0)+g|0]=0;f=Ib(d+192|0,1);i=w[f|0];if((i|0)==252&l){t[f|0]=254;break n}switch(i-252|0){case 1:break m;case 2:break n;case 0:break o;default:break p}}f=v[d+192>>2];v[d+32>>2]=f;v[d+12>>2]=f;f=d+16|0;gu(f,d+12|0,e);i=Kc(f);f=w[e|0];q:{if(!f){break q}t[(d+40|0)+g|0]=0;t[(d+48|0)+g|0]=f;if(f>>>0>48){break q}t[d+31|0]=8;p=d,q=w[ef(d+39|0,d+31|0)|0],t[p+39|0]=q}f=w[i|0];r:{if(!(f|w[d+16|0])){break r}t[e+5|0]=f;s:{t:{switch(w[d+16|0]-1|0){case 0:t[e+3|0]=1;break r;case 1:if(f&240){t[e+3|0]=3;t[e+5|0]=f>>>4;break r}f=f&15;if(f){t[e+3|0]=2;t[e+5|0]=f;break r}t[e+3|0]=0;break r;case 2:if(w[(d+40|0)+g|0]){t[e+3|0]=0;break r}t[e+3|0]=19;t[e+5|0]=0;break r;case 3:if(w[(d+40|0)+g|0]){t[e+3|0]=0;break r}t[e+3|0]=19;t[e+5|0]=1;break r;case 4:if(!w[e+1|0]){break s}t[d+31|0]=63;t[d+30|0]=w[e+5|0]+(x[(B(w[e+1|0],104)+a|0)+484410>>1]>>>2|0);f=w[Vb(d+31|0,d+30|0)|0];t[e+3|0]=13;t[e+5|0]=f;if(!w[(d+40|0)+g|0]){break r}t[e+4|0]=w[e+5|0];t[e+2|0]=1;t[e+3|0]=0;break r;case 5:i=w[e+1|0];if(i){t[e+3|0]=13;i=x[(B(i,104)+a|0)+484410>>1]>>>2|0;f=f>>>0>i>>>0?0:i-f|0;t[e+5|0]=f;if(!w[(d+40|0)+g|0]){break r}t[e+4|0]=f;t[e+2|0]=1}t[e+3|0]=0;break r;case 6:i=f&15;t[(d+40|0)+g|0]=i;k=w[(d+48|0)+g|0];f=k-(f>>>4|0)|0;t[(d+44|0)+g|0]=f;f=GQ(i,f&255,k);t[e+3|0]=3;t[e+5|0]=f;break r;case 7:i=f&15;t[(d+40|0)+g|0]=i;k=f>>>4|0;f=w[(d+48|0)+g|0];k=k+f|0;t[(d+44|0)+g|0]=k;f=GQ(i,f,k&255);t[e+3|0]=2;t[e+5|0]=f;break r;case 8:break t;default:break s}}t[d+31|0]=8;p=d,q=w[ef(d+39|0,d+31|0)|0],t[p+39|0]=q}t[e+3|0]=0}if(w[e+3|0]){break m}i=w[(d+40|0)+g|0];if(!i){break m}k=(d+44|0)+g|0;f=w[k|0];if(f){t[(d+48|0)+g|0]=f;t[e|0]=f;t[e+5|0]=i;t[k|0]=0}t[e+3|0]=4;break m}t[e+3|0]=14;t[d+39|0]=9;break m}t[e+3|0]=13}g=g+1|0;continue}}}f=x[a+480190>>1]}u:{v:{w:{if((f&65535)==15){b=d+16|0;Qf(b,4421);v[23516]=0;U(308,d+192|0,b|0,d+39|0);b=v[23516];v[23516]=0;if((b|0)==1){break u}b=d+192|0;Gb(a+1298344|0,b);xb(b);ac(d+16|0);break w}v[23516]=0;b=Q(1,d+192|0,12358)|0;c=v[23516];v[23516]=0;if((c|0)==1){break v}Gb(a+1298344|0,b);xb(b)}Hl(a+1298356|0,x[a+480190>>1]==15?5285:15223);v[a+1298404>>2]=14;break e}f=P()|0;O()|0;break f}f=P()|0;O()|0;ac(d+16|0);break f}h=h+1|0;continue}}else{u[d+192>>1]=w[(d+g|0)+58|0]+1;p=d,q=x[ie(d+54|0,d+192|0)>>1],u[p+54>>1]=q;g=g+1|0;continue}}f=P()|0;O()|0;wb(g)}S(f|0);L()}g=1;break a}g=0}hb=d+352|0;return g|0}function $H(a,b,c,d,e,f){var g=0,h=C(0),i=0,j=0,k=C(0),l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,A=C(0),D=C(0),E=0,F=0,G=0,H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=B(s,2304)+b|0;v=0;q=(c|0)>0?c:0;n=hb-128|0;x=n+96|0;y=n- -64|0;E=n+32|0;while(1){if((q|0)!=(v|0)){o=G+(v<<2)|0;w=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=z[B(15-j|0,72)+o>>2];g=B(j,72)+o|0;h=z[g+1152>>2];l=C(k+h);m=z[g>>2];A=z[B(31-j|0,72)+o>>2];D=C(m+A);z[p>>2]=l+D;g=B(j,12);k=C(C(k-h)*z[g+71536>>2]);h=C(C(m-A)*z[g+71540>>2]);z[p+64>>2]=k+h;m=C(D-l);l=z[g+71544>>2];z[p+32>>2]=m*l;z[p+96>>2]=C(h-k)*l;p=p+4|0;j=j+1|0;continue}break}while(1){if((w|0)!=4){l=z[i+8>>2];m=z[i+20>>2];h=C(l+m);A=z[i+4>>2];D=z[i+24>>2];H=C(A+D);k=C(h+H);I=z[i+12>>2];J=z[i+16>>2];K=C(I+J);L=z[i>>2];M=z[i+28>>2];N=C(L+M);O=C(K+N);z[i>>2]=k+O;z[i+16>>2]=C(O-k)*C(.7071067690849304);k=C(N-K);h=C(C(k+C(H-h))*C(.7071067690849304));z[i+24>>2]=C(k-h)*C(1.3065630197525024);z[i+8>>2]=C(k+h)*C(.5411961078643799);k=C(L-M);h=C(l-m);l=C(A-D);m=C(C(h+l)*C(.7071067690849304));A=C(k+m);D=C(C(I-J)+h);h=C(l+k);l=C(D-C(h*C(.1989123672246933)));h=C(C(l*C(.3826834261417389))+h);z[i+28>>2]=C(A-h)*C(2.562915563583374);z[i+4>>2]=C(A+h)*C(.509795606136322);k=C(k-m);h=C(l-C(h*C(.1989123672246933)));z[i+20>>2]=C(k+h)*C(.8999761939048767);z[i+12>>2]=C(k-h)*C(.601344883441925);i=i+32|0;w=w+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;z[o>>2]=z[p+n>>2];k=z[p+x>>2];i=i+1|0;j=i<<2;h=z[j+x>>2];z[o+72>>2]=C(z[p+y>>2]+k)+h;z[o+144>>2]=z[p+E>>2]+z[j+E>>2];z[o+216>>2]=h+C(k+z[j+y>>2]);o=o+288|0;continue}break}z[o>>2]=z[n+28>>2];k=z[n+124>>2];z[o+72>>2]=z[n+92>>2]+k;h=z[n+60>>2];z[o+216>>2]=k;z[o+144>>2]=h;v=v+1|0;continue}break}s=s+1|0;continue}break}E=pc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=hb-32|0;hb=i;o=E+(s<<8)|0;v=(s<<2)+b|0;z[o+4080>>2]=z[v+1152>>2];f=d-1|0;w=v+B(f,2304)|0;z[o+4084>>2]=z[w+1152>>2];z[o+4088>>2]=z[v>>2];z[o+4092>>2]=z[w>>2];z[o+4336>>2]=z[v+1156>>2];z[o+4340>>2]=z[w+1156>>2];z[o+4344>>2]=z[v+4>>2];z[o+4348>>2]=z[w+4>>2];x=(B(s,G)<<1)+e|0;y=x+(f<<1)|0;es(y,d,o+244|0);f=d<<6;es(f+y|0,d,o+500|0);es(x,d,o+240|0);es(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=71632;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=B(31-p|0,72);z[j>>2]=z[f+v>>2];z[j+4>>2]=z[f+w>>2];f=f|4;z[j+8>>2]=z[f+v>>2];z[j+12>>2]=z[f+w>>2];f=B(p,72);q=f+76|0;z[j+256>>2]=z[q+v>>2];z[j+260>>2]=z[q+w>>2];f=f+72|0;z[j-248>>2]=z[f+v>>2];z[j-244>>2]=z[f+w>>2];q=p<<2;t=g+o|0;k=z[n+4>>2];h=z[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=z[g+j>>2];m=z[g+t>>2];z[g+(i+16|0)>>2]=C(l*h)-C(k*m);z[i+g>>2]=C(l*k)+C(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=z[n+12>>2];h=z[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=z[n+20>>2];h=z[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=z[n+28>>2];h=z[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=z[n+36>>2];h=z[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=z[n+44>>2];h=z[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=z[n+52>>2];h=z[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=z[n+60>>2];h=z[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=z[j+q>>2];m=z[g+j>>2];z[t>>2]=z[t>>2]+C(C(l*k)+C(h*m));j=j+(i+16|0)|0;z[j>>2]=C(C(m*k)-C(h*l))+z[j>>2];f=f+1|0;continue}break}f=B(15-p|0,d)<<1;P=f+y|0,Q=cj(z[i+20>>2]),u[P>>1]=Q;j=B(p+17|0,d)<<1;P=j+y|0,Q=cj(z[i+4>>2]),u[P>>1]=Q;P=f+x|0,Q=cj(z[i+16>>2]),u[P>>1]=Q;P=j+x|0,Q=cj(z[i>>2]),u[P>>1]=Q;f=B(47-p|0,d)<<1;P=f+y|0,Q=cj(z[i+28>>2]),u[P>>1]=Q;j=B(p+49|0,d)<<1;P=j+y|0,Q=cj(z[i+12>>2]),u[P>>1]=Q;P=f+x|0,Q=cj(z[i+24>>2]),u[P>>1]=Q;P=j+x|0,Q=cj(z[i+8>>2]),u[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}hb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}z[(s<<2)+a>>2]=z[E+(b+s<<2)>>2];s=s+2|0;continue}}pc(a,E+(b<<2)|0,3840)}}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;g=hb-288|0;hb=g;xc(b);e=hb-16|0;hb=e;h=g+80|0;TT(e+8|0,h);f=v[e+12>>2];jc(e,v[b>>2],v[b+8>>2],v[e+8>>2],f);i=v[e+4>>2];if((i|0)==(f|0)){Yb(b,v[e+12>>2])}hb=e+16|0;e=(f|0)==(i|0);if(!e){ST(h)}a:{if(!e){break a}if(!VT(g+80|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(UT(g+80|0),kb))){break a}b:{if(!c){break b}zd(a,16777216);$f(a);v[a+480208>>2]=v[a+480208>>2]|16777216;d=g+56|0;oq(d,32);f=g- -64|0;h=v[f+4>>2];e=a+1074320|0;v[e>>2]=v[f>>2];v[e+4>>2]=h;e=v[g+60>>2];v[a+1074312>>2]=v[g+56>>2];v[a+1074316>>2]=e;Mb(a+1074312|0,114,1);s=a+480188|0,y=Eb(x[g+280>>1]),u[s>>1]=y;jh(a,1);e=vc(d,8570);Gb(a+1298368|0,e);xb(e);e=g+32|0;Qf(e,3927);v[23516]=0;U(369,d|0,e|0,w[g+83|0]);d=v[23516];v[23516]=0;c:{if((d|0)!=1){d=g+56|0;Gb(a+1298344|0,d);xb(d);e=g+32|0;ac(e);f=vc(d,10779);Gb(a+1298356|0,f);xb(f);v[a+1298404>>2]=12;Ke(e,3,g+80|4);Cc(d,e);yc(a+1298308|0,d);wb(d);f=160;while(1){d:{d=f;if(!d){d=0;break d}f=d-1|0;if(w[(g+f|0)+116|0]==32){continue}}break}RT(a+1298332|0,g+116|0,d,4);o=a+480190|0;d=Eb(x[g+276>>1]);u[o>>1]=d;l=1;while(1){e:{f:{g:{h:{i:{e=d&65535;d=l&65535;if(e>>>0<d>>>0){f=a+484360|0;e=a+484376|0;Te(Sb(v[f>>2],w[e|0]),Eb(x[g+284>>1]));d=g+32|0;Wd(d,b,512);j=hc(g+56|0,d);yb(d);d=w[e|0];f=v[f>>2];h=x[g+282>>1];v[23516]=0;U(277,Sb(f,d)|0,j|0,Eb(h)|0);d=v[23516];v[23516]=0;if((d|0)!=1){break i}d=P()|0;O()|0;break h}h=B(d,104)+a|0;i=h+484380|0;jd(i,1);lo(i);RU(b,((d<<5)+a|0)+946304|0,w[g+83|0]==1?32:28);n=1;d=w[g+83|0];if(d>>>0>=3){Yb(b,14);d=XA(b);if((d|0)>=0){e=h+484414|0;u[e>>1]=x[e>>1]|32;s=h+484408|0,y=Bc((((d&65535)<<8)+2047>>>0)/4095|0,0),u[s>>1]=y}d=w[g+83|0]}if((d&255)>>>0>=2){n=Ej(b);s=h+484404|0,y=Ej(b),v[s>>2]=y}d=g+56|0;f=hb-16|0;hb=f;j:{if(!Ob(v[b>>2],v[b+8>>2],12)){v[f>>2]=0;e=d;j=3;while(1){if(j){k=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[e|0]=k;t[e+1|0]=k>>>8;t[e+2|0]=k>>>16;t[e+3|0]=k>>>24;j=j-1|0;e=e+4|0;continue}break}break j}vq(f+8|0,d);pd(f,b,v[f+8>>2],v[f+12>>2])}hb=f+16|0;e=gc(d);d=Db(d);k=_b(v[g+56>>2]);v[i>>2]=k;m=h+484384|0;j=_b(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[m>>2]=j;p=h+484388|0;q=_b(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+j|0;v[p>>2]=q;f=h+484414|0;if(j){e=x[f>>1];break f}e=x[f>>1];if(_b(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>=3){break f}d=e&-3;break e}d=Cb(v[Sb(v[a+484360>>2],w[e|0])>>2]);f=Cb(v[Sb(v[a+484360>>2],w[e|0])+4>>2]);e=hb-16|0;hb=e;k:{if(!Nb(d,f)){break k}v[e+8>>2]=d;while(1){h=v[Qe(e+8|0)>>2];if(!Nb(h,f)){break k}d=xk(x[d>>1],x[h>>1])?h:d;continue}}hb=e+16|0;d=x[d>>1];v[23516]=0;n=a+484344|0;p=d+1&65535;R(224,n|0,p|0);d=v[23516];v[23516]=0;if((d|0)!=1){d=w[g+83|0];v[g+24>>2]=v[a+480204>>2];v[g+20>>2]=v[a+480196>>2];o=d>>>0<4?4:5;q=c&1;k=a+480188|0;h=0;while(1){if((h|0)==(p|0)){if(!(c&2)){break g}d=1;c=a+480190|0;while(1){e=d&65535;if(e>>>0>x[c>>1]){break g}e=B(e,104)+a|0;f=Uc(g+8|0,u[e+484414>>1]&1?16:8,1,1,0);v[23516]=0;W(218,f|0,e+484380|0,b|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){d=d+1|0;continue}break}d=P()|0;O()|0;break h}l:{if(!q){break l}d=x[g+278>>1];e=v[b+8>>2];f=x[k>>1];i=v[b>>2];v[23516]=0;d=W(154,i|0,e|0,B(f,B(Eb(d),o))|0)|0;e=v[23516];v[23516]=0;m:{n:{if((e|0)==1){break n}if(!d){break l}d=x[g+278>>1];v[23516]=0;d=W(225,n|0,h&65535,Eb(d)|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break n}if(!d){break l}d=x[k>>1];t[g+19|0]=0;e=ae(g+8|0,0,g+19|0);v[23516]=0;i=W(370,g+32|0,d|0,e|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break m}e=0;o:while(1){if(Eb(x[g+278>>1])>>>0<=e>>>0){gd(i);break l}d=0;f=Xb(v[n>>2],h);r=xf(v[f>>2],v[v[f+48>>2]+12>>2],e);while(1){if(x[k>>1]<=d>>>0){e=e+1|0;continue o}t[g+12|0]=0;v[g+8>>2]=0;v[23516]=0;U(371,b|0,g+8|0,o|0);f=v[23516];v[23516]=0;p:{if((f|0)==1){break p}l=B(d,6)+r|0;f=w[g+8|0];if((f-24&255)>>>0<=59){f=f+13|0;t[l|0]=f;s=$b(v[i>>2],d),y=f,t[s|0]=y}m=w[g+9|0];q:{if(!m){f=$b(v[i>>2],d);break q}t[l+1|0]=m;f=$b(v[i>>2],d);t[f+1|0]=m}m=w[f+1|0];f=w[f|0];v[23516]=0;Da(372,a|0,l|0,w[g+10|0],w[g+11|0],0-w[g+83|0]|0,f|0,m|0,g+24|0,g+20|0);f=v[23516];v[23516]=0;if((f|0)==1){break p}if(w[g+12|0]){t[l+2|0]=1;t[l+4|0]=w[g+12|0]+1>>>2}d=d+1|0;continue}break}break}d=P()|0;O()|0;gd(i);break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}h=h+1|0;continue}}d=P()|0;O()|0}yb(j);break c}yb(j);break b}d=e|2}u[f>>1]=d;if((n|0)==2){u[f>>1]=d|1;v[i>>2]=k>>>1;v[m>>2]=j>>>1;v[p>>2]=q>>>1}s=h+484410|0,y=Ej(b),u[s>>1]=y;d=XA(b);if(d){sl(i,+(d|0)/96)}t[h+484417|0]=d<<4;l=l+1|0;d=x[o>>1];continue}}d=P()|0;O()|0;ac(g+32|0)}S(d|0);L()}d=1}hb=g+288|0;return d|0}function dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;i=hb-208|0;hb=i;xc(b);a:{if(!$A(b,i+160|0)){break a}if(!LP(i+160|0)){break a}b:{if(!c){break b}if(!Ob(v[b>>2],v[b+8>>2],Bc(KP(w[i+207|0]),kb))){break a}zd(a,128);d=i+144|0;Ke(d,2,i+175|0);h=i+72|0;Cc(h,d);yc(a+1298308|0,h);wb(h);e=vc(h,8482);Gb(a+1298344|0,e);xb(e);e=vc(h,6059);Gb(a+1298356|0,e);xb(e);e=vc(d,17637);v[23516]=0;U(742,h|0,e|0,v[(w[i+174|0]<<2)+27036>>2]);h=v[23516];v[23516]=0;c:{if((h|0)!=1){h=i+72|0;Gb(a+1298368|0,h);xb(h);xb(e);v[a+480208>>2]=12;v[a+1298404>>2]=5;rB(a+1298332|0,b,w[i+207|0]<<5,32,0);l=a+480190|0;d=Je(b);u[l>>1]=d;h=1;while(1){j=h&65535;if(j>>>0>(d&65535)>>>0){ko(Sb(v[a+484360>>2],w[a+484376|0]),b,256,255,254);h=0;d=Je(b);if(d>>>0>=127){break a}g=a+480188|0;u[g>>1]=d+1;e=Je(b);while(1)if(x[g>>1]<=h>>>0){o=a+484344|0;q=e+1|0;vg(o,q);d=0;while(1){d:{g=d&65535;if(g>>>0>e>>>0){r=a+480188|0;e:while(1){y=s&65535;h=x[r>>1];if(y>>>0>=h>>>0){e=Xn(i+8|0);t[e+16|0]=0;u[e+14>>1]=0;u[e+12>>1]=h;v[23516]=0;R(744,e|0,h|0);h=v[23516];v[23516]=0;if((h|0)==1){a=P()|0;O()|0;Ue(e);S(a|0);L()}v[23516]=0;U(743,i+32|0,o|0,e|0);d=v[23516];v[23516]=0;h=1;if((d|0)==1){break d}Ue(i+32|0);Ue(e);if(!(c&2)){break a}c=a+480190|0;while(1){d=h&65535;if(d>>>0>x[c>>1]){break b}d=B(d,104)+a|0;ug(Uc(i+72|0,u[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);h=h+1|0;continue}}n=0;e=sg(i+72|0);f:while(1){g:{if((n|0)!=(q|0)){if(Ob(v[b>>2],v[b+8>>2],5)){break g}}s=s+1|0;continue e}d=0;h=Xb(v[o>>2],n);h=ed(v[h>>2],v[v[h+48>>2]+12>>2],0,y);while(1){h:{i:{if(d>>>0>63){break i}l=w[i+174|0];g=hb-32|0;hb=g;p=1;f=Je(b);if((f|0)==252){p=Je(b);f=Je(b)}t[e|0]=(f-1&255)>>>0<60?f+36|0:0;f=g+24|0;Km(f,b);k=Kc(f);j=Re(f);f=Ji(f);t[e+1|0]=w[g+24|0];m=g+16|0;IP(m,w[k|0]&15,w[j|0],l);j=Kc(m);m=g+8|0;IP(m,w[k|0]>>>4|0,w[f|0],l);l=Kc(m);f=w[g+16|0];m=(f|0)!=10;k=w[g+8|0];j:{if(!(m|(k|0)!=10)){j=w[j|0];f=w[l|0];t[e+3|0]=10;j=j|f<<8;t[e+5|0]=j>>>6;if(j>>>0<16384){break j}t[e+2|0]=15;t[e+4|0]=f>>>6;break j}k:{l:{m:{n:{o:{if(!m){k=w[j|0];m=k<<2;z=j,A=Bl(m),t[z|0]=A;if(k>>>0<64){break o}f=w[g+8|0];if(Hi(f)>>>0>=zz(10)>>>0){break n}t[e+5|0]=m;t[e+2|0]=15;t[e+3|0]=10;t[e+4|0]=k>>>6;break j}if((k|0)==10){f=w[l|0];k=f<<2;z=l,A=Bl(k),t[z|0]=A;if(f>>>0<64){break o}if(Hi(w[g+16|0])>>>0>=zz(10)>>>0){break o}t[e+5|0]=k;t[e+2|0]=15;t[e+3|0]=10;t[e+4|0]=f>>>6;break j}if((f|0)!=(k|0)){break o}t[g+8|0]=0;break m}f=w[g+8|0]}if((f|0)==13){break l}if(f){break k}f=w[g+16|0]}if((f|0)==13){break k}}Bh(g+16|0,g+8|0);Bh(j,l)}Hu(g+8|0,l,g+16|0,j);to(g,e,w[g+16|0],w[j|0],w[g+8|0],w[l|0])}hb=g+32|0;f=d+p|0;d=f>>>0>64?64-d|0:p;if(!d){break i}while(1){if(!d){break h}g=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[h|0]=g;t[h+1|0]=g>>>8;t[h+2|0]=g>>>16;t[h+3|0]=g>>>24;g=w[e+4|0]|w[e+5|0]<<8;t[h+4|0]=g;t[h+5|0]=g>>>8;d=d-1|0;h=B(x[r>>1],6)+h|0;continue}}n=n+1|0;continue f}d=f>>>0<64?f:64;continue}}}}d=d+1|0;h=0;if(kh(o,g,64)){continue}break a}break}d=P()|0;O()|0;Ue(e);break c}else{d=(h<<5)+a|0;af(d+480280|0);d=d+480284|0;p:{if(w[i+174|0]>=51){f=(Je(b)<<4|8)&248;break p}f=h&1?192:64}u[d>>1]=f;h=h+1|0;continue}}else{q:{if(w[i+174|0]>=52){d=i+72|0;if(!AU(b,d)){uB(d)}break q}e=hb-32|0;hb=e;v[e+28>>2]=64;v[e+8>>2]=66;f=v[b>>2];g=v[b+8>>2];d=v[Hb(e+28|0,e+8|0)>>2];if(!Ob(f,g,d)){d=$e(b)}f=e+8|0;n=i+72|0;ru(f,n);g=fc(e+16|0,v[e+8>>2],d);jc(e,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);ru(f,n);Rb(v[e+8>>2]+d|0,0,66-d|0);Yb(b,v[e+28>>2]);hb=e+32|0;u[i+136>>1]=x[i+134>>1];u[i+134>>1]=8363}g=hb-32|0;hb=g;e=(B(j,104)+a|0)+484380|0;jd(e,0);lo(e);d=i+72|0;ok(g,2,d+32|0);f=g+16|0;Cc(f,g);xe(e+43|0,f);wb(f);f=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);n=w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24);r:{if(f>>>0<=n>>>0){break r}v[e>>2]=f-n;v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[g+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);z=e,A=v[Hb(g+16|0,e)>>2],v[z+16>>2]=A;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=w[d+64|0]|w[d+65|0]<<8;if(f){sl(e,+(f<<16>>16)/393216)}f=w[d+61|0];if(f&8){u[e+34>>1]=x[e+34>>1]|8;f=w[d+61|0]}if(f&16){u[e+34>>1]=x[e+34>>1]|16;f=w[d+61|0]}if(!(f&4)){break r}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}hb=g+32|0;e=i+56|0;Ke(e,2,d);d=i+144|0;Cc(d,e);Ac(((j<<5)+a|0)+946304|0,d);h=h+1|0;wb(d);d=x[l>>1];continue}}}d=P()|0;O()|0;xb(e)}S(d|0);L()}h=1}hb=i+208|0;return h|0}function qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=hb-144|0;hb=d;xc(c);a:{b:{c:{d:{if(!mo(c,d+128|0)){break d}if(Qb(d+128|0,13901,4)){break d}g=d+136|0;e:{if(!Qb(g,13547,4)){break e}if(!Qb(g,13605,4)){break e}if(Qb(g,14336,4)){break d}}e=hb-32|0;hb=e;l=Lb(d+112|0);f:{g:{h:{i:{j:{while(1){k=v[c+8>>2];h=v[c>>2];v[23516]=0;k=W(154,h|0,k|0,8)|0;h=v[23516];v[23516]=0;if((h|0)==1){break h}if(!k){break i}v[23516]=0;R(811,e|0,c|0);k=v[23516];v[23516]=0;if((k|0)!=1){v[23516]=0;R(812,l|0,e|0);k=v[23516];v[23516]=0;if((k|0)==1){break j}yd(e);continue}break}a=P()|0;O()|0;break g}a=P()|0;O()|0;yd(e);break g}hb=e+32|0;break f}a=P()|0;O()|0}Ud(l);S(a|0);L()}v[23516]=0;k=T(172,d+88|0)|0;c=v[23516];v[23516]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c|0)!=1){l=Uc(d+80|0,8,1,1,0);if(Qb(g,14336,4)){break t}v[23516]=0;U(727,d+56|0,d+112|0,1296581714);c=v[23516];v[23516]=0;if((c|0)==1){break q}v[23516]=0;U(727,d+32|0,d+112|0,1296318804);c=v[23516];v[23516]=0;if((c|0)==1){break c}c=d+32|0;e=cd(k,c);yb(c);c=0;v[23516]=0;g=T(728,d+56|0)|0;i=v[23516];v[23516]=0;f=1;if((i|0)==1){break c}i=0;if(!g){break u}e=v[e>>2];v[23516]=0;e=T(176,e|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break c}i=0;if(!e){break u}v[23516]=0;i=T(282,d+56|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}v[23516]=0;g=T(274,d+56|0)|0;c=v[23516];v[23516]=0;w:{if((c|0)==1){break w}v[23516]=0;Q(186,d+56|0,2)|0;c=v[23516];v[23516]=0;if((c|0)==1){break w}v[23516]=0;c=T(282,d+56|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break v}}break c}f=P()|0;O()|0;break a}v[23516]=0;R(640,d+32|0,d+56|0);e=v[23516];v[23516]=0;if((e|0)==1){break c}e=KT(d+32|0);j=Eb(x[d+32>>1]);if(!j){break u}c=(c>>>0)/(j>>>0)|0;f=d+32|0;j=gc(f);h=Re(f);f=1;j=Eb(w[j|0]|w[j+1|0]<<8);if((j|0)!=(Eb(w[h|0]|w[h+1|0]<<8)+1|0)){break u}if((j|0)==2){Eo(l,2)}x:{if((g|0)!=16){if((g|0)!=8){break u}y:{switch(Eb(w[e|0]|w[e+1|0]<<8)|0){case 0:cg(l,1);break x;case 2:cg(l,17);break x;case 3:break y;default:break u}}cg(l,16);break x}if(Eb(w[e|0]|w[e+1|0]<<8)){break u}nd(l,16)}f=0}yb(d+56|0);j=0;if(!f){break s}f=0;break k}v[23516]=0;U(727,d+56|0,d+112|0,1447576658);c=v[23516];v[23516]=0;z:{A:{if((c|0)!=1){v[23516]=0;U(727,d+32|0,d+112|0,1128808782);c=v[23516];v[23516]=0;if((c|0)==1){break A}v[23516]=0;U(727,d+8|0,d+112|0,1112491097);c=v[23516];v[23516]=0;if((c|0)==1){break m}c=d+8|0;h=cd(k,c);yb(c);c=v[h>>2];v[23516]=0;m=T(176,c|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break z}c=0;e=0;B:{if(!m){break B}v[23516]=0;m=T(176,v[d+56>>2])|0;c=v[23516];v[23516]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}v[23516]=0;m=Q(729,d+56|0,d+8|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}c=Qb(g,13547,4);v[23516]=0;e=T(282,d+32|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break m}if(c){p=l,q=v[Uc(d,16,1,0,0)>>2],v[p>>2]=q}if((e|0)==6){Eo(l,3)}i=v[h>>2];v[23516]=0;g=v[d+24>>2];h=x[d+20>>1];n=v[d+12>>2];m=v[d+8>>2];i=T(158,i|0)|0;j=v[23516];v[23516]=0;o=1;if((j|0)==1){break m}e=B((e|0)==6?2:1,c?2:1);i=(i>>>0)/(e>>>0)|0;j=_b(g);c=Eb(h);n=(_b(n)>>>0)/(e>>>0)|0;e=(_b(m)>>>0)/(e>>>0)|0}yb(d+32|0);yb(d+56|0);if(o){break r}break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;break l}break m}e=0}bt(a,b);v[23516]=0;f=B(b,104)+a|0;g=f+484380|0;R(280,g|0,0);h=v[23516];v[23516]=0;if((h|0)==1){break p}v[g>>2]=i;h=e+n|0;v[f+484388>>2]=h;v[f+484384>>2]=e;if(!(h>>>0<=e+4>>>0|h>>>0>i>>>0)){e=(B(b,104)+a|0)+484414|0;u[e>>1]=x[e>>1]|2}e=B(b,104)+a|0;v[e+484404>>2]=c?c:22050;c=j>>>8|0;u[e+484410>>1]=(j&16776960)>>>0>65536?256:c&65535?c:256;tz(g,v[a+480180>>2]);v[23516]=0;U(727,d+56|0,d+112|0,1312902469);c=v[23516];v[23516]=0;if((c|0)==1){break o}v[23516]=0;c=T(176,v[d+56>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break n}C:{D:{if(c){v[23516]=0;c=T(158,v[d+56>>2])|0;e=v[23516];v[23516]=0;if((e|0)==1){break n}v[23516]=0;U(330,d+56|0,((b<<5)+a|0)+946304|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break D}break n}v[23516]=0;c=Q(53,d+32|0,21751)|0;e=v[23516];v[23516]=0;if((e|0)==1){break C}Ac(((b<<5)+a|0)+946304|0,c);wb(c)}v[23516]=0;W(218,l|0,g|0,k|0)|0;b=v[23516];v[23516]=0;f=1;if((b|0)==1){break n}rj(g,a);yb(d+56|0);break k}break n}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;yb(d+56|0);break b}f=P()|0;O()|0;yb(d+32|0)}yb(d+56|0);break b}yb(k);Ud(d+112|0)}hb=d+144|0;return f|0}f=P()|0;O()|0;yb(d+56|0)}yb(k)}Ud(d+112|0);S(f|0);L()}function Fd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=hb-96|0;hb=k;t=h;u=i&65535;m=(e^i)&-2147483648;l=e&65535;p=l;A=l;K=i>>>16&32767;L=e>>>16&32767;a:{b:{if(K-32767>>>0>4294934529&L-32767>>>0>=4294934530){break b}l=e&2147483647;j=d;if(!(!d&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){o=d;m=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;m=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(f|h|(e|g))){m=2147450880;b=0;c=0;break a}m=m|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|l;b=0;c=0;if(!(d|e)){m=2147450880;break a}m=m|2147418112;break a}if(!(b|j|(c|l))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){j=b;h=!(d|p);i=h<<6;l=E(h?b:d)+32|0;b=E(h?c:p);b=i+((b|0)==32?l:b)|0;Hf(k+80|0,j,c,d,p,b-15|0);s=16-b|0;d=v[k+88>>2];A=v[k+92>>2];c=v[k+84>>2];b=v[k+80>>2]}if(e>>>0>65535){break b}e=!(t|u);h=e<<6;i=E(e?f:t)+32|0;e=E(e?g:u);e=h+((e|0)==32?i:e)|0;Hf(k- -64|0,f,g,t,u,e-15|0);s=(s-e|0)+16|0;t=v[k+72>>2];u=v[k+76>>2];f=v[k+64>>2];g=v[k+68>>2]}e=f;j=g<<15|e>>>17;h=e<<15;e=j;p=h&-32768;q=c;B=rka(p,0,c,0);c=kb;x=c;C=e;i=0;j=rka(e,0,b,i);e=j+B|0;h=kb+c|0;h=e>>>0<j>>>0?h+1|0:h;c=e;j=e;n=rka(b,i,p,i);l=0+n|0;e=kb+e|0;e=l>>>0<n>>>0?e+1|0:e;y=l;n=l;l=e;D=(j|0)==(e|0)&r>>>0>n>>>0|e>>>0<j>>>0;r=d;M=rka(p,i,d,0);H=kb;e=rka(q,i,C,i);d=e+M|0;j=kb+H|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=t;j=u<<15|e>>>17;z=e<<15|g>>>17;g=j;j=rka(z,0,b,i);e=j+n|0;f=kb+d|0;I=e;f=e>>>0<j>>>0?f+1|0:f;u=f;e=f;f=(h|0)==(x|0)&c>>>0<B>>>0|h>>>0<x>>>0;c=h+I|0;f=e+f|0;B=c;f=c>>>0<h>>>0?f+1|0:f;t=f;c=f;F=A|65536;A=w;N=rka(p,i,F,w);J=kb;h=rka(r,o,C,i);f=h+N|0;e=kb+J|0;O=f;e=f>>>0<h>>>0?e+1|0:e;w=e;G=g|-2147483648;x=0;g=rka(G,x,b,i);b=g+f|0;f=kb+e|0;f=b>>>0<g>>>0?f+1|0:f;P=b;e=rka(z,o,q,i);b=b+e|0;p=f;j=f+kb|0;Q=b;g=b>>>0<e>>>0?j+1|0:j;f=0;b=f+B|0;e=c+Q|0;e=b>>>0<f>>>0?e+1|0:e;R=b;c=b;b=b+D|0;D=e;f=b>>>0<c>>>0?e+1|0:e;c=f;s=((L+K|0)+s|0)-16383|0;j=rka(G,x,q,i);h=kb;i=rka(F,A,C,i);e=i+j|0;f=kb+h|0;f=e>>>0<i>>>0?f+1|0:f;i=(f|0)==(h|0)&e>>>0<j>>>0|f>>>0<h>>>0;h=e;q=i;i=rka(z,o,r,o);e=i+e|0;j=kb+f|0;j=e>>>0<i>>>0?j+1|0:j;i=(f|0)==(j|0)&e>>>0<h>>>0|f>>>0>j>>>0;f=q+i|0;h=0;h=f>>>0<i>>>0?1:h;q=rka(G,x,F,A);i=q+f|0;f=kb+h|0;f=i>>>0<q>>>0?f+1|0:f;q=e;h=j;C=i;e=(d|0)==(u|0)&n>>>0>I>>>0|d>>>0>u>>>0;d=e+((d|0)==(H|0)&n>>>0<M>>>0|d>>>0<H>>>0)|0;j=0;j=d>>>0<e>>>0?1:j;i=d;d=q+d|0;e=h+j|0;e=d>>>0<i>>>0?e+1|0:e;n=d;i=e;e=(e|0)==(h|0)&d>>>0<q>>>0|e>>>0<h>>>0;d=C+e|0;h=d>>>0<e>>>0?f+1|0:f;q=d;j=rka(z,o,F,A);e=kb;r=rka(G,x,r,o);d=r+j|0;f=kb+e|0;f=d>>>0<r>>>0?f+1|0:f;r=d;d=f;f=(e|0)==(f|0)&j>>>0>r>>>0|e>>>0>f>>>0;z=d+q|0;e=f+h|0;e=d>>>0>z>>>0?e+1|0:e;h=0;d=h+n|0;f=i+r|0;f=d>>>0<h>>>0?f+1|0:f;h=f;j=(i|0)==(f|0)&d>>>0<n>>>0|f>>>0<i>>>0;i=j+z|0;n=i;i=i>>>0<j>>>0?e+1|0:e;r=d;e=d;d=h;j=(p|0)==(w|0)&O>>>0>P>>>0|p>>>0<w>>>0;f=j+((w|0)==(J|0)&O>>>0<N>>>0|w>>>0<J>>>0)|0;h=0;j=f+((g|0)==(p|0)&P>>>0>Q>>>0|g>>>0<p>>>0)|0;f=g+e|0;e=d+j|0;e=f>>>0<g>>>0?e+1|0:e;g=f;h=(d|0)==(e|0)&f>>>0<r>>>0|d>>>0>e>>>0;d=h+n|0;f=i;f=d>>>0<h>>>0?f+1|0:f;h=e;n=d;i=(t|0)==(D|0)&B>>>0>R>>>0|t>>>0>D>>>0;d=i+((t|0)==(u|0)&B>>>0<I>>>0|t>>>0<u>>>0)|0;j=0;j=d>>>0<i>>>0?1:j;i=d;d=d+g|0;e=e+j|0;e=d>>>0<i>>>0?e+1|0:e;h=(e|0)==(h|0)&d>>>0<g>>>0|e>>>0<h>>>0;g=n+h|0;f=g>>>0<h>>>0?f+1|0:f;h=g;i=f;c:{if(f&65536){s=s+1|0;break c}w=l>>>31|0;f=i<<1|h>>>31;h=g<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;g=y;f=l<<1|g>>>31;y=g<<1;l=f;f=c<<1|b>>>31;b=b<<1|w;c=f}if((s|0)>=32767){m=m|2147418112;b=0;c=0;break a}d:{if((s|0)<=0){f=1-s|0;if(f>>>0>=128){b=0;c=0;break a}g=s+127|0;Hf(k+48|0,y,l,b,c,g);Hf(k+32|0,d,e,h,i,g);vm(k+16|0,y,l,b,c,f);vm(k,d,e,h,i,f);y=v[k+32>>2]|v[k+16>>2]|(v[k+48>>2]|v[k+56>>2]|(v[k+52>>2]|v[k+60>>2]))!=0;l=v[k+36>>2]|v[k+20>>2];b=v[k+40>>2]|v[k+24>>2];c=v[k+44>>2]|v[k+28>>2];d=v[k>>2];e=v[k+4>>2];f=v[k+8>>2];g=v[k+12>>2];break d}f=h;g=i&65535|s<<16}o=f|o;m=g|m;if(!(!b&(c|0)==-2147483648?!(l|y):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;c=j;f=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=f+o|0;e=m;o=d;m=d>>>0<f>>>0?e+1|0:e;break a}if(b|y|(c^-2147483648|l)){b=d;c=e;break a}j=m;c=d&1;b=c+d|0;f=b>>>0<c>>>0?e+1|0:e;c=f;e=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;d=e+o|0;o=d;m=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=m;hb=k+96|0}function Dfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=hb-144|0;hb=g;xc(b);a:{b:{c:{d:{e:{if(!mR(b,14222)){break e}k=Lb(g+128|0);j=Lb(g+112|0);v[23516]=0;v[g+104>>2]=0;v[g+108>>2]=0;R(248,a|0,32768);d=v[23516];v[23516]=0;if((d|0)==1){break b}v[23516]=0;d=Q(1,g+88|0,8198)|0;i=v[23516];v[23516]=0;if((i|0)==1){break c}Gb(a+1298344|0,d);xb(d);v[23516]=0;d=Q(1,g+72|0,6063)|0;i=v[23516];v[23516]=0;if((i|0)==1){break d}Gb(a+1298356|0,d);xb(d);v[a+1298404>>2]=14;m=a+484376|0;i=a+480280|0;while(1){d=v[b+8>>2];f=v[b>>2];v[23516]=0;d=W(154,f|0,d|0,8)|0;f=v[23516];v[23516]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}v[23516]=0;d=Q(639,b|0,g- -64|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break m}if(!d){break n}d=v[g+68>>2];v[23516]=0;U(188,g+16|0,b|0,_b(d)|0);d=v[23516];v[23516]=0;if((d|0)==1){break l}d=g+16|0;f=hc(g+40|0,d);yb(d);d=v[f>>2];v[23516]=0;d=T(176,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break j}if(d){break k}yb(f)}if(x[a+480188>>1]){break i}i=0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=_b(v[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(x[a+480188>>1]){break f}d=v[f>>2];v[23516]=0;d=T(158,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;v[23516]=0;R(640,g+16|0,f|0);e=v[23516];v[23516]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{e=x[a+480188>>1];h=$b(g+16|0,d);v:{if(!Eb(w[h|0]|w[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+104|0;o=Ib(h,e),p=1,t[o|0]=p;o=Ib(h,x[a+480188>>1]+1|0),p=255,t[o|0]=p;af(i+(x[a+480188>>1]<<5)|0);h=x[a+480188>>1];e=h+1|0;u[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;u[l+4>>1]=h>>>0<2?192:64}af(i+((e&65535)<<5)|0);e=x[a+480188>>1];u[a+480188>>1]=e+1;u[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(x[a+480190>>1]){break f}v[23516]=0;R(641,f|0,a|0);d=v[23516];v[23516]=0;if((d|0)!=1){break f}break j}d=v[f>>2];v[23516]=0;d=T(158,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[23516]=0;d=T(274,f|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break j}o=a,p=Bd(d,1,255),v[o+480196>>2]=p;break f}d=v[f>>2];v[23516]=0;d=T(158,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[23516]=0;n=T(274,f|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break f}break j}d=w[m|0];e=v[a+484360>>2];h=v[f>>2];v[23516]=0;h=T(158,h|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break j}v[23516]=0;da(347,Sb(e,d)|0,f|0,h|0,255,254);d=v[23516];v[23516]=0;if((d|0)==1){break j}break f}d=k;if(wf(v[d>>2],v[d+4>>2])>>>0>=256){break f}break q}if(wf(v[j>>2],v[j+4>>2])>>>0>3998){break f}d=v[f>>2];v[23516]=0;e=T(158,d|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break j}d=j;if(!e){break f}}v[23516]=0;R(642,d|0,f|0);d=v[23516];v[23516]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}yb(f);break g}a=P()|0;O()|0;yb(f);break a}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=w[a+484376|0];d=v[a+484360>>2];v[23516]=0;R(329,Sb(d,b)|0,n&65535);b=v[23516];v[23516]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=v[k+4>>2];i=v[k>>2];d=0;v[23516]=0;R(224,a+484344|0,wf(i,b)&65535);b=v[23516];v[23516]=0;if((b|0)==1){break b}while(1){f=v[k>>2];b=d&65535;if(wf(f,v[k+4>>2])>>>0<=b>>>0){break w}v[23516]=0;i=v[g+108>>2];e=v[g+104>>2];v[g+8>>2]=e;v[g+12>>2]=i;v[g>>2]=e;v[g+4>>2]=i;X(643,Kg(f,b)|0,b|0,a|0,g|0);b=v[23516];v[23516]=0;if((b|0)!=1){d=d+1|0;continue}break}a=P()|0;O()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(x[a+480190>>1]<=d>>>0){break g}if(!f|wf(v[j>>2],v[j+4>>2])>>>0<=b>>>0){break g}c=(B(d,104)+a|0)+484380|0;Fo(c);x:{if(v[c>>2]){e=v[Kg(v[j>>2],b)>>2];v[23516]=0;e=T(158,e|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break h}uc(c,e);e=Uc(g+40|0,8,1,1,0);h=v[j>>2];v[23516]=0;W(218,e|0,c|0,Kg(h,b)|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Nc(j);Nc(k);break e}yb(f);continue}}hb=g+144|0;return i|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Nc(j);Nc(k);S(a|0);L()}function SM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=hb-16|0;hb=h;a:{if(!Wc(d&255)){break a}m=a+1074376|0;j=(m+B(b,872)|0)+616|0;b:{g=x[a+480192>>1];if(!(e?1:!(v[a+480180>>2]&17825824)|!g)){break b}if(lj(v[j+656>>2])){break b}c=B(b,872)+a|0;d=c+1075068|0;if(!v[d>>2]){break a}c=v[c+1075080>>2];if(c&1024){break a}e=B(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(v[g>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=v[a+1298300>>2];if(!vd(c)){break c}nj(c,b,0);break a}c=zy(a,b);if((c|0)==65535){break a}i=B(c,872);c=a+1074992|0;a=i+c|0;Mp(a,j);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;Zn(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=c+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[g>>2]=0;v[e>>2]=0;break a}e=B(b,872)+a|0;k=v[e+1075096>>2];c=c>>>0>g>>>0?0:c;g=v[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}l=d-1|0;c=x[$b(g+236|0,l)>>1];f=a+1074312|0;Ab(h+8|0,f,104);e:{if(zb(v[v[h+8>>2]>>2],v[h+12>>2])){Ab(h,f,34);if(zb(v[v[h>>2]>>2],v[h+4>>2])){break e}}d=w[Ib(g+108|0,l)|0]}if((c-1&65535)>>>0<=3998){k=(B(c,104)+a|0)+484380|0;break d}Ab(h+8|0,f,43);if(!zb(v[v[h+8>>2]>>2],v[h+12>>2])){break d}if(!sj(w[g+31|0])){break a}}if(w[e+1075081|0]&4){break a}o=b>>>0>256?b:256;l=a+1074312|0;p=b+1|0;q=a+480188|0;c=b;f:{while(1){if((c|0)==(o|0)){g:{e=0;c=0;if(!lj(v[j+656>>2])){break f}c=0;if(!Wc(w[(B(b,872)+a|0)+1075789|0])){break f}d=Fl(a,m,b,2,1)-1|0;c=0;if((d&255)>>>0>249){break f}e=v[Id(a+906300|0,d)>>2];if(e){break g}e=0;c=0;break f}}else{h:{if((b|0)!=(c|0)&x[q>>1]>c>>>0){break h}e=B(c,872)+a|0;if(x[e+1075778>>1]!=(p|0)&(b|0)!=(c|0)){break h}n=e+1075648|0;f=v[n>>2];if(!f){break h}i:{j:{k:{l:{m:{n:{o:{switch(w[f+17|0]-1|0){case 0:if(!d){break h}i=w[e+1075789|0]==(d|0)&(f|0)==(g|0);if(!g){break n}if(i){break k}break h;case 1:if(!k|v[e+1075096>>2]!=(k|0)){break h}if((f|0)==(g|0)){break i}Ab(h+8|0,l,104);if(!zb(v[v[h+8>>2]>>2],v[h+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(g){break l}i=(f|0)==(g|0)}if(i){break i}break h}if(!g){break h}i=w[g+34|0];if(!i){break h}if((i|0)==w[f+34|0]){break j}break h}if((f|0)!=(g|0)){break h}}if(!w[g+34|0]){break i}}if(!w[e+1075789|0]|w[f+18|0]>2){break i}jm(a,c&65535,w[e+1075793|0]|256,0)}f=e+1074992|0;p:{q:{switch(w[v[n>>2]+18|0]){case 0:Kn(a,f);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break p}f=v[a+1298300>>2];if(!vd(f)){break p}nj(f,c&65535,1);break p;case 1:Kn(a,f);if(!(w[e+1075081|0]&2)){break p}f=v[a+1298300>>2];if(!vd(f)){break p}fk(f,c&65535);break p;case 2:break q;default:break p}}i=e+1075080|0;f=v[i>>2];v[i>>2]=f|4096;if(!(f&512)){break p}if(!vd(v[a+1298300>>2])){break p}Ab(h+8|0,l,105);if(zb(v[v[h+8>>2]>>2],v[h+12>>2])){break p}fk(v[a+1298300>>2],c&65535)}if(v[e+1075680>>2]){break h}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;continue}break}c=lb[v[v[e>>2]+104>>2]](e,w[(B(b,872)+a|0)+1075793|0],b)|0}if(!(zi(v[j+8>>2],v[j+12>>2])?1:c)){break a}g=zy(a,b);if((g|0)==65535){break a}f=B(g,872)+a|0;d=f+1075080|0;k=f+1074992|0;r:{if(!(w[f+1075081|0]&2)){break r}i=v[a+1298300>>2];if(!vd(i)){break r}nj(i,g,1)}k=Mp(k,j);v[d>>2]=v[d>>2]&-917505;t[f+1075823|0]=0;i=x[a+480188>>1];t[f+1075797|0]=0;u[f+1075778>>1]=b>>>0<i>>>0?b+1|0:0;s:{if(!(c&(e|0)!=0)){break s}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break s}jm(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}t:{u:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:Kn(a,k);if(!(w[d+1|0]&2)){break t}c=v[a+1298300>>2];if(!vd(c)){break t}fk(c,b);Ab(h+8|0,l,105);if(!zb(v[v[h+8>>2]>>2],v[h+12>>2])){break t}iz(v[a+1298300>>2],b,g);break t;case 0:v[(B(g,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}c=v[a+1298300>>2];if(!vd(c)){break t}nj(c,b,1);break t;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}if(!vd(v[a+1298300>>2])){break t}Ab(h+8|0,l,105);c=v[a+1298300>>2];if(zb(v[v[h+8>>2]>>2],v[h+12>>2])){iz(c,b,g);break t}fk(c,b);break t;case 1:break u;default:break t}}if(!(w[d+1|0]&2)){break t}c=v[a+1298300>>2];if(!vd(c)){break t}iz(c,b,g)}if(!v[(B(g,872)+a|0)+1075680>>2]){v[(B(g,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}hb=h+16|0}function VV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-112|0;hb=f;xc(b);a:{if(!Kq(b,11810)){break a}if(!Mu(b,f+96|0)){break a}if(!dC(w[f+97|0])){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(cC(f+96|0),kb))){break a}if(!Yb(b,w[f+105|0]|w[f+106|0]<<8)){break a}b:{if(!c){break b}zd(a,4096);v[a+480208>>2]=12;u[a+480188>>1]=(w[f+98|0]&31)+1;e=a+480190|0;u[e>>1]=w[f+99|0];jh(a,1);d=f+24|0;i=vc(d,8505);Gb(a+1298344|0,i);xb(i);i=vc(d,7053);Gb(a+1298356|0,i);xb(i);i=hb-16|0;hb=i;g=vc(i,4250);Xc(f,g);xb(g);hb=i+16|0;v[23516]=0;X(231,d|0,f|0,w[f+97|0],f+96|0);d=v[23516];v[23516]=0;c:{if((d|0)!=1){d=f+24|0;Gb(a+1298368|0,d);xb(d);ac(f);v[a+1298404>>2]=5;d=w[f+99|0];i=f+80|0;v[i>>2]=0;v[i+4>>2]=0;vj(i+8|0,0);if(d){Rq(i,d);PC(i,d,0)}d=1;d:{while(1){g=d&65535;if(g>>>0>x[e>>1]){v[23516]=0;Q(232,b|0,a+1298308|0)|0;g=v[23516];v[23516]=0;d=1;e:{if((g|0)==1){break e}g=a+480190|0;while(1){e=d&65535;if(e>>>0>x[g>>1]){d=0;g=a+480188|0;f:{while(1){if(x[g>>1]<=d>>>0){d=0;v[23516]=0;g=a+484344|0;R(224,g|0,x[f+100>>1]);e=v[23516];v[23516]=0;if((e|0)==1){break e}break f}e=(d<<5)+a|0;af(e+480280|0);v[23516]=0;R(233,b|0,e+480289|0);e=v[23516];v[23516]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}g:{h:{i:{j:{while(1){if(x[f+100>>1]<=d>>>0){v[23516]=0;e=T(192,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break h}if(!e){break i}d=v[b+8>>2];g=v[b>>2];v[23516]=0;d=W(154,g|0,d|0,e|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break h}if(d){break j}break i}v[23516]=0;e=Q(234,b|0,f+24|0)|0;h=v[23516];v[23516]=0;k:{if((h|0)==1){break k}v[23516]=0;h=W(225,g|0,d&65535,64)|0;j=v[23516];v[23516]=0;if((j|0)==1){break k}if((e&h)==1){e=v[g>>2];v[23516]=0;R(235,Xb(e,d)|0,f+24|0);e=v[23516];v[23516]=0;if((e|0)==1){break k}}d=d+1|0;continue}break}b=P()|0;O()|0;break d}g=Lb(f+24|0);v[23516]=0;U(236,b|0,g|0,e|0);d=v[23516];v[23516]=0;l:{if((d|0)!=1){d=Kb(f);v[23516]=0;R(44,d|0,e|0);e=v[23516];v[23516]=0;m:{if((e|0)==1){break m}k=f,l=Cb(v[g>>2]),v[k+48>>2]=l;h=Cb(v[g+4>>2]);while(1){n:{e=v[f+48>>2];if(!Nb(e,h)){v[23516]=0;X(237,f+48|0,5,6,d|0);e=v[23516];v[23516]=0;if((e|0)==1){break n}h=f+48|0;e=yc(d,h);wb(h);h=Ic(e);j=Fb(e);v[23516]=0;da(238,a+1298332|0,h|0,j|0,76,0);h=v[23516];v[23516]=0;if((h|0)==1){break m}wb(e);dc(g);break i}o:{e=w[e|0];if(e&128){k=f,l=uh(d),v[k+64>>2]=l;j=v[hj(f+72|0,f- -64|0)>>2];v[23516]=0;X(239,d|0,j|0,e&127,32);e=v[23516];v[23516]=0;if((e|0)!=1){break o}break m}v[23516]=0;R(45,d|0,e<<24>>24);e=v[23516];v[23516]=0;if((e|0)!=1){break o}break m}He(f+48|0);continue}break}}b=P()|0;O()|0;wb(d);break l}b=P()|0;O()|0}dc(g);break d}d=w[a+484376|0];g=v[a+484360>>2];v[23516]=0;U(240,Sb(g,d)|0,b|0,x[f+102>>1]);d=v[23516];v[23516]=0;if((d|0)==1){break h}e=c&1;h=a+484348|0;d=0;while(1){p:{q:{if(x[f+100>>1]>d>>>0){g=v[b+8>>2];j=v[b>>2];v[23516]=0;g=W(154,j|0,g|0,4)|0;j=v[23516];v[23516]=0;if((j|0)==1){break p}if(g){break q}}if(!(c&2)){break g}g=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>x[g>>1]){break g}e=B(c,104)+a|0;h=x[e+484414>>1];Ab(f+24|0,v[i>>2],c-1|0);c=Uc(f,h&1?16:8,1,0,zb(v[v[f+24>>2]>>2],v[f+28>>2])?6:0);v[23516]=0;W(218,c|0,e+484380|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}v[23516]=0;g=T(155,b|0)|0;j=v[23516];v[23516]=0;r:{s:{if((j|0)!=1){v[23516]=0;U(188,f|0,b|0,g|0);g=v[23516];v[23516]=0;if((g|0)==1){break s}g=hc(f+24|0,f);yb(f);if(!e){break r}j=v[a+484344>>2];if(!te(j,v[h>>2],d&65535)){break r}v[23516]=0;U(241,Xb(j,d)|0,0,g|0);j=v[23516];v[23516]=0;if((j|0)!=1){break r}b=P()|0;O()|0;yb(g);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}yb(g);d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}Ue(i);break b}v[23516]=0;Q(242,b|0,((e<<5)+a|0)+946304|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[23516]=0;R(243,b|0,f+24|0);h=v[23516];v[23516]=0;t:{if((h|0)==1){break t}v[23516]=0;R(244,f+24|0,(B(g,104)+a|0)+484380|0);h=v[23516];v[23516]=0;if((h|0)==1){break t}h=w[f+40|0];Ab(f,v[i>>2],g-1|0);We(f,(h&3)!=0);d=d+1|0;continue}break}b=P()|0;O()|0}Ue(i);break c}b=P()|0;O()|0;ac(f)}S(b|0);L()}d=1}hb=f+112|0;return d|0}function u9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0;e=hb-336|0;hb=e;d=-1;a:{b:{c:{if(!Tk(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){b=Rl(e+224|0,b);v[23516]=0;d=Q(458,e+208|0,14053)|0;f=v[23516];v[23516]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){v[23516]=0;v[e+192>>2]=83886084;v[e+196>>2]=0;U(459,b|0,d|0,e+192|0);f=v[23516];v[23516]=0;if((f|0)==1){break A}Ub(d);t[e+207|0]=0;v[23516]=0;d=Q(458,e+192|0,14831)|0;f=v[23516];v[23516]=0;if((f|0)==1){break z}v[23516]=0;U(460,b|0,e+207|0,d|0);f=v[23516];v[23516]=0;if((f|0)==1){break y}Ub(d);v[23516]=0;f=w[e+207|0];d=Q(458,e+176|0,15903)|0;g=v[23516];v[23516]=0;if((g|0)==1){break x}v[23516]=0;f=f?0:c;X(900,b|0,a+40|0,d|0,f|0);c=v[23516];v[23516]=0;if((c|0)==1){break w}Ub(d);u[e+174>>1]=65535;v[23516]=0;c=Q(458,e+160|0,15573)|0;d=v[23516];v[23516]=0;if((d|0)==1){break v}v[23516]=0;W(488,b|0,e+174|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break u}Ub(c);u[e+158>>1]=0;v[23516]=0;c=Q(458,e+144|0,15472)|0;d=v[23516];v[23516]=0;if((d|0)==1){break t}v[23516]=0;W(488,b|0,e+158|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break s}Ub(c);u[a>>1]=x[e+158>>1];v[23516]=0;c=Q(458,e+128|0,15154)|0;d=v[23516];v[23516]=0;if((d|0)==1){break r}v[23516]=0;X(901,b|0,a+52|0,c|0,f|0);d=v[23516];v[23516]=0;if((d|0)==1){break q}Ub(c);v[23516]=0;c=Q(458,e+112|0,15084)|0;d=v[23516];v[23516]=0;if((d|0)==1){break p}v[23516]=0;U(892,b|0,a+36|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break o}Ub(c);v[23516]=0;c=Q(458,e+96|0,15580)|0;d=v[23516];v[23516]=0;if((d|0)==1){break n}v[23516]=0;h=a+4|0;U(902,b|0,h|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break m}Ub(c);v[23516]=0;c=Q(458,e+80|0,15474)|0;d=v[23516];v[23516]=0;if((d|0)==1){break l}v[23516]=0;f=a+28|0;U(903,b|0,f|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break k}Ub(c);v[23516]=0;c=Q(458,e- -64|0,15329)|0;d=v[23516];v[23516]=0;if((d|0)==1){break j}v[23516]=0;U(903,b|0,a+30|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break i}Ub(c);v[23516]=0;c=Q(458,e+48|0,15126)|0;d=v[23516];v[23516]=0;if((d|0)==1){break h}v[23516]=0;U(904,b|0,a+32|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break g}Ub(c);u[e+46>>1]=0;v[23516]=0;c=Q(458,e+32|0,15063)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}v[23516]=0;W(488,b|0,e+46|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break f}Ub(c);i=oL(z[a+32>>2]);z[a+32>>2]=i;d=-1;if(!fm(i)){break d}k=e,l=Cb(v[a+4>>2]),v[k+24>>2]=l;c=Cb(v[a+8>>2]);while(1){g=v[e+24>>2];if(!Nb(g,c)){break e}if(!fm(z[g>>2])){break d}Ie(e+24|0);continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(c);break a}a=P()|0;O()|0;Ub(c);break a}if(Ek(w[b|0])){break d}c=x[f>>1];if((c-301&65535)>>>0<64935){break d}g=x[a>>1];if(g>>>0>3|(g|0)==2){break d}j=u[a+30>>1];if((j|0)<0){break d}k=e,l=Di(v[a+36>>2]),v[k+24>>2]=l;v[e+16>>2]=0;k=a,l=v[Gj(e+24|0,e+16|0,44e3)>>2],v[k+36>>2]=l;if(sc(v[a+4>>2],v[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=u[e+46>>1];if((f|0)<=0){break d}u[e+14>>1]=j;z[e+24>>2]=z[a+32>>2];v[23516]=0;u[e+16>>1]=c;u[e+18>>1]=(c+f|0)-1;a=fa(905,a|0,e+14|0,e+24|0,e+16|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;case 0:g=u[e+46>>1];if((g|0)<=0){break d}z[e+24>>2]=z[a+32>>2];v[23516]=0;u[e+16>>1]=c;u[e+18>>1]=(c+g|0)-1;a=ga(906,a|0,h|0,e+24|0,e+16|0,f|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;default:break C}}v[23516]=0;Y(907,a|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}}d=1}fh(b)}hb=e+336|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}fh(b);S(a|0);L()}function rx(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=hb-48|0;hb=l;v[l+44>>2]=0;if(i?1:d|g|h){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}Jb(k);v[j>>2]=0}v[23516]=0;Z(103);k=v[23516];v[23516]=0;b:{c:{if((k|0)==1){m=Va(92664,49120,49176,62944,92840,92944,92892,92784,92772,93088,93056,93024,93012,93236,0)|0;d:{e:{n=O()|0;if((n|0)==(ea(92664)|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=277;if((j|0)==1){break e}break b}if((ea(49120)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}if((ea(49176)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}if((ea(62944)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}if((ea(92840)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}if((ea(92944)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}if((ea(92892)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}if((ea(92784)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}if((ea(92772)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}if((ea(93088)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}if((ea(93056)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}if((ea(93024)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}if((ea(93012)|0)==(n|0)){k=_(m|0)|0;v[23516]=0;R(1067,j|0,k|0);j=v[23516];v[23516]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break d}o=ea(93236)|0;k=257;m=_(m|0)|0;if((n|0)!=(o|0)){break b}v[23516]=0;R(1067,j|0,m|0);j=v[23516];v[23516]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Tb()}L()}S(a|0);L()}$()}m=!g;if(d){j=lb[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){v[g+16>>2]=k;m=g;g=v[l+44>>2];p=m,q=fg(g?g:21751),v[p+20>>2]=q}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];p=i,q=fg(g?g:21751),v[p>>2]=q}g=v[l+44>>2];if(g){Jb(g);v[l+44>>2]=0}f:{if(!(j&1)){break f}v[23516]=0;R(1065,l+32|0,a|0);g=v[23516];v[23516]=0;g:{h:{if((g|0)!=1){i:{if(f){g=v[f+24>>2];v[23516]=0;R(1066,g|0,l+32|0);g=v[23516];v[23516]=0;if((g|0)!=1){break i}break h}g=Ic(l+32|0);if(b){v[23516]=0;R(b|0,g|0,c|0);g=v[23516];v[23516]=0;if((g|0)==1){break h}break i}zs(g,l)}wb(l+32|0);break f}g=V(0)|0;O()|0;break g}g=V(0)|0;O()|0;wb(l+32|0)}_(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+8>>2]=a?a:21751;v[l+4>>2]=250;v[l>>2]=9203;YJ(17967,l);xs(93592);$()}hb=l+48|0}function eja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;e=hb-352|0;hb=e;xc(b);f=hb-16|0;hb=f;$T(f+8|0,e+128|0);h=v[f+12>>2];jc(f,v[b>>2],v[b+8>>2],v[f+8>>2],h);i=v[f+4>>2];if((i|0)==(h|0)){Yb(b,v[f+12>>2])}hb=f+16|0;a:{b:{c:{d:{e:{f:{g:{if((h|0)!=(i|0)){break g}if(!bU(e+128|0)){break g}if(!Ob(v[b>>2],v[b+8>>2],Bc(aU(w[e+344|0],w[e+345|0]),kb))){break g}if(!c){d=1;break g}zd(a,2);$f(a);v[a+480188>>2]=524296;s=a,z=Oe(455e3),v[s+480204>>2]=z;Mb(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;f=e+96|0;Ke(f,2,e+159|0);d=e+112|0;Cc(d,f);yc(a+1298308|0,d);wb(d);d=0;h:{i:{while(1){if((d|0)==8){j:{d=Sb(v[a+484360>>2],w[a+484376|0]);o=w[e+344|0];n=o+1|0;ko(d,b,n,65535,65535);f=Lb(e+112|0);v[23516]=0;U(236,b|0,f|0,n|0);d=v[23516];v[23516]=0;if((d|0)==1){break j}s=e,z=Cb(v[f>>2]),v[s+96>>2]=z;d=Cb(v[f+4>>2]);while(1){h=v[e+96>>2];p=Nb(h,d);if(p){if((w[h|0]-9&255)>>>0<248){break h}He(e+96|0);continue}break}s=a,z=w[Ib(v[f>>2],0)|0],v[s+480196>>2]=z;d=w[e+343|0];i=w[e+345|0];h=Lb(e+96|0);v[23516]=0;m=i+1|0;U(236,b|0,h|0,m|0);i=v[23516];v[23516]=0;k:{if((i|0)==1){break k}v[23516]=0;i=a+484344|0;R(224,i|0,m|0);g=v[23516];v[23516]=0;if((g|0)==1){break k}q=d+1|0;if(!(c&1)){break i}c=0;while(1){if((c|0)==(m|0)){break i}d=w[Ib(v[h>>2],c)|0];v[23516]=0;d=W(225,i|0,d|0,q|0)|0;g=v[23516];v[23516]=0;l:{if((g|0)!=1){if(!d){break i}j=0;k=Xb(v[i>>2],w[Ib(v[h>>2],c)|0]);m:while(1){r=j&65535;if(r>>>0>7){break l}j=j+1|0;d=0;while(1){if(y[k+12>>2]<=d>>>0){continue m}v[23516]=0;g=T(204,b|0)|0;l=v[23516];v[23516]=0;n:{o:{if((l|0)!=1){if(!(g&128)){break o}d=(g&127)+d|0;break n}d=P()|0;O()|0;break b}l=ed(v[k>>2],v[v[k+48>>2]+12>>2],d,r);if((g|0)==1){t[l|0]=254;break n}if((g-1&255)>>>0>96){break n}t[l+1|0]=j;t[l|0]=g+12}d=d+1|0;continue}}}d=P()|0;O()|0;break b}c=c+1|0;continue}}d=P()|0;O()|0;break b}}else{i=e+112|0;f=(e+128|0)+B(d,19)|0;_A(i,f+63|0);h=e+96|0;Cc(h,i);wl(((d<<5)+a|0)+480289|0,h);wb(h);d=d+1|0;g=B(d,104)+a|0;j=g+484380|0;jd(j,2);t[e+107|0]=0;h=w[f+78|0]|w[f+79|0]<<8|(w[f+80|0]<<16|w[f+81|0]<<24);t[e+103|0]=h;t[e+104|0]=h>>>8;t[e+105|0]=h>>>16;t[e+106|0]=h>>>24;h=w[f+75|0]|w[f+76|0]<<8|(w[f+77|0]<<16|w[f+78|0]<<24);f=w[f+71|0]|w[f+72|0]<<8|(w[f+73|0]<<16|w[f+74|0]<<24);v[e+8>>2]=v[e+104>>2];v[e+96>>2]=f;v[e+100>>2]=h;f=v[e+100>>2];v[e>>2]=v[e+96>>2];v[e+4>>2]=f;vl(j,1,e);v[g+484404>>2]=8215;f=e+80|0;Cc(f,i);Ac(((d<<5)+a|0)+946304|0,f);wb(f);continue}break}d=P()|0;O()|0;break a}j=o+1|0;c=a+484376|0;d=0;p:{q:{while(1){if((d|0)==(j|0)){v[23516]=0;b=Q(1,e+80|0,8645)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break p}d=P()|0;O()|0;break b}b=w[c|0];g=v[a+484360>>2];v[23516]=0;k=d&65535;b=Q(314,Sb(g,b)|0,k|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){r:{s:{if(b){b=Sb(v[a+484360>>2],w[c|0]);break s}v[23516]=0;g=Q(366,i|0,q|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break q}if((g|0)==65535){break r}b=Sb(v[a+484360>>2],w[c|0]);s=$b(v[b>>2],d),z=g,u[s>>1]=z}b=ZA(Cb(v[Xb(v[i>>2],x[$b(v[b>>2],d)>>1])+4>>2]),1);g=w[b+5|0];l=w[Ib(v[f>>2],(d+1>>>0)%(n>>>0)|0)|0];if((g|0)==(l|0)){break r}t:{if(w[b+3|0]!=16){break t}g=w[c|0];m=v[a+484360>>2];v[23516]=0;g=Q(367,Sb(m,g)|0,k|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break c}if((g|0)==65535){break t}b=ZA(Cb(v[Xb(v[i>>2],g)+4>>2]),1)}t[b+5|0]=l;t[b+3|0]=16}d=d+1|0;continue}break}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}Gb(a+1298344|0,b);xb(b);v[23516]=0;b=Q(1,e- -64|0,6052)|0;c=v[23516];v[23516]=0;if((c|0)==1){break f}Gb(a+1298356|0,b);xb(b);b=e+16|0;Aj(b,2,e+139|0);v[23516]=0;R(221,e+32|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break e}v[23516]=0;U(11,e+48|0,5,e+32|0);b=v[23516];v[23516]=0;if((b|0)==1){break d}b=e+48|0;Gb(a+1298368|0,b);xb(b);wb(e+32|0);v[a+1298404>>2]=5;dc(h)}dc(f);d=p^1}hb=e+352|0;return d|0}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;wb(e+32|0);break b}d=P()|0;O()|0}dc(h)}dc(f);S(d|0);L()}function AH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,C=0;i=hb-560|0;hb=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;k=g+B(s,-24)|0;o=v[(e<<2)+74032>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){A[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+v[(c<<2)+74048>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;t=(o|0)>0?o:0;h=(d|0)<=0;while(1){a:{if(h){f=0;break a}n=g+j|0;c=0;f=0;while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(n-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;c=(g|0)==(t|0);g=g+1|0;if(!c){continue}break}z=47-k|0;u=48-k|0;C=k-25|0;g=o;b:{while(1){f=A[(g<<3)+i>>3];c=0;h=g;l=(g|0)<=0;if(!l){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(D(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(D(f)<2147483648){j=~~f;break d}j=-2147483648}v[n>>2]=j;h=h-1|0;f=A[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=Vj(f,q);f=f+H(f*.125)*-8;e:{if(D(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{w=(q|0)<=0;i:{if(!w){h=(g<<2)+i|0;j=v[h+476>>2];c=j>>u;r=h;h=j-(c<<u)|0;v[r+476>>2]=h;n=c+n|0;j=h>>z;break i}if(q){break h}j=v[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;h=0;if(!l){while(1){r=(i+480|0)+(c<<2)|0;x=v[r>>2];l=16777215;j:{k:{if(h){break k}l=16777216;if(x){break k}h=0;break j}v[r>>2]=l-x;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(w){break l}c=8388607;m:{switch(C|0){case 1:c=4194303;break;case 0:break m;default:break l}}l=(g<<2)+i|0;v[l+476>>2]=v[l+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!h){break f}f=f-Vj(1,q)}if(f==0){c=1;l=0;h=g;n:{if((g|0)<=(o|0)){break n}while(1){h=h-1|0;l=v[(i+480|0)+(h<<2)>>2]|l;if((h|0)>(o|0)){continue}break}if(!l){break n}k=q;while(1){k=k-24|0;g=g-1|0;if(!v[(i+480|0)+(g<<2)>>2]){continue}break}break b}while(1){h=c;c=c+1|0;if(!v[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;A[(i+320|0)+(j<<3)>>3]=v[(s+g<<2)+74048>>2];c=0;f=0;if((d|0)>0){while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=Vj(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(D(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(D(f)<2147483648){a=~~f;break q}a=-2147483648}v[d>>2]=a;g=g+1|0;break o}if(D(f)<2147483648){c=~~f}else{c=-2147483648}k=q}v[(i+480|0)+(g<<2)>>2]=c}f=Vj(1,k);if((g|0)>=0){d=g;while(1){a=d;A[(a<<3)+i>>3]=f*+v[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}a=0;h=g;while(1){d=a>>>0<t>>>0?a:t;c=0;f=0;while(1){f=A[(c<<3)+76816>>3]*A[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}A[(i+160|0)+(g-h<<3)>>3]=f;h=h-1|0;c=(a|0)!=(g|0);a=a+1|0;if(c){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;y=A[h>>3];f=y+f;A[e+(c<<3)>>3]=m+(y-f);A[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=A[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=p+f;A[d+(c<<3)>>3]=m+(p-f);A[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[i+160>>3];if(j){break s}A[b>>3]=f;f=A[i+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;f=A[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break r}A[b>>3]=-f;f=A[i+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}hb=i+560|0;return n&7}function U_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;h=hb+-64|0;hb=h;v[h+56>>2]=b;v[e>>2]=0;bd(h,d);v[23516]=0;b=T(1153,h|0)|0;i=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((i|0)!=1){Zb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Zb(h);S(a|0);L()}YF(a,f+24|0,h+56|0,c,e,b);break b}XF(a,f+16|0,h+56|0,c,e,b);break b}b=lb[v[v[a+8>>2]+12>>2]](a+8|0)|0;g=a;i=v[h+56>>2];a=wc(b);j=h,k=Wj(g,i,c,d,e,f,a,a+(Fb(b)<<2)|0),v[j+56>>2]=k;break b}a=Si(h+56|0,c,e,b,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}b=v[21023];v[h+24>>2]=v[21022];v[h+28>>2]=b;b=v[21021];v[h+16>>2]=v[21020];v[h+20>>2]=b;b=v[21019];v[h+8>>2]=v[21018];v[h+12>>2]=b;b=v[21017];v[h>>2]=v[21016];v[h+4>>2]=b;j=h,k=Wj(a,v[h+56>>2],c,d,e,f,h,h+32|0),v[j+56>>2]=k;break b}b=v[21031];v[h+24>>2]=v[21030];v[h+28>>2]=b;b=v[21029];v[h+16>>2]=v[21028];v[h+20>>2]=b;b=v[21027];v[h+8>>2]=v[21026];v[h+12>>2]=b;b=v[21025];v[h>>2]=v[21024];v[h+4>>2]=b;j=h,k=Wj(a,v[h+56>>2],c,d,e,f,h,h+32|0),v[j+56>>2]=k;break b}a=Si(h+56|0,c,e,b,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Si(h+56|0,c,e,b,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Si(h+56|0,c,e,b,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Si(h+56|0,c,e,b,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Si(h+56|0,c,e,b,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+56|0;d=hb-16|0;hb=d;v[d+8>>2]=c;while(1){H:{if(!Tr(a,d+8|0)){break H}if(!Pk(b,8192,Qk(v[a>>2]))){break H}rn(a);continue}break}if(Ok(a,d+8|0)){v[e>>2]=v[e>>2]|2}hb=d+16|0;break b}d=h+56|0;a=lb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Fb(a)|0)==(0-Fb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=Hr(d,c,a,a+24|0,b,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}b=pc(h,84128,44);j=b,k=Wj(a,v[b+56>>2],c,d,e,f,b,b+44|0),v[j+56>>2]=k;break b}v[h+16>>2]=v[21048];b=v[21047];v[h+8>>2]=v[21046];v[h+12>>2]=b;b=v[21045];v[h>>2]=v[21044];v[h+4>>2]=b;j=h,k=Wj(a,v[h+56>>2],c,d,e,f,h,h+20|0),v[j+56>>2]=k;break b}a=Si(h+56|0,c,e,b,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}b=v[21059];v[h+24>>2]=v[21058];v[h+28>>2]=b;b=v[21057];v[h+16>>2]=v[21056];v[h+20>>2]=b;b=v[21055];v[h+8>>2]=v[21054];v[h+12>>2]=b;b=v[21053];v[h>>2]=v[21052];v[h+4>>2]=b;j=h,k=Wj(a,v[h+56>>2],c,d,e,f,h,h+32|0),v[j+56>>2]=k;break b}a=Si(h+56|0,c,e,b,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=lb[v[v[a>>2]+20>>2]](a,v[h+56>>2],c,d,e,f)|0;break a}b=lb[v[v[a+8>>2]+24>>2]](a+8|0)|0;g=a;i=v[h+56>>2];a=wc(b);j=h,k=Wj(g,i,c,d,e,f,a,a+(Fb(b)<<2)|0),v[j+56>>2]=k;break b}WF(f+20|0,h+56|0,c,e,b);break b}a=Si(h+56|0,c,e,b,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=hb-16|0;hb=a;v[a+8>>2]=c;c=6;d=h+56|0;L:{M:{if(Ok(d,a+8|0)){break M}c=4;if((jn(b,Qk(v[d>>2]))|0)!=37){break M}c=2;if(!Ok(rn(d),a+8|0)){break L}}v[e>>2]=v[e>>2]|c}hb=a+16|0}a=v[h+56>>2]}hb=h- -64|0;return a|0}function fM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=hb-16|0;hb=k;a:{b:{c:{if(!Wc(c)|!d|v[b+480180>>2]!=16777216|x[b+480192>>1]<d>>>0){break c}d=v[((d<<2)+b|0)+900380>>2];if(!d){break c}e=v[d+44>>2];if(!e){break c}u[k+14>>1]=c-61;c=hb+-64|0;hb=c;d:{e:{d=u[e+28>>1];h=k+14|0;b=u[h>>1];if((d|0)<=(b|0)){if((b|0)<=(sc(v[e+4>>2],v[e+8>>2])+d<<16)-65536>>16){break e}}Kb(a);break d}f:{d=x[e+30>>1];if(!d){b=e+52|0;d=Ox(b,h);if(!Fg(d,tf(b))){break f}Jl(a,sd(d)+4|0);break d}b=Dn(b,d<<16>>16);u[c+62>>1]=b;d=Kb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=e+52|0;f=Ox(a,c+62|0);t:{if(Fg(f,tf(a))){v[23516]=0;R(133,d|0,sd(f)+4|0);a=v[23516];v[23516]=0;if((a|0)==1){break t}a=u[e+30>>1];b=u[h>>1];v[23516]=0;l=c,m=Nx(b,a)+5|0,v[l+32>>2]=m;R(130,c+48|0,c+32|0);a=v[23516];v[23516]=0;u:{if((a|0)!=1){v[23516]=0;Q(96,d|0,c+48|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break u}xb(c+48|0);break d}a=P()|0;O()|0;break g}a=P()|0;O()|0;xb(c+48|0);break g}if(u[e+30>>1]>26){break q}v[23516]=0;b=W(536,c+32|0,1,(b<<24)+1090519040>>24)|0;a=v[23516];v[23516]=0;if((a|0)==1){break s}v[23516]=0;U(11,c+48|0,0,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break r}a=c+48|0;f=Gb(d,a);xb(a);wb(b);v[23516]=0;Q(131,f|0,14732)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break p}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;wb(b);break g}v[23516]=0;a=b<<16>>16;v[c+28>>2]=(a|0)%16;R(860,c+32|0,c+28|0);f=v[23516];v[23516]=0;if((f|0)==1){break o}v[23516]=0;v[c+12>>2]=((a|0)/16<<16>>16)%16;R(860,c+16|0,c+12|0);a=v[23516];v[23516]=0;if((a|0)==1){break n}v[23516]=0;U(2,c+48|0,c+32|0,c+16|0);a=v[23516];v[23516]=0;if((a|0)==1){break m}a=c+48|0;f=Gb(d,a);xb(a);xb(c+16|0);xb(c+32|0);if(b<<16>>16<256){break p}v[23516]=0;U(8,c|0,0,f|0);a=v[23516];v[23516]=0;if((a|0)==1){break k}b=c+32|0;g=ge(c);j=uh(c);i=ge(c);a=hb-32|0;hb=a;v[a+16>>2]=j;v[a+24>>2]=g;v[a+8>>2]=i;while(1){if(mj(a+24|0,a+16|0)){g=a+24|0;j=Np(t[v[g>>2]]);i=a+8|0;t[v[i>>2]]=j;He(g);He(i);continue}break}hb=a+32|0;Xc(b,c);v[23516]=0;U(11,c+48|0,0,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break j}a=c+48|0;Gb(f,a);xb(a);wb(c+32|0);wb(c)}a=u[e+30>>1];b=u[h>>1];v[23516]=0;l=c,m=Nx(b,a)+5|0,v[l+16>>2]=m;R(130,c+48|0,c+16|0);a=v[23516];v[23516]=0;if((a|0)==1){break i}v[23516]=0;Q(96,d|0,c+48|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break h}xb(c+48|0);break d}a=P()|0;O()|0;break g}a=P()|0;O()|0;break l}a=P()|0;O()|0;xb(c+16|0)}xb(c+32|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;wb(c+32|0);wb(c);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;xb(c+48|0)}break a}d=hb-16|0;hb=d;f=hb-32|0;hb=f;e=kf(f+16|0,1,0);v:{w:{x:{while(1){j=f+8|0;b=wc(e);i=Fb(e)+b|0;g=u[h>>1];if(!((b|0)==(i|0)|(g|0)>=0)){t[b|0]=45;g=0-(g&65535)&65535;b=b+1|0}tx(j,b,i,g&65535);if(!v[f+12>>2]){break x}b=Yg(Fb(e));v[23516]=0;R(57,e|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){continue}break}break w}b=v[f+8>>2];h=wc(e);v[23516]=0;R(58,e|0,b-h|0);b=v[23516];v[23516]=0;y:{if((b|0)!=1){v[23516]=0;R(70,d|0,e|0);b=v[23516];v[23516]=0;if((b|0)!=1){break y}break w}break w}wb(e);hb=f+32|0;break v}a=P()|0;O()|0;wb(e);S(a|0);L()}v[23516]=0;R(69,a|0,d|0);a=v[23516];v[23516]=0;z:{if((a|0)!=1){xb(d);hb=d+16|0;break z}a=P()|0;O()|0;break a}}hb=c- -64|0;break b}e=v[b>>2];b=hb-32|0;hb=b;A:{if(Gp(c)){v[b+16>>2]=v[8072];d=v[8071];v[b+8>>2]=v[8070];v[b+12>>2]=d;d=v[8069];v[b>>2]=v[8068];v[b+4>>2]=d;vc(a,(b+(c<<2)|0)-1004|0);break A}if(Wc(c)){d=Kb(b);v[23516]=0;c=c-1|0;f=(c|0)/12|0;c=Q(861,d|0,e+(B(f,-12)+c<<16>>16<<2)|0)|0;e=v[23516];v[23516]=0;B:{if((e|0)==1){break B}v[23516]=0;c=Q(862,c|0,f+48&255)|0;e=v[23516];v[23516]=0;if((e|0)==1){break B}v[23516]=0;Q(3,a|0,c|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break B}xb(c);break A}a=P()|0;O()|0;break a}if(!c){vc(a,16862);break A}vc(a,14703)}hb=b+32|0}hb=k+16|0;return}xb(d);S(a|0);L()}function o9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0;d=hb-128|0;hb=d;g=-1;a:{b:{c:{d:{e:{f:{if(!Mh(v[v[b>>2]-12>>2]+b|0)){break f}e=d+112|0;ke(e,b);f=v[e+8>>2];i=v[e+12>>2];e=d+104|0;Qj(e);b=Mk(b,e,8);if(Qb(e,16838,8)){a=Sg(d+88|0,f,i);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;Uj(b,d+8|0);break f}u[d+86>>1]=0;Wf(b,d+86|0);l=u[d+86>>1];if((l-4&65535)>>>0<65534){break f}e=d+78|0;Qj(e);b=Mk(b,e,8);if(Qb(e,14383,8)){break f}u[d+76>>1]=0;Wf(b,d+76|0);i=u[d+76>>1];if((i-5&65535)>>>0<65534){break f}g:{h:{i:{if(i>>>0<=3){e=Kb(d+112|0);v[23516]=0;f=W(492,b|0,e|0,65535)|0;k=v[23516];v[23516]=0;if((k|0)==1){break b}if(!f){break h}v[23516]=0;U(11,d- -64|0,c|0,e|0);f=v[23516];v[23516]=0;if((f|0)!=1){break i}break b}e=Kb(d+112|0);v[23516]=0;f=Q(494,b|0,e|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break c}if(!f){break g}v[23516]=0;U(11,d- -64|0,c|0,e|0);f=v[23516];v[23516]=0;if((f|0)==1){break c}}f=d- -64|0;Gb(a+40|0,f);xb(f);wb(e);u[d+62>>1]=0;Wf(b,d+62|0);u[d+60>>1]=0;Wf(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;j:{if((i|0)<=3){v[d+112>>2]=0;kk(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break f}f=tl(e);u[d+58>>1]=f;break j}Wf(b,d+58|0);f=x[d+58>>1]}k=a+52|0;n=f&65535;i=(i|0)>3;f=0;k:{l:{m:{while(1){if((f&65535)>>>0>=n>>>0){break l}e=Kb(d+112|0);v[23516]=0;u[d+40>>1]=0;R(911,b|0,d+40|0);h=v[23516];v[23516]=0;if((h|0)==1){break e}n:{if(!i){v[23516]=0;h=W(492,b|0,e|0,65535)|0;j=v[23516];v[23516]=0;if((j|0)==1){break e}if(h){break n}wb(e);break f}v[23516]=0;h=Q(494,b|0,e|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break e}if(!h){break k}}v[23516]=0;U(11,d- -64|0,c|0,e|0);h=v[23516];v[23516]=0;if((h|0)!=1){v[23516]=0;h=Q(908,k|0,d+40|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break m}j=h;h=d- -64|0;Gb(j,h);xb(h);wb(e);f=f+1|0;continue}break}g=P()|0;O()|0;break d}g=P()|0;O()|0;xb(d- -64|0);break d}c=d- -64|0;Qj(c);b=Mk(b,c,8);if(Qb(c,14327,8)){break f}c=x[a>>1];if(c>>>0>3|(c|0)==2){break f}c=a+4|0;o:{if((l|0)<=2){if(mL(b,c)){break o}break f}if(!lL(b,c)){break f}}o=d,p=Cb(v[a+4>>2]),v[o+112>>2]=p;c=Cb(v[a+8>>2]);while(1){e=v[d+112>>2];if(Nb(e,c)){if(!fm(z[e>>2])){break f}Ie(d+112|0);continue}break}c=a+16|0;p:{if((l|0)<=2){if(mL(b,c)){break p}break f}if(!lL(b,c)){break f}}o=d,p=Cb(v[a+16>>2]),v[o+112>>2]=p;c=Cb(v[a+20>>2]);while(1){e=v[d+112>>2];if(Nb(e,c)){if(!fm(z[e>>2])){break f}Ie(d+112|0);continue}break}o=a,p=sc(v[a+16>>2],v[a+20>>2]),v[o+36>>2]=p;u[d+56>>1]=0;Wf(b,d+56|0);c=x[d+56>>1];u[a+28>>1]=c;if((c-201&65535)>>>0<65135){break f}u[d+54>>1]=0;Wf(b,d+54|0);c=u[d+54>>1];u[a+30>>1]=c;if((c|0)<0){break f}v[d+48>>2]=0;yp(b,d+48|0);m=oL(z[d+48>>2]);z[a+32>>2]=m;if(!fm(m)){break f}c=d+40|0;Qj(c);Mk(b,c,8);if(Qb(c,16829,8)){break f}b=sc(v[a+4>>2],v[a+8>>2]);if(b>>>0>32767){break f}c=u[a+30>>1];e=x[a>>1];if(!(e?!(z[a+32>>2]<=C(0))&(c|0)>0:1)){break f}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break f}break;default:break q}}b=0;c=v[a+36>>2];if(c){b=c-1|0;v[a+36>>2]=b}o=d,p=Di(b),v[o+112>>2]=p;v[d+32>>2]=0;o=a,p=v[Gj(d+112|0,d+32|0,44e3)>>2],v[o+36>>2]=p;zp(a);g=1;if(x[a>>1]!=3){break f}c=u[a+30>>1];if((c-u[a+28>>1]|0)>(vL(sc(v[a+4>>2],v[a+8>>2]))|0)){break f}g=a+32|0;e=Lb(d+112|0);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=x[a+28>>1];u[d+32>>1]=b;o=d,p=(sc(v[a+4>>2],v[a+8>>2])+b|0)-1|0,u[o+34>>1]=p;v[23516]=0;u[d+30>>1]=0;ga(906,a|0,e|0,g|0,d+32|0,d+30|0)|0;a=v[23516];v[23516]=0;g=1;if((a|0)==1){break r}lc(e);break f}c=u[a+28>>1];f=v[a+4>>2];v[23516]=0;R(912,e|0,Bb(f,b-c|0)|0);c=v[23516];v[23516]=0;if((c|0)!=1){b=b+1|0;c=x[a+30>>1];continue}}break}g=P()|0;O()|0;lc(e);break a}wb(e);break f}wb(e);break f}wb(e)}hb=d+128|0;return g|0}g=P()|0;O()|0}wb(e);break a}g=P()|0;O()|0;wb(e);break a}g=P()|0;O()|0;wb(e)}S(g|0);L()}function Iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;g=hb-48|0;hb=g;a:{b:{if(!c){break b}f=Gh(a,b);a=Cb(v[d>>2]);v[g+40>>2]=a;d=Cb(v[d+4>>2]);while(1){if(!Nb(a,d)){break b}xc(a);c:{if((Ej(a)|0)==(c|0)){Yb(a,20);d=Ej(a);k=Xf(g+24|0);c=ql(g+16|0,0,b?32:64);v[23516]=0;R(401,f|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break c}o=(b|0)==2?4096:(b|0)==1?2048:16384;c=24;d=d+24|0;p=1;l=1;d:{while(1){h=o;while(1){e=v[a+8>>2];i=v[a>>2];v[23516]=0;e=W(154,i|0,e|0,1)|0;i=v[23516];v[23516]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((i|0)!=1){if(!e){break d}e=v[f+4>>2];i=v[f>>2];m=v[a+8>>2];v[23516]=0;v[g+16>>2]=m;m=Q(402,k|0,g+16|0)|0;q=v[23516];v[23516]=0;if((q|0)==1){break a}y=m,z=Qd(i,e),v[y>>2]=z;v[23516]=0;e=T(204,a|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break a}q:{switch(e-128|0){case 3:case 4:case 7:case 8:break e;case 5:case 6:case 9:case 10:break h;case 2:break i;case 1:break j;case 0:break k;default:break q}}r:{switch(e|0){case 0:break g;case 5:break l;case 4:break m;case 3:break n;case 2:break o;case 1:break p;default:break r}}s:{switch(e-160|0){case 3:case 4:break e;case 5:case 6:break h;case 2:break i;case 1:break j;case 0:break k;default:break s}}switch(e-192|0){case 2:break i;case 1:break j;case 0:break k;default:break e}}break a}if(w[f+12|0]&4){break e}v[23516]=0;e=T(274,a|0)|0;i=v[23516];v[23516]=0;t:{if((i|0)==1){break t}v[23516]=0;v[g+16>>2]=e;e=Q(402,k|0,g+16|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break t}t[f+15|0]=v[e>>2];y=f,z=Qd(v[f>>2],v[f+4>>2])-1|0,t[y+16|0]=z;t[f+12|0]=w[f+12|0]|4;break e}break a}v[23516]=0;e=T(274,a|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break a}u[g+16>>1]=e;u[g+14>>1]=1;e=x[ie(g+16|0,g+14|0)>>1];h=B(e,B(r<<16>>16,l))+h|0;u:{if(e>>>0<2){break u}y=g,z=tl((e+x[yj(v[f+4>>2])>>1]|0)-1|0),u[y+16>>1]=z;e=au(b,h);v[23516]=0;t[g+14|0]=e;U(403,f|0,g+16|0,g+14|0);e=v[23516];v[23516]=0;if((e|0)!=1){break u}break a}y=g,z=tl(x[yj(v[f+4>>2])>>1]+1|0),u[y+16>>1]=z;e=au(b,h);v[23516]=0;t[g+14|0]=e;U(403,f|0,g+16|0,g+14|0);e=v[23516];v[23516]=0;if((e|0)!=1){break e}break a}v[23516]=0;j=T(204,a|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break a}s=v[a+8>>2];break e}v[23516]=0;e=T(274,a|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break a}e=c+e|0;v[g+16>>2]=e;if(!(!(j&255)|e>>>0<s>>>0)){j=j-1|0;if(!(j&255)){break f}v[23516]=0;Q(153,a|0,e|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break e}break a}if(!(j&255)){break f}v[23516]=0;e=Q(404,k|0,g+16|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break a}t[f+13|0]=v[e>>2];y=f,z=Qd(v[f>>2],v[f+4>>2])-1|0,t[y+14|0]=z;t[f+12|0]=w[f+12|0]|2;break e}p=0;n=1;break e}v[23516]=0;h=T(274,a|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break a}e=au(b,h);y=yj(v[f+4>>2]),z=e,t[y+2|0]=z;break e}v[23516]=0;r=T(405,a|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break e}break a}v[23516]=0;e=T(204,a|0)|0;l=v[23516];v[23516]=0;if((l|0)!=1){t[g+16|0]=e;t[g+14|0]=1;l=w[ef(g+16|0,g+14|0)|0];break e}break a}v[23516]=0;Q(186,a|0,1)|0;e=v[23516];v[23516]=0;if((e|0)==1){break a}break e}n=1;if(c>>>0<d>>>0){break e}break d}j=0}if(!n|c>>>0>=d>>>0){continue}break}v[23516]=0;c=Q(153,a|0,d|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}if(!c){break d}c=v[a+8>>2];h=v[a>>2];v[23516]=0;c=W(154,h|0,c|0,2)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}if(!c){break d}h=w[f+12|0];v:{if(!(!(h&4)&p)){c=v[f+4>>2];break v}c=v[f+4>>2];e=v[f>>2];t[f+12|0]=h|4;h=Qd(e,c)-1|0;t[f+15|0]=h;t[f+16|0]=h}y=g,z=tl(x[yj(c)>>1]+1|0),u[y+16>>1]=z;c=au(b,o);v[23516]=0;t[g+14|0]=c;U(403,f|0,g+16|0,g+14|0);c=v[23516];v[23516]=0;if((c|0)!=1){n=1;t[f+17|0]=w[f+16|0]+1;c=d;continue}break}break a}t[f+12|0]=w[f+12|0]|1;DT(k);break b}a=v[Jf(g+40|0)>>2];continue}break}break a}hb=g+48|0;return}a=P()|0;O()|0;DT(k);S(a|0);L()}function cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=hb-752|0;hb=e;xc(b);d=hb-16|0;hb=d;h=e+144|0;TQ(d+8|0,h);f=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],f);g=v[d+4>>2];if((g|0)==(f|0)){Yb(b,v[d+12>>2])}hb=d+16|0;d=(f|0)==(g|0);if(!d){SQ(h)}a:{if(!d){break a}if(!VQ(e+144|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(UQ(x[e+178>>1]),kb))){break a}if(!c){n=1;break a}zd(a,262144);f=e+104|0;Gi(f,2,e+144|0);d=e+24|0;Cc(d,f);yc(a+1298308|0,d);wb(d);h=vc(d,8346);Gb(a+1298344|0,h);xb(h);d=vc(d,10144);Gb(a+1298356|0,d);xb(d);d=hb-16|0;hb=d;i=f;f=vc(d,4196);Xc(i,f);xb(f);hb=d+16|0;t[e+8|0]=w[e+174|0];v[23516]=0;t[e+127|0]=w[e+173|0];R(677,e+128|0,e+127|0);d=v[23516];v[23516]=0;b:{c:{d:{if((d|0)!=1){v[23516]=0;X(252,e+24|0,e+104|0,e+8|0,e+128|0);d=v[23516];v[23516]=0;if((d|0)!=1){d=e+24|0;Gb(a+1298368|0,d);xb(d);xb(e+128|0);f=e+104|0;ac(f);v[a+480208>>2]=12;v[a+1298404>>2]=5;h=a+480188|0;u[h>>1]=x[e+182>>1];u[e+24>>1]=x[e+178>>1];u[e+104>>1]=3999;A=a,C=x[Rc(d,f)>>1],u[A+480190>>1]=C;eU(Sb(v[a+484360>>2],w[a+484376|0]),e+240|0,x[e+176>>1]);d=0;while(1)if(x[h>>1]<=d>>>0){d=e+24|0;Wd(d,b,B(x[e+178>>1],80));h=c&2;l=hc(e+104|0,d);yb(d);g=e+72|0;d=0;e:{f:{while(1){if(x[a+480190>>1]<=d>>>0){n=1;if(c&1){break f}break b}v[23516]=0;R(678,l|0,e+24|0);f=v[23516];v[23516]=0;if((f|0)==1){break e}f=e+8|0;Gi(f,2,g);v[23516]=0;R(221,e+128|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break e}d=d+1|0;f=e+128|0;Ac(((d<<5)+a|0)+946304|0,f);wb(f);v[23516]=0;i=f;f=(B(d,104)+a|0)+484380|0;U(679,i|0,e+24|0,f|0);j=v[23516];v[23516]=0;g:{if((j|0)==1){break g}if(!h|!v[f>>2]){continue}v[23516]=0;j=Q(153,b|0,x[e+42>>1]|x[e+44>>1]<<16)|0;i=v[23516];v[23516]=0;if((i|0)==1){break g}if(!j){continue}v[23516]=0;W(218,e+128|0,f|0,b|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){continue}}break}break e}v[23516]=0;m=a+484344|0;R(224,m|0,x[e+180>>1]);c=v[23516];v[23516]=0;if((c|0)==1){break e}c=e+24|0;r=c|4;s=c|2;o=c|3;y=c|5;z=c|1;p=a+480188|0;a=0;while(1){if(x[e+180>>1]<=a>>>0){break b}v[23516]=0;c=W(225,m|0,a&65535,64)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}h:{if(!c){break h}c=(a<<1)+e|0;c=w[c+496|0]|w[c+497|0]<<8;if(!c){break h}v[23516]=0;c=Q(153,b|0,c<<4)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}if(!c){break h}j=0;c=Xb(v[m>>2],a);c=ed(v[c>>2],v[v[c+48>>2]+12>>2],0,0);while(1){if(j>>>0>63){break h}d=v[b+8>>2];f=v[b>>2];v[23516]=0;d=W(154,f|0,d|0,1)|0;f=v[23516];v[23516]=0;i:{if((f|0)!=1){if(!d){break h}v[23516]=0;h=T(204,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}if(h){break i}j=j+1|0;c=B(x[p>>1],6)+c|0;continue}break e}u[e+28>>1]=0;v[e+24>>2]=0;f=h&31;d=B(f,6)+c|0;i=sg(e+24|0);f=f>>>0<x[p>>1];i=f?d:i;j:{if(!(h&32)){break j}v[23516]=0;R(263,e+128|0,b|0);g=v[23516];v[23516]=0;if((g|0)==1){break e}g=w[e+128|0];t[i|0]=g;A=f?d+1|0:z,C=w[Kc(e+128|0)|0],t[A|0]=C;k:{if(g){if((g|0)==254){break k}if(g>>>0<121){break j}}g=0}t[i|0]=g}l:{if(!(h&64)){break l}v[23516]=0;R(263,e+128|0,b|0);g=v[23516];v[23516]=0;if((g|0)==1){break e}g=f?d+5|0:y;q=Kc(e+128|0);t[g|0]=w[q|0];k=w[e+128|0];m:{if(k>>>0<=15){Nf(i,k,w[q|0]);break m}t[(f?d+3|0:o)|0]=k>>>0<=23?w[k+27175|0]:0}i=f?d+3|0:o;k=w[i|0];if((k|0)!=23){if((k|0)!=9){break l}t[i|0]=20;t[e+8|0]=w[g|0]>>>3;t[e+127|0]=1;A=g,C=w[ef(e+8|0,e+127|0)|0]-1&15|128,t[A|0]=C;break l}t[e+8|0]=64;A=g,C=w[Vb(g,e+8|0)|0]<<1,t[A|0]=C}if(!(h&128)){continue}t[(f?d+2|0:s)|0]=1;v[23516]=0;h=T(204,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break e}t[(f?d+4|0:r)|0]=h;continue}}a=a+1|0;continue}}d=P()|0;O()|0;yb(l);break c}else{f=(d<<5)+a|0;af(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;d=d+1|0;continue}}d=P()|0;O()|0;xb(e+128|0);break d}d=P()|0;O()|0}ac(e+104|0)}S(d|0);L()}yb(l)}hb=e+752|0;return n|0}function bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=hb-224|0;hb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!mo(b,d+208|0)){break l}if(!DR(d+208|0)){break l}g=Ih(d+184|0);h=Kb(d+168|0);lu(d+104|0);v[23516]=0;f=Q(607,b|0,d+96|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break h}m:{if(!f){break m}f=_b(_b(v[d+100>>2])-4|0);while(1){f=_b(_b(f)-8|0);v[d+100>>2]=f;n:{if(c){break n}if((_b(v[d+96>>2])|0)!=1347699796){break n}j=1;break m}v[23516]=0;U(188,d+72|0,b|0,_b(f)|0);f=v[23516];v[23516]=0;if((f|0)==1){break d}e=d+72|0;f=hc(d+8|0,e);yb(e);e=v[f>>2];v[23516]=0;i=T(176,e|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{e=_b(v[d+96>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}v[23516]=0;Q(186,f|0,4)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}v[23516]=0;e=T(608,f|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break b}if(!e){break o}e=_b(v[d+100>>2]);if(e>>>0<7){break o}v[23516]=0;U(609,f|0,h|0,e-6|0);e=v[23516];v[23516]=0;if((e|0)==1){break b}break o}v[23516]=0;l=Q(610,f|0,d+104|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break o}break b}jv(g,f);break o}v[23516]=0;j=W(611,a|0,f|0,c|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}}yb(f);q:{if(!i){break q}v[23516]=0;f=Q(607,b|0,d+96|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break i}if(!f){break q}f=v[d+100>>2];continue}break}if(oh(v[h+4>>2],w[h+11|0])){v[23516]=0;b=Q(1,d+72|0,14980)|0;c=v[23516];v[23516]=0;if((c|0)==1){break g}Gb(h,b);xb(b)}r:{if(!(j&l&1)){break r}b=x[d+146>>1];v[23516]=0;b=Eb(b)&256;W(267,a+1074312|0,5,!b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break f}c=Eb(x[d+142>>1]);if(c){u[d+8>>1]=64;u[d+56>>1]=c;m=a,n=x[Rc(d+8|0,d+56|0)>>1],v[m+480228>>2]=n}c=!b;b=Eb(x[d+144>>1]);if(!(c|!b)){v[a+480204>>2]=B(b,1e4)}if(w[d+104|0]){b=d+56|0;Ke(b,2,d+104|0);v[23516]=0;R(221,d+8|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break e}b=d+8|0;yc(a+1298308|0,b);wb(b)}c=x[d+150>>1];if(!eq(c,1,12)){break r}f=x[d+148>>1];if(!eq(f,1,31)){break r}e=x[d+154>>1];if(!eq(e,0,23)){break r}i=x[d+156>>1];if(!eq(i,0,59)){break r}k=x[d+158>>1];if(!eq(k,0,59)){break r}b=po(d+8|0);m=b,n=Eb(x[d+152>>1]),v[m+20>>2]=n;m=b,n=Eb(c)-1|0,v[m+16>>2]=n;m=b,n=Eb(f),v[m+12>>2]=n;m=b,n=Eb(e),v[m+8>>2]=n;m=b,n=Eb(i),v[m+4>>2]=n;m=b,n=Eb(k),v[m>>2]=n;v[23516]=0;R(442,a+1298408|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break r}a=P()|0;O()|0;break a}if(j&1){b=v[g>>2];v[23516]=0;b=T(176,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break h}if(b){b=Kb(d+8|0);v[23516]=0;U(271,g|0,b|0,32);c=v[23516];v[23516]=0;if((c|0)==1){break c}if(qq(b,13819)){v[23516]=0;U(11,d+56|0,14,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break c}c=d+56|0;Gb(a+1298320|0,c);xb(c)}c=v[g+8>>2];f=v[g>>2];v[23516]=0;c=Q(612,f|0,c|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break c}if(!c){v[23516]=0;c=T(200,g|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break c}v[23516]=0;da(316,a+1298332|0,g|0,c|0,40,0);c=v[23516];v[23516]=0;if((c|0)==1){break c}}wb(b)}v[23516]=0;b=Q(1,d+56|0,17625)|0;c=v[23516];v[23516]=0;if((c|0)==1){break k}v[23516]=0;U(486,d+8|0,b|0,h|0);c=v[23516];v[23516]=0;if((c|0)==1){break j}c=d+8|0;Gb(a+1298368|0,c);xb(c);xb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[23516]=0;a=W(267,a+1074312|0,84,1)|0;b=v[23516];v[23516]=0;if((b|0)==1){break h}v[23516]=0;a=W(267,a|0,83,1)|0;b=v[23516];v[23516]=0;if((b|0)==1){break h}v[23516]=0;Q(268,a|0,85)|0;a=v[23516];v[23516]=0;if((a|0)==1){break h}}xb(h);yb(g)}hb=d+224|0;return j&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;wb(b);break a}a=P()|0;O()|0;yb(f)}xb(h);yb(g);S(a|0);L()}function xV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=hb-3056|0;hb=e;xc(b);g=hb-16|0;hb=g;i=e+1096|0;IB(g+8|0,i);j=b;h=v[b+8>>2];b=v[g+12>>2];jc(g,v[j>>2],h,v[g+8>>2],b);h=v[g+4>>2];if((h|0)==(b|0)){Yb(j,v[g+12>>2])}hb=g+16|0;b=(b|0)==(h|0);if(!b){HB(i)}a:{if(!b){break a}if(!JB(e+1096|0)){break a}b:{if(!c){break b}if(!Ob(v[j>>2],v[j+8>>2],Bc(1024,0))){break a}GB(j,e+576|0);GB(j,e- -64|0);while(1){if((f|0)!=128){b=f<<2;g=v[b+(e+576|0)>>2];if(g>>>0>16777215){break a}b=v[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}f=f+1|0;if(ir(v[j>>2],(b+g|0)+2978|0)){continue}break a}break}zd(a,2);$f(a);b=e+40|0;d=vc(b,13926);Gb(a+1298344|0,d);xb(d);d=vc(b,14848);Gb(a+1298356|0,d);xb(d);b=vc(b,15596);Gb(a+1298368|0,b);xb(b);v[a+1298404>>2]=5;b=w[e+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=b;Te(Sb(v[a+484360>>2],w[a+484376|0]),w[e+1097|0]);v[a+480188>>2]=4194317;Mb(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;f=0;while(1){if((f|0)==4){c:{while(1){d:{if((d|0)==32){f=0;break d}b=d+1|0;f=B(b,104)+a|0;i=f+484380|0;jd(i,2);h=e+16|0;_h(h,1,(B(d,13)+e|0)+1098|0);g=e+40|0;Cc(g,h);Ac(((b<<5)+a|0)+946304|0,g);wb(g);d=(e+1096|0)+(d<<4)|0;g=w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24);v[i>>2]=g;h=g;g=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);if(h>>>0>=g>>>0){d=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);u[f+484414>>1]=2;v[f+484388>>2]=g;v[f+484384>>2]=d}v[f+484404>>2]=8287;d=b;continue}break}while(1){if((f|0)!=32){d=f+33|0;g=(B(d,104)+a|0)+484380|0;jd(g,2);i=e+16|0;_h(i,1,(B(f,13)+e|0)+2026|0);b=e+40|0;Cc(b,i);Ac(((d<<5)+a|0)+946304|0,b);wb(b);v[e+48>>2]=0;v[e+40>>2]=0;v[e+44>>2]=0;d=(e+1096|0)+B(f,11)|0;o=Ib(b,0),p=w[d+1347|0],t[o|0]=p;o=Ib(b,1),p=w[d+1352|0],t[o|0]=p;o=Ib(b,2),p=w[d+1348|0],t[o|0]=p;o=Ib(b,3),p=w[d+1353|0],t[o|0]=p;o=Ib(b,4),p=w[d+1349|0],t[o|0]=p;o=Ib(b,5),p=w[d+1354|0],t[o|0]=p;o=Ib(b,6),p=w[d+1350|0],t[o|0]=p;o=Ib(b,7),p=w[d+1355|0],t[o|0]=p;o=Ib(b,8),p=w[d+1351|0],t[o|0]=p;o=Ib(b,9),p=w[d+1356|0],t[o|0]=p;o=Ib(b,10),p=w[d+1346|0],t[o|0]=p;v[e+8>>2]=v[e+48>>2];b=v[e+44>>2];v[e>>2]=v[e+40>>2];v[e+4>>2]=b;vl(g,1,e);f=f+1|0;continue}break}Mq(Sb(v[a+484360>>2],w[a+484376|0]),e+2794|0,256,255,65535);l=a+484344|0;vg(l,128);m=c&1;g=0;while(1){e:{f:{if((g|0)!=128){b=g<<2;Zc(j,v[b+(e+576|0)>>2]+2978|0);d=e+16|0;Wd(d,j,v[b+(e- -64|0)>>2]);b=hc(e+40|0,d);yb(d);if(!m){break e}v[23516]=0;d=W(225,l|0,g&65535,64)|0;f=v[23516];v[23516]=0;if((f|0)==1){break c}if(!d){break e}f=0;i=Xb(v[l>>2],g);while(1){if(f>>>0>63){break e}g:{while(1){h:{d=v[b>>2];v[23516]=0;d=W(154,d|0,v[e+48>>2],1)|0;h=v[23516];v[23516]=0;if((h|0)==1){break h}if(!d){break e}v[23516]=0;d=T(204,b|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break c}if(d>>>0>12){break g}h=ed(v[i>>2],v[v[i+48>>2]+12>>2],f,d);v[23516]=0;R(263,e+16|0,b|0);k=v[23516];v[23516]=0;if((k|0)==1){break c}k=w[e+16|0];d=d>>>0>3;t[h|0]=((k&15)+(d?13:37)|0)+B(k>>>4&7,12);k=Kc(e+16|0);t[h+1|0]=((w[k|0]>>>4|0)+(d?33:1)|0)+(w[e+16|0]>>>3&16);FB(h,w[k|0],d);continue}break}break c}h=d-32|0;if((h&255)>>>0<=12){h=ed(v[i>>2],v[v[i+48>>2]+12>>2],f,h&65535);v[23516]=0;k=T(204,b|0)|0;n=v[23516];v[23516]=0;if((n|0)==1){break c}FB(h,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!f){break e}o=ed(v[i>>2],v[v[i+48>>2]+12>>2],f-1|0,0),p=14,t[o+3|0]=p;break e}v[23516]=0;d=T(204,b|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break c}f=d+f|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}ug(Uc(e+40|0,8,1,0,1),(B(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}yb(b);d=0;break a}yb(b);g=g+1|0;continue}}}else{u[((f<<5)+a|0)+480284>>1]=f&1?192:64;f=f+1|0;continue}break}a=P()|0;O()|0;yb(b);S(a|0);L()}d=1}hb=e+3056|0;return d|0}function __(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;h=hb-32|0;hb=h;v[h+24>>2]=b;v[e>>2]=0;b=h+8|0;bd(b,d);v[23516]=0;b=T(19,b|0)|0;i=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((i|0)!=1){Zb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Zb(h+8|0);S(a|0);L()}$F(a,f+24|0,h+24|0,c,e,b);break b}_F(a,f+16|0,h+24|0,c,e,b);break b}b=lb[v[v[a+8>>2]+12>>2]](a+8|0)|0;g=a;i=v[h+24>>2];a=Ic(b);j=h,k=Xj(g,i,c,d,e,f,a,Fb(b)+a|0),v[j+24>>2]=k;break b}a=Ti(h+24|0,c,e,b,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;j=h,k=Xj(a,v[h+24>>2],c,d,e,f,h+8|0,h+16|0),v[j+24>>2]=k;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;j=h,k=Xj(a,v[h+24>>2],c,d,e,f,h+8|0,h+16|0),v[j+24>>2]=k;break b}a=Ti(h+24|0,c,e,b,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Ti(h+24|0,c,e,b,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Ti(h+24|0,c,e,b,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Ti(h+24|0,c,e,b,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Ti(h+24|0,c,e,b,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+24|0;d=hb-16|0;hb=d;v[d+8>>2]=c;while(1){H:{if(!jp(a,d+8|0)){break H}c=Rk(v[a>>2]);if(!qh(v[b+8>>2],8192,c)){break H}Yl(a);continue}break}if(Yj(a,d+8|0)){v[e>>2]=v[e>>2]|2}hb=d+16|0;break b}d=h+24|0;a=lb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Fb(a)|0)==(0-Fb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=Jr(d,c,a,a+24|0,b,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}b=w[84052]|w[84053]<<8|(w[84054]<<16|w[84055]<<24);t[h+15|0]=b;t[h+16|0]=b>>>8;t[h+17|0]=b>>>16;t[h+18|0]=b>>>24;b=w[84049]|w[84050]<<8|(w[84051]<<16|w[84052]<<24);v[h+8>>2]=w[84045]|w[84046]<<8|(w[84047]<<16|w[84048]<<24);v[h+12>>2]=b;j=h,k=Xj(a,v[h+24>>2],c,d,e,f,h+8|0,h+19|0),v[j+24>>2]=k;break b}t[h+12|0]=w[84060];v[h+8>>2]=w[84056]|w[84057]<<8|(w[84058]<<16|w[84059]<<24);j=h,k=Xj(a,v[h+24>>2],c,d,e,f,h+8|0,h+13|0),v[j+24>>2]=k;break b}a=Ti(h+24|0,c,e,b,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;j=h,k=Xj(a,v[h+24>>2],c,d,e,f,h+8|0,h+16|0),v[j+24>>2]=k;break b}a=Ti(h+24|0,c,e,b,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=lb[v[v[a>>2]+20>>2]](a,v[h+24>>2],c,d,e,f)|0;break a}b=lb[v[v[a+8>>2]+24>>2]](a+8|0)|0;g=a;i=v[h+24>>2];a=Ic(b);j=h,k=Xj(g,i,c,d,e,f,a,Fb(b)+a|0),v[j+24>>2]=k;break b}ZF(f+20|0,h+24|0,c,e,b);break b}a=Ti(h+24|0,c,e,b,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=hb-16|0;hb=a;v[a+8>>2]=c;c=6;d=h+24|0;L:{M:{if(Yj(d,a+8|0)){break M}c=4;if((kn(b,Rk(v[d>>2]))|0)!=37){break M}c=2;if(!Yj(Yl(d),a+8|0)){break L}}v[e>>2]=v[e>>2]|c}hb=a+16|0}a=v[h+24>>2]}hb=h+32|0;return a|0}function Lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=hb-256|0;hb=e;xc(b);a:{if(!TU(b,e+184|0)){break a}if(!tR(e+184|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(sR(e+184|0),kb))){break a}b:{if(!c){break b}zd(a,16);f=e+24|0;Aj(f,2,e+184|4);d=e+48|0;Cc(d,f);yc(a+1298308|0,d);wb(d);l=a+480190|0;u[l>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];g=vc(d,8394);Gb(a+1298344|0,g);xb(g);g=vc(d,10148);Gb(a+1298356|0,g);xb(g);Qf(f,4214);g=w[e+187|0];v[e>>2]=g>>>4;v[23516]=0;v[e+180>>2]=g&15;X(305,d|0,f|0,e|0,e+180|0);d=v[23516];v[23516]=0;c:{d:{e:{if((d|0)!=1){d=e+48|0;Gb(a+1298368|0,d);xb(d);ac(e+24|0);v[a+1298404>>2]=5;g=1;while(1){j=g&65535;if(j>>>0>x[l>>1]){g=0;d=a+480188|0;while(1)if(x[d>>1]<=g>>>0){f=e+48|0;d=hb-16|0;hb=d;h=b;f:{if(!Ob(v[b>>2],v[b+8>>2],128)){b=0;while(1){if((b|0)!=128){Ch(b+f|0);b=b+1|0;continue}break}break f}LS(d+8|0,f);pd(d,h,v[d+8>>2],v[d+12>>2])}hb=d+16|0;Wu(Sb(v[a+484360>>2],w[a+484376|0]),f,w[e+211|0]+1|0);b=w[e+216|0];Wd(e,h,B(x[e+208>>1],192));i=hc(e+24|0,e);yb(e);n=c&1;if(n){v[23516]=0;R(224,a+484344|0,w[e+210|0]+1|0);d=v[23516];v[23516]=0;if((d|0)==1){break d}}o=b?b:64;p=a+484344|0;q=a+480188|0;while(1){if(w[e+210|0]<m>>>0){b=x[e+212>>1];if(b){v[23516]=0;da(316,a+1298332|0,h|0,b|0,39,1);b=v[23516];v[23516]=0;if((b|0)==1){break d}}if(!(c&2)){break e}g=1;b=a+480190|0;while(1){c=g&65535;if(c>>>0>x[b>>1]){break e}c=B(c,104)+a|0;d=Uc(e,u[c+484414>>1]&1?16:8,1,0,1);v[23516]=0;W(218,d|0,c+484380|0,h|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){g=g+1|0;continue}break}break d}g:{h:{if(n){v[23516]=0;b=W(225,p|0,m&65535,o|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break d}k=0;if(b){break h}}v[23516]=0;Q(186,h|0,64)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break g}break d}while(1){d=k&65535;if(d>>>0>31){break g}v[23516]=0;b=T(192,h|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break d}i:{if(!b|b>>>0>x[e+208>>1]|d>>>0>=x[q>>1]){break i}v[23516]=0;Q(153,i|0,B(b,192)-192|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break d}l=0;b=Xb(v[p>>2],m);g=ed(v[b>>2],v[v[b+48>>2]+12>>2],0,d);while(1){if((l|0)==(o|0)){break i}v[23516]=0;R(543,e|0,i|0);b=v[23516];v[23516]=0;if((b|0)!=1){j=Kc(e);d=Re(e);b=w[e|0];if(b>>>0>=4){t[g|0]=(b>>>2|0)+37;b=w[e|0]}t[g+1|0]=b<<4&48|w[j|0]>>>4;b=w[d|0];d=0;f=0;j:{k:{l:{m:{n:{o:{j=w[j|0]&15;switch(j-8|0){case 0:break l;case 6:break n;case 2:break o;default:break m}}b=(b&240?-16:15)&b;j=10;break k}j=14;r=(b+16&240)>>>4|0;if(r>>>0>8){break k}if(1<<r&435){break l}break k}d=j;f=b}j=d;b=f;if(!((d|b)&255)){break j}}Nf(g,j,b&255)}l=l+1|0;g=B(x[q>>1],6)+g|0;continue}break}break d}k=k+1|0;continue}}m=m+1|0;continue}}else{f=(g<<5)+a|0;af(f+480280|0);u[f+480284>>1]=(w[(e+g|0)+218|0]<<4|8)&248;g=g+1|0;continue}}else{f=e+48|0;vC(b,f);h=hb-16|0;hb=h;d=(B(j,104)+a|0)+484380|0;jd(d,0);u[h+14>>1]=w[f+35|0]<<2;u[h+12>>1]=256;s=d,y=x[Rc(h+14|0,h+12|0)>>1],u[s+30>>1]=y;i=w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24);p:{if(i>>>0<3){break p}v[d>>2]=i;v[d+4>>2]=w[f+26|0]|w[f+27|0]<<8|(w[f+28|0]<<16|w[f+29|0]<<24);v[h+8>>2]=w[f+30|0]|w[f+31|0]<<8|(w[f+32|0]<<16|w[f+33|0]<<24);v[h+4>>2]=1;s=d,y=v[Vc(h+8|0,h+4|0)>>2]-1|0,v[s+8>>2]=y;uc(d+8|0,i);k=v[d+8>>2];i=v[d+4>>2];q:{if(k>>>0<=i+4>>>0){v[d+4>>2]=0;v[d+8>>2]=0;k=0;i=0;break q}u[d+34>>1]=x[d+34>>1]|2;k=k>>>1|0;i=i>>>1|0}t[d+37|0]=w[f+34|0];s=d,y=Ku(0,t[f+34|0]<<4),v[s+24>>2]=y;if(!(t[f+36|0]&1)){break p}v[d+8>>2]=k;v[d+4>>2]=i;u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1}hb=h+16|0;xl(e,2,f);d=e+24|0;Cc(d,e);Ac(((j<<5)+a|0)+946304|0,d);g=g+1|0;wb(d);continue}}}g=P()|0;O()|0;ac(e+24|0);break c}v[a+480260>>2]=64;v[a+480264>>2]=32767;yb(i);break b}g=P()|0;O()|0;yb(i)}S(g|0);L()}g=1}hb=e+256|0;return g|0}function $j(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=1;o(+b);f=j(1)|0;d=j(0)|0;a:{b:{m=f&2147483647;g=d;c:{if(!(m|d)){break c}o(+a);d=j(1)|0;t=j(0)|0;if(!t&(d|0)==1072693248){break c}q=d&2147483647;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(t|0)!=0|m>>>0>2146435072)&(!g|(m|0)!=2146435072))){return a+b}d:{e:{f:{r=0;g:{if((d|0)>0|(d|0)>=0){break g}r=2;if(m>>>0>1128267775){break g}r=0;if(m>>>0<1072693248){break g}h=m>>>20|0;if(m>>>0<1094713344){break f}e=1075-h|0;h=g>>>e|0;r=0;if((g|0)!=h<<e){break g}r=2-(h&1)|0}e=r;if(!g){break e}break d}if(g){break d}g=1043-h|0;h=m>>>g|0;e=0;if((m|0)!=h<<g){break e}e=2-(h&1)|0}if((m|0)==2146435072){if(!(q-1072693248|t)){break c}if(q>>>0>=1072693248){return(f|0)>0|(f|0)>=0?b:0}return(f|0)>0|(f|0)>=0?0:-b}if((m|0)==1072693248){if((f|0)>0|(f|0)>=0){return a}return 1/a}if((f|0)==1073741824){return a*a}if((f|0)!=1071644672|(d|0)<0){break d}return K(a)}c=D(a);h:{if(t){break h}i:{if((d|0)<0){if((d|0)==-2147483648|(d|0)==-1074790400){break i}if((d|0)!=-1048576){break h}break i}if(!d|(d|0)==2146435072){break i}if((d|0)!=1072693248){break h}}k=(f|0)<0?1/c:c;if((d|0)>0|(d|0)>=0){break c}if(!(q-1072693248|e)){a=k-k;return a/a}return(e|0)==1?-k:k}j:{if((d|0)>0|(d|0)>=0){break j}k:{switch(e|0){case 0:a=a-a;return a/a;case 1:break k;default:break j}}k=-1}l:{if(m>>>0>=1105199105){if(m>>>0>=1139802113){if(q>>>0<=1072693247){return(f|0)<0?N:0}return(f|0)>0?N:0}if(q>>>0<=1072693246){return(f|0)<0?k*1e300*1e300:k*1e-300*1e-300}if(q>>>0>=1072693249){return(f|0)>0?k*1e300*1e300:k*1e-300*1e-300}a=c+-1;c=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;i=c;c=a*1.4426950216293335;o(+(i+c));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=i-(a-c);break l}a=c*9007199254740992;g=q>>>0<1048576;c=g?a:c;o(+a);e=j(1)|0;j(0)|0;h=g?e:q;d=h&1048575;e=d|1072693248;h=(h>>20)+(g?-1076:-1023)|0;g=0;m:{if(d>>>0<235663){break m}if(d>>>0<767610){g=1;break m}e=d|1071644672;h=h+1|0}d=g<<3;w=A[d+3536>>3];o(+c);j(1)|0;q=0;l(0,j(0)|q);l(1,e|0);p=+n();s=A[d+3520>>3];i=p-s;u=1/(s+p);c=i*u;o(+c);m=j(1)|0;j(0)|0;l(0,0);l(1,m|0);a=+n();x=a;l(0,q|0);l(1,((g<<18)+(e>>>1|0)|0)+537395200|0);v=a*a;y=i;i=+n();p=u*(y-a*i-a*(p-(i-s)));i=p*(c+a);a=c*c;s=i+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();i=x*a;c=p*a+c*(s-(a+-3-v));o(+(i+c));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=w+(a*-7.028461650952758e-9+(c-(a-i))*.9617966939259756);i=c;p=A[d+3552>>3];c=a*.9617967009544373;s=+(h|0);o(+(p+(i+c)+s));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=i-(a-s-p-c)}l(0,0);l(1,f|0);p=+n();c=(b-p)*a+c*b;b=a*p;a=c+b;o(+a);d=j(1)|0;e=j(0)|0;n:{f=d;if((d|0)>=1083179008){if(e|f-1083179008){break b}if(!(c+8.008566259537294e-17>a-b)){break n}break b}if((f&2147482624)>>>0<1083231232){break n}if(e|f+1064252416){break a}if(!(c<=a-b)){break n}break a}g=0;h=f&2147483647;if(h>>>0>=1071644673){e=f+(1048576>>>(h>>>20|0)-1022|0)|0;f=e>>>20&2047;g=(e&1048575|1048576)>>>1043-f|0;g=(d|0)<0?0-g|0:g;l(0,0);l(1,e&-1048576>>f-1023);b=b-+n();o(+(c+b));d=j(1)|0;j(0)|0}l(0,0);l(1,d|0);a=+n();p=a*.6931471824645996;c=(c-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=p+c;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);i=a*b/(b+-2);b=a;a=c-(a-p);a=b-(i-(b*a+a))+1;o(+a);e=j(1)|0;d=j(0)|0;e=(g<<20)+e|0;o:{if((e|0)<=1048575){a=Vj(a,g);break o}l(0,d|0);l(1,e|0);a=+n()}k=k*a}return k}return k*1e300*1e300}return k*1e-300*1e-300}function via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=hb-736|0;hb=h;a:{b:{if(d>>>0<=511){a=hb-16|0;hb=a;e=h+56|0;ec(a+8|0,e,554);d=v[a+12>>2];jc(a,v[b>>2],v[b+8>>2],v[a+8>>2],d);f=v[a+4>>2];if((f|0)==(d|0)){Yb(b,v[a+12>>2])}hb=a+16|0;a=(d|0)==(f|0);if(!a){Rb(e,0,554)}if(!a){break b}d=hb-32|0;hb=d;c:{a=h+56|0;if(Qb(a,14083,4)){break c}Uq(d,a+32|0);b=d+16|0;Cc(b,d);Ac(c+492|0,b);wb(b);_h(d,1,a+4|0);Cc(b,d);Ac(c+524|0,b);wb(b);b=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];f=c+108|0;g=c+236|0;b=0;while(1)if((b|0)==120){b=w[c+60|0]&-2|t[a+17|0]&1;t[c+60|0]=b;b=b&-3|w[a+17|0]&2;t[c+60|0]=b;t[c+60|0]=b&251|w[a+17|0]&4;g=c+61|0;t[g|0]=w[a+18|0];i=c+62|0;t[i|0]=w[a+19|0];j=c+63|0;t[j|0]=w[a+20|0];k=c- -64|0;t[k|0]=w[a+21|0];f=c+48|0;Mg(f,25);e=v[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=Bb(e,b);m=b<<1;n=w[(a+m|0)+504|0];u[l>>1]=n;if((n|0)!=255){break d}Mg(f,b);e=v[f>>2]}b=ef(g,i);a=Qd(e,v[c+52>>2]);if(a>>>0<=w[b|0]){t[c+60|0]=w[c+60|0]&253}if(a>>>0>w[ef(j,k)|0]){break c}t[c+60|0]=w[c+60|0]&251;break c}t[l+2|0]=w[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{i=a+(b<<1)|0;e=w[i- -64|0];o=$b(g,b),p=w[i+65|0],u[o>>1]=p;o=Ib(f,b),p=(e>>>0<120?e:b)+1|0,t[o|0]=p;b=b+1|0;continue}}hb=d+32|0;break b}i=v[b+8>>2];d=hb-32|0;hb=d;v[d+28>>2]=674;v[d+8>>2]=674;e=v[b>>2];g=v[b+8>>2];f=v[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,g,f)){f=$e(b)}j=d+8|0;e=h+56|0;oT(j,e);g=fc(d+16|0,v[d+8>>2],f);jc(d,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);oT(j,e);Rb(v[d+8>>2]+f|0,0,674-f|0);Yb(b,v[d+28>>2]);hb=d+32|0;f=v[a+480180>>2];a=0;d=hb-32|0;hb=d;if(!Qb(e,14083,4)){Uq(d,e+32|0);a=d+16|0;Cc(a,d);Ac(c+492|0,a);wb(a);_h(d,1,e+4|0);Cc(a,d);Ac(c+524|0,a);wb(a);v[c>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[c+4>>2]=w[e+24|0]>>>1;uc(c+4|0,64);g=w[e+25|0]&127;v[c+8>>2]=g>>>0>64?128:g<<2;t[c+15|0]=w[c+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[d+16|0]=w[e+26|0];t[d|0]=100;o=c,p=w[Vb(a,d)|0],t[o+20|0]=p;t[d+16|0]=w[e+27|0];t[d|0]=64;o=c,p=w[Vb(a,d)|0],t[o+19|0]=p;t[c+16|0]=w[e+17|0];t[c+17|0]=w[e+18|0];t[c+18|0]=w[e+19|0];t[c+26|0]=w[e+22|0];t[c+27|0]=w[e+23|0];a=w[e+58|0];Ij(c,a&127,a>>>7|0);a=w[e+59|0];Hj(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=w[e+28|0]|w[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=w[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){t[c+30|0]=a}a=w[e+62|0]|w[e+63|0]<<8;if(a>>>0<129){break f}break e}a=t[e+61|0];if((a|0)<0){break g}t[c+30|0]=a+1}a=w[e+62|0];a=a<<24>>24>=0?a+1|0:0;g=t[e+63|0];if((g|0)<0){break f}a=((g&255)<<7)+a|0}u[c+28>>1]=a}a=t[e+60|0];t[c+31|0]=a;if((a|0)<0){t[c+31|0]=0;t[c+34|0]=a^128}a=0;f=f&16777216?240:25;gv(e+304|0,c+48|0,0,f);gv(e+386|0,c+68|0,32,f);gv(e+468|0,c+88|0,32,f);t[c+100|0]=w[c+100|0]&239|w[e+468|0]>>>3&16;g=c+108|0;j=c+236|0;while(1){if((a|0)!=120){k=e+(a<<1)|0;f=w[k- -64|0];o=$b(j,a),p=w[k+65|0],u[o>>1]=p;o=Ib(g,a),p=(f>>>0<120?f:a)+1|0,t[o|0]=p;a=a+1|0;continue}break}a=554}hb=d+32|0;d=0;k:{if(!a){break k}d=e+550|0;l:{if(Qb(d,13552,4)){if(Qb(d,13911,4)){break l}}d=c+236|0;a=0;while(1){if((a|0)!=120){f=$b(d,a);u[f>>1]=x[f>>1]|w[(a+e|0)+554|0]<<8;a=a+1|0;continue}break}a=674}d=a}Zc(b,d+i|0);if(!Fh(b,14088)){break b}d=h+8|0;Wd(d,b,zg(b));a=hc(h+32|0,d);yb(d);b=v[a>>2];v[23516]=0;T(158,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break a}v[23516]=0;b=Q(410,a|0,13834)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}if(b){v[23516]=0;b=T(204,a|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}t[c+34|0]=b>>>0>250?0:b}yb(a)}hb=h+736|0;return}b=P()|0;O()|0;yb(a);S(b|0);L()}function MM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;g=a+1074376|0;h=B(b,872);e=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(uj(v[e+656>>2])){a=B(b,872)+a|0;u[a+1075764>>1]=d-8;a=a+1075843|0;t[a|0]=w[a|0]|64;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=d<<28>>24;c=x[(d<<1)+33456>>1];v[b+1075696>>2]=c;e=b+1075692|0;if(!v[e>>2]){break a}l=e,m=_g(a,w[b+1075789|0],d<<28>>24,c),v[l>>2]=m;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(d,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}Ab(f+8|0,a+1074312|0,21);if(zb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}Ab(f+8|0,a+1074312|0,21);if(zb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Ab(f+8|0,a+1074312|0,21);if(zb(v[v[f+8>>2]>>2],v[f+12>>2])){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+d;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(d>>>0<=2){d=x[a+480188>>1];h=d>>>0>256?d:256;i=a+906300|0;j=b+1|0;k=(c&15)-1|0;while(1){if((d|0)==(h|0)){break a}c=B(d,872)+a|0;c:{if(x[c+1075778>>1]!=(j|0)){break c}d:{e:{switch(k|0){case 0:Kn(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}e=v[a+1298300>>2];if(!vd(e)){break d}fk(e,d&65535);break d;case 1:g=c+1075080|0;e=v[g>>2];v[g>>2]=e|4096;if(!(e&512)){break d}e=v[a+1298300>>2];if(!vd(e)){break d}fk(e,d&65535);break d;default:break e}}v[c+1075688>>2]=0;g=c+1075080|0;e=v[g>>2];v[g>>2]=e|4096;if(!(e&512)){break d}e=v[a+1298300>>2];if(!vd(e)){break d}nj(e,d&65535,1)}e=v[c+1075648>>2];if(!e){break c}g=w[e+34|0];if(!g){break c}g=v[Id(i,g-1|0)>>2];if(!g){break c}lb[v[v[g>>2]+96>>2]](g,e,w[c+1075789|0]|256,0,b)}d=d+1|0;continue}}eP(e,d,v[a+480180>>2]);break a;case 7:if(!(w[a+480209|0]&16)){break a}lm(a,e,d,4);break a;case 8:b=e;c=v[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d&15){case 0:v[b+88>>2]=v[b+88>>2]&-257;break f;case 1:v[b+692>>2]=128;v[b+88>>2]=v[b+88>>2]|256;break f;case 8:v[b+88>>2]=v[b+88>>2]&-25165825|16777216;break f;case 9:v[b+88>>2]=v[b+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=c&-16385;break f;case 11:v[a+480208>>2]=c|16384;break f;case 12:v[a+480208>>2]=c&-8193;break f;case 13:v[a+480208>>2]=c|8192;break f;case 14:v[b+88>>2]=v[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(v[b>>2]|v[b+4>>2]){break h}a=v[b+76>>2];if(!a){break h}if(!(l=Wc(w[b+788|0]),m=1,n=w[b+88|0]&2,n?l:m)){break h}v[b>>2]=-1;v[b+4>>2]=a-1}v[b+88>>2]=v[b+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=d;Ab(f+8|0,a+1074312|0,35);if(zb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}if(!Wc(w[c+1075780|0])){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}v[e+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}Qy(a,g,e,d);break a;case 11:i:{if(d){break i}d=1;c=v[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Ab(f+8|0,a+1074312|0,30);yy(a,b,d,zb(v[v[f+8>>2]>>2],v[f+12>>2])|v[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=d}hb=f+16|0}function PJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=hb-192|0;hb=g;v[g+188>>2]=c;v[g+184>>2]=b;a:{if(!c){break a}h=w[Xk(b,c)|0];if((h|0)==33){f=1}else{if((h|0)!=63){break a}f=0}cl(g+8|0,b,c,c-1|0);b=v[g+12>>2];v[g+184>>2]=v[g+8>>2];v[g+188>>2]=b}c=g+8|0;Rd(c);b=v[g+8>>2];Rd(g+160|0);b=Wk(b,v[g+164>>2],g+184|0);Rd(c);h=v[g+188>>2];c=v[g+184>>2];b:{c:{d:{e:{if((b|0)==v[g+12>>2]){a=qc(g+176|0,21751);if(Mc(c,h,v[a>>2],v[a+4>>2])){f=ba(8)|0;v[23516]=0;b=Lh(g+160|0,d,e);a=v[23516];v[23516]=0;f:{g:{h:{if((a|0)!=1){v[23516]=0;U(981,g+8|0,17730,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}d=0;a=rc(f,g+8|0);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(g+8|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}wb(b);if(!d){break c}}ca(f|0);break c}if(!f){break e}i=ba(8)|0;v[23516]=0;h=Lh(g+128|0,v[g+184>>2],v[g+188>>2]);a=v[23516];v[23516]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23516]=0;U(981,g+144|0,17766,h|0);a=v[23516];v[23516]=0;if((a|0)==1){break q}v[23516]=0;R(983,g+160|0,g+144|0);a=v[23516];v[23516]=0;f=1;if((a|0)==1){break p}v[23516]=0;b=Lh(g+112|0,d,e);a=v[23516];v[23516]=0;if((a|0)==1){break o}v[23516]=0;U(985,g+8|0,g+160|0,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break n}a=rc(i,g+8|0);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(g+8|0);f=0;break m}c=P()|0;O()|0;break i}c=P()|0;f=1;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;O()|0;break l}c=P()|0;O()|0}wb(b)}wb(g+160|0)}wb(g+144|0)}wb(h);if(!f){break c}}ca(i|0);break c}b=qc(g+104|0,21751);if(Mc(c,h,v[b>>2],v[b+4>>2])){f=ba(8)|0;v[23516]=0;b=Lh(g+160|0,d,e);a=v[23516];v[23516]=0;r:{s:{t:{if((a|0)!=1){v[23516]=0;U(981,g+8|0,17730,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break t}d=0;a=rc(f,g+8|0);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(g+8|0);break s}c=P()|0;O()|0;break r}c=P()|0;d=1;O()|0}wb(b);if(!d){break c}}ca(f|0);break c}b=qc(g+96|0,12389);if(Mc(c,h,v[b>>2],v[b+4>>2])){b=qc(g+88|0,5604);if(Mc(d,e,v[b>>2],v[b+4>>2])){v[a+52>>2]=0;break e}b=qc(g+80|0,11321);if(Mc(d,e,v[b>>2],v[b+4>>2])){v[a+52>>2]=1;break e}b=qc(g+72|0,9235);if(Mc(d,e,v[b>>2],v[b+4>>2])){v[a+52>>2]=2;break e}f=ba(8)|0;v[23516]=0;b=Lh(g+160|0,d,e);a=v[23516];v[23516]=0;u:{v:{w:{if((a|0)!=1){v[23516]=0;U(981,g+8|0,14709,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break w}d=0;a=rc(f,g+8|0);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(g+8|0);break v}c=P()|0;O()|0;break u}c=P()|0;d=1;O()|0}wb(b);if(!d){break c}}ca(f|0);break c}b=qc(g- -64|0,11558);if(!Mc(c,h,v[b>>2],v[b+4>>2])){break e}b=0;x:{c=qc(g+56|0,15693);if(Mc(d,e,v[c>>2],v[c+4>>2])){break x}b=1;c=qc(g+48|0,15698);if(Mc(d,e,v[c>>2],v[c+4>>2])){break x}b=2;c=qc(g+40|0,12663);if(Mc(d,e,v[c>>2],v[c+4>>2])){break x}b=3;c=qc(g+32|0,9299);if(Mc(d,e,v[c>>2],v[c+4>>2])){break x}d=ba(8)|0;v[23516]=0;b=Q(53,g+8|0,11594)|0;a=v[23516];v[23516]=0;if((a|0)==1){break d}a=rc(d,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}v[a+56>>2]=b;d=v[a+24>>2];if(!v[d+24668>>2]){break e}c=d+24664|0;a=v[c+4>>2];v[g+24>>2]=v[c>>2];v[g+28>>2]=a;c=d+24656|0;a=v[c+4>>2];v[g+16>>2]=v[c>>2];v[g+20>>2]=a;a=v[d+24652>>2];v[g+8>>2]=v[d+24648>>2];v[g+12>>2]=a;j=g,k=qJ(b),v[j+28>>2]=k;if(!ox(g+8|0,d+24648|0)){break e}hy(d,g+8|0)}hb=g+192|0;return}c=P()|0;O()|0;ca(d|0)}S(c|0)}L()}function Pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-192|0;hb=e;a:{b:{if(Ob(v[c>>2],v[c+8>>2],8)){Yb(c,4);while(1){if(Tt(v[c>>2],v[c+8>>2])){break b}m=hb-288|0;hb=m;f=BO(m);h=hb-384|0;hb=h;i=pc(f,BO(h+96|0),282);f=0;c:{d:{e:{f:{g:{if(Fh(c,13725)){wg(c,4);l=he(h+72|0,c);v[23516]=0;j=Q(777,l|0,i|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break g}h:{if(!j){break h}j=v[l+8>>2];g=v[l>>2];k=w[i+26|0];v[23516]=0;j=W(154,g|0,j|0,k|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break g}if(!j){break h}j=0;i:{while(1){if(w[i+26|0]<=f>>>0){g=v[l+8>>2];k=v[l>>2];f=0;v[23516]=0;j=j&65535;g=W(154,k|0,g|0,j|0)|0;k=v[23516];v[23516]=0;if((k|0)==1){break e}if(!g){break h}v[23516]=0;Q(186,l|0,j|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}wg(l,CO(i));f=wh(h- -64|0);g=h+96|0;ez(g);v[23516]=0;R(778,l|0,g|0);g=v[23516];v[23516]=0;if((g|0)!=1){u[h+118>>1]=0;u[h+120>>1]=0;f=fz(f,h+96|0,h+123|0);g=w[i+26|0];v[23516]=0;Q(186,l|0,g|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){break i}}f=P()|0;O()|0;break d}v[23516]=0;g=T(196,l|0)|0;k=v[23516];v[23516]=0;if((k|0)!=1){t[(f+i|0)+27|0]=g;f=f+1|0;j=g+j|0;continue}break}f=P()|0;O()|0;break d}k=f;f=i+27|0;k=fz(k,f,f+w[i+26|0]|0);v[23516]=0;U(188,h+16|0,l|0,j|0);f=v[23516];v[23516]=0;if((f|0)==1){break f}g=h+16|0;j=hc(h+40|0,g);yb(g);f=0;v[23516]=0;R(569,g|0,j|0);g=v[23516];v[23516]=0;if((g|0)==1){f=P()|0;O()|0;yb(j);break d}g=h+16|0;_B(h+8|0,g);n=k;k=v[h+8>>2];k=fz(n,k,Ib(k,v[h+12>>2]));Qc(g);yb(j);if(v[k>>2]!=(w[i+22|0]|w[i+23|0]<<8|(w[i+24|0]<<16|w[i+25|0]<<24))){break h}f=CO(i);v[23516]=0;Q(186,c|0,f|0)|0;i=v[23516];v[23516]=0;f=1;if((i|0)==1){break e}}yb(l)}hb=h+384|0;break c}f=P()|0;O()|0;break d}f=P()|0;O()|0;break d}f=P()|0;O()|0}yb(l);S(f|0);L()}hb=m+288|0;if(f){continue}break}}xc(c);ug(b,a,c);a=1;break a}t[d|0]=1;xc(c);f=zg(c);d=e+144|0;Wd(d,c,$e(c));h=hc(e+168|0,d);yb(d);b=x[a+34>>1]&-66|w[b|0]>15|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=f>>>(b&1)>>>(b>>>6&1);v[e+140>>2]=0;v[e+136>>2]=0;v[23516]=0;R(569,d|0,h|0);b=v[23516];v[23516]=0;j:{k:{l:{m:{if((b|0)!=1){c=Ee(e+144|0);d=v[e+144>>2];i=iA(c,Di(d),e+140|0,e+136|0);v[23516]=0;b=v[e+140>>2];Q(186,h|0,b|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){if(!i){break j}Jg(a);l=b+c|0;b=d-b|0;d=v[e+136>>2];c=0;while(1){n:{if(d){if(!b|(d|0)!=1){break k}d=v[a>>2];if(d>>>0>c>>>0){break n}break k}d=v[a>>2];if(d>>>0<=c>>>0){break k}}if(!Vd(d,v[a+20>>2])){break k}v[e+132>>2]=0;v[e+128>>2]=0;j=eS(i,l,Di(b),e+132|0,e+124|0,e+128|0);v[23516]=0;Q(186,h|0,j|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break m}bi(e+128|0,Di(v[a>>2]-c|0));d=v[e+128>>2];o:{if((d|0)<=0){break o}f=v[e+132>>2];k=x[a+34>>1];if((Hd(k)|0)!=(f|0)){break o}m=B(c,f);g=v[a+20>>2];if(k&1){v[e+120>>2]=d;v[e+104>>2]=d;v[e+56>>2]=d;v[e+40>>2]=d;v[e+100>>2]=f;v[e+96>>2]=v[e+124>>2];v[e+116>>2]=f;v[e+112>>2]=g+(m<<1);v[23516]=0;f=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=f;f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;R(570,e+48|0,e+32|0);f=v[23516];v[23516]=0;if((f|0)!=1){break o}break m}v[e+88>>2]=d;v[e+72>>2]=d;v[e+24>>2]=d;v[e+8>>2]=d;v[e+68>>2]=f;v[e+64>>2]=v[e+124>>2];v[e+84>>2]=f;v[e+80>>2]=g+m;v[23516]=0;f=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=f;f=v[e+84>>2];v[e+16>>2]=v[e+80>>2];v[e+20>>2]=f;R(571,e+16|0,e|0);f=v[23516];v[23516]=0;if((f|0)==1){break m}}b=b-j|0;l=j+l|0;c=c+d|0;d=dS(i);continue}}break m}c=P()|0;O()|0;break l}c=P()|0;O()|0;Qc(e+144|0)}yb(h);S(c|0);L()}cS(i)}Qc(e+144|0);yb(h);a=(i|0)!=0}hb=e+192|0;return a|0}function Qaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;i=hb-32|0;hb=i;s=v[a+4>>2];e=_e(v[a+8>>2],b);y=v[e>>2];a:{if(y+1>>>0<2){break a}j=(B(b,872)+s|0)+616|0;if(!(I=1,J=zi(v[j+8>>2],v[j+12>>2]),K=w[e+4|0],K?I:J)){break a}h=B(b,872)+s|0;if(!v[h+720>>2]){break a}g=v[h+704>>2]&2;e=v[(g?h+700|0:h+692|0)>>2];k=v[h+700>>2];f=v[h+696>>2];Ab(i+8|0,v[a>>2]+1074312|0,31);z=zb(v[v[i+8>>2]>>2],v[i+12>>2]);m=mf(v[h+624>>2],v[h+628>>2],c);q=m;l=w[h+704|0]&128;m=l?0-m|0:m;n=kb;l=l?0-(n+((q|0)!=0)|0)|0:n;q=e;D=g?A:0;e=f;r=g?e:0;n=k-e|0;F=n<<1;G=h+1316|0;o=h+1467|0;E=h+1362|0;A=(w[E|0]&17)!=1;b:{c:{while(1){if((p|0)!=(y|0)){d:{if(d>>>0>p>>>0){f=(w[E|0]&17)==1;break d}v[v[a+4>>2]+16>>2]=p-d;t[o|0]=w[o|0]&254|(d|0)==(p|0);f=v[a>>2];k=v[a+4>>2];e=Xb(v[f+484344>>2],x[k+70>>1]);e=ed(v[e>>2],v[v[e+48>>2]+12>>2],v[k+48>>2],b);g=w[e+3|0];e:{f:{switch(w[e+2|0]-11|0){case 0:k=i+8|0;Ry(k,f,g,w[e+4|0],0);k=Re(k);Ys(v[a>>2],v[a+4>>2],b,x[i+8>>1]);f=1;if(!w[k|0]){break e}break d;case 1:u=w[e+4|0];Ab(i+8|0,f+1074312|0,12);Ly(f,k,b,u<<2&252,zb(v[v[i+8>>2]>>2],v[i+12>>2]));break e;case 2:break f;default:break e}}u=w[e+4|0];Ab(i+8|0,f+1074312|0,12);Ky(f,k,b,u<<2&252,zb(v[v[i+8>>2]>>2],v[i+12>>2]))}f=1;g:{h:{i:{j:{k:{switch(g-2|0){default:if(g-38>>>0<4){break h}if((g|0)==19){break j}if((g|0)!=28){break g}e=w[e+5|0];f=e&240;if((f|0)==32){break i}if((f|0)!=16){break g}Jy(v[a>>2],j,e&15);break g;case 2:Ys(v[a>>2],v[a+4>>2],b,w[e+5|0]);break g;case 4:Ys(v[a>>2],v[a+4>>2],b,0);break g;case 0:e=w[e+5|0];g=v[a>>2];if(!e&(t[g+480180|0]&1)){break d}Ly(g,v[a+4>>2],b,e,0);break g;case 1:break k;case 3:break d}}e=w[e+5|0];g=v[a>>2];if(!e&(t[g+480180|0]&1)){break d}Ky(g,v[a+4>>2],b,e,0);break g}f=w[e+5|0];e=f&15;if(!(v[v[a>>2]+480180>>2]&1048580?1:e)){break g}f=f&240;if((f|0)!=32){if((f|0)!=16){break g}Iy(v[a>>2],j,e);break g}Hy(v[a>>2],j,e);break g}Gy(v[a>>2],j,e&15);break g}lN(v[a>>2],j,w[e+5|0],(g|0)==38|(g|0)==40,(g&254)==40)}f=1}v[i+28>>2]=v[G>>2];if(z){Xs(v[a>>2],j)}if(!A){kN(v[a>>2],j,i+28|0);f=1}if(!z){Xs(v[a>>2],j)}v[i+24>>2]=0;jN(j,i+24|0);l:{if(w[h+705|0]&2){break l}m:{if(!f){if(!w[_e(v[a+8>>2],b)+4|0]){break m}}if(w[o|0]&96){fP(j,C(1),0,v[a>>2]);e=w[o|0];t[o|0]=(e&64?-65:-33)&e}Sy(i+8|0,v[a>>2],j,v[i+28>>2],0);e=v[i+12>>2];v[h+624>>2]=v[i+8>>2];v[h+628>>2]=e;I=_e(v[a+8>>2],b),J=0,t[I+4|0]=J;e=mf(v[h+624>>2],v[h+628>>2],c);f=w[h+704|0]&128;m=f?0-e|0:e;g=kb;l=f?0-(g+((e|0)!=0)|0)|0:g}Pb(j,m,l);k=v[j>>2];e=v[j+4>>2];if((k>>>0<H>>>0&(e|0)<=(q|0)|(e|0)<(q|0))&((e|0)>=(r|0)&k>>>0>=D>>>0|(e|0)>(r|0)|((l|0)>0|(l|0)>=0))){break l}g=v[h+704>>2];if(!(g&2)){break c}if(g&4){f=v[h+696>>2];if(k>>>0<D>>>0&(e|0)<=(r|0)|(e|0)<(r|0)){I=j,J=Pg(0,f<<1,k,e),v[I>>2]=J;e=kb;v[j+4>>2]=e;v[h+704>>2]=g^128;g=m;m=0-g|0;l=0-(((g|0)!=0)+l|0)|0}Ab(i+8|0,v[a>>2]+1074312|0,33);e=(e-f>>>0)%(F-zb(v[v[i+8>>2]>>2],v[i+12>>2])>>>0)|0;n:{if(e>>>0<n>>>0){f=e+v[h+696>>2]|0;break n}f=v[h+700>>2]+(n-e|0)|0}v[j+4>>2]=f;f=v[h+704>>2];if((f&128)>>>7^e>>>0<n>>>0){break l}v[h+704>>2]=f^128;e=m;m=0-e|0;l=0-(((e|0)!=0)+l|0)|0;break l}f=e;g=v[h+700>>2];if(e>>>0>=g+n>>>0){f=g+((f-g>>>0)%(n>>>0)|0)|0}while(1){e=f;f=e-n|0;if(e>>>0>=g>>>0){continue}break}v[j>>2]=k;v[j+4>>2]=e}p=p+1|0;continue}break}v[v[a+4>>2]+16>>2]=0;break b}v[v[a+4>>2]+16>>2]=0;hP(j);v[(B(b,872)+s|0)+1324>>2]=0}I=_e(v[a+8>>2],b),J=0,v[I>>2]=J}hb=i+32|0}function gja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=hb-976|0;hb=e;xc(b);d=hb-16|0;hb=d;h=e+872|0;hU(d+8|0,h);f=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],f);g=v[d+4>>2];if((g|0)==(f|0)){Yb(b,v[d+12>>2])}hb=d+16|0;d=(f|0)==(g|0);if(!d){gU(h)}a:{if(!d){break a}if(!jU(e+872|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(iU(w[e+919|0]|w[e+920|0]<<8),kb))){break a}if(!c){l=1;break a}zd(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[e+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Mb(a+1074312|0,7,1);d=e+96|0;f=vc(d,8253);Gb(a+1298344|0,f);xb(f);f=vc(d,8941);Gb(a+1298356|0,f);xb(f);v[a+1298404>>2]=5;f=e+16|0;fU(f,e+872|4);Cc(d,f);yc(a+1298308|0,d);wb(d);d=0;while(1){if((d|0)==16){b:{d=x[e+968>>1];if(d){rB(a+1298332|0,b,d,132,0)}d=hb-16|0;hb=d;h=e+96|0;ec(d+8|0,h,771);f=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],f);g=v[d+4>>2];if((g|0)==(f|0)){Yb(b,v[d+12>>2])}hb=d+16|0;l=(f|0)==(g|0);if(!l){Rb(h,0,771)}if(!l){break a}d=a+484360|0;f=a+484376|0;eU(Sb(v[d>>2],w[f|0]),e+96|0,w[e+353|0]);Te(Sb(v[d>>2],w[f|0]),w[e+354|0]);Zc(b,w[e+919|0]|w[e+920|0]<<8);o=a+484344|0;p=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}lV(b,e- -64|0);d=0;while(1){if((d|0)==64){break a}if(!(w[e- -64+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!$A(b,e+16|0)){break a}d=d+1|0;u[a+480190>>1]=d;Ke(e,1,e+16|0);h=e+72|0;Cc(h,e);Ac(((x[a+480190>>1]<<5)+a|0)+946304|0,h);wb(h);c=(B(d,104)+a|0)+484380|0;jd(c,0);i=w[e+48|0]|w[e+49|0]<<8|(w[e+50|0]<<16|w[e+51|0]<<24);v[c>>2]=i;f=w[e+54|0]|w[e+55|0]<<8|(w[e+56|0]<<16|w[e+57|0]<<24);v[c+4>>2]=f;g=w[e+58|0]|w[e+59|0]<<8|(w[e+60|0]<<16|w[e+61|0]<<24);v[c+24>>2]=16726;v[c+8>>2]=g;u[c+30>>1]=w[e+53|0]<<4;if(t[e+62|0]&1){g=g>>>1|0;v[c+8>>2]=g;f=f>>>1|0;v[c+4>>2]=f;v[c>>2]=i>>>1}if(!(!(w[e+63|0]&8)|f>>>0>=g>>>0)){u[c+34>>1]=x[c+34>>1]|2}Uc(h,t[e+62|0]&1?16:8,1,0,0);ug(h,c,b);continue}}d:{d=(h<<1)+e|0;g=w[d+355|0]|w[d+356|0]<<8;if(g){f=e+72|0;Wd(f,b,g);i=hc(e+16|0,f);yb(f);n=((w[d+355|0]|w[d+356|0]<<8)-2|0)/64|0;e:{if(!p){break e}v[23516]=0;d=W(225,o|0,h&65535,n|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break d}if(!d){break e}v[23516]=0;d=T(204,i|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break b}v[23516]=0;Q(186,i|0,1)|0;f=v[23516];v[23516]=0;if((f|0)==1){break b}q=d?d>>>0<n-2>>>0?d+1|0:-1:-1;f=0;f:while(1){g:{d=Xb(v[o>>2],h);if((f|0)==(n|0)){break g}m=0;r=xf(v[d>>2],v[v[d+48>>2]+12>>2],f);while(1){if((m|0)==16){f=f+1|0;continue f}v[23516]=0;R(356,e+72|0,i|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}d=B(m,6)+r|0;j=e+72|0;g=Re(j);j=Ji(j);k=w[e+72|0];if((k-1&255)>>>0<=71){t[d|0]=k+36;s=d,y=w[Kc(e+72|0)|0]+1|0,t[s+1|0]=y}if((w[g|0]-1&255)>>>0<=15){t[d+2|0]=1;t[d+4|0]=((w[g|0]<<6)+-64>>>0)/15}k=w[j|0];g=k&15;t[d+5|0]=g;h:{i:{switch((w[j|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=k|240;break h;case 2:t[d+5|0]=g<<2;break h;case 3:t[d+5|0]=(6/(g+1>>>0)|0)+1;break h;case 5:case 6:t[d+5|0]=g<<3;break h;case 9:t[d+4|0]=(g<<2)+4;t[d+2|0]=1;break h;case 10:t[d+5|0]=g|128;break h;case 11:break i;default:break h}}t[d+5|0]=(6/(g+1>>>0)|0)+1|13}t[d+3|0]=w[(w[j|0]>>>4|0)+26544|0];m=m+1|0;continue}}break}ve(d,Eh(Se(Le(e+72|0,14,0),q)))}yb(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;af(h);g=h;h=(e+872|0)+d|0;v[g>>2]=!w[h+50|0]<<10;u[f+480284>>1]=(w[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=P()|0;O()|0;yb(i);S(a|0);L()}hb=e+976|0;return l|0}function AK(){var a=0,b=0,c=0,d=0,e=0,f=0;if(w[468016]){return v[117003]}b=Yd(469624);v[b>>2]=84248;c=b+8|0;v[c>>2]=0;v[c+4>>2]=0;e=wh(c+8|0),f=0,t[e+128|0]=f;v[23516]=0;Y(1225,c|0);a=v[23516];v[23516]=0;if((a|0)==1){b=P()|0;O()|0;jw(c);S(b|0);L()}GF(c,30);v[23516]=0;d=Q(53,b+152|0,14381)|0;a=v[23516];v[23516]=0;a:{b:{c:{if((a|0)!=1){Gc(c);Yd(469312);v[117328]=85572;v[23516]=0;Y(1194,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469320);v[117330]=85604;v[23516]=0;Y(1195,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}a=Yd(469328);t[a+12|0]=0;v[a+8>>2]=0;v[a>>2]=84268;v[a+8>>2]=80208;v[23516]=0;Y(1196,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469344);v[117336]=84752;v[23516]=0;Y(1197,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469352);v[117338]=84900;v[23516]=0;Y(1198,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}v[23516]=0;Z(1199);a=v[23516];v[23516]=0;if((a|0)==1){break c}v[23516]=0;Y(1200,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469376);v[117344]=85048;v[23516]=0;Y(1201,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469384);v[117346]=85164;v[23516]=0;Y(1202,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}a=Yd(469392);u[a+8>>1]=11310;v[a>>2]=84368;Kb(a+12|0);v[23516]=0;Y(1203,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}a=Yd(469416);v[a+8>>2]=46;v[a+12>>2]=44;v[a>>2]=84408;Kb(a+16|0);v[23516]=0;Y(1204,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469448);v[117362]=85636;v[23516]=0;Y(1205,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469456);v[117364]=85880;v[23516]=0;Y(1206,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469464);v[117366]=86092;v[23516]=0;Y(1207,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469472);v[117368]=86324;v[23516]=0;Y(1208,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469480);v[117370]=87308;v[23516]=0;Y(1209,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469488);v[117372]=87456;v[23516]=0;Y(1210,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469496);v[117374]=87572;v[23516]=0;Y(1211,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469504);v[117376]=87688;v[23516]=0;Y(1212,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469512);v[117378]=87804;v[23516]=0;Y(1213,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469520);v[117380]=87968;v[23516]=0;Y(1214,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469528);v[117382]=88132;v[23516]=0;Y(1215,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469536);v[117384]=88296;v[23516]=0;Y(1216,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469544);v[117388]=89552;v[117388]=86572;v[117386]=86524;v[23516]=0;Y(1217,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469560);v[117392]=89588;v[117392]=86836;v[117390]=86788;v[23516]=0;Y(1218,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}v[23516]=0;Z(1219);a=v[23516];v[23516]=0;if((a|0)==1){break c}v[23516]=0;Y(1220,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}v[23516]=0;Z(1221);a=v[23516];v[23516]=0;if((a|0)==1){break c}v[23516]=0;Y(1222,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469608);v[117402]=88460;v[23516]=0;Y(1223,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}Yd(469616);v[117404]=88580;v[23516]=0;Y(1224,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;wb(d)}jw(c);S(b|0);L()}v[117002]=469624;t[468016]=1;v[117003]=468008;return 468008}function mW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-576|0;hb=e;xc(b);d=hb-16|0;hb=d;f=e+72|0;FC(d+8|0,f);g=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],g);j=v[d+4>>2];if((j|0)==(g|0)){Yb(b,v[d+12>>2])}hb=d+16|0;d=(g|0)==(j|0);if(!d){EC(f)}a:{if(!d){break a}if(!HC(e+72|0)){break a}b:{if(!c){break b}if(!Ob(v[b>>2],v[b+8>>2],Bc(GC(w[e+182|0],w[e+183|0]),kb))){break a}zd(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;Mb(a+1074312|0,7,1);d=e+40|0;g=vc(d,14745);Gb(a+1298344|0,g);xb(g);d=vc(d,14778);Gb(a+1298356|0,d);xb(d);Hl(a+1298368|0,Qb(e+72|0,11122,2)?14773:14745);v[a+1298404>>2]=5;f=w[e+182|0];u[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=hb-16|0;hb=f;d=e+40|0;ec(f+8|0,d,25);k=v[f+12>>2];jc(f,v[b>>2],v[b+8>>2],v[f+8>>2],k);i=v[f+4>>2];if((i|0)==(k|0)){Yb(b,v[f+12>>2])}hb=f+16|0;if((i|0)!=(k|0)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;t[d+24|0]=0;t[d+16|0]=0;t[d+17|0]=0;t[d+18|0]=0;t[d+19|0]=0;t[d+20|0]=0;t[d+21|0]=0;t[d+22|0]=0;t[d+23|0]=0;t[d+8|0]=0;t[d+9|0]=0;t[d+10|0]=0;t[d+11|0]=0;t[d+12|0]=0;t[d+13|0]=0;t[d+14|0]=0;t[d+15|0]=0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}f=(B(j,104)+a|0)+484380|0;jd(f,0);v[f+24>>2]=8363;k=e+40|0;d=k;i=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[f>>2]=i;l=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);v[f+4>>2]=l;d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>i>>>0?l?d:0:d;v[f+8>>2]=d;if(d){u[f+34>>1]=2;wk(f)}f=e+8|0;_h(f,2,k);d=e+24|0;Cc(d,f);Ac(((j<<5)+a|0)+946304|0,d);g=g+1|0;wb(d);f=x[a+480190>>1];continue}break}g=e+24|0;h=e+72|2;bg(g,3,h,36);d=e+40|0;Cc(d,g);yc(a+1298308|0,d);wb(d);g=0;CC(a+1298332|0,h,108,36,0);d=a+484360|0;h=a+484376|0;Wu(Sb(v[d>>2],w[h|0]),e+185|0,128);d=Sb(v[d>>2],w[h|0]);h=w[e+184|0];if(x[$b(v[d>>2],h)>>1]<w[e+183|0]){Te(d,h)}while(1)if((g|0)==8){j=a+484344|0;vg(j,w[e+183|0]);n=c&1;f=0;while(1){if(w[e+183|0]<=f>>>0){h=1;if(!(c&2)){break a}c=Uc(e+40|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>x[a+480190>>1]){break b}ug(c,(B(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(n){if(kh(j,f&65535,64)){break d}}Yb(b,1536);break c}v[e+24>>2]=-1;v[e+28>>2]=-1;k=0;e:while(1){if((k|0)==64){d=(e+72|0)+f|0;g=w[d+369|0];if(g>>>0<63){ve(Xb(v[j>>2],f),Eh(Se(Le(e+40|0,14,0),g)))}ve(Xb(v[j>>2],f),Eh(Le(e+40|0,16,w[d+241|0])));break c}g=0;d=Xb(v[j>>2],f);h=xf(v[d>>2],v[v[d+48>>2]+12>>2],k);while(1){if((g|0)==8){k=k+1|0;continue e}d=e+40|0;Oq(d,b);i=Kc(d);l=Re(d);i=w[i|0];d=w[e+40|0];if(d>>>0<=253){t[h|0]=(d>>>2|0)+37;t[h+1|0]=(d<<4&48|i>>>4)+1;t[(e+24|0)+g|0]=255;d=w[e+40|0]}if((d&255)!=255){t[h+2|0]=1;t[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=w[l|0];if((d|0)!=255){t[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;f:{g:{if(d&15?0:(d|0)!=48){break g}l=w[i|0];if((l|0)==255){break f}m=l<<24>>24;d=m&15;t[h+5|0]=d;h:{if((m|0)<0){break h}l=l>>>4|0;t[h+3|0]=w[l+26328|0];i:{switch(l-3|0){case 0:t[h+5|0]=d|32;break g;case 1:t[h+5|0]=d|m<<4;break f;case 2:break g;case 3:break i;default:break f}}j:{switch(d|0){case 0:t[h+5|0]=79;break f;case 1:break j;default:break h}}t[h+5|0]=244;break f}t[h+3|0]=0;break f}t[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;af(d+480280|0);u[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}hb=e+576|0;return h|0}function Rn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;f=hb-96|0;hb=f;q=bz(v[a+24>>2],w[a+32|0]);s=qj(q);c=s;e=v[a>>2];d=ud(e,v[a+4>>2]);a:{if(c>>>0>d>>>0){i=hb-32|0;hb=i;c=c-d|0;d=v[Db(a)>>2];e=v[a+4>>2];b:{if(c>>>0<=(d-e|0)/12>>>0){e=hb-16|0;hb=e;c=At(e,a,c);d=v[c+4>>2];h=v[c+8>>2];while(1){if((d|0)==(h|0)){ic(c);hb=e+16|0}else{bO(d);d=d+12|0;v[c+4>>2]=d;continue}break}break b}d=Db(a);d=Bk(i+8|0,$m(a,ud(v[a>>2],e)+c|0),ud(v[a>>2],v[a+4>>2]),d);h=hb-16|0;hb=h;e=nQ(h,d+8|0,c);c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){bO(c);c=v[e>>2]+12|0;v[e>>2]=c;continue}break}Kd(e);hb=h+16|0;h=v[a>>2];c=v[a+4>>2];e=d+4|0;while(1){if((c|0)!=(h|0)){c=c-12|0;Pz(v[e>>2]-12|0,c);v[e>>2]=v[e>>2]-12;continue}break}oc(a,e);oc(a+4|0,d+8|0);oc(Db(a),zc(d));v[d>>2]=v[d+4>>2];c=v[d+4>>2];while(1){e=v[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;v[d+8>>2]=e;Ue(e);continue}break}c=v[d>>2];if(c){Vo(d);Jb(c)}}hb=i+32|0;break a}if(d>>>0>c>>>0){gO(a,e+B(c,12)|0)}}if(b){c=a+12|0;Sp(c,Pd(c));z=Db(c),A=0,v[z>>2]=A;d=c;c=gc(c);v[d>>2]=c;v[c>>2]=0;v[a+28>>2]=0}i=Lb(f+80|0);c=v[a+24>>2];c=ft(v[c+484344>>2],v[c+484348>>2]);v[23516]=0;h=W(616,f- -64|0,c|0,30396)|0;c=v[23516];v[23516]=0;c:{if((c|0)!=1){e=a+12|0;d:{while(1){if((k|0)==(s|0)){gd(h);dc(i);hb=f+96|0;return}c=v[a+24>>2];m=x[$b(v[q>>2],k)>>1];d=mO(c,m);v[f+60>>2]=d;c=Jd(v[a>>2],k);e:{f:{if(b){v[23516]=0;t[f+40|0]=0;U(786,c|0,d|0,f+40|0);d=v[23516];v[23516]=0;if((d|0)!=1){break f}d=P()|0;O()|0;break d}v[23516]=0;R(744,c|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break e}}v[23516]=0;d=Q(314,q|0,k&65535)|0;g=v[23516];v[23516]=0;if((g|0)==1){break e}g:{if(!d){break g}v[f+40>>2]=b?0:v[c+4>>2];r=v[Hb(f+40|0,f+60|0)>>2];o=tf(e);c=x[$b(v[h>>2],m)>>1];if((c|0)!=65535){d=kO(e,x[om(f+40|0,c,r)>>1],v[f+44>>2]);h:{if(Fg(d,tf(e))){c=kO(e,x[om(f+40|0,x[$b(v[h>>2],m)>>1],v[f+60>>2])>>1],v[f+44>>2]);break h}c=tf(e)}v[f+56>>2]=d;while(1){i:{if(!Fg(d,c)){break g}g=Lb(f+40|0);d=Zm(sd(d)+8|0);v[23516]=0;R(787,g|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){d=vj(f+24|0,o);j=om(f+16|0,k,v[sd(v[f+56>>2])+4>>2]);d=v[d>>2];v[23516]=0;d=fa(788,e|0,d|0,j|0,g|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break i}v[f+32>>2]=d;o=v[Ig(f+32|0)>>2];be(g);d=v[Ig(f+56|0)>>2];continue}}break}d=P()|0;O()|0;be(g);break d}p=Xb(v[v[a+24>>2]+484344>>2],m);c=Lg(v[v[p+48>>2]+12>>2]);v[23516]=0;t[f+40|0]=0;U(767,i|0,c|0,f+40|0);c=v[23516];v[23516]=0;if((c|0)!=1){n=v[f+60>>2];j:while(1){k:{if((n|0)==(r|0)){if(r){break g}z=$b(v[h>>2],m),A=k,u[z>>1]=A;break g}g=1;j=0;c=v[v[p+48>>2]+12>>2];n=n-1|0;d=xf(v[p>>2],c,n);while(1){if(g>>>0<16&Lg(c)>>>0>j>>>0){y=Ib(v[i>>2],j);c=w[y|0];l:{m:{n:{switch(w[d+3|0]-19|0){case 1:l=w[d+5|0];if((l&240)==176){break m}break l;case 0:break n;default:break l}}l=w[d+5|0];if((l&240)!=96){break l}}t[y|0]=l&15;l=w[Ib(v[i>>2],j)|0];c=l?l:c}c=c&255;g=B(c?c+1|0:1,g);d=d+6|0;j=j+1|0;c=v[v[p+48>>2]+12>>2];continue}else{o:{if(g>>>0<=1){continue j}c=Lb(f+40|0);v[23516]=0;R(787,c|0,g|0);d=v[23516];v[23516]=0;if((d|0)==1){break o}d=vj(f+8|0,o);g=om(f+16|0,k,n);d=v[d>>2];v[23516]=0;o=fa(788,e|0,d|0,g|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break k}be(c);continue j}}break}}break}d=P()|0;O()|0;be(c);break d}d=P()|0;O()|0;break d}k=k+1|0;continue}break}d=P()|0;O()|0}gd(h);break c}d=P()|0;O()|0}dc(i);S(d|0);L()}function Ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=hb-336|0;hb=d;xc(b);a:{if(!mo(b,d+320|0)){break a}if(!yU(d+320|0)){break a}if(!Qb(d+320|0,14250,4)){Yb(b,4)}if(!di(b,d+312|0)){break a}if(Qb(d+312|0,14226,4)){break a}if(!c){n=1;break a}NB(b,d+120|0,v[d+316>>2]);if(x[d+156>>1]>128|x[d+162>>1]>16|(x[d+160>>1]>256|x[d+154>>1]>128)){break a}zd(a,8192);f=d+32|0;e=vc(f,6542);Gb(a+1298344|0,e);xb(e);e=vc(f,10160);Gb(a+1298356|0,e);xb(e);v[a+1298404>>2]=5;e=d+96|0;Gi(e,2,d+120|0);Cc(f,e);yc(a+1298308|0,f);wb(f);u[d+32>>1]=x[d+162>>1];u[d+96>>1]=1;g=x[ie(f,e)>>1];u[a+480188>>1]=g;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[Vb(f,e)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=w[d+165|0];b:{if((e|0)==128){v[d+32>>2]=256/(g>>>0);v[d+96>>2]=128;l=v[Hb(d+32|0,d+96|0)>>2];break b}l=e&127}v[a+480228>>2]=l;f=0;while(1){if((f|0)==16){g=a+484376|0;Wu(Sb(v[a+484360>>2],w[g|0]),d+184|0,x[d+156>>1]);e=x[d+154>>1];if(e>>>0<x[d+156>>1]){Te(Sb(v[a+484360>>2],w[g|0]),e)}q=c&2;o=a+484344|0;n=1;r=c&1;l=d+68|0;m=a+480190|0;f=a+480188|0;while(1){if(!di(b,d+312|0)){break a}c=d+32|0;Wd(c,b,v[d+316>>2]);h=hc(d+96|0,c);yb(c);c:{d:{if(!(Qb(d+312|0,13615,4)|!r)){v[23516]=0;g=p&65535;e=W(225,o|0,g|0,64)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}if(!e){break c}v[23516]=0;Q(186,h|0,2)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}Cj(d+32|0);j=0;e:{while(1){c=v[h>>2];v[23516]=0;e=W(154,c|0,v[d+104>>2],1)|0;c=v[23516];v[23516]=0;f:{if((c|0)!=1){if(!(e&j>>>0<64)){break e}v[23516]=0;k=T(204,h|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}if(k){break f}j=j+1|0;continue}break d}i=d+32|0;e=k&15;if(e>>>0<x[f>>1]){c=Xb(v[o>>2],g);i=ed(v[c>>2],v[v[c+48>>2]+12>>2],j,e)}g:{if(!(k&128)){break g}v[23516]=0;e=T(204,h|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}if(!e){break g}t[i|0]=e>>>0<109?e+12|0:e}if(k&64){v[23516]=0;e=T(204,h|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}t[i+1|0]=e}if(k&32){t[i+2|0]=1;v[23516]=0;e=T(204,h|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}t[d+16|0]=e;t[d|0]=64;s=i,y=w[Vb(d+16|0,d)|0],t[s+4|0]=y}if(!(k&16)){continue}v[23516]=0;R(263,d+16|0,h|0);c=v[23516];v[23516]=0;if((c|0)!=1){e=Kc(d+16|0);h:{i:{j:{k:{l:{c=w[d+16|0];switch(c-17|0){case 2:break k;case 0:case 1:break l;default:break j}}c=c&15;break i}t[d+16|0]=33;t[e|0]=145;c=w[d+16|0];break h}if(c>>>0<17){break h}c=(c&240)==32?9:-1}t[d+16|0]=c}Nf(i,c&255,w[e|0]);continue}break}break d}p=p+1|0;break c}if(Qb(d+312|0,13620,4)){break c}c=x[m>>1];if(!Yh(c)){break c}e=c+1|0;u[m>>1]=e;v[23516]=0;R(324,h|0,d+32|0);c=v[23516];v[23516]=0;m:{if((c|0)==1){break m}v[23516]=0;e=(B(e&65535,104)+a|0)+484380|0;R(325,d+32|0,e|0);c=v[23516];v[23516]=0;if((c|0)==1){break m}Gi(d,2,l);v[23516]=0;R(221,d+16|0,d|0);c=v[23516];v[23516]=0;if((c|0)==1){break m}c=d+16|0;Ac(((x[m>>1]<<5)+a|0)+946304|0,c);wb(c);if(!q){break c}j=w[d+45|0]|w[d+46|0]<<8;i=2;c=d+16|0;g=Uc(c,8,1,0,1);n:{if(!(j&64)){i=0;if(!(j&2)){break n}}cg(g,i)}if(j&4){nd(g,16)}v[23516]=0;W(218,c|0,e|0,h|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break c}}}a=P()|0;O()|0;yb(h);S(a|0);L()}yb(h);continue}}g=(f<<5)+a|0;af(g+480280|0);e=w[(d+f|0)+168|0];if(e>>>0<=128){u[g+480284>>1]=e<<1}f=f+1|0;continue}}hb=d+336|0;return n|0}function Tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=hb-192|0;hb=e;xc(b);a:{if(!$A(b,e+144|0)){break a}if(!EQ(e+144|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(DQ(w[e+175|0],w[e+177|0]),kb))){break a}b:{if(!c){break b}zd(a,256);g=e+32|0;Aj(g,2,e+144|0);d=e- -64|0;Cc(d,g);yc(a+1298308|0,d);wb(d);f=vc(d,15435);Gb(a+1298344|0,f);xb(f);d=vc(d,10139);Gb(a+1298356|0,d);xb(d);Qf(g,4274);v[23516]=0;R(251,e+128|0,e+175|0);d=v[23516];v[23516]=0;c:{d:{if((d|0)!=1){v[23516]=0;X(686,e- -64|0,e+32|0,e+174|0,e+128|0);d=v[23516];v[23516]=0;if((d|0)!=1){d=e- -64|0;Gb(a+1298368|0,d);xb(d);xb(e+128|0);ac(e+32|0);v[a+1298404>>2]=5;d=Mb(a+1074312|0,107,1);v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;Mb(d,107,1);f=w[e+176|0];d=w[e+175|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|B(g,-10)+f}g=(f&255?f:96)&255;f=Nz(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=f;f=0;if(d>>>0>=11){t[e+64|0]=64;o=a,p=w[Vb(e+178|0,e- -64|0)|0]<<2,v[o+480200>>2]=p}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){Ht(b,e+32|0);d=w[e+44|0];if(d?(d|0)!=46:0){break c}h=hb-32|0;hb=h;d=(B(f,104)+a|0)+484380|0;jd(d,0);k=e+32|0;g=k;ok(h,2,g);i=h+16|0;Cc(i,h);xe(d+43|0,i);wb(i);v[d+24>>2]=w[g+24|0]|w[g+25|0]<<8;t[h+16|0]=w[g+22|0];t[h|0]=64;o=d,p=w[Vb(i,h)|0]<<2,u[o+30>>1]=p;i=w[g+16|0]|w[g+17|0]<<8;v[d>>2]=i;j=w[g+18|0]|w[g+19|0]<<8;v[d+4>>2]=j;g=w[g+20|0]|w[g+21|0]<<8;v[d+8>>2]=g;e:{if(i>>>0<=1){v[d>>2]=0;break e}if((g|0)==65535|i>>>0<=j>>>0|g>>>0<=j>>>0){break e}u[d+34>>1]=2;o=d,p=v[Hb(d+8|0,d)>>2],v[o+8>>2]=p}hb=h+32|0;g=e+16|0;ok(g,2,k);d=e+128|0;Cc(d,g);Ac(((f<<5)+a|0)+946304|0,d);wb(d);u[((f<<1)+e|0)+62>>1]=x[e+46>>1];f=f+1|0;continue}break}d=a+484360|0;g=a+484376|0;ko(Sb(v[d>>2],w[g|0]),b,w[e+175|0]?128:64,65535,65535);f=0;if(!BQ(Sb(v[d>>2],w[g|0]))){break a}m=c&1;if(m){vg(a+484344|0,w[e+177|0])}i=a+484344|0;while(1){if(w[e+177|0]<=l>>>0){f=1;if(!(c&2)){break a}c=Uc(e+32|0,8,1,0,0);while(1){if((f|0)==32){break b}d=B(f,104)+a|0;g=d+484380|0;f:{if(!v[g>>2]|!x[d+484410>>1]){break f}d=x[((f<<1)+e|0)+62>>1];if(d>>>0<4){break f}if(!Zc(b,d<<4)){break f}ug(c,g,b)}f=f+1|0;continue}}f=0;g:{h:{if(m){if(kh(i,l&65535,64)){break h}}while(1){if((f|0)==256){break g}if((Je(b)+2&255)>>>0<=252){Yb(b,3)}f=f+1|0;continue}}o=e,p=Cb(v[Xb(v[i>>2],l)>>2]),v[o+128>>2]=p;u[e+14>>1]=65535;v[e+16>>2]=63;h=0;i:while(1){f=0;if((h|0)==64){d=x[e+14>>1];if((d|0)==65535){break g}ve(Xb(v[i>>2],l),Dm(Se(Le(e+32|0,12,d&255),v[e+16>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=Je(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}t[v[e+128>>2]]=254;break j}d=e+32|0;Oq(d,b);j=w[Ib(d,0)|0];k=w[Ib(d,1)|0];n=w[Ib(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(B(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=v[e+128>>2];t[d|0]=g;break k}h=h+1|0;continue i}d=v[e+128>>2]}t[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){t[d+4|0]=g;t[d+2|0]=1}t[d+5|0]=n;AQ(d,k&15,h,w[e+175|0],e+14|0,e+16|0)}f=f+1|0;Wz(e+128|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;af(d+480280|0);u[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=P()|0;O()|0;xb(e+128|0);break d}f=P()|0;O()|0}ac(e+32|0);S(f|0);L()}f=0;break a}f=1}hb=e+192|0;return f|0}function vy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0,D=0,E=0;f=hb-16|0;hb=f;k=B(b,872)+a|0;m=k+1075800|0;i=w[m|0];l=a+1074312|0;Ab(f+8|0,l,23);h=c&15;a:{b:{c:{if(zb(v[v[f+8>>2]>>2],v[f+12>>2])){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[m|0]=h;break c}e=w[m|0];if(e){g=e-1|0;t[m|0]=g;e=0;if(g&255){break c}}t[m|0]=h;e=1;break c}Ab(f+8|0,l,52);d:{e:{g=c&256;if(!(!g|!zb(v[v[f+8>>2]>>2],v[f+12>>2]))){g=v[a+480208>>2]&4096;if(!g){break e}e=B(b,872)+a|0;if(w[e+1075781|0]){i=pT(w[e+1075780|0])?1:i}if(w[(B(b,872)+a|0)+1075784|0]?w[e+1075782|0]==1:0){break b}e=0;if(h>>>0>i>>>0){break c}if(!g){break d}if(Wc(w[(B(b,872)+a|0)+1075780|0])){break c}break d}j=v[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((h?h:1)>>>0)|0:1);i=i+1|0;break c}f:{if((j|0)!=16){if((j|0)!=1){break f}g=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!g){if(Wc(w[(B(b,872)+a|0)+1075780|0])){break a}}e=h?!((g>>>0)%(h>>>0)|0):e;break c}e=v[a+1074392>>2]==(h|0)&(h|0)!=0;break c}g:{if(!g){break g}e=B(b,872)+a|0;if(w[e+1075782|0]!=1){break g}h=(w[e+1075785|0]>15)+h|0}h:{if(v[a+480208>>2]&4096?g:1){h=h?h:1;e=0;e=!v[a+1074416>>2]|g?e:!(y[a+1074392>>2]%(h>>>0)|0);i=i+1|0;break h}e=0;i=j&1048580?0:i}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!g?v[a+1074392>>2]:1)|(i&255)>>>0<h>>>0)){e=1}Ab(f+8|0,l,52);if(!zb(v[v[f+8>>2]>>2],v[f+12>>2])|c){break c}e=!v[a+1074392>>2];break c}if(h>>>0>i>>>0){break c}}i=0;e=1}h=k+1074992|0;n=(B(b,872)+a|0)+1075068|0;i:{if(v[n>>2]){break i}Ab(f+8|0,l,38);if(!zb(v[v[f+8>>2]>>2],v[f+12>>2])){break i}if(!lj(v[h+656>>2])){break a}}Ab(f+8|0,l,106);if(C=0,D=zb(v[v[f+8>>2]>>2],v[f+12>>2]),E=v[(B(b,872)+a|0)+1075688>>2],E?C:D){break a}if(e){j=B(b,872)+a|0;q=j+1075680|0;g=v[q>>2];v[f+4>>2]=g;e=c>>>4&15;j:{if(!e){e=v[j+1075080>>2];break j}Ab(f+8|0,l,52);k:{if(C=zb(v[v[f+8>>2]>>2],v[f+12>>2]),D=0,E=w[(B(b,872)+a|0)+1075782|0]==1,E?C:D){break k}if(!(16191>>>e&1)){v[f+4>>2]=(B(g,t[e+33872|0])|0)/16;break k}v[f+4>>2]=g+(t[e+33888|0]<<2)}me(f+4|0,0,256);g=(B(b,872)+a|0)+1075080|0;e=v[g>>2]|2097152;v[g>>2]=e}k=B(b,872)+a|0;r=k+1075692|0;s=v[r>>2];g=w[k+1075794|0];j=0;if(e&512){Ab(f+8|0,l,108);j=zb(v[v[f+8>>2]>>2],v[f+12>>2])}if(!((j^-1)&v[a+480180>>2]==2|(!v[n>>2]|(g-1&255)>>>0>119))){SM(a,b,0,g,1)}k=k+1075080|0;l:{if(!(v[a+480180>>2]&1048580)){break l}u=(c|0)<256;if((c|0)>255){break l}e=w[(B(b,872)+a|0)+1075781|0];if(!e){break l}u=1;Pp(a,h,e,0,0,1)}o=B(b,872)+a|0;p=o+1075652|0;z=v[p>>2];A=v[k>>2];v[p>>2]=0;Ab(f+8|0,l,23);e=1;m:{if(zb(v[v[f+8>>2]>>2],v[f+12>>2])){break m}e=0;if(v[a+480180>>2]!=2){break m}e=(j^1)&v[n>>2]!=0}$s(a,h,g,e,u,0,b);if(!w[o+1075781|0]){v[p>>2]=z}if(!(!(A&4096)|v[a+480180>>2]!=4)){v[k>>2]=v[k>>2]|4096}j=o+1075780|0;v[q>>2]=v[f+4>>2];if(x[a+480192>>1]){t[j|0]=g;QM(a,b)}g=v[a+480180>>2];if(!(!(g&16777248)|(w[j|0]|!s))){v[r>>2]=s}if(e){v[h>>2]=0;v[h+4>>2]=0}e=g&16777250;n:{if(d-11>>>0<4294967286){break n}g=v[(B(b,872)+a|0)+1075096>>2];if(!g){break n}o:{if((d|0)==1){b=v[(B(b,872)+a|0)+1075656>>2];break o}j=(B(b,872)+a|0)+1075656|0;b=v[Bb(g+68|0,d-2|0)>>2];v[j>>2]=b}Pn(a,h,b)}i=e?i:0}a=f+8|0;Ab(a,l,52);b=v[v[f+8>>2]>>2];d=v[f+12>>2];Ab(a,l,23);if(zb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}i=(zb(b,d)&c>>>8)+i|0}t[m|0]=i}hb=f+16|0}function lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-112|0;hb=e;g=a+140|0;zj(e+88|0,g,1296125513);v[23516]=0;f=T(176,v[e+88>>2])|0;h=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Kb(e+32|0);v[23516]=0;h=T(158,v[e+88>>2])|0;i=v[23516];v[23516]=0;if((i|0)==1){break p}v[23516]=0;U(796,e+88|0,f|0,h|0);h=v[23516];v[23516]=0;if((h|0)==1){break p}h=x[a+174>>1];v[23516]=0;U(797,e+72|0,h|0,f|0);h=v[23516];v[23516]=0;if((h|0)==1){break o}v[23516]=0;U(8,e+8|0,c|0,e+72|0);c=v[23516];v[23516]=0;if((c|0)==1){break n}c=e+8|0;Ac(d,c);wb(c);xb(e+72|0);wb(f)}if(w[a+176|0]){v[23516]=0;R(798,e+32|0,d|0);c=v[23516];v[23516]=0;if((c|0)==1){break e}c=e+32|0;xe(b+43|0,c);wb(c)}v[23516]=0;U(791,e+32|0,g|0,1413894985);c=v[23516];v[23516]=0;if((c|0)==1){break l}v[23516]=0;f=T(799,e+32|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break k}g=e+32|0;yb(g);c=a+40|0;xc(c);v[23516]=0;g=Q(800,c|0,g|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break j}if(g){q:{if(y[e+60>>2]<2){break q}v[23516]=0;g=Q(801,c|0,e+8|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break i}if(!g){break q}PL(e+8|0,b+12|0,b+16|0,v[b>>2],b+34|0,8,16,f)}v[23516]=0;c=Q(801,c|0,e+8|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break i}if(c){PL(e+8|0,b+4|0,b+8|0,v[b>>2],b+34|0,2,4,f)}c=v[e+44>>2];t[b+42|0]=c&128?0:c+1|0;wk(b)}r:{if(w[b+42|0]){break r}c=v[a+60>>2];v[23516]=0;c=Q(665,c|0,7)|0;f=v[23516];v[23516]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;xc(c);v[23516]=0;c=Q(802,c|0,e+8|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break d}if(!c){break r}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}c=v[a+120>>2];v[23516]=0;c=T(176,c|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break j}if(!c){break f}v[23516]=0;h=a+120|0;c=T(155,h|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break c}v[e+72>>2]=c;uc(e+72|0,9);f=b+68|0;g=v[e+72>>2];c=0;while(1){if((c|0)==(g|0)){break g}v[23516]=0;R(803,h|0,e+8|0);i=v[23516];v[23516]=0;if((i|0)==1){break h}j=Bb(f,c),k=v[e+12>>2],v[j>>2]=k;c=c+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;xb(e+72|0)}wb(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(e+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Uz(f+(g<<2)|0,gT(f),42856)}c=a+80|0;xc(c);v[23516]=0;f=Q(804,c|0,e+8|0)|0;g=v[23516];v[23516]=0;s:{if((g|0)==1){break s}if(!f){break b}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}u[e+72>>1]=x[e+12>>1];u[e+6>>1]=256;j=b,k=x[Rc(e+72|0,e+6|0)>>1],u[j+28>>1]=k;u[e+72>>1]=x[e+14>>1];u[e+6>>1]=256;j=b,k=x[Rc(e+72|0,e+6|0)>>1],u[j+30>>1]=k;u[e+72>>1]=x[e+16>>1];u[e+6>>1]=64;j=b,k=x[Rc(e+72|0,e+6|0)>>1],u[j+32>>1]=k;t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];f=v[a+88>>2];a=v[a+80>>2];v[23516]=0;a=W(154,a|0,f|0,32)|0;f=v[23516];v[23516]=0;if((f|0)==1){break s}if(!a){break b}v[23516]=0;R(805,c|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break s}v[23516]=0;a=T(200,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break s}v[23516]=0;U(806,c|0,b+43|0,a|0);a=v[23516];v[23516]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}yb(e+88|0);hb=e+112|0;return}yb(e+88|0);S(a|0);L()}function Ov(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=hb-96|0;hb=c;i=a+32|0;Pc(c+56|0,i,11);a:{if(k=1,l=zb(v[v[c+56>>2]>>2],v[c+60>>2]),m=v[a+8>>2],m?k:l){d=v[a+36>>2];b=v[a+76>>2]+v[a+20>>2]|0;f=v[a+16>>2];e=f+v[a+72>>2]|0;b=Sg(c+80|0,e,e>>>0<f>>>0?b+1|0:b);e=v[b+12>>2];v[c+24>>2]=v[b+8>>2];v[c+28>>2]=e;e=v[b+4>>2];v[c+16>>2]=v[b>>2];v[c+20>>2]=e;Uj(d,c+16|0);b=v[a+36>>2];if(Tk(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){ph(a,2,256);break a}b=v[a+104>>2];e=a+52|0;f=v[e>>2];d=Ni(f,v[e+4>>2]);b:{if(b>>>0>d>>>0){h=hb-32|0;hb=h;f=b-d|0;d=v[Db(e)>>2];g=v[e+4>>2];c:{if(f>>>0<=(d-g|0)/24>>>0){d=hb-16|0;hb=d;b=cE(d,e,f);e=v[b+4>>2];f=v[b+8>>2];while(1){if((e|0)==(f|0)){ic(b);hb=d+16|0}else{bE(e);e=e+24|0;v[b+4>>2]=e;continue}break}break c}b=Db(e);d=fE(h+8|0,gE(e,Ni(v[e>>2],g)+f|0),Ni(v[e>>2],v[e+4>>2]),b);b=hb-16|0;hb=b;v[b>>2]=v[d+8>>2];g=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=g+B(f,24);f=v[b>>2];while(1){if(v[b+4>>2]!=(f|0)){bE(f);f=v[b>>2]+24|0;v[b>>2]=f;continue}break}Kd(b);hb=b+16|0;eE(e,d);dE(d)}hb=h+32|0;break b}if(b>>>0<d>>>0){Ld(e,f+B(b,24)|0)}}h=a+40|0;hn(h,v[a+104>>2]<<2);e=0;while(1){if(y[a+104>>2]>e>>>0){d=v[a+36>>2];if(Tk(v[(v[v[d>>2]-12>>2]+d|0)+16>>2])){ph(a,2,1024);break a}b=x[a+24>>1];u[c+32>>1]=b;if((b|0)==65535){Sv(d,c+32|0);b=x[c+32>>1]}d=ad(v[a+40>>2],v[a+44>>2]);f=b&65535;d:{if(!f){b=0;break d}if(f>>>0>(d^-1)>>>0){break d}Oi(h,d+f|0);Mk(v[a+36>>2],Ib(v[a+40>>2],d),f)}f=ff(v[a+52>>2],e);v[f>>2]=d;u[f+20>>1]=b;Pc(c+56|0,i,6);if(zb(v[v[c+56>>2]>>2],v[c+60>>2])){Ck(v[a+36>>2],c+56|0);d=v[c+56>>2];b=v[c+60>>2];if(!Qv(d,b)){ph(a,2,2048);break a}f=ff(v[a+52>>2],e);v[f+8>>2]=d;v[f+12>>2]=b}d=v[a+8>>2];e:{if(d){b=ff(v[a+52>>2],e);v[b+16>>2]=d;break e}Pc(c+56|0,i,7);if(!zb(v[v[c+56>>2]>>2],v[c+60>>2])){b=ff(v[a+52>>2],e);break e}Ck(v[a+36>>2],c+56|0);d=v[c+56>>2];if(!Qv(d,v[c+60>>2])){ph(a,2,2048);break a}b=ff(v[a+52>>2],e);v[b+16>>2]=d}f:{if(v[b+16>>2]==-1){break f}Pc(c+56|0,i,6);if(zb(v[v[c+56>>2]>>2],v[c+60>>2])){break f}g:{if(!e){f=0;b=0;d=ff(v[a+52>>2],0);break g}g=v[a+52>>2];b=ff(g,e-1|0);f=v[b+16>>2];d=v[b+8>>2]+f|0;b=v[b+12>>2];b=d>>>0<f>>>0?b+1|0:b;f=d;d=ff(g,e)}v[d+8>>2]=f;v[d+12>>2]=b}Pc(c+56|0,i,8);if(zb(v[v[c+56>>2]>>2],v[c+60>>2])){u[c+78>>1]=0;Sv(v[a+36>>2],c+78|0);Pc(c+56|0,i,9);Ul(v[a+36>>2],x[c+78>>1]<<zb(v[v[c+56>>2]>>2],v[c+60>>2]))}e=e+1|0;continue}break}ke(c+56|0,v[a+36>>2]);b=v[c+68>>2];v[a+80>>2]=v[c+64>>2];v[a+84>>2]=b}e=c+56|0;Pc(e,i,4);We(e,1);f=v[a+84>>2];h=v[a+96>>2];g=v[a+16>>2];d=h+g|0;j=v[a+100>>2];b=j+v[a+20>>2]|0;b=d>>>0<g>>>0?b+1|0:b;g=d;d=(h|0)==v[a+72>>2]&(j|0)==v[a+76>>2];h=d?v[a+80>>2]:g;v[a+88>>2]=h;b=d?f:b;v[a+92>>2]=b;d=v[a+36>>2];b=Sg(c+40|0,h,b);f=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=f;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;Uj(d,c);Pc(e,i,6);if(zb(v[v[c+56>>2]>>2],v[c+60>>2])){break a}Pc(c+32|0,i,7);if(!(k=1,l=zb(v[v[c+32>>2]>>2],v[c+36>>2]),m=v[a+8>>2],m?k:l)){break a}b=v[a+88>>2];e=v[a+16>>2];i=b-e|0;d=v[a+92>>2]-(v[a+20>>2]+(b>>>0<e>>>0)|0)|0;f=v[a+52>>2];h=v[a+104>>2];a=0;while(1){if((a|0)==(h|0)){break a}b=ff(f,a);g=b;j=v[b+8>>2];e=j+i|0;b=v[b+12>>2]+d|0;v[g+8>>2]=e;v[g+12>>2]=e>>>0<j>>>0?b+1|0:b;a=a+1|0;continue}}hb=c+96|0}function pK(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=C(0),p=0,q=C(0),r=C(0),s=C(0),u=0,w=C(0);j=hb-16|0;hb=j;b=a+4208|0;i=tj(C(z[Bb(b,12)>>2]*C(3)));v[a+4264>>2]=i;d=C(v[v[a+16>>2]+24620>>2]>>>((i>>>1^-1)&1)>>>0);z[a+4268>>2]=d;u=a,w=C(C(z[Bb(b,9)>>2]*C(100))*C(.0061803399585187435)),z[u+4272>>2]=w;u=j,w=qe(C(10),C(C(oK(a)+C(C(z[Bb(b,5)>>2]*C(11e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[j+8>>2]=1065353216;u=a,w=C(z[em(j+12|0,j+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=w;c=qe(C(10),C(C(C(C(z[Bb(b,1)>>2]*C(1e4))+C(-1e4))/C(100))/C(10)));if(c!=C(1)){d=vp(C(C(nK(a)*C(6.2831854820251465))/d));f=C(c+c);e=C(c*c);c=Uy(C(C(C(C(d*f)+C(-2))+C(K(C(C(C(C(d*C(C(d*e)*C(4)))+C(c*C(8)))-C(e*C(4)))-C(C(d*c)*C(8))))))/C(f+C(-2))),C(0),C(1))}else{c=C(0)}z[a+4276>>2]=c;i=hb-16|0;hb=i;c=z[a+4268>>2];b=a+4208|0;d=C(z[Bb(b,6)>>2]*C(.30000001192092896));u=i,w=C(z[Bb(b,8)>>2]*C(.10000000149011612)),z[u+12>>2]=w;v[i+8>>2]=1000593162;f=z[Ax(i+12|0,i+8|0)>>2];e=C(c*C(C(d+f)+C(.007000000216066837)));a:{if(C(D(e))<C(2147483648)){b=~~e;break a}b=-2147483648}v[a+4352>>2]=b;b=1;while(1){if((b|0)==12){u=i,w=C(C(C(C(z[Bb(a+4208|0,10)>>2]*C(100))/C(100))+C(.10000000149011612))*C(.9090999960899353)),z[u+12>>2]=w;v[i+8>>2]=1065353216;d=z[em(i+12|0,i+8|0)>>2];f=C(c*C(C(d*C(75))/C(1e3)));d=C(c*C(C(d*C(67))/C(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=C(c*C(.0035299998708069324));b:{if(C(D(d))<C(2147483648)){b=~~d;break b}b=-2147483648}v[h>>2]=b;h=a+4344|0;d=C(c*C(.0032500000670552254));c:{if(C(D(d))<C(2147483648)){b=~~d;break c}b=-2147483648}v[h>>2]=b;h=a+4340|0;c=C(c*C(.009999999776482582));d:{if(C(D(c))<C(2147483648)){b=~~c;break d}b=-2147483648}v[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=qe(C(.9300000071525574),C(n|0));g=C(f*e);e:{if(C(D(g))<C(2147483648)){k=~~g;break e}k=-2147483648}v[p>>2]=k;k=h+4292|0;e=C(d*e);f:{if(C(D(e))<C(2147483648)){h=~~e;break f}h=-2147483648}v[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){rK((B(b,24)+a|0)+4504|0,v[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}hb=i+16|0}else{k=((B(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=C(c*C(C(f*z[(b<<2)+47120>>2])+d));g:{if(C(D(e))<C(2147483648)){h=~~e;break g}h=-2147483648}v[k>>2]=h;b=b+1|0;continue}break}b=hb-16|0;hb=b;d=sh(a,5);e=sh(a,11);c=C(d*sh(a,4));d=C(C(c*C(.03999999910593033))+C(C(d*C(.02250000089406967))+C(0)));f=C(e*sh(a,10));e=C(C(f*C(.03999999910593033))+C(C(e*C(.02250000089406967))+C(0)));if(t[a+4264|0]&1){g=sh(a,3);l=sh(a,9);g=C(c*g);c=C(g*sh(a,2));d=C(C(c*C(.1444000005722046))+C(C(g*C(.12250000238418579))+d));g=C(f*l);f=C(g*sh(a,8));e=C(C(f*C(.1444000005722046))+C(C(g*C(.12250000238418579))+e))}sh(a,12);g=z[a+4496>>2];l=sh(a,1);m=sh(a,7);q=sh(a,0);r=sh(a,6);u=b,w=qe(C(10),C(C(oK(a)+C(C(z[Bb(a+4208|0,7)>>2]*C(12e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[b+8>>2]=1065353216;o=z[em(b+12|0,b+8|0)>>2];s=c;c=C(g*g);g=C(l*C(s*c));l=C(q*g);c=C(m*C(f*c));f=C(r*c);m=C(C(C(l+f)*C(-.5))+C(1));z[a+4284>>2]=o*C(K(C(m/C(C(l*C(.1444000005722046))+C(C(c*C(.1444000005722046))+d)))));z[a+4288>>2]=o*C(K(C(m/C(C(f*C(.1444000005722046))+C(C(g*C(.1444000005722046))+e)))));hb=b+16|0;t[a+5046|0]=0;hb=j+16|0}function HM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0;if(b){h=a+327720|0;c=hb-400|0;hb=c;zO(c+384|0,8);v[23516]=0;oa(779,c+368|0,9);i=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((i|0)!=1){v[23516]=0;i=Q(780,c+352|0,14)|0;e=v[23516];v[23516]=0;if((e|0)==1){break l}v[23516]=0;R(781,c+384|0,i|0);e=v[23516];v[23516]=0;if((e|0)==1){break k}v[23516]=0;R(781,c+368|0,i|0);e=v[23516];v[23516]=0;if((e|0)==1){break k}yO(c+280|0,4900);yO(c+208|0,32e3);rO(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[23516]=0;e=Q(782,c+104|0,c+384|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break j}it(c+120|0,c+280|0,e);be(e);v[23516]=0;e=Q(782,c+72|0,c+368|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break i}it(c+88|0,c+208|0,e);be(e);v[23516]=0;e=Q(782,c+40|0,c+120|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break h}it(c+56|0,c+136|0,e);be(e);v[23516]=0;e=Q(782,c+8|0,c+88|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break g}g=c+24|0;it(g,c+136|0,e);be(e);e=c+120|0;Up(e);l=c+56|0;Up(l);m=c+88|0;Up(m);Up(g);p=c+368|0;Up(p);Tp(v[c+120>>2],v[c+124>>2],Sn(h,0));Tp(v[c+56>>2],v[c+60>>2],Sn(h,1));Tp(v[c+88>>2],v[c+92>>2],Sn(h,2));Tp(v[c+24>>2],v[c+28>>2],Sn(h,3));Tp(v[c+368>>2],v[c+372>>2],Sn(h,4));be(g);be(l);be(m);be(e);kl(i);be(p);be(c+384|0);hb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;be(c+56|0)}be(c+88|0)}be(c+120|0)}kl(i)}be(c+368|0)}be(c+384|0);S(a|0);L()}Yx(a+131112|0,9.6377,.97);Yx(a+196648|0,8.5,.5);Yx(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(t=0,x=SL(c,a),y=b,y?t:x)){e=a+24|0;r=A[a+8>>3];g=w[a+16|0];h=hb+-64|0;hb=h;m:while(1){if((n|0)!=8193){s=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){j=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;d=H(A[h+(b<<3)>>3]*32768*j+.5);d=d<-32768?-32768:F(d,32768);n:{if(D(d)<2147483648){i=~~d;break n}i=-2147483648}u[m>>1]=i;b=b+1|0;continue}}else{j=r;f=1;d=+(b|0)-s;q=d+-3.5;if(!(D(q)<1e-8)){o:{p:{switch(g|0){case 0:f=Ze(d*.8975979010256552)*-.5+.5;break o;case 1:f=Ze(d*.8975979010256552)*-.46+.54;break o;case 2:f=Ze(d*1.7951958020513104)*.08+(Ze(d*.8975979010256552)*-.5+.42);break o;case 3:f=Ze(d*1.7951958020513104)*.05677+(Ze(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=Ze(d*1.7951958020513104)*.07922+(Ze(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=Ze(d*1.7951958020513104);k=Ze(d*.8975979010256552);f=Ze(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=Ze(d*1.7951958020513104);k=Ze(d*.8975979010256552);f=Ze(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=Ze(d*1.7951958020513104);k=Ze(d*.8975979010256552);f=Ze(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=q*3.141592653589793;j=Bi(d*j)/d}j=f*j;A[h+(b<<3)>>3]=j;o=o+j;b=b+1|0;continue}}break}hb=h- -64|0;b=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=b;b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b}}function Eha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-240|0;hb=f;ke(f+224|0,b);g=hb-48|0;hb=g;v[g+44>>2]=0;kk(b,g+44|0);a:{b:{c:{if(v[g+44>>2]!=(Lm(14190)|0)){break c}v[g+40>>2]=0;e=hb-32|0;hb=e;v[e+24>>2]=0;Kv(e+8|0,e+24|0);nn(e+16|0,b,v[e+8>>2],v[e+12>>2]);v[g+40>>2]=v[e+24>>2];hb=e+32|0;e=-1;i=v[g+40>>2];if(i-3>>>0<4294967294){break c}d:{e:{f:{if(i>>>0<=1){i=Kb(g+24|0);v[23516]=0;h=W(492,b|0,i|0,256)|0;j=v[23516];v[23516]=0;if((j|0)==1){break b}if(!h){break e}v[23516]=0;U(11,g+8|0,d|0,i|0);h=v[23516];v[23516]=0;if((h|0)!=1){break f}break b}i=Kb(g+24|0);v[23516]=0;h=Q(494,b|0,i|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break b}if(!h){break d}v[23516]=0;U(11,g+8|0,d|0,i|0);h=v[23516];v[23516]=0;if((h|0)==1){break b}}h=g+8|0;Gb(c,h);xb(h);wb(i);Wf(b,h);i=0;v[g+24>>2]=0;kk(b,g+24|0);h=v[g+24>>2];if(h>>>0>50){break c}while(1){if((h|0)!=(i|0)){if(!kL(a,b,d)){break c}i=i+1|0;continue}break}v[g+24>>2]=0;kk(b,g+24|0);e=v[g+24>>2]==(Lm(14236)|0)?1:-1;break c}wb(i);break c}wb(i)}hb=g+48|0;break a}a=P()|0;O()|0;wb(i);S(a|0);L()}g:{if(e){break g}Kl(v[v[b>>2]-12>>2]+b|0,0);e=v[f+236>>2];v[f+16>>2]=v[f+232>>2];v[f+20>>2]=e;e=v[f+228>>2];v[f+8>>2]=v[f+224>>2];v[f+12>>2]=e;b=Rl(f+112|0,Uj(b,f+8|0));v[23516]=0;e=Q(458,f+96|0,14375)|0;g=v[23516];v[23516]=0;h:{if((g|0)!=1){v[23516]=0;v[f+80>>2]=3;v[f+84>>2]=0;U(459,b|0,e|0,f+80|0);g=v[23516];v[23516]=0;if((g|0)!=1){Ub(e);t[f+95|0]=0;v[23516]=0;e=Q(458,f+80|0,14831)|0;g=v[23516];v[23516]=0;if((g|0)!=1){v[23516]=0;U(460,b|0,f+95|0,e|0);g=v[23516];v[23516]=0;if((g|0)!=1){Ub(e);v[23516]=0;g=w[f+95|0];e=T(473,b|0)|0;i=v[23516];v[23516]=0;if((i|0)!=1){v[23516]=0;i=T(474,b|0)|0;h=v[23516];v[23516]=0;if((h|0)!=1){g=g?0:d;v[f+72>>2]=e;i:{j:{k:{l:{while(1){if(!Nb(e,i)){a=Ek(w[b|0]);fh(b);e=a?-1:1;break g}v[23516]=0;d=Q(458,f+56|0,15903)|0;e=v[23516];v[23516]=0;if((e|0)==1){break k}e=v[b+44>>2];h=v[b+40>>2];v[23516]=0;e=fa(475,h|0,e|0,v[f+72>>2],d|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break j}Ub(d);m:{n:{if(e){v[23516]=0;X(476,b|0,f+72|0,c|0,g|0);d=v[23516];v[23516]=0;if((d|0)!=1){break n}break i}v[23516]=0;d=Q(458,f+40|0,15573)|0;e=v[23516];v[23516]=0;o:{p:{if((e|0)!=1){e=v[b+44>>2];h=v[b+40>>2];v[23516]=0;e=fa(475,h|0,e|0,v[f+72>>2],d|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break p}Ub(d);if(!e){break o}v[23516]=0;U(477,b|0,f+72|0,f+70|0);d=v[23516];v[23516]=0;if((d|0)==1){break i}break n}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ub(d);break h}v[23516]=0;d=Q(458,f+24|0,15472)|0;e=v[23516];v[23516]=0;if((e|0)==1){break m}e=v[b+44>>2];h=v[b+40>>2];v[23516]=0;e=fa(475,h|0,e|0,v[f+72>>2],d|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break l}Ub(d);if(!e){break n}v[23516]=0;X(478,b|0,f+72|0,a|0,g|0);d=v[23516];v[23516]=0;if((d|0)==1){break i}}Mx(f+72|0);e=v[f+72>>2];continue}break}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ub(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ub(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ub(e);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ub(e);break h}a=P()|0;O()|0}fh(b);S(a|0);L()}hb=f+240|0;return e|0}function Tha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-400|0;hb=e;g=hb-32|0;hb=g;d=g+8|0;EA(d,b);Gu(g,d);v[23516]=0;U(472,e+240|0,v[g>>2],v[g+4>>2]);b=v[23516];v[23516]=0;a:{if((b|0)!=1){Qc(g+8|0);hb=g+32|0;break a}a=P()|0;O()|0;Qc(g+8|0);S(a|0);L()}v[23516]=0;U(454,e+128|0,v[e+240>>2],v[e+244>>2]);b=v[23516];v[23516]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){v[23516]=0;g=Q(87,e+256|0,e+128|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break z}wb(e+128|0);dc(e+240|0);if(c>>>0<2189){break g}b=Rl(e+128|0,g);v[23516]=0;c=Q(458,e+112|0,10143)|0;d=v[23516];v[23516]=0;if((d|0)==1){break x}v[23516]=0;v[e+96>>2]=19988497;v[e+100>>2]=0;U(459,b|0,c|0,e+96|0);d=v[23516];v[23516]=0;if((d|0)==1){break w}Ub(c);t[e+111|0]=0;v[23516]=0;c=Q(458,e+96|0,11016)|0;d=v[23516];v[23516]=0;if((d|0)==1){break i}v[23516]=0;U(460,b|0,e+111|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break v}Ub(c);c=0;c=w[e+111|0]?c:v[a+1298404>>2];f=v[a+4>>2];v[23516]=0;d=Q(458,e+80|0,15903)|0;h=v[23516];v[23516]=0;if((h|0)==1){break u}v[23516]=0;X(461,b|0,f|0,d|0,c|0);f=v[23516];v[23516]=0;if((f|0)==1){break t}Ub(d);v[23516]=0;d=Q(458,e- -64|0,15573)|0;f=v[23516];v[23516]=0;if((f|0)==1){break s}v[23516]=0;X(462,b|0,a|0,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break r}Ub(d);v[23516]=0;c=Q(458,e+48|0,15472)|0;d=v[23516];v[23516]=0;if((d|0)==1){break q}v[23516]=0;d=a+484360|0;U(463,b|0,d|0,c|0);f=v[23516];v[23516]=0;if((f|0)==1){break p}Ub(c);v[23516]=0;c=Q(458,e+32|0,26822)|0;f=v[23516];v[23516]=0;if((f|0)==1){break o}v[23516]=0;U(464,b|0,a+484344|0,c|0);f=v[23516];v[23516]=0;if((f|0)==1){break n}Ub(c);f=v[a+1298404>>2];v[23516]=0;c=Q(458,e+16|0,26828)|0;h=v[23516];v[23516]=0;if((h|0)==1){break m}v[23516]=0;X(465,b|0,d|0,c|0,f|0);d=v[23516];v[23516]=0;if((d|0)==1){break l}Ub(c);if(Ek(w[b|0])){v[23516]=0;c=Q(1,e|0,16382)|0;d=v[23516];v[23516]=0;if((d|0)==1){break k}a=v[a+1298464>>2];v[23516]=0;U(384,a|0,1,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break j}xb(c)}fh(b);break f}a=P()|0;O()|0;break y}a=P()|0;O()|0;wb(e+128|0)}dc(e+240|0);break b}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ub(c);break h}a=P()|0;O()|0;Ub(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ub(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ub(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ub(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ub(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ub(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;xb(c);break h}a=P()|0;O()|0}fh(b);break c}b=Kb(e+128|0);d=v[a+1298404>>2];f=v[a+4>>2];v[23516]=0;d=fa(466,f|0,g|0,b|0,d|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}A:{if((d|0)!=1){v[23516]=0;c=Q(1,e+112|0,16688)|0;d=v[23516];v[23516]=0;B:{if((d|0)!=1){a=v[a+1298464>>2];v[23516]=0;U(384,a|0,1,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break B}xb(c);break A}a=P()|0;O()|0;break d}a=P()|0;O()|0;xb(c);break d}d=v[a+1298404>>2];v[23516]=0;X(467,g|0,a|0,d|0,c>>>0<2188|0);a=v[23516];v[23516]=0;if((a|0)==1){break e}}xb(b)}pf(g);hb=e+400|0;return}a=P()|0;O()|0}xb(b)}pf(g)}S(a|0);L()}function Jb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[116028]){break a}a=a+b|0;if(v[116029]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=464096,j=v[116024]&vka(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+464400|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=464100,j=v[116025]&vka(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[116026]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[116030]==(f|0)){v[116030]=d;a=v[116027]+a|0;v[116027]=a;v[d+4>>2]=a|1;if(v[116029]!=(d|0)){break a}v[116026]=0;v[116029]=0;return}if(v[116029]==(f|0)){v[116029]=d;a=v[116026]+a|0;v[116026]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=464096,j=v[116024]&vka(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+464400|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=464100,j=v[116025]&vka(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[116029]!=(d|0)){break f}v[116026]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+464136|0;c=v[116024];a=1<<a;k:{if(!(c&a)){v[116024]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;v[d+16>>2]=0;v[d+20>>2]=0;g=(e<<2)+464400|0;l:{m:{c=v[116025];b=1<<e;n:{if(!(c&b)){v[116025]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[116032]-1|0;v[116032]=a?a:-1}}function HI(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=hb-48|0;hb=g;a:{b:{if(gs(c)){h=v[b+484344>>2];if(te(h,v[b+484348>>2],c&65535)){break b}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);oi(c,a,b);wb(b);wb(a);break a}c=Xb(h,c);if(!(v[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);oi(c,a,b);wb(b);wb(a);break a}if(!(x[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);oi(c,a,b);wb(b);wb(a);break a}if(f>>>0>=6){c=a;a=Kb(g+32|0);b=Kb(g+16|0);oi(c,a,b);wb(b);wb(a);break a}c=ed(v[c>>2],v[v[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=w[c|0];if(!Wc(d)){if(!Gp(d)){break k}}e=g+16|0;fM(e,b,d,w[c+1|0]);v[23516]=0;R(1029,g+32|0,e|0);b=v[23516];v[23516]=0;d=1;if((b|0)!=1){break j}c=P()|0;O()|0;break g}d=0;v[23516]=0;Q(53,g+32|0,16862)|0;b=v[23516];v[23516]=0;if((b|0)==1){break i}}b=9987;c=w[c|0];if(!Wc(c)){b=Gp(c)?10297:16862}v[23516]=0;b=Q(53,g|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break h}c=a;a=g+32|0;oi(c,a,b);wb(b);wb(a);if(!d){break a}xb(g+16|0);break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;wb(g+32|0);if(!d){break d}}xb(g+16|0);break d;case 1:b=c+1|0;l:{if(w[c+1|0]){Kt(g+32|0,b);break l}Fc(g+32|0,16867)}b=w[b|0];v[23516]=0;b=Q(53,g+16|0,(b?10791:16867)|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break e}c=a;a=g+32|0;oi(c,a,b);wb(b);wb(a);break a;case 2:m:{if($g(w[c|0])){Fc(g+32|0,17922);break m}d=w[c+2|0];if(d){kf(g+32|0,1,HL(v[v[b+8>>2]+88>>2],d));break m}Fc(g+32|0,17922)}b=17922;if(!$g(w[c|0])){b=w[c+2|0]?5508:17922}v[23516]=0;b=Q(53,g+16|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){c=a;a=g+32|0;oi(c,a,b);wb(b);wb(a);break a}c=P()|0;O()|0;wb(g+32|0);break d;case 4:n:{if($g(w[c|0])){i=g,j=ek(w[c+2|0],w[c+4|0])&255,v[i>>2]=j;kA(g+32|0,g);break n}if(w[c+2|0]){Kt(g+32|0,c+4|0);break n}Fc(g+32|0,16867)}b=5492;if(!$g(w[c|0])){b=w[c+2|0]?5492:16867}v[23516]=0;b=Q(53,g+16|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){c=a;a=g+32|0;oi(c,a,b);wb(b);wb(a);break a}c=P()|0;O()|0;wb(g+32|0);break d;case 3:o:{if($g(w[c|0])){i=g,j=(ek(w[c+3|0],w[c+5|0])&3840)!=0,t[i|0]=j;b=hb-32|0;hb=b;v[b+8>>2]=-1;v[b+12>>2]=0;v[b>>2]=0;Kb(b+16|0);v[23516]=0;v[b>>2]=v[b>>2]&-1332|1058;v[b+4>>2]=1;U(1107,g+32|0,g|0,b|0);d=v[23516];v[23516]=0;p:{if((d|0)!=1){bm(b);hb=b+32|0;break p}a=P()|0;O()|0;bm(b);S(a|0);L()}break o}d=w[c+3|0];if(d){kf(g+32|0,1,GL(v[v[b+8>>2]+84>>2],d));break o}Fc(g+32|0,16868)}b=12343;if(!$g(w[c|0])){b=w[c+3|0]?12343:16868}v[23516]=0;b=Q(53,g+16|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){c=a;a=g+32|0;oi(c,a,b);wb(b);wb(a);break a}c=P()|0;O()|0;wb(g+32|0);break d;case 5:break f;default:break c}}q:{if($g(w[c|0])){i=g,j=ek(w[c+3|0],w[c+5|0])&255,v[i>>2]=j;kA(g+32|0,g);break q}if(w[c+3|0]){Kt(g+32|0,c+5|0);break q}Fc(g+32|0,16867)}b=11135;if(!$g(w[c|0])){b=w[c+3|0]?11135:16867}v[23516]=0;b=Q(53,g+16|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){c=a;a=g+32|0;oi(c,a,b);wb(b);wb(a);break a}c=P()|0;O()|0;wb(g+32|0);break d}c=P()|0;O()|0;wb(g+32|0)}S(c|0);L()}c=a;a=Kb(g+32|0);b=Kb(g+16|0);oi(c,a,b);wb(b);wb(a)}hb=g+48|0}function Dg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=hb-112|0;hb=j;k=i&2147483647;l=e&2147483647;m=l;a:{b:{p=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:p)){n=k-2147418112|0;if(!h&(n|0)==-2147418112?f|g:(n|0)==-2147418112&(h|0)!=0|n>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?p:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){m=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:m;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}l=(k|0)==(m|0);k=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|k>>>0>m>>>0;o=k?f:b;l=k?g:c;m=k?i:e;r=m;q=k?h:d;n=m&65535;e=k?e:i;s=e;h=k?d:h;m=e>>>16&32767;p=r>>>16&32767;if(!p){d=!(n|q);e=d<<6;i=E(d?o:q)+32|0;d=E(d?l:n);d=e+((d|0)==32?i:d)|0;Hf(j+96|0,o,l,q,n,d-15|0);q=v[j+104>>2];n=v[j+108>>2];o=v[j+96>>2];p=16-d|0;l=v[j+100>>2]}f=k?b:f;g=k?c:g;i=s&65535;if(!m){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;Hf(j+80|0,f,g,h,i,b-15|0);m=16-b|0;h=v[j+88>>2];i=v[j+92>>2];g=v[j+84>>2];f=v[j+80>>2]}b=h;k=i<<3|b>>>29;d=b<<3|g>>>29;e=k|524288;b=q;c=n<<3|b>>>29;h=b<<3|l>>>29;i=c;b=f;c=g<<3|b>>>29;b=b<<3;g=r^s;c:{if((m|0)==(p|0)){break c}f=p-m|0;if(f>>>0>127){d=0;e=0;b=1;c=0;break c}Hf(j- -64|0,b,c,d,e,128-f|0);vm(j+48|0,b,c,d,e,f);b=v[j+48>>2]|(v[j+64>>2]|v[j+72>>2]|(v[j+68>>2]|v[j+76>>2]))!=0;c=v[j+52>>2];d=v[j+56>>2];e=v[j+60>>2]}m=h;q=i|524288;f=o;k=l<<3|f>>>29;n=f<<3;d:{if((g|0)<0){f=0;g=0;h=0;i=0;if(!(b^n|d^m|(c^k|e^q))){break a}o=n-b|0;l=k-((b>>>0>n>>>0)+c|0)|0;f=m-d|0;b=(c|0)==(k|0)&b>>>0>n>>>0|c>>>0>k>>>0;i=(q-((d>>>0>m>>>0)+e|0)|0)-(f>>>0<b>>>0)|0;h=f-b|0;if(i>>>0>524287){break d}b=!(h|i);c=b<<6;d=E(b?o:h)+32|0;b=E(b?l:i);b=c+((b|0)==32?d:b)|0;b=b-12|0;Hf(j+32|0,o,l,h,i,b);p=p-b|0;h=v[j+40>>2];i=v[j+44>>2];o=v[j+32>>2];l=v[j+36>>2];break d}k=c+k|0;f=b+n|0;k=f>>>0<n>>>0?k+1|0:k;o=f;l=k;f=(c|0)==(k|0)&b>>>0>f>>>0|c>>>0>k>>>0;c=e+q|0;b=d+m|0;c=b>>>0<m>>>0?c+1|0:c;d=b;b=f+b|0;h=b;i=b>>>0<d>>>0?c+1|0:c;if(!(i&1048576)){break d}o=o&1|((l&1)<<31|o>>>1);c=h;l=c<<31|l>>>1;p=p+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}d=0;e=r&-2147483648;if((p|0)>=32767){h=d;i=e|2147418112;f=0;g=0;break a}m=0;e:{if((p|0)>0){m=p;break e}Hf(j+16|0,o,l,h,i,p+127|0);vm(j,o,l,h,i,1-p|0);o=v[j>>2]|(v[j+16>>2]|v[j+24>>2]|(v[j+20>>2]|v[j+28>>2]))!=0;l=v[j+4>>2];h=v[j+8>>2];i=v[j+12>>2]}c=h<<29;b=l>>>3|0;n=(l&7)<<29|o>>>3;l=o&7;g=l>>>0>4;f=n+g|0;b=b|c;k=f>>>0<g>>>0?b+1|0:b;c=f;g=k;b=(b|0)==(k|0)&c>>>0<n>>>0|b>>>0>k>>>0;c=d|((i&7)<<29|h>>>3);b=b+c|0;i=e|(i>>>3&65535|m<<16);i=b>>>0<c>>>0?i+1|0:i;h=b;f:{if((l|0)==4){c=g+0|0;e=f&1;b=f+e|0;c=b>>>0<f>>>0?c+1|0:c;f=b;g=c;c=(d|0)==(c|0)&b>>>0<e>>>0|c>>>0<d>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;hb=j+112|0}function SJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=e|0;var f=0,g=0,h=0,i=0;f=hb-144|0;hb=f;v[f+140>>2]=c;v[f+136>>2]=b;A[f+128>>3]=d;a:{if(!c){break a}g=w[Xk(b,c)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}cl(f+104|0,b,c,c-1|0);b=v[f+108>>2];v[f+136>>2]=v[f+104>>2];v[f+140>>2]=b}b=f+104|0;Rd(b);c=v[f+104>>2];Rd(f+88|0);g=Wk(c,v[f+92>>2],f+136|0);Rd(b);b=v[f+140>>2];c=v[f+136>>2];b:{c:{d:{e:{if((g|0)==v[f+108>>2]){a=qc(f+120|0,21751);if(Mc(c,b,v[a>>2],v[a+4>>2])){b=ba(8)|0;v[23516]=0;R(978,f+88|0,f+128|0);a=v[23516];v[23516]=0;f:{g:{h:{if((a|0)!=1){v[23516]=0;U(981,f+104|0,17730,f+88|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}a=0;c=rc(b,f+104|0);v[23516]=0;U(117,c|0,62944,970);c=v[23516];v[23516]=0;if((c|0)!=1){break b}c=P()|0;O()|0;wb(f+104|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}wb(f+88|0);if(!a){break c}}ca(b|0);break c}if(!e){break e}b=ba(8)|0;v[23516]=0;e=Lh(f+56|0,v[f+136>>2],v[f+140>>2]);a=v[23516];v[23516]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23516]=0;U(981,f+72|0,17766,e|0);a=v[23516];v[23516]=0;if((a|0)==1){break q}v[23516]=0;R(983,f+88|0,f+72|0);c=v[23516];v[23516]=0;a=1;if((c|0)==1){break p}v[23516]=0;R(978,f+40|0,f+128|0);a=v[23516];v[23516]=0;if((a|0)==1){break o}v[23516]=0;U(985,f+104|0,f+88|0,f+40|0);c=v[23516];v[23516]=0;a=1;if((c|0)==1){break n}a=rc(b,f+104|0);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(f+104|0);a=0;break m}c=P()|0;O()|0;break i}c=P()|0;a=1;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;a=1;O()|0;break l}c=P()|0;O()|0}wb(f+40|0)}wb(f+88|0)}wb(f+72|0)}wb(e);if(!a){break c}}ca(b|0);break c}e=qc(f+32|0,21751);if(Mc(c,b,v[e>>2],v[e+4>>2])){b=ba(8)|0;v[23516]=0;R(978,f+88|0,f+128|0);a=v[23516];v[23516]=0;r:{s:{t:{if((a|0)!=1){v[23516]=0;U(981,f+104|0,17730,f+88|0);a=v[23516];v[23516]=0;if((a|0)==1){break t}a=0;c=rc(b,f+104|0);v[23516]=0;U(117,c|0,62944,970);c=v[23516];v[23516]=0;if((c|0)!=1){break b}c=P()|0;O()|0;wb(f+104|0);break s}c=P()|0;O()|0;break r}c=P()|0;a=1;O()|0}wb(f+88|0);if(!a){break c}}ca(b|0);break c}e=qc(f+24|0,7719);if(Mc(c,b,v[e>>2],v[e+4>>2])){if(!Sd(w[a+28|0])){break e}if(d<=0|d>4){a=ba(8)|0;v[23516]=0;b=Q(53,f+104|0,7814)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}a=v[a+24>>2];h=a,i=Oe(65536/d),v[h+480244>>2]=i;Hp(a);break e}e=qc(f+16|0,7771);if(Mc(c,b,v[e>>2],v[e+4>>2])){if(!Sd(w[a+28|0])){break e}if(d<=0|d>4){a=ba(8)|0;v[23516]=0;b=Q(53,f+104|0,7835)|0;c=v[23516];v[23516]=0;if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}c=P()|0;O()|0;ca(a|0);break c}a=v[a+24>>2];h=a,i=Oe(d*65536),v[h+480240>>2]=i;Hp(a);break e}e=b;b=qc(f+8|0,7789);if(!Mc(c,e,v[b>>2],v[b+4>>2])){break e}h=v[a+24>>2],i=pl(d*65536),v[h+480236>>2]=i}hb=f+144|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function tH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[116029]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=464096,j=v[116024]&vka(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+464400|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=464100,j=v[116025]&vka(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[116026]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[116030]==(f|0)){v[116030]=a;b=v[116027]+b|0;v[116027]=b;v[a+4>>2]=b|1;if(v[116029]!=(a|0)){break a}v[116026]=0;v[116029]=0;return}if(v[116029]==(f|0)){v[116029]=a;b=v[116026]+b|0;v[116026]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=464096,j=v[116024]&vka(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+464400|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=464100,j=v[116025]&vka(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[116029]!=(a|0)){break g}v[116026]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+464136|0;d=v[116024];b=1<<b;l:{if(!(d&b)){v[116024]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;v[a+16>>2]=0;v[a+20>>2]=0;g=(e<<2)+464400|0;m:{d=v[116025];c=1<<e;n:{if(!(d&c)){v[116025]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function TJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=hb-192|0;hb=f;v[f+188>>2]=c;v[f+184>>2]=b;t[f+183|0]=d;a:{if(!c){break a}g=w[Xk(b,c)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}cl(f+8|0,b,c,c-1|0);b=v[f+12>>2];v[f+184>>2]=v[f+8>>2];v[f+188>>2]=b}b=f+8|0;Rd(b);c=v[f+8>>2];Rd(f+152|0);g=Wk(c,v[f+156>>2],f+184|0);Rd(b);b=v[f+188>>2];c=v[f+184>>2];b:{c:{d:{e:{f:{g:{h:{if((g|0)==v[f+12>>2]){a=qc(f+168|0,21751);if(Mc(c,b,v[a>>2],v[a+4>>2])){b=ba(8)|0;v[23516]=0;R(974,f+152|0,f+183|0);a=v[23516];v[23516]=0;if((a|0)==1){break g}v[23516]=0;U(981,f+8|0,17730,f+152|0);a=v[23516];v[23516]=0;if((a|0)==1){break f}d=0;a=rc(b,f+8|0);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(f+8|0);break e}if(!e){break h}b=ba(8)|0;v[23516]=0;d=Lh(f+120|0,v[f+184>>2],v[f+188>>2]);a=v[23516];v[23516]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[23516]=0;U(981,f+136|0,17766,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break p}v[23516]=0;R(983,f+152|0,f+136|0);c=v[23516];v[23516]=0;a=1;if((c|0)==1){break o}v[23516]=0;R(974,f+104|0,f+183|0);a=v[23516];v[23516]=0;if((a|0)==1){break n}v[23516]=0;U(985,f+8|0,f+152|0,f+104|0);c=v[23516];v[23516]=0;a=1;if((c|0)==1){break m}a=rc(b,f+8|0);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(f+8|0);a=0;break l}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0;break i}c=P()|0;O()|0;break j}c=P()|0;a=1;O()|0;break k}c=P()|0;O()|0}wb(f+104|0)}wb(f+152|0)}wb(f+136|0)}wb(d);if(a){break d}break c}e=qc(f+96|0,21751);if(Mc(c,b,v[e>>2],v[e+4>>2])){b=ba(8)|0;v[23516]=0;R(974,f+152|0,f+183|0);a=v[23516];v[23516]=0;q:{r:{if((a|0)!=1){v[23516]=0;U(981,f+8|0,17730,f+152|0);a=v[23516];v[23516]=0;if((a|0)==1){break r}d=0;a=rc(b,f+8|0);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(f+8|0);break q}c=P()|0;O()|0;break d}c=P()|0;d=1;O()|0}wb(f+152|0);if(d){break d}break c}s:{e=qc(f+88|0,7422);if(!Mc(c,b,v[e>>2],v[e+4>>2])){e=qc(f+80|0,7404);if(!Mc(c,b,v[e>>2],v[e+4>>2])){break s}}t[a+60|0]=d;break h}t:{e=qc(f+72|0,6937);if(!Mc(c,b,v[e>>2],v[e+4>>2])){e=qc(f- -64|0,6918);if(!Mc(c,b,v[e>>2],v[e+4>>2])){break t}}t[a+61|0]=d;break h}e=qc(f+56|0,7021);if(Mc(c,b,v[e>>2],v[e+4>>2])){t[a+62|0]=d;break h}e=qc(f+48|0,6067);if(Mc(c,b,v[e>>2],v[e+4>>2])){t[a+63|0]=d;break h}e=qc(f+40|0,7471);if(Mc(c,b,v[e>>2],v[e+4>>2])){t[a+64|0]=d;break h}e=b;b=qc(f+32|0,13421);if(!Mc(c,e,v[b>>2],v[b+4>>2])){break h}b=v[a+24>>2];c=b+24664|0;e=v[c+4>>2];v[f+24>>2]=v[c>>2];v[f+28>>2]=e;c=b+24656|0;e=v[c+4>>2];v[f+16>>2]=v[c>>2];v[f+20>>2]=e;c=v[b+24652>>2];v[f+8>>2]=v[b+24648>>2];v[f+12>>2]=c;if(d){a=qJ(v[a+56>>2])}else{a=0}v[f+28>>2]=a;if(!ox(f+8|0,b+24648|0)){break h}hy(b,f+8|0)}hb=f+192|0;return}c=P()|0;O()|0;break d}c=P()|0;d=1;O()|0}wb(f+152|0);if(!d){break c}}ca(b|0)}S(c|0)}L()}function Zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-736|0;hb=e;xc(b);f=hb-16|0;hb=f;h=e+120|0;YU(f+8|0,h);j=b;g=v[b>>2];i=v[b+8>>2];b=v[f+12>>2];jc(f,g,i,v[f+8>>2],b);g=v[f+4>>2];if((g|0)==(b|0)){Yb(j,v[f+12>>2])}hb=f+16|0;b=(b|0)==(g|0);if(!b){XU(h)}a:{if(!b){break a}if(!ZU(e+120|0)){break a}b:{if(!c){break b}zd(a,67108864);$f(a);b=w[e+145|0];u[a+480190>>1]=31;u[a+480188>>1]=b;v[a+480228>>2]=256/(b>>>0);b=vc(e,8208);Gb(a+1298344|0,b);xb(b);b=vc(e,10794);Gb(a+1298356|0,b);xb(b);d=e+96|0;Qf(d,4177);f=w[e+144|0];v[e+72>>2]=f>>>4;b=0;v[23516]=0;v[e+116>>2]=f&15;X(305,e|0,d|0,e+72|0,e+116|0);d=v[23516];v[23516]=0;c:{d:{if((d|0)!=1){Gb(a+1298368|0,e);xb(e);ac(e+96|0);v[a+1298404>>2]=14;Aq(Sb(v[a+484360>>2],w[a+484376|0]),e+168|0,w[e+167|0]+1|0);while(1){e:{if((b|0)==31){xu(j,a+1298308|0,32);d=1;break e}d=b+1|0;h=B(d,104)+a|0;g=h+484380|0;jd(g,1);f=(e+120|0)+(b<<2)|0;p=g,q=_b(w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24)),v[p>>2]=q;k=_b(w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24));v[h+484384>>2]=k;f=_b(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24));v[h+484388>>2]=f+k;if(f){f=h+484414|0;u[f>>1]=x[f>>1]|2}wk(g);b=(e+120|0)+b|0;t[e|0]=w[b+548|0];t[e+96|0]=64;p=h+484410|0,q=w[Vb(e,e+96|0)|0]<<2,u[p>>1]=q;t[h+484417|0]=w[b+579|0]<<4;b=d;continue}break}while(1){if((d|0)!=32){WU(j,((d<<5)+a|0)+946304|0,30);d=d+1|0;continue}break}n=c&1;if(n){vg(a+484344|0,w[e+166|0]+1|0)}k=a+484344|0;m=a+480188|0;f=0;while(1){if(w[e+166|0]<f>>>0){d=1;if(!(c&2)){break a}b=Uc(e,8,1,1,0);while(1){if((d|0)==32){break b}ug(b,(B(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}h=Ih(e+96|0);f:{g:{if(w[e+146|0]){v[23516]=0;b=T(274,j|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break f}v[23516]=0;U(188,e+72|0,j|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break f}break g}b=x[m>>1];v[23516]=0;U(188,e+72|0,j|0,b<<8);b=v[23516];v[23516]=0;if((b|0)==1){break d}}b=e+72|0;d=hc(e,b);cd(h,d);yb(d);yb(b);h:{if(!n){break h}v[23516]=0;b=W(225,k|0,f&65535,64)|0;d=v[23516];v[23516]=0;if((d|0)==1){break d}if(!b){break h}b=0;if(w[e+146|0]){g=0;v[23516]=0;R(306,h|0,e|0);b=v[23516];v[23516]=0;if((b|0)==1){break d}i:while(1){if((g|0)==64){break h}i=e+g|0;b=128;d=0;l=Xb(v[k>>2],f);l=xf(v[l>>2],v[v[l+48>>2]+12>>2],g);while(1){if(x[m>>1]<=d>>>0){g=g+1|0;continue i}j:{if(!(w[i|0]&b)){break j}v[23516]=0;R(307,h|0,l+B(d,6)|0);o=v[23516];v[23516]=0;if((o|0)!=1){break j}break d}b=b>>>1|0;d=d+1|0;continue}}}k:while(1){d=0;g=b&65535;if(g>>>0>=x[m>>1]){break h}while(1){if((d|0)==64){b=b+1|0;continue k}i=Xb(v[k>>2],f);i=ed(v[i>>2],v[v[i+48>>2]+12>>2],d,g);v[23516]=0;R(307,h|0,i|0);i=v[23516];v[23516]=0;if((i|0)!=1){d=d+1|0;continue}break}break}break d}yb(h);f=f+1|0;continue}break}break d}d=P()|0;O()|0;ac(e+96|0);break c}d=P()|0;O()|0;yb(h)}S(d|0);L()}d=1}hb=e+736|0;return d|0}function bT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb-176|0;hb=g;i=Xf(g+160|0);a:{b:{c:{if(d){v[23516]=0;U(479,a|0,i|0,c|0);c=v[23516];v[23516]=0;if((c|0)!=1){break c}break b}v[23516]=0;U(480,a|0,i|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}}k=Lb(g+144|0);m=b+480192|0;n=b+1298464|0;d=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=d&65535;if(h>>>0<=x[m>>1]){v[23516]=0;u[g+142>>1]=0;R(481,a|0,g+142|0);c=v[23516];v[23516]=0;t:{u:{v:{w:{if((c|0)!=1){j=hb-16|0;hb=j;o=x[g+142>>1];c=Pd(i);e=gc(i);f=hb-16|0;hb=f;while(1){if(c){l=bo(x[c+16>>1],o);e=l?e:c;c=v[(l?c+4|0:c)>>2];continue}break}c=v[cc(f+8|0,e)>>2];hb=f+16|0;x:{if(Nb(c,Yf(i))){if(!bo(x[g+142>>1],x[sd(c)>>1])){break x}}c=Yf(i)}c=cc(j+8|0,c);hb=j+16|0;j=((h<<2)+b|0)+900380|0;if(!v[j>>2]){break d}c=v[c>>2];if(!Fg(c,tf(i))){break u}v[23516]=0;c=Q(3,g+128|0,sd(c)+4|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break t}v[23516]=0;e=Q(1,g+112|0,16878)|0;f=v[23516];v[23516]=0;if((f|0)==1){break v}f=hq(c,e);xb(e);if(f){break p}e=v[b+4>>2];v[23516]=0;e=Q(482,e|0,c|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break r}v[v[j>>2]+44>>2]=e;if(!v[v[j>>2]+44>>2]){break w}break e}d=P()|0;O()|0;break f}v[23516]=0;e=Q(1,g+96|0,13452)|0;f=v[23516];v[23516]=0;y:{z:{A:{if((f|0)!=1){B:{if(!hq(c,e)){v[23516]=0;f=Q(1,g+80|0,13709)|0;h=v[23516];v[23516]=0;if((h|0)==1){break A}h=hq(c,f);xb(f);xb(e);if(h){break B}break s}xb(e)}v[23516]=0;e=T(483,c|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break z}v[g+56>>2]=e;e=v[b+4>>2];f=v[dg(g+72|0,g+56|0)>>2];v[23516]=0;e=Q(484,e|0,f|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break y}qg(g+56|0);if(e){break e}break s}d=P()|0;O()|0;break g}d=P()|0;O()|0;xb(e);break g}d=P()|0;O()|0;break g}d=P()|0;O()|0;qg(g+56|0);break g}d=P()|0;O()|0;break g}c=v[j>>2];if(!c){break d}v[c+44>>2]=0;break d}d=P()|0;O()|0;break f}Il(k);aT(i);hb=g+176|0;return}e=Cb(v[k>>2]);h=Cb(v[k+4>>2]);f=hb-16|0;hb=f;v[f+8>>2]=e;while(1){C:{if(!Nb(e,h)){break C}if(hq(e,c)){break C}e=v[gq(f+8|0)>>2];continue}break}hb=f+16|0;if(Nb(e,Cb(v[k+4>>2]))){break p}v[23516]=0;R(485,k|0,c|0);e=v[23516];v[23516]=0;if((e|0)!=1){break q}}d=P()|0;O()|0;break g}v[23516]=0;e=Q(1,g+24|0,17579)|0;f=v[23516];v[23516]=0;if((f|0)==1){break o}v[23516]=0;U(486,g+40|0,e|0,c|0);f=v[23516];v[23516]=0;if((f|0)==1){break n}v[23516]=0;f=Q(1,g+8|0,16431)|0;h=v[23516];v[23516]=0;if((h|0)==1){break m}v[23516]=0;U(2,g+56|0,g+40|0,f|0);h=v[23516];v[23516]=0;if((h|0)==1){break l}h=v[n>>2];v[23516]=0;U(384,h|0,2,g+56|0);h=v[23516];v[23516]=0;if((h|0)==1){break k}xb(g+56|0);xb(f);xb(g+40|0);xb(e)}v[v[j>>2]+44>>2]=0;break e}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break i}d=P()|0;O()|0;break j}d=P()|0;O()|0;xb(g+56|0)}xb(f)}xb(g+40|0)}xb(e)}xb(c)}Il(k);break a}xb(c)}d=d+1|0;continue}}d=P()|0;O()|0}aT(i);S(d|0);L()}function zW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=hb-32|0;hb=e;v[e+28>>2]=b;a:{if((d|0)<=0){b=0;break a}v[e+8>>2]=d;v[e+16>>2]=214748364;r=e,s=B(v[Hb(e+28|0,e+16|0)>>2],20),v[r+20>>2]=s;hn(c,v[Hb(e+8|0,e+20|0)>>2]);v[e+12>>2]=b;v[e+8>>2]=a;b=0;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}a=v[e+8>>2];g=v[e+12>>2];f=mh(a,g,b);k=mh(a,g,b+4|0);o=mh(a,g,b+5|0);r=e,s=mh(a,g,b+6|0)<<8|mh(a,g,b+7|0),v[r+24>>2]=s;k=o|k<<8;q=b+8|0;f:{g:{switch(f|0){case 0:b=0;if((d|0)<(k|0)){b=ba(8)|0;v[23516]=0;a=T(191,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break f}break d}while(1){if((b|0)!=(k|0)){r=e,s=mh(v[e+8>>2],v[e+12>>2],b+q|0),t[r+20|0]=s;fn(c,e+20|0);b=b+1|0;continue}break};o=k;break b;case 1:break g;default:break e}}bi(e+24|0,d);o=v[e+24>>2];m=mh(a,g,b+10|0);t[e+20|0]=m;fn(c,e+20|0);h=b+11|0;k=k+3&65532;b=o-1|0;g=0;j=0;n=0;l=0;while(1){if((b|0)<=0){break c}f=yg(h,g,1,e+8|0);h:{i:{j:{k:{l:{if((j|0)<=7){if(f){a=g;break i}a=g+1|0;l=8;break l}a=g+1|0;m:{if(!f){if(!yg(h,a,1,e+8|0)){break i}i=2;n:{o:{f=g+2|0;if(!yg(h,f,1,e+8|0)){break o}i=3;f=g+3|0;if(!yg(h,f,1,e+8|0)){break o}i=yg(h,f,3,e+8|0);a=g+6|0;break n}a=f+1|0}f=4;p:{q:{r:{g=((l<<3)+i|0)-17|0;s:{if((g|0)<0){a=ba(8)|0;v[23516]=0;b=T(191,a|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break r}break s}if(g>>>0<56){break p}a=ba(8)|0;v[23516]=0;b=T(191,a|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break q}}b=P()|0;O()|0;ca(a|0);S(b|0);L()}ia(b|0,26232,166);L()}ia(b|0,26232,166);L()}l=w[g+26272|0];if((l|0)!=8){break k}break m}f=4;if((l|0)!=8){break k}}l=8;f=1;if((n|0)>19){break k}}f=0;break j}n=n+8|0}while(1){if(!((f|0)<0|(b|0)<=0)){i=(a|0)/8|0;g=i+h|0;p=mh(v[e+8>>2],v[e+12>>2],g);m=m-hd((mh(v[e+8>>2],v[e+12>>2],g+1|0)<<8|p<<16|mh(v[e+8>>2],v[e+12>>2],g+2|0))<<(a-(i<<3)|0)+8,32-l|0)|0;t[e+20|0]=m;fn(c,e+20|0);f=f-1|0;b=b-1|0;a=a+l|0;continue}break}j=(j|0)==31?31:j+1|0;g=a;break h}t:{u:{v:{f=a+1|0;if(!yg(h,f,1,e+8|0)){g=2;break v}f=a+2|0;if(!yg(h,f,1,e+8|0)){g=4;break v}f=a+3|0;if(!yg(h,f,1,e+8|0)){g=6;break v}f=a+5|0;if(!yg(h,a+4|0,1,e+8|0)){a=a+8|0;f=yg(h,f,3,e+8|0)+8|0;break t}a=a+10|0;g=16;f=yg(h,f,5,e+8|0);break u}a=f+2|0;f=yg(h,f+1|0,1,e+8|0)}f=g+f|0}w:{if(yg(h,a,1,e+8|0)){i=-256;g=12;break w}a=a+1|0;g=yg(h,a,1,e+8|0);i=g?-4352:0;g=g?14:8}p=a+1|0;a=yg(h,p,g,e+8|0);if(f>>>0>=3){j=j-((f|0)!=3)|0;j=((j|0)>1?j:1)-1|0}i=(a^-1)+i|0;a=ad(v[c>>2],v[c+4>>2])+i|0;if(a>>>0<i>>>0){g=g+p|0;while(1){if((f|0)<=0|(b|0)<=0){break h}m=w[Ib(v[c>>2],a)|0];t[e+20|0]=m;fn(c,e+20|0);b=b-1|0;a=a+1|0;f=f-1|0;continue}}b=ba(8)|0;v[23516]=0;a=T(191,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}ia(a|0,26232,166);L()}n=n-(n>>3)|0;continue}}ia(a|0,26232,166);L()}b=nc(v[c>>2],v[c+4>>2])^1;break a}a=P()|0;O()|0;ca(b|0);S(a|0);L()}v[e+24>>2]=b}d=d-o|0;b=k+q|0;continue}}hb=e+32|0;return b|0}function rY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-352|0;hb=d;e=hb-16|0;hb=e;v[a+4>>2]=0;t[a|0]=0;f=a+40|0;hn(f,32);t[e+15|0]=0;fn(f,e+15|0);hb=e+16|0;e=v[a+36>>2];a:{if(!Mh(v[v[e>>2]-12>>2]+e|0)){ph(a,2,16777216);break a}f=d+88|0;ke(f,e);e=v[f+12>>2];v[a+16>>2]=v[f+8>>2];v[a+20>>2]=e;v[f>>2]=3;h=v[a+36>>2];g=d+24|0;e=0;while(1){if(y[f>>2]>e>>>0){ki(h,e+g|0);e=e+1|0;continue}break}if(Qb(g,26128,3)){ph(a,2,512);break a}t[d+351|0]=0;ki(v[a+36>>2],d+351|0);Rb(d+88|0,0,256);e=w[d+351|0];if(e){Mk(v[a+36>>2],d+88|0,e)}g=b;b=Fk(d+24|0,d+88|0,e);e=_v(g,b);Ub(b);if(!e){ph(a,2,4096)}if(Ek(w[a|0])){break a}ki(v[a+36>>2],d+87|0);g=w[d+87|0];b=g&3;u[a+24>>1]=(b|0)==3?4:b;if(Qi(g,6)){b=d+24|0;Pc(b,a+32|0,9);We(b,1)}v[d+80>>2]=0;OE(v[a+36>>2],d+80|0);b=v[d+80>>2];t[d+79|0]=0;if(b>>>0>=2){ki(v[a+36>>2],d+87|0);e=-1;if(!w[d+87|0]){ki(v[a+36>>2],d+79|0);e=-2}Ul(v[a+36>>2],b+e|0)}v[d+64>>2]=0;v[d+68>>2]=0;b:{if(!Qi(g,4)){break b}Ck(v[a+36>>2],d- -64|0);b=v[d+68>>2];e=v[d+64>>2];v[a+64>>2]=e;v[a+68>>2]=b;f=v[c+4>>2];if((f|0)==(b|0)&y[c>>2]>=e>>>0|b>>>0<f>>>0){break b}ph(a,1,4)}if(Qi(g,5)){ki(v[a+36>>2],d+87|0);Ul(v[a+36>>2],w[d+87|0])}c=w[d+79|0];c:{if(!Qi(c,0)){break c}ki(v[a+36>>2],d+87|0);b=w[d+87|0];b=b&1?-1:b>>>1|0;u[a+24>>1]=b;if(b){break c}ph(a,1,2)}v[a+8>>2]=0;e=1;if(Qi(c,1)){OE(v[a+36>>2],a+8|0)}h=Qi(g,2);b=d+24|0;f=a+32|0;Pc(b,f,6);We(b,h);h=Qi(g,3);Pc(b,f,7);We(b,h);h=x[a+24>>1];Pc(b,f,5);We(b,(h|0)!=0);g=Qi(g,7);Pc(b,f,8);We(b,g);Pc(b,f,5);d:{if(zb(v[v[d+24>>2]>>2],v[d+28>>2])){break d}Pc(d+8|0,f,6);if(zb(v[v[d+8>>2]>>2],v[d+12>>2])){break d}Pc(d+56|0,f,7);if(zb(v[v[d+56>>2]>>2],v[d+60>>2])){break d}Pc(d+48|0,f,8);e=zb(v[v[d+48>>2]>>2],v[d+52>>2])}b=d+40|0;Pc(b,f,11);We(b,e);Pc(d+24|0,f,11);if(Qi(c,2)){u[d+8>>1]=0;Sv(v[a+36>>2],d+8|0);b=v[a+36>>2];e=x[d+8>>1];Pc(d+24|0,f,9);Ul(b,B(e,zb(v[v[d+24>>2]>>2],v[d+28>>2])?2:1))}if(Qi(c,3)){Ul(v[a+36>>2],5)}Ck(v[a+36>>2],d- -64|0);c=v[d+68>>2];g=c;b=v[d+64>>2];if(!c&b>>>0>=16001|c){ph(a,2,8192);break a}v[a+104>>2]=b;if(!b){ph(a,1,1)}Pc(d+24|0,f,11);e:{if(!zb(v[v[d+24>>2]>>2],v[d+28>>2])){break e}Ck(v[a+36>>2],d- -64|0);c=v[d+68>>2];g=c;b=v[d+64>>2];if(Qv(b,c)){break e}ph(a,2,2048);break a}c=d+8|0;ke(c,v[a+36>>2]);e=v[a+16>>2];h=v[a+20>>2];i=v[c+4>>2];v[d+24>>2]=v[c>>2];v[d+28>>2]=i;i=v[c+12>>2];v[d+32>>2]=v[c+8>>2];v[d+36>>2]=i;c=v[d+32>>2];h=v[d+36>>2]-(h+(e>>>0>c>>>0)|0)|0;v[d+32>>2]=c-e;v[d+36>>2]=h;e=v[d+32>>2];c=v[d+36>>2];if((c|0)<0){ph(a,2,16384);break a}v[a+96>>2]=e;v[a+100>>2]=c;c=d+24|0;Pc(c,f,11);e=v[a+100>>2];h=b;i=v[a+96>>2];b=zb(v[v[d+24>>2]>>2],v[d+28>>2]);v[a+72>>2]=b?h:i;v[a+76>>2]=b?g:e;Pc(c,f,11);if(!zb(v[v[d+24>>2]>>2],v[d+28>>2])){b=v[a+100>>2]+v[a+20>>2]|0;e=v[a+16>>2];c=e+v[a+96>>2]|0;v[a+80>>2]=c;v[a+84>>2]=c>>>0<e>>>0?b+1|0:b}a=d+24|0;Pc(a,f,10);We(a,1)}hb=d+352|0}function cM(a,b){var c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=C(0),t=0;if(b){iy(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;hM(a)}bM(a+24648|0);o=v[a+24620>>2];f=hb-144|0;hb=f;e=a+397456|0;c=v[e+4>>2];if(c>>>0>=29){v[e+4>>2]=0;c=0}h=B(c,44)+47696|0;if(!(b?0:(h|0)==v[e+8>>2])){v[e+8>>2]=h;m=C(o>>>0);c=f+8|0;d=v[h+24>>2];v[c>>2]=d;j=v[h+16>>2];v[c+4>>2]=j;v[c+8>>2]=v[h+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){i=j;j=k+600|0;v[c+4>>2]=i-j;v[c>>2]=d-j}g=C(z[h+36>>2]*C(79.30999755859375));a:{if(C(D(g))<C(2147483648)){d=~~g;break a}d=-2147483648}v[c+16>>2]=d- -8192;g=C(C(C(z[h+32>>2]*C(.0036000001709908247))+C(.15000000596046448))*C(32767));b:{if(C(D(g))<C(2147483648)){d=~~g;break b}d=-2147483648}v[c+20>>2]=(d|0)<32512?d:32512;j=0;g=z[h+8>>2];l=C(C(F(z[h+20>>2],C(.10000000149011612)))*m);c:{if(C(D(l))<C(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)>96?d:96;i=k-7500|0;n=k>>>0<i>>>0?0:i;l=C(z[h+28>>2]*m);d:{if(C(D(l))<C(2147483648)){i=~~l;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)>128?d:128;p=i>>>0<3800?i:3800;v[c+24>>2]=p;n=(d|0)<128?d-128|0:0;g=C(g*m);e:{if(C(D(g))<C(2147483648)){q=~~g;break e}q=-2147483648}d=i-3800|0;i=(q+n|0)+(d>>>0>i>>>0?0:d)|0;v[c+32>>2]=i;n=k>>>0<7500?k:7500;while(1){if((j|0)==8){g=C(i|0);l=C(qe(C(.0010000000474974513),(i|0)<4721?C(1):C(C(4720)/g))*C(32768));f:{if(C(D(l))<C(2147483648)){d=~~l;break f}d=-2147483648}v[c+12>>2]=d;g=C(z[h+12>>2]*g);r=c,s=qe(C(.0010000000474974513),g<=C(4720)?C(1):C(C(4720)/g)),z[r+28>>2]=s}else{d=B(j,12);k=d+c|0;u[k+42>>1]=x[d+48986>>1];u[k+36>>1]=x[d+48980>>1];u[k+40>>1]=x[d+48984>>1];u[k+38>>1]=x[d+48982>>1];v[k+44>>2]=n+((B(v[d+48976>>2],p)+50|0)/100|0);j=j+1|0;continue}break}v[e+20>>2]=v[f+40>>2];c=eK(fK(v[f+16>>2]),m);u[e+86>>1]=c;u[e+84>>1]=c;c=x[f+24>>1]<<1;u[e+94>>1]=c;u[e+92>>1]=c;c=0;while(1){if((c|0)==8){v[e+49892>>2]=v[f+32>>2];c=v[f+12>>2];if((c|0)>-9e3){c=dK(c)}else{c=0}v[e+80>>2]=c;d=e+49948|0;c=v[f+8>>2];if((c|0)>=-8999){c=dK(c)}else{c=0}v[d>>2]=c;c=v[f+28>>2];d=e+49932|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[e+49906>>1]=c;u[e+49904>>1]=c;u[e+49902>>1]=c;u[e+49900>>1]=c;v[f+4>>2]=v[f+20>>2];me(f+4|0,0,32752);c=x[f+4>>1];u[e+49914>>1]=c;d=e+49910|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49908>>1]=c;g=z[f+36>>2];r=f,t=eK(C(g*g),m),v[r>>2]=t;me(f,256,32512);c=x[f>>1];u[e+49922>>1]=c;d=e+49918|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49916>>1]=c}else{d=(c<<4)+e|0;h=(f+8|0)+B(c,12)|0;j=v[h+44>>2];v[d+100>>2]=j;v[d+104>>2]=j;u[d+108>>1]=x[h+36>>1];u[d+110>>1]=x[h+42>>1];u[d+112>>1]=x[h+40>>1];u[d+114>>1]=x[h+38>>1];c=c+1|0;continue}break}}c=a+397448|0;d=a+397452|0;if(b){v[e+16>>2]=0;hK(e,c,d)}b=B(o,5);if(b>>>0>y[e+20>>2]){v[e+20>>2]=b}hb=f+144|0;b=v[a+1298300>>2];if(vd(b)){GO(b,v[a+24620>>2])}}function a6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=hb-96|0;hb=f;a:{if(Pe(b)){break a}e=w[tJ(b)|0];if((e|0)==33){d=1}else{if((e|0)!=63){break a}d=0}e=f+80|0;Fv(e,b,0,Fb(b)-1|0);yc(b,e);wb(e)}g=f+80|0;Rd(g);e=v[f+80>>2];Rd(f- -64|0);e=sJ(e,v[f+68>>2],b);Rd(g);b:{c:{d:{e:{if((e|0)==v[f+84>>2]){if(re(b,21751)){a=ba(8)|0;v[23516]=0;U(972,f+80|0,17730,c|0);b=v[23516];v[23516]=0;if((b|0)==1){break d}a=rc(a,f+80|0);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}b=P()|0;O()|0;wb(f+80|0);break c}if(!d){break e}a=ba(8)|0;v[23516]=0;U(972,f+48|0,17766,b|0);b=v[23516];v[23516]=0;f:{g:{h:{i:{j:{if((b|0)!=1){v[23516]=0;R(983,f- -64|0,f+48|0);b=v[23516];v[23516]=0;if((b|0)==1){break j}v[23516]=0;U(538,f+80|0,f- -64|0,c|0);b=v[23516];v[23516]=0;d=1;if((b|0)==1){break i}b=rc(a,f+80|0);v[23516]=0;U(117,b|0,62944,970);b=v[23516];v[23516]=0;if((b|0)!=1){break b}b=P()|0;O()|0;wb(f+80|0);d=0;break h}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0;break g}b=P()|0;O()|0}wb(f- -64|0)}wb(f+48|0);if(!d){break c}}ca(a|0);break c}k:{switch(v[e+4>>2]){case 0:Be(f+40|0,b);b=hb-192|0;hb=b;e=b+16|0;pi(e,c);v[23516]=0;R(86,b+32|0,e|0);c=v[23516];v[23516]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[23516]=0;c=Q(87,b+48|0,b+32|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break p}wb(b+32|0);wb(b+16|0);e=v[v[c>>2]-12>>2];v[23516]=0;g=ha(60)|0;h=v[23516];v[23516]=0;if((h|0)==1){break n}v[23516]=0;U(61,b+8|0,c+e|0,g|0);e=v[23516];v[23516]=0;if((e|0)==1){break n}Zb(b+8|0);v[23516]=0;e=Q(1084,c|0,b+32|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break n}c=Tk(v[(e+v[v[e>>2]-12>>2]|0)+16>>2]);g=w[b+32|0];pf(e);hb=b+192|0;b=(c^-1)&(g|0)!=0;break l}a=P()|0;O()|0;break o}a=P()|0;O()|0;wb(b+32|0)}wb(b+16|0);break m}a=P()|0;O()|0;pf(c)}S(a|0);L()}TJ(a,v[f+40>>2],v[f+44>>2],b,d);break e;case 1:Be(f+32|0,b);b=hb-192|0;hb=b;e=b+16|0;pi(e,c);v[23516]=0;R(86,b+32|0,e|0);c=v[23516];v[23516]=0;q:{r:{s:{t:{u:{if((c|0)!=1){v[23516]=0;c=Q(87,b+48|0,b+32|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break u}wb(b+32|0);wb(b+16|0);e=v[v[c>>2]-12>>2];v[23516]=0;g=ha(60)|0;h=v[23516];v[23516]=0;if((h|0)==1){break s}v[23516]=0;U(61,b+8|0,c+e|0,g|0);e=v[23516];v[23516]=0;if((e|0)==1){break s}Zb(b+8|0);v[23516]=0;e=Q(94,c|0,b+32|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break s}c=Tk(v[(e+v[v[e>>2]-12>>2]|0)+16>>2]);g=v[b+32>>2];h=v[b+36>>2];pf(e);hb=b+192|0;b=c?0:g;c=c?0:h;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;wb(b+32|0)}wb(b+16|0);break r}a=P()|0;O()|0;pf(c)}S(a|0);L()}RJ(a,v[f+32>>2],v[f+36>>2],b,c,d);break e;case 2:Be(f+24|0,b);i=rH(c);SJ(a,v[f+24>>2],v[f+28>>2],i,d);break e;case 3:break k;default:break e}}Be(f+16|0,b);Be(f+8|0,c);PJ(a,v[f+16>>2],v[f+20>>2],v[f+8>>2],v[f+12>>2],d)}hb=f+96|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=hb-32|0;hb=j;a:{if(nt(a)>>>0<b>>>0){n=Xn(j+16|0);v[23516]=0;R(748,n|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}ml(j+8|0,v[a>>2]);tm(j,v[a>>2],v[a+4>>2]);m=hb-48|0;hb=m;c=v[n+4>>2];e=fc(m+40|0,v[j+8>>2],v[j+12>>2]);f=fc(m+32|0,v[j>>2],v[j+4>>2]);b=hb-16|0;hb=b;e=fc(b+8|0,v[e>>2],v[e+4>>2]);f=fc(b,v[f>>2],v[f+4>>2]);e=ZQ(v[e>>2],v[e+4>>2],v[f>>2],v[f+4>>2]);hb=b+16|0;e=c+e|0;v[n+4>>2]=e;b:{c:{if(!c){b=e-1|0;break c}b=e-1|0;if((b^c-1)>>>0<32){break b}}v[v[n>>2]+((e>>>0<33?0:b>>>5|0)<<2)>>2]=0}f=fc(m+24|0,v[j+8>>2],v[j+12>>2]);e=fc(m+16|0,v[j>>2],v[j+4>>2]);b=m+8|0;Go(b,v[n>>2],c);c=v[f>>2];o=hb-48|0;hb=o;f=v[f+4>>2];d:{if((f|0)==v[b+4>>2]){f=fc(o+40|0,c,f);c=fc(o+32|0,v[e>>2],v[e+4>>2]);b=fc(o+24|0,v[b>>2],v[b+4>>2]);e=hb-16|0;hb=e;g=v[f>>2];d=v[f+4>>2];c=ll(v[c>>2],v[c+4>>2],g,d);v[e+12>>2]=c;e:{if((c|0)<=0){c=v[b>>2];break e}if(d){i=32-d|0;v[e+8>>2]=i;k=c;c=v[od(e+8|0,e+12|0)>>2];v[e+12>>2]=k-c;h=v[b>>2];d=-1<<d&-1>>>i-c;v[h>>2]=v[h>>2]&(d^-1)|d&v[g>>2];c=c+v[b+4>>2]|0;v[b+4>>2]=c&31;v[b>>2]=h+(c>>>3&536870908);g=v[f>>2]+4|0;v[f>>2]=g;c=v[e+12>>2]}k=g;d=(c|0)/32|0;g=d<<2;dj(v[b>>2],k,g);d=c-(d<<5)|0;v[e+12>>2]=d;c=g+v[b>>2]|0;v[b>>2]=c;if((d|0)<=0){break e}c=f;f=g+v[f>>2]|0;v[c>>2]=f;c=v[b>>2];g=-1>>>32-d|0;v[c>>2]=v[c>>2]&(g^-1)|g&v[f>>2];v[b+4>>2]=v[e+12>>2]}fc(m,c,v[b+4>>2]);break d}g=fc(o+16|0,c,f);c=fc(o+8|0,v[e>>2],v[e+4>>2]);f=fc(o,v[b>>2],v[b+4>>2]);e=hb-16|0;hb=e;k=v[c>>2];d=v[c+4>>2];b=v[g>>2];c=v[g+4>>2];d=ll(k,d,b,c);v[e+12>>2]=d;f:{if((d|0)<=0){c=v[f+4>>2];break f}g:{if(!c){c=v[f+4>>2];break g}l=32-c|0;v[e+8>>2]=l;i=e+8|0;h=v[od(i,e+12|0)>>2];v[e+12>>2]=d-h;d=v[f+4>>2];p=v[b>>2];v[e+8>>2]=h;k=32-d|0;v[e+4>>2]=k;b=v[f>>2];q=v[b>>2];i=v[Hb(i,e+4|0)>>2];l=p&(-1<<c&-1>>>l-h);v[b>>2]=(-1<<d&-1>>>k-i^-1)&q|(c>>>0<d>>>0?l<<d-c:l>>>c-d|0);d=d+i|0;c=d&31;v[f+4>>2]=c;d=b+(d>>>3&536870908)|0;v[f>>2]=d;b=h-i|0;if((b|0)>0){v[d>>2]=v[d>>2]&(-1>>>32-b^-1)|l>>>i+v[g+4>>2];v[f+4>>2]=b;c=b}b=v[g>>2]+4|0;v[g>>2]=b;d=v[e+12>>2]}h=32-c|0;i=-1<<c;l=i^-1;while(1){if((d|0)>=32){d=v[f>>2];b=v[b>>2];v[d>>2]=l&v[d>>2]|b<<c;v[f>>2]=d+4;v[d+4>>2]=i&v[d+4>>2]|b>>>h;d=v[e+12>>2]-32|0;v[e+12>>2]=d;b=v[g>>2]+4|0;v[g>>2]=b;continue}break}if((d|0)<=0){break f}l=v[b>>2];v[e+8>>2]=h;g=v[f>>2];b=v[g>>2];k=b;b=v[od(e+12|0,e+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-d;v[g>>2]=k|h<<c;d=b+c|0;c=d&31;v[f+4>>2]=c;g=g+(d>>>3&536870908)|0;v[f>>2]=g;d=v[e+12>>2]-b|0;v[e+12>>2]=d;if((d|0)<=0){break f}v[g>>2]=v[g>>2]&(-1>>>32-d^-1)|h>>>b;c=v[e+12>>2];v[f+4>>2]=c}fc(m,v[f>>2],c)}hb=e+16|0;hb=o+48|0;hb=m+48|0;xt(a,n);Ue(n)}hb=j+32|0;return}a=P()|0;O()|0;Ue(n);S(a|0);L()}function hE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=hb-176|0;hb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){Lv(a+128|0,c);v[23516]=0;c=Q(1,a+112|0,17866)|0;d=v[23516];v[23516]=0;if((d|0)==1){break E}v[23516]=0;U(2,a+144|0,a+128|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break D}v[23516]=0;d=Q(3,a+80|0,e|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break C}v[23516]=0;e=Q(1,a- -64|0,19694)|0;f=v[23516];v[23516]=0;if((f|0)==1){break B}v[23516]=0;U(4,a+96|0,d|0,e|0);f=v[23516];v[23516]=0;if((f|0)==1){break A}v[23516]=0;U(2,a+160|0,a+144|0,a+96|0);f=v[23516];v[23516]=0;if((f|0)==1){break z}xb(a+96|0);xb(e);xb(d);d=a+144|0;xb(d);xb(c);xb(a+128|0);c=v[b>>2];v[23516]=0;U(5,d|0,1,(c?c:21751)|0);c=v[23516];v[23516]=0;if((c|0)==1){break t}c=v[b+4>>2];v[23516]=0;U(5,a+128|0,1,(c?c:21751)|0);c=v[23516];v[23516]=0;if((c|0)==1){break s}b=v[b+8>>2];v[23516]=0;v[a+48>>2]=b;R(6,a+96|0,a+48|0);b=v[23516];v[23516]=0;if((b|0)==1){break r}v[23516]=0;Y(7,17745);b=v[23516];v[23516]=0;if((b|0)==1){break q}v[23516]=0;U(8,a+48|0,0,a+144|0);b=v[23516];v[23516]=0;if((b|0)==1){break p}v[23516]=0;Y(9,a+48|0);b=v[23516];v[23516]=0;if((b|0)==1){break o}v[23516]=0;Y(7,17539);b=v[23516];v[23516]=0;if((b|0)==1){break o}v[23516]=0;U(8,a+32|0,0,a+96|0);b=v[23516];v[23516]=0;if((b|0)==1){break n}v[23516]=0;Y(9,a+32|0);b=v[23516];v[23516]=0;if((b|0)==1){break m}v[23516]=0;Y(7,17537);b=v[23516];v[23516]=0;if((b|0)==1){break m}v[23516]=0;Y(7,17866);b=v[23516];v[23516]=0;if((b|0)==1){break m}v[23516]=0;U(8,a+16|0,0,a+160|0);b=v[23516];v[23516]=0;if((b|0)==1){break l}v[23516]=0;Y(9,a+16|0);b=v[23516];v[23516]=0;if((b|0)==1){break k}v[23516]=0;Y(7,13478);b=v[23516];v[23516]=0;if((b|0)==1){break k}v[23516]=0;U(8,a|0,0,a+128|0);b=v[23516];v[23516]=0;if((b|0)==1){break j}v[23516]=0;Y(9,a|0);b=v[23516];v[23516]=0;if((b|0)==1){break i}v[23516]=0;Y(7,13476);b=v[23516];v[23516]=0;if((b|0)==1){break i}v[23516]=0;Z(10);b=v[23516];v[23516]=0;if((b|0)==1){break i}wb(a);wb(a+16|0);wb(a+32|0);wb(a+48|0);xb(a+96|0);xb(a+128|0);xb(a+144|0);xb(a+160|0)}hb=a+176|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;xb(a+96|0)}xb(e)}xb(d)}xb(a+144|0)}xb(c)}xb(a+128|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;wb(a)}wb(a+16|0)}wb(a+32|0)}wb(a+48|0)}xb(a+96|0)}xb(a+128|0)}xb(a+144|0)}xb(a+160|0)}S(b|0);L()}function yea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,B=0,C=0;f=hb-4144|0;hb=f;a:{h=Eb(w[a+14|0]|w[a+15|0]<<8);b:{if(!h|h>>>0>20){break b}i=b+480190|0;if(x[i>>1]<=w[a+23|0]){break b}jd(d,32);u[d+34>>1]=1;g=f+24|0;h=a+20|0;v[g>>2]=h;B=g,C=Qd(h,h+80|0),v[B+4>>2]=C;fQ(f+4136|0,v[f+24>>2],v[f+28>>2],Eb(w[a+14|0]|w[a+15|0]<<8));h=v[f+4136>>2];j=w[Bb(h,0)+3|0];v[f+24>>2]=1;j=v[Vc(Fi(b,j+1|0)+24|0,g)>>2];k=g;g=v[f+4140>>2];fQ(k,h,g,c?g:1);r=1/+(j>>>0);g=v[f+24>>2];h=Bb(g,v[f+28>>2]);j=v[f+4136>>2];i=x[i>>1];while(1){if((g|0)==(h|0)){c:{p=Jg(d);if(!p){break c}i=(e<<12>>>0)/1e4|0;e=v[f+4140>>2];j=Lb(f+4120|0);d:{if(!e){break d}v[23516]=0;R(740,j|0,e|0);g=v[23516];v[23516]=0;if((g|0)!=1){v[23516]=0;VP(j,e);e=v[23516];v[23516]=0;if((e|0)!=1){break d}}break a}s=v[j>>2];k=v[f+4136>>2];z=v[f+4140>>2];A=b+480190|0;g=0;while(1){if((g|0)==(z|0)){h=b+24648|0}else{h=Bb(k,g);e=eQ(s,g);n=w[h+3|0];e:{if(n>>>0>=x[A>>1]){break e}o=t[h+1|0];if((o|0)<0){break e}l=0;h=w[h+2|0];if((h+14&255)>>>0<=5){l=t[h+26974|0]}h=Fi(b,n+1|0);n=v[h+24>>2];q=r*(ni(+(l<<24>>24)/96+ +(o-t[Bb(k,0)+1|0]|0)/12)*+(n>>>0));if(q<=0){break e}l=dQ(q);v[e+8>>2]=l;n=kb;v[e+12>>2]=n;v[e+16>>2]=v[h+20>>2];o=v[h>>2];v[e+76>>2]=o;v[e+88>>2]=x[h+34>>1]&1023;f:{if(c){v[e+664>>2]=m;m=Oe(+(o>>>0)/Kz(l,n))+m|0;h=i;break f}h=(i>>>0)/(Eb(w[a+14|0]|w[a+15|0]<<8)>>>0)|0}v[e+20>>2]=h;v[e+24>>2]=h}g=g+1|0;continue}break}b=0;while(1){g:{a=v[d>>2];if(a>>>0>b>>>0){Rb(f+24|0,0,4096);v[f+16>>2]=512;v[f+12>>2]=a-b;c=v[Hb(f+16|0,f+12|0)>>2];B=f,C=Cb(v[j>>2]),v[B+16>>2]=C;i=Cb(v[j+4>>2]);while(1){a=v[f+16>>2];if(!Nb(a,i)){break g}h:{i:{if(!v[a+16>>2]){break i}e=v[a+664>>2];if(e>>>0>=c>>>0){v[a+664>>2]=e-c;break i}g=v[a+88>>2];v[f+12>>2]=c-e;B=f,C=Oe((+y[a+76>>2]-Kz(v[a>>2],v[a+4>>2]))/Kz(v[a+8>>2],v[a+12>>2])),v[B+8>>2]=C;m=v[Hb(f+12|0,f+8|0)>>2];v[23516]=0;X(v[((g&1|(g&64?18:16))<<2)+27568>>2],a|0,h|0,(f+24|0)+(e<<3)|0,m|0);e=v[23516];v[23516]=0;if((e|0)==1){break h}v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break i}v[a+16>>2]=0}v[f+16>>2]=v[f+16>>2]+872;continue}break}break a}bq(j);break c}e=v[d+20>>2]+(b<<1)|0;g=f+24|0;a=hb-16|0;hb=a;v[a+12>>2]=c;uc(a+12|0,512);m=v[a+12>>2];while(1){if(m){i=hd(v[g>>2]+2048|0,12);i=(i|0)<32767?i:32767;u[e>>1]=(i|0)>-32768?i:-32768;g=g+8|0;e=e+2|0;m=m-1|0;continue}break}hb=a+16|0;b=b+c|0;continue}}g=(p|0)!=0}else{k=w[g+3|0];j:{if(k>>>0>=i>>>0){break j}l=t[g+1|0];if((l|0)<0){break j}k=Fi(b,k+1|0);p=v[k>>2];q=ni(+(l-t[Bb(j,0)+1|0]|0)/-12);B=d,C=v[d>>2]+Oe(r*(q*+(p>>>0)*+y[k+24>>2]))|0,v[B>>2]=C}g=g+4|0;continue}break}}hb=f+4144|0;return g|0}a=P()|0;O()|0;bq(j);S(a|0);L()}function FW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-160|0;hb=d;xc(b);Ro(a);a:{if(!lv(b,d+120|0)){break a}if(!fD(d+120|0)){break a}j=v[b+8>>2];b:{if(!Zc(b,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){break b}while(1){c:{if((w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0>h>>>0){if(Ob(v[b>>2],v[b+8>>2],5)){break c}}f=i&1;break b}f=0;g=1;d:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((vi(b)|0)<=0){break d}}while(1){l=Je(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(Np(l<<24>>24)&255)==w[f+13133|0]}g=e;f=f+1|0;continue}break}Yb(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}Zc(b,j);if(!f){break a}if(!Ob(v[b>>2],v[b+8>>2],eD(d+120|0))){break a}if(!c){k=1;break a}g=hb-16|0;hb=g;e=d+120|0;Zc(b,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24));i=d+104|0;f=Lb(i);c=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);v[23516]=0;R(179,f|0,c|0);c=v[23516];v[23516]=0;e:{f:{g:{if((c|0)!=1){c=0;h:{i:{while(1){if((w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0<=c>>>0){break h}h=v[b+8>>2];j=v[b>>2];v[23516]=0;h=W(154,j|0,h|0,5)|0;j=v[23516];v[23516]=0;if((j|0)==1){break g}if(!h){break h}h=w[e+4|0]|w[e+5|0]<<8;v[23516]=0;U(180,g|0,b|0,h|0);h=v[23516];v[23516]=0;if((h|0)!=1){v[23516]=0;R(181,f|0,g|0);h=v[23516];v[23516]=0;if((h|0)==1){break i}c=c+1|0;wb(g);continue}break}c=P()|0;O()|0;break f}c=P()|0;O()|0;wb(g);break f}hb=g+16|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0}Me(f);S(c|0);L()}v[23516]=0;X(174,d+88|0,b|0,e|0,i|0);c=v[23516];v[23516]=0;j:{if((c|0)!=1){v[23516]=0;Q(153,b|0,v[d+144>>2])|0;c=v[23516];v[23516]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if(y[d+140>>2]>k>>>0){c=v[b+8>>2];e=v[b>>2];v[23516]=0;c=W(154,e|0,c|0,8)|0;e=v[23516];v[23516]=0;if((e|0)==1){break q}if(c){break p}}k=nc(v[a>>2],v[a+4>>2])^1;lc(d+88|0);Me(d+104|0);break a}b=P()|0;O()|0;break k}v[23516]=0;da(175,d- -64|0,b|0,d+120|0,d+88|0,d+104|0);c=v[23516];v[23516]=0;if((c|0)!=1){e=So(d- -64|0);v[23516]=0;c=T(176,v[d+64>>2])|0;f=v[23516];v[23516]=0;if((f|0)==1){break o}if(c){v[23516]=0;c=T(177,d+24|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break n}e=v[e>>2];r:{if((e|0)<0){break r}f=v[d+104>>2];if(ud(f,v[d+108>>2])>>>0<=e>>>0){break r}v[23516]=0;U(11,d+8|0,8,Jd(f,e)|0);e=v[23516];v[23516]=0;if((e|0)==1){break m}e=d+8|0;Gb(c,e);xb(e)}jv(g,d- -64|0);v[23516]=0;R(178,a|0,c|0);e=v[23516];v[23516]=0;if((e|0)==1){break m}_q(c)}k=k+1|0;yb(d- -64|0);continue}break}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;_q(c)}yb(d- -64|0);break k}b=P()|0;O()|0}lc(d+88|0);break j}b=P()|0;O()|0}Me(d+104|0);S(b|0);L()}hb=d+160|0;return k|0}function mK(a){var b=C(0),c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),r=C(0),s=0,t=C(0),u=0,w=C(0),x=C(0);d=a+4208|0;ON(Bb(d,0),z[a+4272>>2]);b=C(C(z[Bb(d,0)>>2]*C(15920))+C(80));t=qe(C(10),C(C(C(z[Bb(d,2)>>2]+C(-.5))*C(30))/C(40)));c=C(C(b/C(y[v[a+16>>2]+24620>>2]))*C(6.2831854820251465));b=EK(c);w=vp(c);x=b;f=C(C(c*C(C(C(z[Bb(d,1)>>2]*C(35))+C(1))*C(.02888113260269165)))/b);m=(l(2,(p(f),j(2))&-2147483648|1056964608),q());g=(p(f),j(2))&2147483647;c=(l(2,g),q());a:{if(g>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(p(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((h|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=C(b-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=C(c*C(.5));i=C(c*b);r=C(C(i*C(C(i*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));b=C(C(3)-C(r*b));r=C(i*C(C(r-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*r)-i));if(!d){break b}e=C(C(C(c*C(r-e))-e)-i);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}b=C(c-e);b=C(C(b+b)+C(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}i=(l(2,1065353216-h|0),q());c=C((d>>>0<=22?C(C(C(1)-i)+C(c-e)):C(C(c-C(e+i))+C(1)))*b)}b=c}if(g>>>0<=1065353215){if(g>>>0<964689920){break a}f=C(m*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}f=C(m*C(b+C(b/C(b+C(1)))));break a}m=C(C(m+m)*C(1.661534994731145e35));b=C(c+C(-162.88958740234375));d=Ww(b)&2047;j:{k:{if(Ww(C(88))>>>0>d>>>0){break k}c=C(0);if(((p(b),j(2))|0)==-8388608){break j}c=C(b+b);if(Ww(C(N))>>>0<=d>>>0){break j}if(b>C(88.72283172607422)){c=QD(0);break j}if(!(b<C(-103.97207641601562))){break k}c=vD(0);break j}k=A[165]*+b;s=A[164];u=k+s;k=k-(u-s);s=(A[166]*k+A[167])*(k*k)+(A[168]*k+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;g=v[d>>2];d=v[d+4>>2]+h|0;l(0,g|0);l(1,(g>>>0<g>>>0?d+1|0:d)|0);c=C(s*+n())}f=C(C(m*c)*C(1.661534994731145e35))}c=C(x*f);f=C(c/t);b=C(f+C(1));z[a+4236>>2]=C(C(1)-f)/b;f=C(C(w*C(-2))/b);z[a+4232>>2]=f;c=C(c*t);z[a+4228>>2]=C(C(1)-c)/b;z[a+4224>>2]=f;z[a+4220>>2]=C(c+C(1))/b}function jF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=hb-48|0;hb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6.077100506506192e-11;p=c-g;e=p<-.7853981633974483;if(D(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256}a=c-g;A[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6.077100506303966e-11;c=c-a;g=f*2.0222662487959506e-21-(g-c-a);a=c-g;A[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*2.0222662487111665e-21;c=c-a;g=f*8.4784276603689e-32-(g-c-a);a=c-g;A[b>>3]=a}A[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=h&1;h=0;if(m){continue}break}A[i+32>>3]=a;f:{if(a!=0){h=3;break f}d=2;while(1){h=d;d=d-1|0;if(A[(i+16|0)+(d<<3)>>3]==0){continue}break}}d=AH(i+16|0,i,(k>>>20|0)-1046|0,h,1);a=A[i>>3];if((e|0)<0){A[b>>3]=-a;A[b+8>>3]=-A[i+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[i+8>>3]}hb=i+48|0;return d}function RJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-128|0;hb=g;v[g+124>>2]=c;v[g+120>>2]=b;v[g+112>>2]=d;v[g+116>>2]=e;a:{if(!c){break a}h=w[Xk(b,c)|0];if((h|0)==33){f=1}else{if((h|0)!=63){break a}f=0}cl(g+88|0,b,c,c-1|0);b=v[g+92>>2];v[g+120>>2]=v[g+88>>2];v[g+124>>2]=b}b=g+88|0;Rd(b);c=v[g+88>>2];Rd(g+72|0);h=Wk(c,v[g+76>>2],g+120|0);Rd(b);b=v[g+124>>2];c=v[g+120>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[g+92>>2]){a=qc(g+104|0,21751);if(Mc(c,b,v[a>>2],v[a+4>>2])){b=ba(8)|0;v[23516]=0;R(976,g+72|0,g+112|0);a=v[23516];v[23516]=0;if((a|0)==1){break g}v[23516]=0;U(981,g+88|0,17730,g+72|0);a=v[23516];v[23516]=0;if((a|0)==1){break f}a=0;c=rc(b,g+88|0);v[23516]=0;U(117,c|0,62944,970);c=v[23516];v[23516]=0;if((c|0)!=1){break b}c=P()|0;O()|0;wb(g+88|0);break e}if(!f){break h}b=ba(8)|0;v[23516]=0;a=Lh(g+40|0,v[g+120>>2],v[g+124>>2]);c=v[23516];v[23516]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((c|0)!=1){v[23516]=0;U(981,g+56|0,17766,a|0);c=v[23516];v[23516]=0;if((c|0)==1){break p}v[23516]=0;R(983,g+72|0,g+56|0);c=v[23516];v[23516]=0;f=1;if((c|0)==1){break o}v[23516]=0;R(976,g+24|0,g+112|0);c=v[23516];v[23516]=0;if((c|0)==1){break n}v[23516]=0;U(985,g+88|0,g+72|0,g+24|0);c=v[23516];v[23516]=0;if((c|0)==1){break m}c=rc(b,g+88|0);v[23516]=0;U(117,c|0,62944,970);c=v[23516];v[23516]=0;if((c|0)!=1){break b}c=P()|0;O()|0;wb(g+88|0);f=0;break l}c=P()|0;O()|0;break d}c=P()|0;f=1;O()|0;break i}c=P()|0;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;O()|0}wb(g+24|0)}wb(g+72|0)}wb(g+56|0)}wb(a);if(f){break d}break c}f=qc(g+16|0,21751);if(Mc(c,b,v[f>>2],v[f+4>>2])){b=ba(8)|0;v[23516]=0;R(976,g+72|0,g+112|0);a=v[23516];v[23516]=0;q:{r:{if((a|0)!=1){v[23516]=0;U(981,g+88|0,17730,g+72|0);a=v[23516];v[23516]=0;if((a|0)==1){break r}a=0;c=rc(b,g+88|0);v[23516]=0;U(117,c|0,62944,970);c=v[23516];v[23516]=0;if((c|0)!=1){break b}c=P()|0;O()|0;wb(g+88|0);break q}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0}wb(g+72|0);if(a){break d}break c}f=qc(g+8|0,10943);if(Mc(c,b,v[f>>2],v[f+4>>2])){JJ(a,Dc(d,e));break h}f=b;b=qc(g,8656);if(!Mc(c,f,v[b>>2],v[b+4>>2])){break h}a=v[a+32>>2];b=Vy(d,e);b=b>>>0<4?b:1;c=hb-16|0;hb=c;s:{if((_j(w[a+140|0])|0)==(b|0)){d=a+120|0;ns(w[d+20|0]);b=hb-16|0;hb=b;v[b+8>>2]=c+8;a=hb-16|0;hb=a;e=v[15659];v[a+8>>2]=v[15658];v[a+12>>2]=e;e=v[15657];v[a>>2]=v[15656];v[a+4>>2]=e;lb[v[qp(a,_j(w[d+20|0]))>>2]](b+8|0,d);hb=a+16|0;hb=b+16|0;break s}nJ(a,b,oJ(a))}hb=c+16|0}hb=g+128|0;return}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0}wb(g+72|0);if(!a){break c}}ca(b|0)}S(c|0)}L()}function sm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-80|0;hb=e;h=Lb(a);v[23516]=0;a=T(282,b|0)|0;c=v[23516];v[23516]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=v[b+8>>2];d=v[b>>2];v[23516]=0;c=W(154,d|0,c|0,a|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}if(c){break d}v[23516]=0;a=T(200,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break e}v[23516]=0;Q(186,b|0,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;break a}v[23516]=0;U(188,e+32|0,b|0,a|0);b=v[23516];v[23516]=0;f:{g:{h:{if((b|0)!=1){b=e+32|0;c=hc(e+56|0,b);yb(b);if(a>>>0<10){break g}v[23516]=0;b=T(722,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}if(!b){break g}v[23516]=0;b=T(282,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}v[e+28>>2]=b;a=a-10|0;uc(e+28|0,a>>>0>25264513?-1:B(a,170));v[23516]=0;d=v[e+28>>2];R(288,h|0,d|0);a=v[23516];v[23516]=0;if((a|0)!=1){break h}break b}a=P()|0;O()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=v[c+8>>2];f=v[c>>2];v[23516]=0;a=Q(723,f|0,a|0)|0;f=v[23516];v[23516]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}v[23516]=0;a=T(528,c|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}v[23516]=0;a=T(204,c|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=v[c+8>>2];i=v[c>>2];v[23516]=0;g=W(154,i|0,g|0,a|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break b}if(!g){continue}oe(e+32|0,v[h>>2],v[h+4>>2]);uq(e+16|0,v[e+32>>2],v[e+36>>2],b,a);v[23516]=0;X(468,e+8|0,c|0,v[e+16>>2],v[e+20>>2]);f=v[23516];v[23516]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}v[23516]=0;a=T(204,c|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}v[23516]=0;i=Q(724,c|0,e+24|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+24|0;i=gc(f);lh(f,i,Pf(Cb(v[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}v[23516]=0;a=Q(724,c|0,e+24|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}if(!a){continue}a=e+24|0;f=gc(a);lh(a,f,Pf(Cb(v[h>>2]),b));lh(a,f,Pf(Pf(Cb(v[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}v[23516]=0;a=T(204,c|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}a=Lb(e+32|0);xt(a,h);dc(a);break f}v[23516]=0;U(332,c|0,h|0,a|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}}yb(c)}hb=e+80|0;return}a=P()|0;O()|0;yb(c)}dc(h);S(a|0);L()}function Faa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=43744;v[a+4>>2]=0;v[a>>2]=32352;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;Zp(a+24604|0);LM(a+24648|0,0);v[a+397448>>2]=0;v[a+397452>>2]=0;b=a+397456|0;v[b>>2]=8;v[b+4>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;t[b+12|0]=0;v[b+8>>2]=0;u[b+24>>1]=0;Rb(b+28|0,0,40);Rb(b+68|0,0,49824);Rb(b+49892|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;h=Lb(a+480248|0);v[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;BC(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Lb(c);v[f+12>>2]=a;v[23516]=0;i=Q(828,a+484360|0,a|0)|0;b=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+900380|0;b=a+484380|0;while(1){v[23516]=0;b=T(695,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break i}b=b+104|0;if((c|0)!=(b|0)){continue}break}v[23516]=0;T(829,a+901404|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break h}d=a+906300|0;b=0;while(1){GM(d+B(b,160)|0);b=b+1|0;if((b|0)!=250){continue}break}v[a+946300>>2]=0;e=a+1074304|0;g=a+946304|0;b=g;while(1){b=lt(b)+32|0;if((e|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;Zq(a+1074312|0);v[23516]=0;Z(830);b=v[23516];v[23516]=0;if((b|0)==1){break g}r=a,s=FM(),v[r+1074328>>2]=s;b=a+1074332|0;v[b+12>>2]=1065353216;tM(b,4);v[23516]=0;e=T(831,a+1074376|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break g}v[23516]=0;j=W(593,a+1298264|0,a|0,255)|0;b=v[23516];v[23516]=0;if((b|0)==1){break f}k=yf(a+1298300|0);l=yf(a+1298304|0);m=Kb(a+1298308|0);n=Kb(a+1298320|0);o=Kb(a+1298332|0);p=KM(a+1298344|0);q=Lb(a+1298408|0);t[a+1298420|0]=0;b=a+1298424|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298464>>2]=0;Jp(a+12|0);ry(a+8204|0);ry(a+12300|0);b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;Rb(c,0,1024);EM(g);v[23516]=0;b=T(832,12)|0;c=v[23516];v[23516]=0;if((c|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;r=a,s=Lb(b),v[r+4>>2]=s;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;DM(q);uy(p);wb(o);xb(n);wb(m);ty(l);sy(k);_s(j)}Fy(e)}JM(d)}SO(i)}AM(f);lc(h);S(b|0);L()}function dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=hb-560|0;hb=f;a:{if(!Zc(b,1464)){break a}if(!eo(b,f+556|0)){break a}zd(a,1);Mb(Mb(Lf(a+1074312|0,83),84,1),85,1);b:{if(le(f+556|0,27065)){d=f+32|0;e=vc(d,8459);Gb(a+1298344|0,e);xb(e);e=vc(d,14912);Gb(a+1298356|0,e);xb(e);d=vc(d,14984);Gb(a+1298368|0,d);break b}if(!le(f+556|0,15629)){break a}d=f+32|0;e=vc(d,8633);Gb(a+1298344|0,e);xb(e);e=vc(d,12308);Gb(a+1298356|0,e);xb(e);d=vc(d,15536);Gb(a+1298368|0,d)}xb(d);v[a+1298404>>2]=14;Zc(b,0);GA(b,a+1298308|0,20);u[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(g>>>0>40){break a}d=f+552|0;Tu(d,b);m=Kc(d);if(w[f+552|0]>128){break a}e=f+32|0;d=hb-16|0;hb=d;c:{if(!Ob(v[b>>2],v[b+8>>2],512)){ER(e);break c}yu(d+8|0,e);pd(d,b,v[d+8>>2],v[d+12>>2])}hb=d+16|0;d=0;e=w[m|0];while(1){n=(d|0)==512;if(!n){g=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=w[g|0]){continue}break a}break}if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;jh(a,0);o=a+484376|0;tg(Sb(v[a+484360>>2],w[o|0]),w[f+552|0]);l=a+484344|0;vg(l,w[f+552|0]);while(1){if(w[f+552|0]<=i>>>0){if(!(c&2)){break a}Zc(b,(w[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(B(d,104)+a|0)+484380|0;if(v[c>>2]){ug(Uc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}s=$b(v[Sb(v[a+484360>>2],w[o|0])>>2],i),x=i,u[s>>1]=x;d:{if(!kh(l,i&65535,64)){break d}r=i<<2;e=0;e:while(1){if((e|0)==4){s=f,x=Cb(v[Xb(v[l>>2],i)>>2]),v[s+24>>2]=x;e=0;while(1){if((e|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{t[f+31|0]=p;t[f+30|0]=q;d=h&255;if(d){break g}h=0;break f}}else{g=v[f+24>>2];h:{if((w[g+3|0]&254)!=16){break h}t[g+3|0]=16;h=0;k=w[g+5|0];if(k>>>0<16){break h}h=k>>>4|0;t[g+5|0]=h;j=h;h=k&15;g=(j|0)==(h|0)|!h;q=g?q:j;p=g?p:h;h=!g}d=d+1|0;Wz(f+24|0);continue}break}ve(Xb(v[l>>2],i),Se(Le(f+8|0,16,w[(d+f|0)+29|0]),e));h=h+1|0;h=(h&255)==3?1:h}e=e+1|0;continue}}Zc(b,(w[f+32+(e+r)|0]<<8)+1468|0);g=0;d=Xb(v[l>>2],i);d=ed(v[d>>2],v[v[d+48>>2]+12>>2],0,e&65535);while(1)if((g|0)==64){e=e+1|0;continue e}else{j=f+8|0;tu(j,b,d);k=w[f+8|0];j=w[Kc(j)|0];i:{if(!(!(k|j)|(k-5&255)>>>0<5|(k|0)==14&j>>>0>15)){Nf(d,k,j);break i}t[d+3|0]=0}d=d+24|0;g=g+1|0;continue}}}i=i+1|0;continue}}else{g=cA(b,f+32|0,(B(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}}hb=f+560|0;return n|0}function D2(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=hb-192|0;hb=d;v[d+184>>2]=c;a:{b:{c:{if(b>=.8){v[23516]=0;e=ha(1097)|0;f=v[23516];v[23516]=0;d:{e:{f:{if((f|0)!=1){v[d+80>>2]=e;v[23516]=0;c=T(1098,c|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break e}v[d+176>>2]=c;xn(e,c);a=he(d+152|0,a);v[23516]=0;f=v[a+12>>2];c=d- -64|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=f;v[d+72>>2]=v[a+16>>2];c=v[a+4>>2];v[d+56>>2]=v[a>>2];v[d+60>>2]=c;a=W(1090,e|0,d+56|0,15)|0;c=v[23516];v[23516]=0;if((c|0)==1){break f}if(a){v[23516]=0;Y(833,e|0);a=v[23516];v[23516]=0;g=1;if((a|0)==1){break f}}ej(d+176|0);fj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;ej(d+176|0);break d}c=V(0)|0;O()|0}fj(d+80|0);break c}if(b>=.6){v[23516]=0;e=ha(1097)|0;f=v[23516];v[23516]=0;g:{h:{i:{if((f|0)!=1){v[d+80>>2]=e;v[23516]=0;c=T(1098,c|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break h}v[d+176>>2]=c;xn(e,c);a=he(d+128|0,a);v[23516]=0;c=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=c;v[d+48>>2]=v[a+16>>2];c=v[a+4>>2];v[d+32>>2]=v[a>>2];v[d+36>>2]=c;a=W(1090,e|0,d+32|0,2)|0;c=v[23516];v[23516]=0;if((c|0)==1){break i}if(a){v[23516]=0;Y(833,e|0);a=v[23516];v[23516]=0;g=.8;if((a|0)==1){break i}}ej(d+176|0);fj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;ej(d+176|0);break g}c=V(0)|0;O()|0}fj(d+80|0);break c}g=.2;if(b>=.2){v[23516]=0;e=ha(1097)|0;f=v[23516];v[23516]=0;j:{k:{l:{if((f|0)!=1){v[d+80>>2]=e;v[23516]=0;c=T(1098,c|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break k}v[d+176>>2]=c;xn(e,c);a=he(d+104|0,a);v[23516]=0;c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;v[d+24>>2]=v[a+16>>2];c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;a=W(1090,e|0,d+8|0,0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break l}g=0;if(a){v[23516]=0;Y(833,e|0);a=v[23516];v[23516]=0;g=.6;if((a|0)==1){break l}}ej(d+176|0);fj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;ej(d+176|0);break j}c=V(0)|0;O()|0}fj(d+80|0);break c}if(!(b>=.1)){break b}v[23516]=0;U(201,d+80|0,a|0,2048);c=v[23516];v[23516]=0;if((c|0)!=1){c=Ee(d+80|0);a=v[a>>2];v[23516]=0;e=v[d+80>>2];a=T(158,a|0)|0;f=v[23516];v[23516]=0;m:{if((f|0)==1){break m}v[23516]=0;a=fF(1099,c,e,a,0);c=v[23516];v[23516]=0;if((c|0)==1){break m}g=A[(a<<3)+62648>>3];Qc(d+80|0);break b}c=V(0)|0;O()|0;Qc(d+80|0);break c}c=V(0)|0;O()|0}_(c|0)|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;g=0;if((a|0)==1){break a}}ze(d+184|0);hb=d+192|0;return+g}a=P()|0;O()|0;ze(d+184|0);S(a|0);L()}function I9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-48|0;hb=c;a:{b:{if(!Nb(v[b>>2],v[b+4>>2])){break b}l=v[b+12>>2];k=Lg(v[v[b+48>>2]+12>>2]);d=k;g=Lb(c+32|0);c:{if(d){v[23516]=0;R(457,g|0,d|0);e=v[23516];v[23516]=0;if((e|0)==1){break a}f=hb-16|0;hb=f;e=yq(f,g,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){ic(e);hb=f+16|0}else{t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;sg(d);d=d+6|0;v[e+4>>2]=d;continue}break}}break c}while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(j>>>0>=l>>>0){break s}if(!Mh(v[v[a>>2]-12>>2]+a|0)){break s}v[23516]=0;t[c+31|0]=0;Q(895,a|0,c+31|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}d=t[c+31|0];if(!d){j=j+1|0;continue}t[c+30|0]=0;t:{if((d|0)>=0){break t}v[23516]=0;Q(895,a|0,c+30|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break t}break a}t[c+29|0]=0;Cj(c+16|0);u:{d=d&127;f=(d?d-1|0:0)&65535;i=f>>>0>=k>>>0;v:{w:{if(!i){h=ed(v[b>>2],v[v[b+48>>2]+12>>2],j,f);e=w[c+30|0];if(e&1){break w}d=Ed(v[g>>2],f);break v}h=c+16|0;e=w[c+30|0];if(!(e&1)){break u}}v[23516]=0;Q(895,a|0,c+29|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}if(i){break u}d=Ed(v[g>>2],f);t[d|0]=w[c+29|0]}t[h|0]=w[d|0];e=w[c+30|0];if(!(e&2)){break q}break r}if(e&2){break r}break p}Ah(g);break b}v[23516]=0;Q(895,a|0,c+29|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}if(i){break p}d=Ed(v[g>>2],f);t[d+1|0]=w[c+29|0]}t[h+1|0]=w[d+1|0];if(e&4){break o}break n}if(!(e&4)){break m}}v[23516]=0;Q(895,a|0,c+29|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}if(i){break m}d=Ed(v[g>>2],f);t[d+2|0]=w[c+29|0]}t[h+2|0]=w[d+2|0];if(!(e&8)){break k}break l}if(!(e&8)){break j}}v[23516]=0;Q(895,a|0,c+29|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}if(i){break j}d=Ed(v[g>>2],f);t[d+4|0]=w[c+29|0]}t[h+4|0]=w[d+4|0];if(e&16){break i}break h}if(!(e&16)){break g}}v[23516]=0;Q(895,a|0,c+29|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}if(i){break g}d=Ed(v[g>>2],f);t[d+3|0]=w[c+29|0]}t[h+3|0]=w[d+3|0];if(!(e&32)){break e}break f}if(!(e&32)){break d}}v[23516]=0;Q(895,a|0,c+29|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}if(i){break d}d=Ed(v[g>>2],f);t[d+5|0]=w[c+29|0]}t[h+5|0]=w[d+5|0]}if(!(e&64)){continue}v[23516]=0;Q(895,a|0,c+15|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;Q(896,a|0,w[c+15|0])|0;d=v[23516];v[23516]=0;if((d|0)!=1){continue}}break}break a}hb=c+48|0;return}a=P()|0;O()|0;Ah(g);S(a|0);L()}function zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;g=hb-32|0;hb=g;a:{if(!Ob(v[a>>2],v[a+8>>2],2)){kh(c+484344|0,b,64);break a}l=c+484344|0;m=Bd(Ej(a),1,1024);if(!kh(l,b,m)){break a}p=x[c+480188>>1];q=c+480190|0;b:while(1){if((k|0)==(m|0)){break a}i=0;e=Xb(v[l>>2],b);n=xf(v[e>>2],v[v[e+48>>2]+12>>2],k);while(1)if((i|0)==(p|0)){k=k+1|0;continue b}else{f=g+24|0;Km(f,a);e=B(i,6)+n|0;r=Re(f);f=Ji(f);h=w[g+24|0];c:{if((h-1&255)>>>0>35){break c}t[e|0]=h+48;o=w[Kc(g+24|0)|0];h=o+1|0;t[e+1|0]=h;j=h;h=h&255;if((j|0)!=(h|0)|h>>>0>x[q>>1]){break c}h=Fi(c,h);j=Ib(d,i);if(!(!w[j|0]|x[h+30>>1]>255)){t[e+4|0]=64;t[e+2|0]=1}h=v[Bb(h+68|0,0)>>2];if(!(w[j|0]|h?w[j|0]?(h|0)==1:0:1)){break c}t[e+1|0]=o+101}d:{e:{switch(w[r|0]){case 1:if(!w[f|0]){break d}t[e+3|0]=2;t[e+5|0]=w[f|0];break d;case 2:if(!w[f|0]){break d}t[e+3|0]=3;t[e+5|0]=w[f|0];break d;case 12:if(!w[f|0]){break d}t[e+3|0]=1;t[e+5|0]=w[f|0];break d;case 13:if(!w[f|0]){break d}t[e+3|0]=39;t[g+23|0]=15;s=e,u=w[Vb(g+23|0,f)|0]|16,t[s+5|0]=u;break d;case 30:if(!w[f|0]){break d}t[e+3|0]=38;t[g+22|0]=15;s=e,u=w[Vb(g+22|0,f)|0]|16,t[s+5|0]=u;break d;case 21:if(!w[f|0]){break d}t[e+3|0]=39;t[g+21|0]=15;s=e,u=w[Vb(g+21|0,f)|0]|80,t[s+5|0]=u;break d;case 17:if(!w[f|0]){break d}t[e+3|0]=38;t[g+20|0]=15;s=e,u=w[Vb(g+20|0,f)|0]|80,t[s+5|0]=u;break d;case 15:t[e+3|0]=19;t[e+5|0]=w[f|0]!=0;break d;case 25:t[e+3|0]=12;t[e+5|0]=w[f|0];break d;case 27:Zn(e);t[e|0]=255;break d;case 28:if(w[f|0]>31){break d}t[e+3|0]=16;t[e+5|0]=w[f|0];break d;case 31:h=w[f|0];if(h&15){s=e,u=w[Ib(d,i)|0]?22:11,t[s+3|0]=u;t[e+5|0]=w[f|0]&15;h=w[f|0]}f:{g:{switch(h>>>4|0){case 4:if((h|0)!=64){break f}case 0:case 1:case 2:case 3:if(w[Ib(d,i)|0]){t[e+3|0]=21;t[e+5|0]=w[f|0];break f}t[e+2|0]=1;f=w[f|0];t[e+3|0]=0;t[e+4|0]=f;break f;case 5:t[e+5|0]=w[e+5|0]<<4;break f;case 6:t[g+19|0]=w[e+5|0];t[g+18|0]=14;s=e,u=w[Vb(g+19|0,g+18|0)|0]|240,t[s+5|0]=u;break f;case 7:t[g+17|0]=w[e+5|0];t[g+16|0]=14;s=e,u=w[Vb(g+17|0,g+16|0)|0]<<4|15,t[s+5|0]=u;break f;default:break g}}t[e+3|0]=0}if((w[e+3|0]-21&255)>>>0>1){break d}f=B(t[Ib(d,i)|0]+i|0,6)+n|0;Gq(g+8|0,w[f+3|0],w[f+5|0],1);if(w[g+8|0]){h=x[g+8>>1];t[f+4|0]=h>>>8;t[f+2|0]=h}t[f+3|0]=w[e+3|0];t[f+5|0]=w[e+5|0];break d;case 0:break d;default:break e}}t[e+3|0]=0}i=i+1|0;continue}}}hb=g+32|0}function Rda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=hb+-64|0;hb=d;u[d+62>>1]=c;Bf(d+62|0,32);j=Lb(a);v[23516]=0;o=x[d+62>>1];R(532,j|0,o|0);a=v[23516];v[23516]=0;a:{b:{if((a|0)!=1){k=b+480190|0;p=b+480192|0;c:{d:{while(1){if((q&65535)>>>0>=o>>>0){break d}e=1;a=x[k>>1];c=a+1|0;u[d+60>>1]=c;e:{f:{g:{if((c&65535)>>>0<4e3){break g}h:{while(1){f=e&65535;if(f>>>0>a>>>0){break h}i:{g=Fi(b,f);if(!Vd(v[g>>2],v[g+20>>2])){if(!Nb(Xz(Cb(v[j>>2]),Cb(v[j+4>>2]),e),Cb(v[j+4>>2]))){break i}a=x[k>>1]}e=e+1|0;continue}break}u[d+60>>1]=e;c=1;while(1){if(x[p>>1]<c>>>0){c=e;break h}j:{a=v[((c<<2)+b|0)+900380>>2];if(!a){break j}a=a+236|0;g=rq(a);while(1){if((a|0)==(g|0)){break j}if((f|0)==x[a>>1]){u[a>>1]=0}a=a+2|0;continue}}c=c+1|0;continue}}if((c&65535)>>>0<4e3){break g}e=Xn(d+48|0);v[23516]=0;a=Q(764,b|0,e|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break b}if(!a){break e}v[23516]=0;R(765,b|0,e|0);a=v[23516];v[23516]=0;c=1;if((a|0)==1){break b}while(1){a=c&65535;if(a>>>0<=x[p>>1]){k:{a=v[((a<<2)+b|0)+900380>>2];if(!a){break k}a=a+236|0;f=rq(a);while(1){if((a|0)==(f|0)){break k}g=x[a>>1];l:{if(g>>>0>=y[d+52>>2]){break l}Ab(d+40|0,v[e>>2],g);if(zb(v[v[d+40>>2]>>2],v[d+44>>2])){break l}u[a>>1]=0}a=a+2|0;continue}}c=c+1|0;continue}break}ml(d+24|0,v[e>>2]);yP(d+32|0,v[d+24>>2],v[d+28>>2],1);tm(d+16|0,v[e>>2],v[d+52>>2]);m=hb-16|0;hb=m;g=d+40|0;c=fc(m,v[d+32>>2],v[d+36>>2]);a=ll(v[d+16>>2],v[d+20>>2],v[d+32>>2],v[d+36>>2]);f=hb-16|0;hb=f;v[f+12>>2]=a;h=v[c+4>>2];m:{if(h){i=32-h|0;v[f+8>>2]=i;n=v[Hb(f+8|0,f+12|0)>>2];l=-1<<h&-1>>>i-n;i=v[c>>2];l=l&(v[i>>2]^-1);if(l){fc(g,i,qka(l));break m}if((a|0)==(n|0)){yP(g,i,h,a);break m}a=a-n|0;v[f+12>>2]=a;v[c>>2]=i+4}while(1){if(a>>>0>=32){h=v[c>>2];i=v[h>>2];if((i|0)!=-1){fc(g,h,qka(i^-1));break m}else{v[c>>2]=h+4;a=a-32|0;v[f+12>>2]=a;continue}}break}if(!a){fc(g,v[c>>2],0);break m}c=v[c>>2];h=(v[c>>2]^-1)&-1>>>32-a;if(!h){fc(g,c,a);break m}fc(g,c,qka(h))}hb=f+16|0;hb=m+16|0;ml(d+8|0,v[e>>2]);c=ll(v[d+40>>2],v[d+44>>2],v[d+8>>2],v[d+12>>2]);u[d+60>>1]=c;Ue(e);if((c&65535)>>>0>3999){break f}}v[23516]=0;R(259,j|0,d+60|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}if(x[k>>1]>=(c&65535)>>>0){break f}u[k>>1]=c}q=q+1|0;continue}break}Ue(e)}hb=d- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ue(e)}gd(j);S(a|0);L()}function c3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-192|0;hb=d;h=fJ(d+176|0);v[h>>2]=49508;Lb(h+4|0);xn(v[a+24>>2],h);e=v[a+24>>2];i=w[a+62|0];f=w[a+61|0];g=w[a+60|0];b=he(d+152|0,b);v[23516]=0;j=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=j;v[d+24>>2]=v[b+16>>2];j=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=j;b=g?13:15;b=f?b&14:b;b=W(1090,e|0,d+8|0,(i?b&3:b)|0)|0;e=v[23516];v[23516]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ba(8)|0;v[23516]=0;c=Q(53,d+136|0,12046)|0;a=v[23516];v[23516]=0;if((a|0)!=1){a=rc(b,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(c);break b}a=P()|0;O()|0;ca(b|0);break b}if(!w[a+63|0]){v[23516]=0;R(1091,a|0,a+36|0);b=v[23516];v[23516]=0;if((b|0)==1){break e}}t[a+28|0]=1;xn(v[a+24>>2],v[a+4>>2]);v[23516]=0;R(1092,d+136|0,h|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}k=d,l=Cb(v[d+136>>2]),v[k+128>>2]=l;e=a+68|0;i=Cb(v[d+140>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=v[d+128>>2];if(!Nb(b,i)){k=d,l=Ei(v[c>>2]),v[k+112>>2]=l;c=tf(c);while(1){b=v[d+112>>2];if(!Fg(b,c)){break d}v[23516]=0;e=sd(b);b=Q(52,d+32|0,e|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break h}v[23516]=0;X(982,a|0,b|0,e+12|0,0);e=v[23516];v[23516]=0;if((e|0)==1){break g}wb(b);Ig(d+112|0);continue}}f=v[a+24>>2];g=v[b>>2];v[23516]=0;j=f;f=b+4|0;U(1093,j|0,g|0,f|0);g=v[23516];v[23516]=0;if((g|0)!=1){b=v[b>>2];v[23516]=0;R(1094,d- -64|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break r}v[23516]=0;R(1029,d+80|0,d- -64|0);b=v[23516];v[23516]=0;if((b|0)==1){break q}v[23516]=0;b=Q(53,d+48|0,17866)|0;g=v[23516];v[23516]=0;if((g|0)==1){break p}v[23516]=0;U(985,d+96|0,d+80|0,b|0);g=v[23516];v[23516]=0;if((g|0)==1){break o}v[23516]=0;U(538,d+112|0,d+96|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break n}v[23516]=0;R(181,e|0,d+112|0);f=v[23516];v[23516]=0;if((f|0)==1){break m}wb(d+112|0);wb(d+96|0);wb(b);wb(d+80|0);xb(d- -64|0);$p(d+128|0);continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;break l}a=P()|0;O()|0;wb(d+112|0)}wb(d+96|0)}wb(b)}wb(d+80|0)}xb(d- -64|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;wb(b)}rs(d+136|0);break b}a=P()|0;O()|0;break b}rs(d+136|0);ls(h);hb=d+192|0;return}a=P()|0;O()|0}ls(h);S(a|0)}L()}function Nga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=hb-32|0;hb=e;a:{b:{if(!c){break b}s=e,u=Je(a),t[s+16|0]=u;fn(b,e+16|0);k=c-1|0;c=0;while(1){g=1;if(!k){break a}c:{d:{d=c<<1;c=d&254;if(!c){if(!hf(a,e+16|0)){break b}i=1;d=w[e+16|0]<<1|1;c=d&255;if(d>>>0<=255){break d}break c}if((d&65535)>>>0<=255){break d}i=1;break c}if(!hf(a,e+16|0)){break b}oU(b,e+16|0);k=k-1|0;continue}while(1){e:{f:{g:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!hf(a,e+16|0)){break g}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}i=fq(i,1)+c|0;c=d<<1&254;if(c){break f}if(!hf(a,e+16|0)){break g}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(d>>>0>127){continue}}break}h:{if((i|0)<=2){j=0;h=i-2|0;break h}if(!hf(a,e+16|0)){break b}d=fq(i-3|0,8)|w[e+16|0];j=((d|0)>1279?2:1)+((d|0)>31999)|0;n=d^-1;h=0}d=c<<1&254;if(d){f=c>>>0>127}else{if(!hf(a,e+16|0)){break b}c=w[e+16|0]<<1|1;d=c&255;f=c>>>0>255}g=fq(h,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!hf(a,e+16|0)){break b}d=w[e+16|0]<<1|1;c=d&255;d=d>>>0>255}i=1;h=k;d=fq(f+g|0,1)+d|0;if(!d){while(1){i:{j:{k:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!hf(a,e+16|0)){break k}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}i=fq(i,1)+c|0;c=d<<1&254;if(c){break j}if(!hf(a,e+16|0)){break k}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break i}c=0;break i}if(d>>>0>127){continue}}break}d=i+2|0}f=h;h=d+j|0;g=0;if(f>>>0<h>>>0|(h|0)<=0|(n|0)>=0){break a}d=v[b+4>>2];g=0;if((0-ad(v[b>>2],d)|0)>(n|0)){break a}d=cc(e+24|0,Cb(d));t[e+16|0]=0;l=e+16|0;o=hb-32|0;hb=o;f=v[d>>2];d=v[b>>2];j=jo(f,Cb(d))+d|0;f=v[Db(b)>>2];g=v[b+4>>2];l:{if(h>>>0<=f-g>>>0){d=h;f=g-j|0;if(d>>>0>f>>>0){Ho(b,h-f|0,l);d=f;if(!d){break l}}p=hb-16|0;hb=p;f=g;r=v[b+4>>2];g=(r-(h+j|0)|0)+j|0;q=Gk(p,b,f-g|0);m=v[q+4>>2];i=g;while(1){if(i>>>0>=f>>>0){ic(q);tq(j,g,r);hb=p+16|0}else{nd(m,w[i|0]);m=m+1|0;v[q+4>>2]=m;i=i+1|0;continue}break}ci(j,d,(j>>>0<=l>>>0?y[b+4>>2]>l>>>0?h:0:0)+l|0);break l}d=Db(b);d=Ql(o+8|0,Ol(b,ad(v[b>>2],g)+h|0),j-v[b>>2]|0,d);PS(d,h,l);j=pU(b,d,j);Pl(d)}Cb(j);hb=o+32|0;s=e,u=Pf(bS(Cb(v[b+4>>2]),h),n),v[s+16>>2]=u;s=e,u=bS(Cb(v[b+4>>2]),h),v[s+8>>2]=u;d=h;while(1){f=w[aS(e+16|0)|0];s=aS(e+8|0),u=f,t[s|0]=u;f=d>>>0>1;d=d-1|0;if(f){continue}break}k=k-h|0;continue}}g=0}f=g;hb=e+32|0;return f|0}function h6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-128|0;hb=e;v[e+124>>2]=c;v[e+120>>2]=b;a:{if(!c){break a}f=w[Xk(b,c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}cl(e+96|0,b,c,c-1|0);b=v[e+100>>2];v[e+120>>2]=v[e+96>>2];v[e+124>>2]=b}c=e+96|0;Rd(c);b=v[e+96>>2];Rd(e+80|0);b=Wk(b,v[e+84>>2],e+120|0);Rd(c);b:{c:{d:{e:{if((b|0)==v[e+100>>2]){b=v[e+120>>2];c=v[e+124>>2];a=qc(e+112|0,21751);if(Mc(b,c,v[a>>2],v[a+4>>2])){a=ba(8)|0;v[23516]=0;b=Q(53,e+96|0,10501)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}b=0;if(!d){break e}b=ba(8)|0;v[23516]=0;d=Lh(e+80|0,v[e+120>>2],v[e+124>>2]);a=v[23516];v[23516]=0;f:{g:{h:{if((a|0)!=1){v[23516]=0;U(981,e+96|0,17766,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}a=0;c=rc(b,e+96|0);v[23516]=0;U(117,c|0,62944,970);c=v[23516];v[23516]=0;if((c|0)!=1){break b}c=P()|0;O()|0;wb(e+96|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}wb(d);if(!a){break c}}ca(b|0);break c}if(v[b+4>>2]){a=ba(8)|0;v[23516]=0;b=Q(53,e+96|0,11620)|0;c=v[23516];v[23516]=0;if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}c=P()|0;O()|0;ca(a|0);break c}c=v[e+120>>2];d=v[e+124>>2];b=qc(e+72|0,21751);if(Mc(c,d,v[b>>2],v[b+4>>2])){a=ba(8)|0;v[23516]=0;b=Q(53,e+96|0,10501)|0;c=v[23516];v[23516]=0;if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}c=P()|0;O()|0;ca(a|0);break c}i:{b=qc(e- -64|0,7422);if(!Mc(c,d,v[b>>2],v[b+4>>2])){b=qc(e+56|0,7404);if(!Mc(c,d,v[b>>2],v[b+4>>2])){break i}}b=w[a+60|0]!=0;break e}j:{b=qc(e+48|0,6937);if(!Mc(c,d,v[b>>2],v[b+4>>2])){b=qc(e+40|0,6918);if(!Mc(c,d,v[b>>2],v[b+4>>2])){break j}}b=w[a+61|0]!=0;break e}b=qc(e+32|0,7021);if(Mc(c,d,v[b>>2],v[b+4>>2])){b=w[a+62|0]!=0;break e}b=qc(e+24|0,6067);if(Mc(c,d,v[b>>2],v[b+4>>2])){b=w[a+63|0]!=0;break e}b=qc(e+16|0,7471);if(Mc(c,d,v[b>>2],v[b+4>>2])){b=w[a+64|0]!=0;break e}f=c;c=qc(e+8|0,13421);b=0;if(!Mc(f,d,v[c>>2],v[c+4>>2])){break e}b=v[v[a+24>>2]+24668>>2]!=0}hb=e+128|0;return b|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function D3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Kb(a);v[23516]=0;Z(103);c=v[23516];v[23516]=0;a:{b:{if((c|0)==1){c=Ua(62944,92664,93236,0)|0;d=O()|0;c:{d:{e:{if((ea(62944)|0)==(d|0)){c=_(c|0)|0;v[23516]=0;b=Q(955,a|0,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}v[23516]=0;b=Q(955,b|0,17866)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}v[23516]=0;d=Q(955,b|0,17842)|0;b=v[23516];v[23516]=0;if((b|0)==1){break e}b=lb[v[v[c>>2]+8>>2]](c)|0;v[23516]=0;Q(955,d|0,(b?b:21751)|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break e}v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ea(92664)|0)==(d|0)){c=_(c|0)|0;v[23516]=0;b=Q(955,a|0,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break f}v[23516]=0;b=Q(955,b|0,17866)|0;d=v[23516];v[23516]=0;if((d|0)==1){break f}v[23516]=0;d=Q(955,b|0,17817)|0;b=v[23516];v[23516]=0;if((b|0)==1){break f}b=lb[v[v[c>>2]+8>>2]](c)|0;v[23516]=0;Q(955,d|0,(b?b:21751)|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break f}v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ea(93236)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){v[23516]=0;b=Q(955,a|0,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break g}v[23516]=0;b=Q(955,b|0,17866)|0;d=v[23516];v[23516]=0;if((d|0)==1){break g}v[23516]=0;d=Q(955,b|0,17833)|0;b=v[23516];v[23516]=0;if((b|0)==1){break g}b=lb[v[v[c>>2]+8>>2]](c)|0;v[23516]=0;Q(955,d|0,(b?b:21751)|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break g}v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[23516]=0;b=Q(955,a|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}v[23516]=0;b=Q(955,b|0,17866)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}v[23516]=0;Q(955,b|0,13796)|0;b=v[23516];v[23516]=0;if((b|0)==1){break d}v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[23516]=0;Z(18);c=v[23516];v[23516]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23516]=0;Z(18);c=v[23516];v[23516]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23516]=0;Z(18);c=v[23516];v[23516]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[23516]=0;Z(18);c=v[23516];v[23516]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Tb()}L()}return}wb(a);S(b|0);L()}function X9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=hb-16|0;hb=h;f=v[a+8>>2];e=v[a>>2];v[23516]=0;f=Q(612,e|0,f|0)|0;e=v[23516];v[23516]=0;a:{b:{if((e|0)!=1){if(f){break b}v[23516]=0;f=T(204,a|0)|0;e=v[23516];v[23516]=0;c:{if((e|0)==1){break c}v[23516]=0;j=d+484344|0;k=Bd(f+1|0,1,1024);f=W(225,j|0,b|0,k|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}if(!f){break b}d=x[d+480188>>1];if(!d){break b}l=d-1|0;d=0;d:while(1){if(d>>>0>=k>>>0){break b}while(1){f=v[a+8>>2];e=v[a>>2];v[23516]=0;f=W(154,e|0,f|0,1)|0;e=v[23516];v[23516]=0;e:{if((e|0)!=1){if(!f){break b}v[23516]=0;i=T(204,a|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break a}if(i){break e}d=d+1|0;continue d}break a}e=v[j>>2];u[h+14>>1]=i&31;u[h+12>>1]=l;e=Xb(e,b);e=ed(v[e>>2],v[v[e+48>>2]+12>>2],d,x[Rc(h+14|0,h+12|0)>>1]);if(!(i&224)){continue}break}f:{if(!(i&128)){break f}v[23516]=0;g=T(204,a|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break a}t[e+5|0]=g;v[23516]=0;g=T(204,a|0)|0;f=v[23516];v[23516]=0;g:{h:{if((f|0)!=1){if(g>>>0<26){break h}break g}break a}f=w[g+42864|0];t[e+3|0]=f;i:{switch(f-1|0){case 0:if(!w[e+5|0]){break g}break f;case 12:if(w[e+2|0]){break f}t[e+2|0]=1;f=w[e+5|0];t[e+5|0]=0;t[e+3|0]=0;m=e,n=Bd(f,0,64),t[m+4|0]=n;break f;case 5:case 6:case 10:case 23:case 28:f=w[e+5|0]&240;if(!f){break f}t[e+5|0]=f;break f;case 8:f=w[e+5|0];if(f>>>0<=128){m=e,n=rg(f<<1),t[m+5|0]=n;break f}if((f|0)!=164){break f}t[e+5|0]=145;t[e+3|0]=20;break f;case 13:f=w[e+5|0];t[e+5|0]=B(f>>>4|0,10)+(f&15);break f;case 18:Iu(e);break f;case 16:if(w[e+5|0]>31){break f}t[e+3|0]=16;break f;case 27:break i;default:break f}}g=w[e+5|0];f=g&240;j:{if((f|0)==16){f=2}else{if((f|0)!=32){break j}f=3}t[e+3|0]=f}t[e+5|0]=g&15|224;break f}t[e+3|0]=0}k:{l:{if(!(i&64)){break l}v[23516]=0;R(263,h+8|0,a|0);f=v[23516];v[23516]=0;if((f|0)==1){break k}t[e+1|0]=w[h+8|0];g=w[Kc(h+8|0)|0];t[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break l}}t[e|0]=f}if(!(i&32)){continue}t[e+2|0]=1;v[23516]=0;g=T(204,a|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break a}t[e+4|0]=g;if(!c){continue}t[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}yb(a);hb=h+16|0;return}b=P()|0;O()|0;yb(a);S(b|0);L()}function jW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=hb-384|0;hb=f;xc(b);d=hb-16|0;hb=d;h=f+344|0;xC(d+8|0,h);e=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],e);i=v[d+4>>2];if((i|0)==(e|0)){Yb(b,v[d+12>>2])}hb=d+16|0;d=(e|0)==(i|0);if(!d){wC(h)}a:{if(!d){break a}if(!zC(f+344|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Bc(yC(w[f+379|0]),kb))){break a}b:{if(!c){break b}zd(a,2097152);$f(a);jh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);j=a+480190|0;u[j>>1]=w[f+378|0];d=w[f+381|0];if(d>>>0<w[f+380|0]){Te(Sb(v[a+484360>>2],w[a+484376|0]),d)}d=f+80|0;g=vc(d,6522);Gb(a+1298344|0,g);xb(g);g=vc(d,11118);Gb(a+1298356|0,g);xb(g);v[a+1298404>>2]=5;Uu(b,d);Mq(Sb(v[a+484360>>2],w[a+484376|0]),d,w[f+380|0],65535,65535);g=1;while(1){i=g&65535;if(i>>>0>x[j>>1]){Yb(b,B(64-w[f+378|0]|0,37));h=a+484344|0;vg(h,w[f+379|0]);i=c&1;g=0;while(1){if(w[f+379|0]<=g>>>0){if(!(c&2)){break b}c=Uc(f+40|0,8,1,0,0);d=a+480190|0;g=1;while(1){e=g&65535;if(e>>>0>x[d>>1]){break b}ug(c,(B(e,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(i){if(kh(h,g&65535,64)){break d}}Yb(b,2048);break c}d=Xb(v[h>>2],g);n=f,o=Cb(v[d>>2]),v[n+40>>2]=o;j=Cb(v[d+4>>2]);while(1){d=v[f+40>>2];if(!Nb(d,j)){break c}e=f+24|0;Km(e,b);k=Kc(e);m=Re(e);e=Ji(e);l=w[f+24|0];if((l-1&255)>>>0<=106){t[d|0]=l+13}t[d+1|0]=w[k|0];Nf(d,w[m|0],w[e|0]);vk(f+40|0);continue}}g=g+1|0;continue}}else{d=f+40|0;vC(b,d);h=hb-16|0;hb=h;e=(B(i,104)+a|0)+484380|0;jd(e,0);t[e+37|0]=w[d+22|0]<<4;t[h+15|0]=w[d+23|0];t[h+14|0]=64;n=e,o=w[Vb(h+15|0,h+14|0)|0]<<2,u[n+30>>1]=o;t[e+36|0]=w[d+24|0];v[e>>2]=w[d+25|0]|w[d+26|0]<<8|(w[d+27|0]<<16|w[d+28|0]<<24);k=w[d+33|0]|w[d+34|0]<<8|(w[d+35|0]<<16|w[d+36|0]<<24);if(!(k>>>0<3|k+(w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24))>>>0>(w[d+25|0]|w[d+26|0]<<8|(w[d+27|0]<<16|w[d+28|0]<<24))>>>0)){u[e+34>>1]=x[e+34>>1]|2;v[e+4>>2]=w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24);v[e+8>>2]=(w[d+33|0]|w[d+34|0]<<8|(w[d+35|0]<<16|w[d+36|0]<<24))+(w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24))}hb=h+16|0;e=f+8|0;xl(e,2,d);d=f+24|0;Cc(d,e);Ac(((i<<5)+a|0)+946304|0,d);g=g+1|0;wb(d);continue}}}g=1}hb=f+384|0;return g|0}function Rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;s=v[a+16>>2];u=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;o=v[a+128>>2];if(o){e=v[a+8>>2];k=v[a+12>>2];p=kg(e,k,o);q=kb;i=v[a+76>>2];Of(v[a>>2],v[a+4>>2],mf(e,k,d),kb);k=i>>>0<kb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}l=v[a+40>>2];m=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;k=k-1|0;p=k?p:0;q=k?q:0;n=(((b&2147483647)<<1|e>>>31)&-2)+s|0;e=o;a:{b:while(1){c:{if((e|0)<=0){Pb(j,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(!h){break a}e=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Od(j,(g|0)/8<<16>>16);Nd(j,4);Pb(f+40|0,p,q);e=e-1|0;continue b}else{g=(t[n+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[n+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Od(j,(g|0)/8<<16>>16);Nd(j,h);v[j>>2]=v[j>>2];v[j+4>>2]=0}b=ig(j,u);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=v[r>>2];i=(f+16|0)+(b<<3)|0;G=v[i+8>>2];g=v[i+4>>2];v[i+8>>2]=g;n=e<<8;e=n;e=rka(E,F,e,e>>31);h=kb;H=i;i=e;e=Wb(g,-16777216,16776704);e=rka(C,D,e,e>>31);g=i+e|0;i=kb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Wb(G,-16777216,16776704);h=rka(z,A,e,e>>31);g=h+g|0;e=kb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Tc(h,e,24);v[H+4>>2]=e-(n&y);v[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];m=v[a+28>>2]+m|0;v[c>>2]=v[c>>2]+B(v[f>>2],m>>12);l=b+l|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],l>>12);Pb(f+8|0,w,x);c=c+8|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function PV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0;f=hb-32|0;hb=f;k=sg(f+24|0);p=k+3|0;q=k+5|0;r=k+4|0;s=k+2|0;x=k+1|0;d=f+16|0;z=d|5;A=d|3;while(1){a:{if(y[a+12>>2]>m>>>0){C=xf(v[a>>2],v[v[a+48>>2]+12>>2],m);b:while(1){if(!Ob(v[c>>2],v[c+8>>2],1)){break a}l=Je(c);if((l|0)==255){break a}d=l&31;g=B(d,6)+C|0;i=Lg(v[v[a+48>>2]+12>>2])>>>0>d>>>0;j=i?g:k;e=1;if(!(l&64)){d=Je(c);h=d<<24>>24;e=255;d=d&127;c:{d:{if((d|0)==1){break d}e=d-1|0;if(b?e>>>0<=120:0){break d}if((d-109&255)>>>0<159|b){break c}e=d+13|0}t[j|0]=e}E=i?g+1|0:x,F=Je(c),t[E|0]=F;e=(h|0)<0}h=i?g+3|0:p;d=i?g+5|0:q;n=i?g+4|0:r;i=i?g+2|0:s;while(1){e:{f:{g:{if(e&1){v[f+16>>2]=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);u[f+20>>1]=w[j+4|0]|w[j+5|0]<<8;o=Je(c);g=o&63;if(o&64){t[i|0]=1;t[n|0]=g;break e}e=Je(c);t[d|0]=e;if(g>>>0<=15){Nf(j,g,e);h:{i:{j:{e=w[h|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[h|0]=9;t[d|0]=B(w[d|0]&15,17);break f}t[h|0]=0;t[i|0]=1;v[f+12>>2]=w[d|0]+1>>>1;v[f+8>>2]=64;E=n,F=v[od(f+12|0,f+8|0)>>2],t[E|0]=F;break f}if((e|0)!=19){break f}if(w[d|0]==128){break g}Iu(j);break f}if(g>>>0>44){break f}t[h|0]=w[g+26384|0];k:{switch(g-16|0){case 0:if(e>>>0>1){break g}t[d|0]=e|158;break f;case 1:case 2:t[f+12|0]=15;E=d,F=w[Vb(f+12|0,d)|0]|224,t[E|0]=F;break f;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=e+1;E=d,F=v[od(f+12|0,f+8|0)>>2]/2|240,t[E|0]=F;break f;case 14:l:{m:{n:{o:{p:{g=e>>>4|0;switch(g-1|0){case 1:break n;case 0:break o;default:break p}}switch(g-10|0){case 1:break l;case 0:break m;default:break g}}t[h|0]=2;t[d|0]=e|240;break f}t[h|0]=3;t[d|0]=e|240;break f}t[h|0]=11;t[d|0]=(e<<3&120)+8|15;break f}t[h|0]=11;t[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[f+12>>2]=e+1>>>1;v[f+8>>2]=64;E=d,F=v[od(f+12|0,f+8|0)>>2],t[E|0]=F;break f}if(!(l&128)){continue b}break a}t[h|0]=0}Hu(h,d,A,z);e=w[f+19|0];D=Hi(e);g=w[h|0];if(D>>>0<=Hi(g)>>>0){break e}if(!w[i|0]){Gq(f,g,w[d|0],1);g=w[f+1|0];t[i|0]=w[f|0];t[n|0]=g}t[h|0]=e;t[d|0]=w[f+21|0]}e=o>>>7|0;continue}}}hb=f+32|0;return}m=m+1|0;continue}}function ct(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=hb-16|0;hb=i;f=v[a+24>>2];h=bz(f,w[a+32|0]);j=v[h>>2];a:{if(Oc(j,v[h+4>>2])>>>0<=b>>>0){break a}if(mO(f,x[$b(j,b)>>1])>>>0<=c>>>0){break a}h=v[a>>2];b:{if(ud(h,v[a+4>>2])>>>0>b>>>0){if(y[Jd(h,b)+4>>2]>c>>>0){break b}}Rn(a,0);if(ud(v[a>>2],v[a+4>>2])>>>0<=b>>>0){break a}f=v[a+24>>2]}ec(i,v[d>>2],x[f+480188>>1]);d=i+8|0;h=v[i>>2];f=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;j=v[i+4>>2];while(1){if(!g&(k|0)==(j|0)){v[d>>2]=f;v[d+4>>2]=e}else{l=w[eQ(h,k)+841|0];m=l^rka(f^k,e^g,435,256);l=!l;f=(q=f,r=rka(m,kb,435,256),s=l,s?q:r);e=l?e:kb;k=k+1|0;g=k?g:g+1|0;continue}break}e=d;d=0;f=om(i,b,c);h=hb-16|0;hb=h;k=a+12|0;g=cO(x[f>>1],v[f+4>>2],Pd(k),gc(k));c:{if(Nb(g,Yf(k))){j=x[f>>1];l=v[f+4>>2];f=sd(g);if(!el(j,l,x[f>>1],v[f+4>>2])){break c}}g=Yf(k)}f=v[cc(h+8|0,g)>>2];hb=h+16|0;if(Fg(f,tf(k))){d=sd(f);d=nc(v[d+8>>2],v[d+12>>2])^1}h=v[e>>2]!=-2078137563|v[e+4>>2]!=-873292572;Ab(i,v[Jd(v[a>>2],b)>>2],c);g=1;j=d|h;m=zb(v[v[i>>2]>>2],v[i+4>>2])^1;if(!(m?1:j)){break a}d:{e:{f:{g:{if(d){l=sd(f);f=Cb(v[l+8>>2]);n=Cb(v[l+12>>2]);o=v[e>>2];p=v[e+4>>2];j=hb-16|0;hb=j;v[j+8>>2]=f;while(1){if(!(!Nb(f,n)|v[f>>2]==(o|0)&v[f+4>>2]==(p|0))){f=v[gt(j+8|0)>>2];continue}break}hb=j+16|0;if(Nb(f,Cb(v[l+12>>2]))){break a}if(!h){break e}break g}if(h){break g}if(!j){break d}break f}v[a+28>>2]=v[a+28>>2]+1}if(d|m){break e}d=aO(k,om(i,b,c));h:{if(y[d+4>>2]<y[Db(d)>>2]){g=hb-16|0;hb=g;d=$N(g,d);ZN(v[d+4>>2]);v[d+4>>2]=v[d+4>>2]+8;ic(d);hb=g+16|0;break h}f=hb-32|0;hb=f;g=Db(d);g=cr(f+8|0,dr(d,Qg(v[d>>2],v[d+4>>2])+1|0),Qg(v[d>>2],v[d+4>>2]),g);ZN(v[g+8>>2]);v[g+8>>2]=v[g+8>>2]+8;Cd(d,g);br(g);hb=f+32|0}}d=aO(k,om(i,b,c));i:{if(y[d+4>>2]<y[Db(d)>>2]){g=hb-16|0;hb=g;d=$N(g,d);_N(v[d+4>>2],v[e>>2],v[e+4>>2]);v[d+4>>2]=v[d+4>>2]+8;ic(d);hb=g+16|0;break i}f=hb-32|0;hb=f;g=Db(d);g=cr(f+8|0,dr(d,Qg(v[d>>2],v[d+4>>2])+1|0),Qg(v[d>>2],v[d+4>>2]),g);_N(v[g+8>>2],v[e>>2],v[e+4>>2]);v[g+8>>2]=v[g+8>>2]+8;Cd(d,g);br(g);hb=f+32|0}}Ab(i,v[Jd(v[a>>2],b)>>2],c);We(i,1);g=0}hb=i+16|0;return g|0}function wx(a){a=a|0;var b=0,c=0,d=C(0),e=0;Rb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[23516]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}da(943,e|0,67,5,c|0,b|0);b=v[23516];v[23516]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[23516]=0;da(943,a+4528|0,62,5,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[23516]=0;da(943,a+4552|0,53,5,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[23516]=0;da(943,a+4576|0,43,5,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[23516]=0;da(943,a+4600|0,32,5,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[23516]=0;da(943,a+4624|0,22,5,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[23516]=0;da(943,a+4648|0,75,5,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[23516]=0;da(943,a+4672|0,69,5,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[23516]=0;da(943,a+4696|0,60,5,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[23516]=0;da(943,a+4720|0,48,5,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[23516]=0;da(943,a+4744|0,36,5,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[23516]=0;da(943,a+4768|0,25,5,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}v[23516]=0;da(943,a+4792|0,0,0,0,0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[23516]=0;da(943,a+4816|0,3,0,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[23516]=0;da(943,a+4840|0,3,0,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}v[23516]=0;da(943,a+4864|0,407,1,c|0,0);b=v[23516];v[23516]=0;if((b|0)==1){break a}v[23516]=0;da(943,a+4888|0,400,1,c|0,0);b=v[23516];v[23516]=0;if((b|0)==1){break a}v[23516]=0;da(943,a+4912|0,10,0,c|0,-1);b=v[23516];v[23516]=0;if((b|0)==1){break a}v[23516]=0;da(943,a+4936|0,10,0,c|0,-1);c=v[23516];v[23516]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(92664)|0;if((O()|0)==(ea(92664)|0)){_(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function sea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-128|0;hb=d;a:{b:{c:{d:{switch(w[a|0]-23|0){case 0:e=t[a+1|0];f=d,g=TA(c,+w[a+2|0]*1e4/240),t[f|0]=g;v[d+96>>2]=127;v[d+80>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[od(d+96|0,d+80|0)>>2],t[f+127|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:vu(d+80|0,15704);v[23516]=0;R(553,d- -64|0,d|0);a=v[23516];v[23516]=0;f:{g:{h:{i:{if((a|0)!=1){v[23516]=0;R(553,d+48|0,d+127|0);a=v[23516];v[23516]=0;if((a|0)==1){break i}v[23516]=0;X(554,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}a=d+96|0;Be(d+112|0,a);cf(b,v[d+112>>2],v[d+116>>2]);wb(a);wb(d+48|0);wb(d- -64|0);Ub(d+80|0);break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;wb(d+48|0)}wb(d- -64|0)}break c;case 1:vu(d+80|0,15644);v[23516]=0;R(553,d- -64|0,d|0);a=v[23516];v[23516]=0;j:{k:{l:{m:{if((a|0)!=1){v[23516]=0;R(553,d+48|0,d+127|0);a=v[23516];v[23516]=0;if((a|0)==1){break m}v[23516]=0;X(554,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[23516];v[23516]=0;if((a|0)==1){break l}a=d+96|0;Be(d+40|0,a);cf(b,v[d+40>>2],v[d+44>>2]);wb(a);wb(d+48|0);wb(d- -64|0);Ub(d+80|0);break b}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;wb(d+48|0)}wb(d- -64|0)}break c;default:break e}}a=qc(d+32|0,15731);cf(b,v[a>>2],v[a+4>>2]);break b;case 1:break d;default:break a}}c=t[a+1|0];t[d+127|0]=(c|0)<5?c:0;c=t[a+2|0];t[d+31|0]=(c|0)>=0?c:127;a=t[a+3|0];t[d+30|0]=(a|0)>=0?a:127;a=hb-16|0;hb=a;c=Fc(a,4051);Xc(d+80|0,c);wb(c);hb=a+16|0;v[23516]=0;R(553,d- -64|0,d+127|0);a=v[23516];v[23516]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){v[23516]=0;R(553,d+48|0,d+31|0);a=v[23516];v[23516]=0;if((a|0)==1){break s}v[23516]=0;R(553,d|0,d+30|0);a=v[23516];v[23516]=0;if((a|0)==1){break r}v[23516]=0;da(726,d+96|0,d+80|0,d- -64|0,d+48|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break q}a=d+96|0;Be(d+16|0,a);cf(b,v[d+16>>2],v[d+20>>2]);wb(a);wb(d);wb(d+48|0);wb(d- -64|0);Ub(d+80|0);break b}a=P()|0;O()|0;break n}a=P()|0;O()|0;break o}a=P()|0;O()|0;break p}a=P()|0;O()|0;wb(d)}wb(d+48|0)}wb(d- -64|0)}}Ub(d+80|0);S(a|0);L()}e=1}hb=d+128|0;return e|0}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;s=v[a+16>>2];t=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;o=v[a+128>>2];if(o){e=v[a+8>>2];j=v[a+12>>2];p=kg(e,j,o);q=kb;g=v[a+76>>2];Of(v[a>>2],v[a+4>>2],mf(e,j,d),kb);j=g>>>0<kb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;j=j-1|0;p=j?p:0;q=j?q:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+s|0;b=o;while(1)if((b|0)<=0){Pb(i,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(h){b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Od(i,(u[(b<<1|2)+l>>1]+u[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Nd(i,h);v[i>>2]=v[i>>2];v[i+4>>2]=0}b=ig(i,t);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=v[r>>2];g=(f+16|0)+(b<<3)|0;G=v[g+8>>2];k=v[g+4>>2];v[g+8>>2]=k;l=e<<8;e=l;e=rka(E,F,e,e>>31);h=kb;H=g;g=e;e=Wb(k,-16777216,16776704);e=rka(C,D,e,e>>31);k=g+e|0;g=kb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Wb(G,-16777216,16776704);h=rka(z,A,e,e>>31);k=h+k|0;e=kb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Tc(h,e,24);v[H+4>>2]=e-(l&y);v[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];n=v[a+28>>2]+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],n>>12);m=b+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],m>>12);Pb(f+8|0,w,x);c=c+8|0;continue a}else{e=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Od(i,(u[(e<<1|2)+l>>1]+u[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Nd(i,4);Pb(f+40|0,p,q);b=b-1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function $7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=C(0),A=0,B=0,E=0,F=0,G=0,H=0,I=C(0),J=0,K=0,L=0,M=0,N=0,O=C(0),P=0,Q=C(0);a:{if(!v[a+4316>>2]){break a}if(!ai(a+44|0)){break a}G=a+4300|0;H=a+4288|0;J=a+4264|0;K=a+4276|0;e=v[a+44>>2];s=Ec(e,0);t=Ec(e,1);e=v[a+56>>2];u=Ec(e,0);x=Ec(e,1);L=lb[v[v[a>>2]+196>>2]](a)|0;y=C(C(lb[v[v[a>>2]+204>>2]](a))/C(100));I=C(lb[v[v[a>>2]+192>>2]](a));A=lb[v[v[a>>2]+216>>2]](a)|0;M=A&1;o=v[a+4324>>2];i=v[a+4320>>2];m=v[a+4328>>2];k=v[a+4312>>2];N=v[a+4276>>2];p=v[a+4264>>2];B=v[a+4256>>2];E=w[a+4260|0];r=a+4316|0;F=d;while(1){if(F){h=z[t>>2];l=z[s>>2];j=v[r>>2];e=Cn(j,k+B|0);j=Cn(j,k);b:{if(E){P=Bb(H,m),Q=l,z[P>>2]=Q;P=Bb(G,m),Q=h,z[P>>2]=Q;q=Bb(p,e);P=Bb(p,j),Q=C(C(z[q>>2]*y)+l),z[P>>2]=Q;g=C(C(z[Bb(N,e)>>2]*y)+h);e=K;break b}g=C(C(z[Bb(p,e)>>2]*y)+C(C(l+h)*C(.5)));e=J}P=Bb(v[e>>2],j),Q=g,z[P>>2]=Q;c:{if(L){f=z[a+4244>>2];g=C(f+z[a+4236>>2]);z[a+4236>>2]=g;f=C(f+z[a+4240>>2]);z[a+4240>>2]=f;if(g>C(1)){g=C(g+C(-2));z[a+4236>>2]=g}if(f>C(1)){f=C(f+C(-2));z[a+4240>>2]=f}g=C(D(g));g=C(C(g+g)+C(-1));f=C(D(f));f=C(C(f+f)+C(-1));break c}f=z[a+4240>>2];n=z[a+4244>>2];g=C(C(f*n)+z[a+4236>>2]);z[a+4236>>2]=g;f=C(f-C(g*n));z[a+4240>>2]=f}if(E){e=(m+2|0)%3|0;l=z[Bb(H,e)>>2];h=z[Bb(G,e)>>2]}e=v[r>>2];j=Bb(p,Cn(e,i+k|0));q=e;e=k+4096|0;O=z[Bb(p,Cn(q,e+i|0))>>2];n=z[j>>2];z[u>>2]=C(C(C(C(C(O-n)*C(C(i&4095)*C(.000244140625)))+n)-l)*I)+l;i=v[(E?4276:4264)+a>>2];j=v[r>>2];q=Bb(i,Cn(j,k+o|0));n=z[Bb(i,Cn(j,e+o|0))>>2];l=z[q>>2];z[x>>2]=C(C(C(C(C(n-l)*C(C(o&4095)*C(.000244140625)))+l)-h)*I)+h;m=((m|0)<=0?m+3|0:m)-1|0;v[a+4328>>2]=m;k=(((k|0)>0?0:v[r>>2]<<12)+k|0)-4096|0;v[a+4312>>2]=k;h=M?f:g;f=z[a+4248>>2];h=C(h*f);d:{if(C(D(h))<C(2147483648)){e=~~h;break d}e=-2147483648}o=(A>>>0>1?e:0-e|0)+B|0;v[a+4324>>2]=o;i=A>>>0<4;t=t+4|0;s=s+4|0;g=C(g*f);e:{if(C(D(g))<C(2147483648)){e=~~g;break e}e=-2147483648}i=(i?e:0-e|0)+B|0;v[a+4320>>2]=i;F=F-1|0;x=x+4|0;u=u+4|0;continue}else{e=a;a=v[a+56>>2];si(e,b,c,Ec(a,0),Ec(a,1),d)}break}}}function G6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=C(0),n=0,o=C(0),p=C(0),q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,A=C(0),B=0,D=0,E=0,F=0,G=C(0),H=0,I=0,J=0,K=0,L=C(0),M=C(0),N=C(0),O=C(0),P=C(0),Q=0,R=C(0);if(ai(a+44|0)){f=v[a+44>>2];B=Ec(f,0);D=Ec(f,1);f=v[a+56>>2];E=Ec(f,0);F=Ec(f,1);s=v[a+4296>>2];g=s+1|0;l=a+4304|0;f=a+4272|0;u=g+v[Bb(f,0)>>2]&4095;q=l+(u<<4)|0;w=g+v[Bb(f,1)>>2]&4095;n=((w<<4)+l|0)+4|0;x=g+v[Bb(f,2)>>2]&4095;j=((x<<4)+l|0)+8|0;h=Bb(f,3);i=v[Bb(f,4)>>2];r=v[a+4300>>2];i=i+r|0;y=g+v[h>>2]&4095;h=((y<<4)+l|0)+12|0;t=v[Bb(f,5)>>2]+r|0;g=a+4232|0;H=a+69840|0;I=a+78032|0;f=d;while(1){if(f){L=z[h>>2];M=z[j>>2];N=z[n>>2];O=z[q>>2];A=z[D>>2];P=z[B>>2];J=i&1023;j=(J<<3)+H|0;k=z[j+4>>2];u=u-1&4095;q=(u<<4)+l|0;e=z[q>>2];h=r<<3;i=h+H|0;w=w-1&4095;n=(w<<4)+l|0;m=z[n+4>>2];o=m;p=C(m*C(.6180340051651001));G=z[j>>2];m=z[Bb(g,0)>>2];p=C(p+C(G*m));z[i+4>>2]=o+C(p*C(-.6180340051651001));o=e;e=C(C(k*m)+C(e*C(-.6180340051651001)));z[i>>2]=o+C(e*C(.6180340051651001));z[q>>2]=p;z[n+4>>2]=e;t=t&1023;K=(t<<3)+I|0;m=z[K+4>>2];x=x-1&4095;i=(x<<4)+l|0;e=z[i+8>>2];h=h+I|0;y=y-1&4095;j=(y<<4)+l|0;k=z[j+12>>2];o=k;G=z[K>>2];p=z[Bb(g,1)>>2];k=C(C(k*C(.6180340051651001))+C(G*p));z[h+4>>2]=o+C(k*C(-.6180340051651001));o=e;e=C(C(m*p)+C(e*C(-.6180340051651001)));z[h>>2]=o+C(e*C(.6180340051651001));z[i+8>>2]=k;z[j+12>>2]=e;e=C(P+C(1.0000000031710769e-30));z[E>>2]=k+C(C(e*z[a+4224>>2])+z[q>>2]);k=C(A+C(1.0000000031710769e-30));z[F>>2]=C(C(k*z[a+4224>>2])+z[n+4>>2])+z[j+12>>2];h=(s<<4)+l|0;m=e;e=z[a+4228>>2];A=C(m*e);Q=h,R=C(A+C(C(z[q>>2]*z[Bb(g,2)>>2])+C(O*z[Bb(g,3)>>2]))),z[Q>>2]=R;e=C(k*e);Q=h,R=C(e+C(C(z[n+4>>2]*z[Bb(g,4)>>2])+C(N*z[Bb(g,5)>>2]))),z[Q+4>>2]=R;Q=h,R=C(C(C(z[i+8>>2]*z[Bb(g,6)>>2])+C(M*z[Bb(g,7)>>2]))-e),z[Q+8>>2]=R;Q=h,R=C(A+C(C(z[j+12>>2]*z[Bb(g,8)>>2])+C(L*z[Bb(g,9)>>2]))),z[Q+12>>2]=R;h=j+12|0;j=i+8|0;n=n+4|0;f=f-1|0;F=F+4|0;E=E+4|0;D=D+4|0;B=B+4|0;t=t-1|0;i=J-1|0;r=r-1&1023;s=s-1&4095;continue}else{v[a+4300>>2]=r;v[a+4296>>2]=s;f=a;a=v[a+56>>2];si(f,b,c,Ec(a,0),Ec(a,1),d)}break}}}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;q=v[a+16>>2];r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;m=v[a+128>>2];if(m){e=v[a+8>>2];k=v[a+12>>2];n=kg(e,k,m);o=kb;i=v[a+76>>2];Of(v[a>>2],v[a+4>>2],mf(e,k,d),kb);k=i>>>0<kb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];u=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;k=k-1|0;n=k?n:0;o=k?o:0;l=(((b&2147483647)<<1|e>>>31)&-2)+q|0;e=m;a:{b:while(1){c:{if((e|0)<=0){Pb(j,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(!h){break a}e=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Od(j,(g|0)/8<<16>>16);Nd(j,4);Pb(f+40|0,n,o);e=e-1|0;continue b}else{g=(t[l+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[l+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Od(j,(g|0)/8<<16>>16);Nd(j,h);v[j>>2]=v[j>>2];v[j+4>>2]=0}b=ig(j,r);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];i=(f+16|0)+(b<<3)|0;G=v[i+8>>2];g=v[i+4>>2];v[i+8>>2]=g;l=e<<8;e=l;e=rka(E,F,e,e>>31);h=kb;H=i;i=e;e=Wb(g,-16777216,16776704);e=rka(C,D,e,e>>31);g=i+e|0;i=kb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Wb(G,-16777216,16776704);h=rka(z,A,e,e>>31);g=h+g|0;e=kb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Tc(h,e,24);v[H+4>>2]=e-(l&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],u);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],s);Pb(f+8|0,w,x);c=c+8|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function mP(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=hb-128|0;hb=j;a:{b:{c:{if(!zm(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}r=e>>>16|0;o=r&32767;if((o|0)==32767){break c}if(l){break b}}Fd(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];WP(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if((zm(b,c,l,p,f,g,h,k)|0)<=0){if(zm(b,c,l,p,f,g,m,k)){h=b;i=c;break a}Fd(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{Fd(j+96|0,b,c,l,p,0,0,0,1081540608);h=v[j+108>>2];p=h;l=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Fd(j+80|0,f,g,m,k,0,0,0,1081540608);f=v[j+92>>2];k=f;m=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((l>>>0<m>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){Fd(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;p=n;break f}n=p<<1|l>>>31;l=l<<1|i>>>31;p=n}n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((l>>>0<m>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}Fd(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Fd(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;hb=j+128|0}function Bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;c=nf(a,c);ke(h,v[a+36>>2]);j=a;a:{if(!c){Pc(h,a+32|0,5);e=0;if(zb(v[v[h>>2]>>2],v[h+4>>2])){break a}}e=hb-240|0;hb=e;g=Rl(e+128|0,v[a+36>>2]);v[23516]=0;f=Q(458,e+112|0,27976)|0;a=v[23516];v[23516]=0;b:{c:{d:{e:{if((a|0)!=1){v[23516]=0;v[e+96>>2]=19988497;v[e+100>>2]=0;U(459,g|0,f|0,e+96|0);a=v[23516];v[23516]=0;if((a|0)==1){break e}Ub(f);if(!Ek(w[g|0])){break d}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Ub(f);break c}t[e+111|0]=0;v[23516]=0;f=Q(458,e+96|0,5508)|0;a=v[23516];v[23516]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23516]=0;U(460,g|0,e+111|0,f|0);a=v[23516];v[23516]=0;if((a|0)==1){break q}Ub(f);f=Kb(e+80|0);v[23516]=0;a=Q(458,e- -64|0,10113)|0;i=v[23516];v[23516]=0;if((i|0)==1){break p}v[23516]=0;U(773,g|0,f|0,a|0);i=v[23516];v[23516]=0;if((i|0)==1){break o}Ub(a);v[23516]=0;U(11,e+48|0,(w[e+111|0]?0:d)|0,f|0);d=v[23516];v[23516]=0;if((d|0)==1){break n}v[23516]=0;R(276,b|0,e+48|0);d=v[23516];v[23516]=0;if((d|0)==1){break m}d=e+48|0;xb(d);u[e+46>>1]=0;v[23516]=0;d=Q(458,d|0,10773)|0;a=v[23516];v[23516]=0;if((a|0)==1){break g}v[23516]=0;W(488,g|0,e+46|0,d|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break l}Ub(d);Bf(e+46|0,4e3);v[23516]=0;d=Q(458,e+32|0,13450)|0;a=v[23516];v[23516]=0;if((a|0)==1){break k}i=x[e+46>>1];a=v[cc(e+24|0,i)>>2];v[23516]=0;X(774,g|0,b|0,d|0,a|0);a=v[23516];v[23516]=0;if((a|0)==1){break j}Ub(d);u[e+22>>1]=65535;v[23516]=0;d=Q(458,e+8|0,8993)|0;a=v[23516];v[23516]=0;if((a|0)==1){break i}v[23516]=0;k=W(488,g|0,e+22|0,d|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break h}a=x[e+22>>1];Ub(d);if(a>>>0<i>>>0&k){Te(b,a)}wb(f);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Ub(f);break c}b=P()|0;O()|0;break f}b=P()|0;O()|0;Ub(a);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;xb(e+48|0);break f}b=P()|0;O()|0;Ub(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;Ub(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;Ub(d);break f}b=P()|0;O()|0}wb(f)}fh(g);S(b|0);L()}fh(g);hb=e+240|0;e=c}Ve(j,e);hb=h+16|0}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=hb-48|0;hb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;t=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;w=v[a+32>>2];x=v[a+28>>2];y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;while(1){if(d){b=v[e+16>>2];G=((((v[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(b>>>16&65520)+s|0;H=u[b+14>>1];g=u[b+12>>1];q=u[b+10>>1];r=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=G+(p<<1)|0;v[(e+8|0)+(p<<2)>>2]=(((((((B(u[i-8>>1],f)+B(u[i-12>>1],b)|0)+B(u[i-4>>1],k)|0)+B(u[i>>1],h)|0)+B(u[i+4>>1],r)|0)+B(u[i+8>>1],q)|0)+B(g,u[i+12>>1])|0)+B(H,u[i+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=v[q>>2];g=(e+24|0)+(o<<3)|0;r=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=rka(E,F,b,b>>31);f=kb;i=g;g=b;b=Wb(h,-16777216,16776704);b=rka(C,D,b,b>>31);h=g+b|0;g=kb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Wb(r,-16777216,16776704);f=rka(z,A,b,b>>31);h=f+h|0;b=kb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Tc(f,b,24);v[i+4>>2]=b-(k&y);v[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+x|0;v[c>>2]=v[c>>2]+B(v[e+8>>2],n>>12);m=m+w|0;v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],m>>12);Pb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=e+48|0}function Sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0),h=0,i=C(0);d=hb-112|0;hb=d;c=hb-16|0;hb=c;e=b+16|0;LS(c+8|0,e);f=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],f);h=v[c+4>>2];if((h|0)==(f|0)){Yb(a,v[c+12>>2])}hb=c+16|0;if((f|0)!=(h|0)){Rb(e,0,128)}t[b+79|0]=0;t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;c=d- -64|0;Wd(c,a,zg(a));f=hc(d+88|0,c);yb(c);v[23516]=0;c=T(200,f|0)|0;e=v[23516];v[23516]=0;a:{b:{if((e|0)==1){break b}v[23516]=0;R(288,b+4|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}oe(d+56|0,v[b+4>>2],v[b+8>>2]);v[23516]=0;X(468,d- -64|0,f|0,v[d+56>>2],v[d+60>>2]);c=v[23516];v[23516]=0;if((c|0)!=1){v[23516]=0;c=T(155,a|0)|0;e=v[23516];v[23516]=0;c:{if((e|0)==1){break c}v[23516]=0;U(188,d+32|0,a|0,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}a=d+32|0;c=hc(d- -64|0,a);yb(a);a=v[c>>2];v[23516]=0;a=T(176,a|0)|0;e=v[23516];v[23516]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{a=v[c+8>>2];e=v[c>>2];v[23516]=0;a=W(154,e|0,a|0,5)|0;e=v[23516];v[23516]=0;if((e|0)==1){break e}if(!a){break f}v[23516]=0;Q(469,c|0,d+28|0)|0;a=v[23516];v[23516]=0;h:{if((a|0)!=1){a=4;if(!Qb(d+28|0,13635,4)){break h}if(!Qb(d+28|0,14203,4)){break h}v[23516]=0;a=T(155,c|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[23516]=0;U(188,d+8|0,c|0,a|0);a=v[23516];v[23516]=0;i:{j:{k:{if((a|0)!=1){a=d+8|0;e=hc(d+32|0,a);yb(a);if(Qb(d+28|0,13635,4)){break k}v[23516]=0;g=C(Ca(470,e|0));a=v[23516];v[23516]=0;if((a|0)==1){break g}z[d+8>>2]=g;v[d+4>>2]=0;v[d>>2]=1065353216;g=z[St(d+8|0,d+4|0,d)>>2];z[b+144>>2]=g;i=C(D(g));if((i<C(1.1754943508222875e-38)^-1)&(!(i>=C(N))&g==g)){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if(Qb(d+28|0,14203,4)){break j}v[23516]=0;a=T(155,e|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break i}v[b+148>>2]=a}yb(e);continue}}break}a=P()|0;O()|0;yb(e);break d}yb(c);yb(f);hb=d+112|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}yb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}yb(f);S(a|0);L()}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=hb-48|0;hb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;w=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;x=v[a+32>>2];y=v[a+28>>2];z=v[a+72>>2];b=v[a+68>>2];A=b;C=b>>31;b=v[a+64>>2];D=b;E=b>>31;b=v[a+60>>2];F=b;G=b>>31;while(1){if(d){b=v[e+16>>2];H=(((v[e+20>>2]&2147483647)<<1|b>>>31)&-2)+w|0;b=(b>>>16&65520)+s|0;I=u[b+14>>1];g=u[b+12>>1];q=u[b+10>>1];r=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=p+H|0;v[(e+8|0)+(p<<2)>>2]=(((((((B(t[i-4|0],f)+B(t[i-6|0],b)|0)+B(t[i-2|0],k)|0)+B(t[i|0],h)|0)+B(t[i+2|0],r)|0)+B(t[i+4|0],q)|0)+B(g,t[i+6|0])|0)+B(I,t[i+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=v[q>>2];g=(e+24|0)+(o<<3)|0;r=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=rka(F,G,b,b>>31);f=kb;i=g;g=b;b=Wb(h,-16777216,16776704);b=rka(D,E,b,b>>31);h=g+b|0;g=kb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Wb(r,-16777216,16776704);f=rka(A,C,b,b>>31);h=f+h|0;b=kb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Tc(f,b,24);v[i+4>>2]=b-(k&z);v[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+y|0;v[c>>2]=v[c>>2]+B(v[e+8>>2],n>>12);m=m+x|0;v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],m>>12);Pb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=e+48|0}function T5(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=hb-96|0;hb=j;a:{b:{c:{k=tp(1,32);d:{e:{if(!k){a=An(ba(4)|0);v[23516]=0;U(117,a|0,92664,26);a=v[23516];v[23516]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:947;c=Xf(j+80|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[23516]=0;d=Q(53,j- -64|0,d|0)|0;f=v[23516];v[23516]=0;j:{if((f|0)!=1){v[23516]=0;f=Q(958,c|0,d|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break j}v[23516]=0;Q(273,f|0,e|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;wb(d);break f}v[23516]=0;d=Q(53,j+48|0,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break g}ws(c,d)}wb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23516]=0;a=T(832,104)|0;i=v[23516];v[23516]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[23516]=0;b=Q(959,d|0,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break m}v[j+16>>2]=b;b=v[dg(j+24|0,j+16|0)>>2];d=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=d;v[23516]=0;d=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=d;b=fa(989,a|0,j|0,b|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break k}i=V(0)|0;O()|0;ze(j+16|0);break l}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0}Jb(a);break f}v[k+28>>2]=b;ze(j+16|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;dl(c);break d}i=V(0)|0;O()|0}dl(c);_(i|0)|0;v[23516]=0;X(953,11376,k|0,g|0,h|0);a=v[23516];v[23516]=0;if((a|0)!=1){v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)!=1){a=v[k+28>>2];if(a){lb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Jb(a);v[k+20>>2]=0}Jb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;v[23516]=0;X(953,11376,0,g|0,h|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}$()}hb=j+96|0;return k|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Tb()}L()}function f6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-80|0;hb=e;v[e+76>>2]=c;v[e+72>>2]=b;a:{if(!c){break a}g=w[Xk(b,c)|0];if((g|0)==33){d=1}else{if((g|0)!=63){break a}d=0}cl(e+48|0,b,c,c-1|0);b=v[e+52>>2];v[e+72>>2]=v[e+48>>2];v[e+76>>2]=b}c=e+48|0;Rd(c);b=v[e+48>>2];Rd(e+32|0);b=Wk(b,v[e+36>>2],e+72|0);Rd(c);b:{c:{d:{e:{if((b|0)==v[e+52>>2]){b=v[e+72>>2];c=v[e+76>>2];a=qc(e- -64|0,21751);if(Mc(b,c,v[a>>2],v[a+4>>2])){a=ba(8)|0;v[23516]=0;b=Q(53,e+48|0,10501)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}f=0;if(!d){break e}a=ba(8)|0;v[23516]=0;b=Lh(e+32|0,v[e+72>>2],v[e+76>>2]);c=v[23516];v[23516]=0;f:{g:{h:{if((c|0)!=1){v[23516]=0;U(981,e+48|0,17766,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break h}d=0;c=rc(a,e+48|0);v[23516]=0;U(117,c|0,62944,970);c=v[23516];v[23516]=0;if((c|0)!=1){break b}c=P()|0;O()|0;wb(e+48|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}wb(b);if(!d){break c}}ca(a|0);break c}if(v[b+4>>2]!=2){a=ba(8)|0;v[23516]=0;b=Q(53,e+48|0,11620)|0;c=v[23516];v[23516]=0;if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}c=P()|0;O()|0;ca(a|0);break c}b=v[e+72>>2];c=v[e+76>>2];d=qc(e+24|0,21751);if(Mc(b,c,v[d>>2],v[d+4>>2])){a=ba(8)|0;v[23516]=0;b=Q(53,e+48|0,10501)|0;c=v[23516];v[23516]=0;if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}c=P()|0;O()|0;ca(a|0);break c}d=qc(e+16|0,7719);if(Mc(b,c,v[d>>2],v[d+4>>2])){f=1;if(!Sd(w[a+28|0])){break e}f=65536/+y[v[a+24>>2]+480244>>2];break e}d=qc(e+8|0,7771);if(Mc(b,c,v[d>>2],v[d+4>>2])){f=1;if(!Sd(w[a+28|0])){break e}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break e}d=b;b=qc(e,7789);f=0;if(!Mc(d,c,v[b>>2],v[b+4>>2])){break e}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}hb=e+80|0;return+f}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function uO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=hb-176|0;hb=c;i=1;p=2;d=v[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;w=B(i,3);x=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=v[a+12>>2];continue a}d=v[a>>2];e=Gd(d,h<<1);RL(c+160|0,A[e>>3],A[e+8>>3]);d=Gd(d,h);RL(c+144|0,A[d>>3],A[d+8>>3]);wi(c+128|0,A[c+144>>3],A[c+152>>3],A[c+160>>3],A[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=v[b>>2];e=Gd(f,d);g=e+8|0;j=v[g+4>>2];v[c+120>>2]=v[g>>2];v[c+124>>2]=j;g=v[e+4>>2];v[c+112>>2]=v[e>>2];v[c+116>>2]=g;k=d+i|0;g=Gd(f,k);n=A[g+8>>3];o=A[g>>3];r=d+x|0;g=Gd(f,r);j=v[g+12>>2];v[c+104>>2]=v[g+8>>2];v[c+108>>2]=j;j=v[g+4>>2];v[c+96>>2]=v[g>>2];v[c+100>>2]=j;s=d+w|0;f=Gd(f,s);t=A[f+8>>3];u=A[f>>3];g=c+80|0;f=c+112|0;_k(g,f,o,n);j=c- -64|0;ij(j,f,o,n);l=c+96|0;_k(c+48|0,l,u,t);f=c+16|0;ij(f,l,u,t);wi(c+32|0,0,1,A[c+16>>3],A[c+24>>3]);_k(f,g,A[c+48>>3],A[c+56>>3]);l=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=l;l=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=l;_k(c,j,A[c+32>>3],A[c+40>>3]);wi(f,A[c+160>>3],A[c+168>>3],A[c>>3],A[c+8>>3]);e=Gd(v[b>>2],k);k=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=k;k=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=k;ij(c,g,A[c+48>>3],A[c+56>>3]);wi(f,A[c+144>>3],A[c+152>>3],A[c>>3],A[c+8>>3]);e=Gd(v[b>>2],r);g=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=g;g=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=g;ij(c,j,A[c+32>>3],A[c+40>>3]);wi(f,A[c+128>>3],A[c+136>>3],A[c>>3],A[c+8>>3]);e=Gd(v[b>>2],s);f=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=f;f=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=v[b>>2];a=Gd(h,d+i|0);m=Gd(h,d);n=A[a>>3];o=A[a+8>>3];ij(c+160|0,m,n,o);h=v[c+172>>2];v[a+8>>2]=v[c+168>>2];v[a+12>>2]=h;h=v[c+164>>2];v[a>>2]=v[c+160>>2];v[a+4>>2]=h;Wx(Gd(v[b>>2],d),n,o);d=d+1|0;continue}}hb=c+176|0}function Ys(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-16|0;hb=f;e=B(c,872)+b|0;h=e+704|0;v[h>>2]=v[h>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){Ab(f+8|0,a+1074312|0,15);if(zb(v[v[f+8>>2]>>2],v[f+12>>2])){break b}}if(v[a+480180>>2]!=268435456){break a}}g=B(c,872)+b|0;d=d?d:w[(B(c,872)+b|0)+1427|0];t[g+1427|0]=d;t[g+1428|0]=d}if(d){u[(B(c,872)+b|0)+1384>>1]=d}c:{d:{g=e+616|0;j=v[g+656>>2];if(uj(j)){a=x[(B(c,872)+b|0)+1384>>1];if(!a){break d}e=0;d=v[b+16>>2];e=d?v[(B(c,872)+b|0)+1472>>2]:e;k=0-a|0;l=a;i=B(c,872)+b|0;g=i+1324|0;a=v[g>>2];m=(+(d>>>0)+1)*+(((a|0)<0?k:l)|0)/+y[b+40>>2];e:{if(D(m)<2147483648){d=~~m;break e}d=-2147483648}i=i+1472|0;v[i>>2]=d;if(w[h+2|0]&16){d=B(v[v[j+44>>2]+36>>2]+1|0,d);v[i>>2]=d}d=d-e|0;h=d>>31;e=a>>31;if((e^a)-e>>>0<=(d^h)-h>>>0){if(!a){break d}b=B(c,872)+b|0;c=b+1468|0;v[c>>2]=a+v[c>>2];v[g>>2]=0;a=b+1467|0;t[a|0]=w[a|0]|64;a=0;break c}b=B(c,872)+b|0;c=b+1468|0;v[c>>2]=d+v[c>>2];v[g>>2]=a-d;a=b+1467|0;t[a|0]=w[a|0]|64;break d}h=1;j=B(c,872)+b|0;e=j+1467|0;f:{if(!(t[e|0]&1)){break f}d=v[a+480180>>2];if(d&524352){break f}if(v[b+40>>2]==1){Ab(f+8|0,a+1074312|0,6);if(zb(v[v[f+8>>2]>>2],v[f+12>>2])){break f}d=v[a+480180>>2]}h=0;if((d|0)!=8){break f}h=(w[a+480208|0]&2)>>>1|0}i=v[a+480180>>2];d=x[j+1384>>1];if(!((i|0)!=268435456|d>>>0<240)){h=t[e|0]&1;d=d-240|0}d=B((i|0)==64?2:4,d);j=B(c,872)+b|0;b=j+1316|0;g:{if(!v[b>>2]){break g}c=j+1324|0;if(!v[c>>2]|!h){break g}i=jj(a)?d:0-d|0;l=v[b>>2];k=v[c>>2];if(!(w[e|0]&16?0:(l|0)>=(k|0))){dk(a,g,b,i,1);c=v[c>>2];if((c|0)>=v[b>>2]){break g}v[b>>2]=c;break g}if((l|0)<=(k|0)){break g}dk(a,g,b,0-i|0,1);g=v[b>>2];c=v[c>>2];h:{if((g|0)<(c|0)){v[b>>2]=c;break h}if((c|0)!=(g|0)){break g}}Ab(f+8|0,a+1074312|0,112);if(!zb(v[v[f+8>>2]>>2],v[f+12>>2])){break g}t[e|0]=w[e|0]|16}c=v[b>>2];b=j+1324|0;i:{if((c|0)!=v[b>>2]){break i}Ab(f+8|0,a+1074312|0,25);if(!zb(v[v[f+8>>2]>>2],v[f+12>>2])&v[a+480180>>2]!=1){break i}v[b>>2]=0}a=h?d:0;break c}a=0}hb=f+16|0;return a}function ve(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-16|0;hb=h;e=v[a>>2];a:{if(nc(e,v[a+4>>2])){break a}g=v[b+4>>2];if(g>>>0>=y[a+12>>2]){break a}c=x[b+8>>1];i=v[v[a+48>>2]+12>>2];f=Lg(i);if(c>>>0>=f>>>0&(c|0)!=65535){break a}d=(c|0)==65535;l=d?f-1|0:c;f=g;g=d?0:c;c=ed(e,i,f,g);f=w[b+12|0];j=f&4;b:{c:{if(f&2){break c}k=w[b+10|0];e=c;d=g;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!j){if((k|0)!=w[e+3|0]){break d}break b}if((k|0)==w[e+2|0]){break b}}e=e+6|0;d=d+1|0;continue}}k=l&65535;d=c;e=g;while(1){if(k>>>0>=(e&65535)>>>0){e:{if(!j){if(w[d+3|0]){break e}t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break b}if(w[d+2|0]){break e}t[d+2|0]=w[b+10|0];t[d+4|0]=w[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}f:{if(!(f&1)){break f}d=v[i+480180>>2]&2;g:{h:{i:{if(!j){while(1){if((g&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(w[c+3|0]-9|0){case 4:if(!WT(v[v[i+8>>2]+88>>2])){break j}d=1;t[c+2|0]=1;t[c+4|0]=w[c+5|0];t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break a;case 0:break k;default:break j}}l:{if(d){e=w[c+5|0];if(e>>>0>128){break j}t[c+2|0]=2;t[c+3|0]=w[b+10|0];a=1;break l}t[c+2|0]=2;t[c+3|0]=w[b+10|0];e=w[c+5|0];a=2}t[c+4|0]=a+e>>>a;t[c+5|0]=w[b+11|0];break b}c=c+6|0;g=g+1|0;continue}break}if(!j){break i}}e=w[b+11|0];g=13;m:{switch(w[b+10|0]-1|0){case 1:g=9;e=Bl(B(d?2:4,e));break;case 0:break m;default:break g}}t[b+11|0]=e;t[b+10|0]=g;f=f&254;break h}t[h+15|0]=0;t[h+14|0]=0;g=b;c=!d;d=w[b+10|0];n:{if(!(c|(d|0)!=9)){e=w[b+11|0];if(e>>>0>128){break g}d=2;c=e>>>1|0;break n}e=h+8|0;Gq(e,d,w[b+11|0],1);hB(h,h+15|0,h+14|0);gB(h,e);d=w[h+15|0];if(!d){f=w[b+12|0];break g}f=w[b+12|0];c=w[h+14|0]}t[g+11|0]=c;t[b+10|0]=d;f=f&254}t[b+12|0]=f}d=1;if(f&1){break f}t[b+12|0]=f^4;if(ve(a,b)){break a}}d=0;o:{p:{switch(v[b>>2]-1|0){case 0:c=v[b+4>>2]+1|0;if(c>>>0>=y[a+12>>2]){break a}v[b+4>>2]=c;break o;case 1:break p;default:break a}}c=v[b+4>>2];if(!c){break a}v[b+4>>2]=c-1}t[b+12|0]=w[b+12|0]|1;d=ve(a,b);break a}d=1}hb=h+16|0;return d}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;q=v[a+16>>2];r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;m=v[a+128>>2];if(m){e=v[a+8>>2];j=v[a+12>>2];n=kg(e,j,m);o=kb;g=v[a+76>>2];Of(v[a>>2],v[a+4>>2],mf(e,j,d),kb);j=g>>>0<kb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];t=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;j=j-1|0;n=j?n:0;o=j?o:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=m;while(1)if((b|0)<=0){Pb(i,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(h){b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Od(i,(u[(b<<1|2)+l>>1]+u[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Nd(i,h);v[i>>2]=v[i>>2];v[i+4>>2]=0}b=ig(i,r);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];g=(f+16|0)+(b<<3)|0;G=v[g+8>>2];k=v[g+4>>2];v[g+8>>2]=k;l=e<<8;e=l;e=rka(E,F,e,e>>31);h=kb;H=g;g=e;e=Wb(k,-16777216,16776704);e=rka(C,D,e,e>>31);k=g+e|0;g=kb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Wb(G,-16777216,16776704);h=rka(z,A,e,e>>31);k=h+k|0;e=kb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Tc(h,e,24);v[H+4>>2]=e-(l&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],t);v[c+4>>2]=v[c+4>>2]+B(s,v[f+4>>2]);Pb(f+8|0,w,x);c=c+8|0;continue a}else{e=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Od(i,(u[(e<<1|2)+l>>1]+u[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Nd(i,4);Pb(f+40|0,n,o);b=b-1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function XJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=hb-96|0;hb=j;a:{b:{c:{d:{e:{f:{k=tp(1,28);if(!k){a=An(ba(4)|0);v[23516]=0;U(117,a|0,92664,26);a=v[23516];v[23516]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:947;c=Xf(j+80|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[23516]=0;d=Q(53,j- -64|0,d|0)|0;f=v[23516];v[23516]=0;k:{if((f|0)!=1){v[23516]=0;f=Q(958,c|0,d|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break k}v[23516]=0;Q(273,f|0,e|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;wb(d);break g}v[23516]=0;d=Q(53,j+48|0,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break h}ws(c,d)}wb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23516]=0;a=T(832,80)|0;i=v[23516];v[23516]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[23516]=0;b=Q(959,d|0,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break n}v[j+16>>2]=b;b=v[dg(j+24|0,j+16|0)>>2];d=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=d;v[23516]=0;d=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=d;b=fa(960,a|0,j|0,b|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break l}i=V(0)|0;O()|0;ze(j+16|0);break m}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0}Jb(a);break g}v[k+24>>2]=b;ze(j+16|0);dl(c);i=k;break d}i=V(0)|0;O()|0}dl(c);_(i|0)|0;v[23516]=0;X(953,15302,k|0,g|0,h|0);a=v[23516];v[23516]=0;if((a|0)!=1){v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Jb(vs(a))}i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Jb(a);v[k+20>>2]=0}Jb(k);break d}i=V(0)|0;O()|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[23516]=0;X(953,15302,0,g|0,h|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}$()}hb=j+96|0;return i|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Tb()}L()}function wG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=v[d>>2];if(!h){break k}if(!a){g=c;break j}v[d>>2]=0;g=c;break i}l:{if(!v[v[116018]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=t[e|0];if(g){v[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return Og(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=w[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=v[e>>2];if((d|d-16843009)&-2139062144){break p}v[a>>2]=d&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=w[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}v[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=v[(f<<2)+83792>>2];d=1;continue}d=w[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=w[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=w[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;v[a>>2]=d;g=g-1|0;a=a+4|0;break q}v[115992]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=w[e|0];if(!(e&3|d-1>>>0>126)){d=v[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=v[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=v[(h<<2)+83792>>2];d=1;continue}d=w[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=w[e|0]}if(d&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-g|0}v[115992]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c}function bh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Fb(c);v[23516]=0;R(44,a|0,d|0);d=v[23516];v[23516]=0;d:{if((d|0)!=1){e:{while(1){if(Fb(c)>>>0>b>>>0){d=v[oj(c,b)>>2];v[23516]=0;R(45,a|0,(d>>>0<128?d:63)<<24>>24);d=v[23516];v[23516]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Kb(a);d=Fb(c);v[23516]=0;R(44,a|0,d|0);d=v[23516];v[23516]=0;f:{if((d|0)!=1){g:{while(1){if(Fb(c)>>>0>b>>>0){d=v[oj(c,b)>>2];v[23516]=0;R(45,a|0,(d>>>0<256?d:63)<<24>>24);d=v[23516];v[23516]=0;if((d|0)==1){break g}b=b+1|0;continue}break}break f}}break a}return;case 3:il(a,c,49808);return;case 5:il(a,c,50832);return;case 4:il(a,c,51856);return;case 6:il(a,c,52880);return;case 7:il(a,c,53904);return;case 8:il(a,c,54928);return;case 9:il(a,c,55952);return;case 10:qz(a,c,56976);return;case 11:qz(a,c,49808);return;case 12:qz(a,c,53904);return;default:a=ba(8)|0;v[23516]=0;b=Q(43,a|0,11075)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}b=P()|0;O()|0;ca(a|0);S(b|0);L();case 0:break c}}e=hb-16|0;hb=e;f=Kb(a);h:{while(1){i:{j:{k:{if(Fb(c)>>>0>g>>>0){b=v[oj(c,g)>>2];if(b>>>0>=2097152){v[23516]=0;R(45,f|0,63);a=v[23516];v[23516]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;t[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=w[e+10|0]|64}else{a=w[e+10|0]}v[23516]=0;R(45,f|0,a<<24>>24);a=v[23516];v[23516]=0;if((a|0)!=1){break j}break i}hb=e+16|0;break h}i=(-1<<b^-1)<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=w[j|0];v[23516]=0;R(45,f|0,(a|i)<<24>>24);h=v[23516];v[23516]=0;a=d;break l}v[23516]=0;a=a-1|0;R(45,f|0,t[a+(e+10|0)|0]|-128);h=v[23516];v[23516]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=P()|0;O()|0;wb(f);S(a|0);L()}return}ia(b|0,92784,25);L()}b=P()|0;O()|0;wb(a);S(b|0);L()}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;e=hb-48|0;hb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];t=v[a+20>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;w=v[a+72>>2];b=v[a+68>>2];x=b;y=b>>31;b=v[a+64>>2];z=b;A=b>>31;b=v[a+60>>2];C=b;D=b>>31;while(1){if(d){b=v[e+16>>2];E=((((v[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=(b>>>16&65520)+q|0;F=u[b+14>>1];g=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=E+(n<<1)|0;v[(e+8|0)+(n<<2)>>2]=(((((((B(u[i-8>>1],f)+B(u[i-12>>1],b)|0)+B(u[i-4>>1],k)|0)+B(u[i>>1],h)|0)+B(u[i+4>>1],p)|0)+B(u[i+8>>1],o)|0)+B(g,u[i+12>>1])|0)+B(F,u[i+16>>1])|0)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=v[o>>2];g=(e+24|0)+(m<<3)|0;p=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=rka(C,D,b,b>>31);f=kb;i=g;g=b;b=Wb(h,-16777216,16776704);b=rka(z,A,b,b>>31);h=g+b|0;g=kb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Wb(p,-16777216,16776704);f=rka(x,y,b,b>>31);h=f+h|0;b=kb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Tc(f,b,24);v[i+4>>2]=b-(k&w);v[o>>2]=(b|0)/256;m=m+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],t);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],s);Pb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=e+48|0}function Aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;e=hb-48|0;hb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];w=v[a+20>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;x=v[a+72>>2];b=v[a+68>>2];y=b;z=b>>31;b=v[a+64>>2];A=b;C=b>>31;b=v[a+60>>2];D=b;E=b>>31;while(1){if(d){b=v[e+16>>2];F=(((v[e+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=(b>>>16&65520)+q|0;G=u[b+14>>1];g=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=n+F|0;v[(e+8|0)+(n<<2)>>2]=(((((((B(t[i-4|0],f)+B(t[i-6|0],b)|0)+B(t[i-2|0],k)|0)+B(t[i|0],h)|0)+B(t[i+2|0],p)|0)+B(t[i+4|0],o)|0)+B(g,t[i+6|0])|0)+B(G,t[i+8|0])<<8)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=v[o>>2];g=(e+24|0)+(m<<3)|0;p=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=rka(D,E,b,b>>31);f=kb;i=g;g=b;b=Wb(h,-16777216,16776704);b=rka(A,C,b,b>>31);h=g+b|0;g=kb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Wb(p,-16777216,16776704);f=rka(y,z,b,b>>31);h=f+h|0;b=kb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Tc(f,b,24);v[i+4>>2]=b-(k&x);v[o>>2]=(b|0)/256;m=m+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],s);Pb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=e+48|0}function g$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=hb-16|0;hb=j;k=Hw(g);o=ow(g);Wg(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23516]=0;g=Q(1171,k|0,g<<24>>24)|0;i=v[23516];v[23516]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[23516]=0;g=Q(1171,k|0,48)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;g=t[i+1|0];v[23516]=0;g=Q(1171,k|0,g|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Dd();if(!JG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Dd();if(!Zj(h)){break d}g=g+1|0;continue}}e:{if(Pe(j)){h=v[f>>2];v[23516]=0;X(1165,k|0,i|0,g|0,h|0);h=v[23516];v[23516]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i<<2);break e}Sl(i,g);v[23516]=0;q=T(1163,o|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Ir((i-a<<2)+d|0,v[f>>2]);break e}f:{if(t[Jc(j,l)|0]<=0){break f}if(t[Jc(j,l)|0]!=(m|0)){break f}m=v[f>>2];v[f>>2]=m+4;v[m>>2]=q;l=(Fb(j)-1>>>0>l>>>0)+l|0;m=0}p=t[h|0];v[23516]=0;p=Q(1171,k|0,p|0)|0;n=v[23516];v[23516]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+4;v[n>>2]=p;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=w[g|0];if((i|0)==46){v[23516]=0;i=T(1166,o|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}l=v[f>>2];h=l+4|0;v[f>>2]=h;v[l>>2]=i;g=g+1|0;break g}v[23516]=0;i=Q(1171,k|0,i<<24>>24)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;continue}break}h=v[f>>2]}v[23516]=0;X(1165,k|0,g|0,c|0,h|0);i=v[23516];v[23516]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g<<2)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;wb(j);hb=j+16|0;return}a=P()|0;O()|0;wb(j);S(a|0);L()}function _r(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Md(b)}if(b>>>0>=4294967232){v[115992]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[116144]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;tH(c,b);return a}if(v[116030]==(f|0)){c=c+v[116027]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[116027]=c;v[116030]=b;return a}if(v[116029]==(f|0)){c=c+v[116026]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[116029]=d;v[116026]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=464096,o=v[116024]&vka(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+464400|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=464100,o=v[116025]&vka(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;tH(b,l);return a}c=Md(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;pc(c,a,b>>>0>d>>>0?d:b);Jb(a);a=c}return a}function si(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=C(0),q=0,r=C(0);m=lb[v[v[a>>2]+140>>2]](a)|0;h=v[a+20>>2];g=m?g:w[h+25|0];j=z[h+144>>2];k=C(1);if(!(lb[v[v[a>>2]+140>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((lb[v[v[a>>2]+156>>2]](a)|0)<=0){break a}if(!RK(w[v[a+20>>2]+24|0])){break a}j=C(C(j+j)+C(-1));k=C(-j)}n=z[a+4196>>2];k=C(k*n);j=C(j*n);h=0;l=v[a+44>>2];m=Ec(l,0);l=Ec(l,1);b:{c:{switch(g&255){case 0:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(C(z[d+g>>2]*j)+C(k*z[g+m>>2]));i=c+g|0;z[i>>2]=z[i>>2]+C(C(z[e+g>>2]*j)+C(k*z[g+l>>2]));h=h+1|0;continue};case 1:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(z[g+m>>2]-C(z[d+g>>2]*j));i=c+g|0;z[i>>2]=z[i>>2]+C(z[g+l>>2]-C(z[e+g>>2]*j));h=h+1|0;continue};case 2:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(z[d+g>>2]-C(z[g+m>>2]*k));i=c+g|0;z[i>>2]=z[i>>2]+C(z[e+g>>2]-C(z[g+l>>2]*k));h=h+1|0;continue};case 3:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]-C(z[d+g>>2]-C(z[g+m>>2]*j));i=c+g|0;z[i>>2]=z[i>>2]-C(z[e+g>>2]-C(z[g+l>>2]*j));h=h+1|0;continue};case 4:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;k=z[i>>2];q=i;r=k;n=z[g+m>>2];i=c+g|0;o=z[i>>2];p=z[g+l>>2];k=C(C(C(C(k+n)+o)+p)*C(.5));z[q>>2]=r-C(C(k+C(k-C(z[d+g>>2]*j)))-n);z[i>>2]=o-C(C(k+C(k-C(z[e+g>>2]*j)))-p);h=h+1|0;continue};case 5:break c;default:break b}}h=RK(w[v[a+20>>2]+24|0]);j=h?C(j*C(.5)):j;k=h?C(k*C(.5)):k;g=0;while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;n=C(z[d+h>>2]-z[h+m>>2]);o=C(z[h+l>>2]-z[e+h>>2]);z[i>>2]=z[i>>2]+C(C(j*n)+C(k*o));h=c+h|0;z[h>>2]=z[h>>2]+C(C(k*n)+C(j*o));g=g+1|0;continue}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(lb[v[v[a>>2]+140>>2]](a)|0){break d}h=0;while(1){if((f|0)==(h|0)){break d}a=h<<2;d=a+b|0;z[d>>2]=z[a+m>>2]+z[d>>2];d=a+c|0;z[d>>2]=z[a+l>>2]+z[d>>2];h=h+1|0;continue}}}function Bja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=hb-1104|0;hb=d;v[d+1100>>2]=c;i=nB(d+40|0,b);q=wq(i);e=Lb(a);v[23516]=0;a=T(200,b|0)|0;c=v[23516];v[23516]=0;a:{if((c|0)!=1){v[d+8>>2]=a;v[d+36>>2]=85899345;s=d,z=B(v[Hb(d+8|0,d+36|0)>>2],50),v[s+24>>2]=z;a=v[Hb(d+1100|0,d+24|0)>>2];v[23516]=0;R(327,e|0,a|0);a=v[23516];v[23516]=0;if((a|0)!=1){v[23516]=0;h=T(339,d+24|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){v[23516]=0;f=Q(340,d+8|0,8192)|0;a=v[23516];v[23516]=0;b:{if((a|0)!=1){c=v[h>>2];a=0;while(1){if((a|0)!=256){g=Bb(c,a);t[g+2|0]=a;u[g>>1]=8192;a=a+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){r=m&255;e:{while(1){j=n&65535;while(1){v[23516]=0;o=Q(162,i|0,r|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(ad(v[e>>2],v[e+4>>2])>>>0>=y[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}a=j>>>0>k>>>0?o:g;c=v[h>>2];l=8192;while(1){a=a&65535;c=Bb(c,a);l=l-1|0;p=l&65535;s=Ib(v[f>>2],p),z=w[c+2|0],t[s|0]=z;c=v[h>>2];a=x[Bb(c,a)>>1];if(a>>>0<8192){continue}break}a=cc(d,Cb(v[e+4>>2]));c=Pf(Cb(v[f>>2]),p);l=Cb(v[f+4>>2]);a=v[a>>2];v[23516]=0;X(328,e|0,a|0,c|0,l|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=v[f>>2];v[23516]=0;R(341,e|0,Ib(a,p)|0);a=v[23516];v[23516]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(ad(v[e>>2],v[e+4>>2])>>>0>=y[d+1100>>2]){continue}break}a=w[Ib(v[f>>2],p)|0];c=Bb(v[h>>2],j);u[c>>1]=g;t[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<r)+m|0;n=a;continue}break}break}a=wq(i);v[23516]=0;Q(153,b|0,((a-q|0)+3&-4)+q|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}dc(f);lc(h);yb(i);hb=d+1104|0;return}a=P()|0;O()|0;dc(f);break b}a=P()|0;O()|0}lc(h);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}dc(e);yb(i);S(a|0);L()}function v4(a,b,c){a=a|0;b=C(b);c=c|0;var d=0,e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),k=C(0),m=0,n=0,o=0;d=hb-16|0;hb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(p(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=C(C(-1)/C(b*b));if(!(a&2147483647)){break e}e=C(C(b-b)/C(0));if((a|0)<0){break e}a=(p(C(b*C(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=C((a>>>23|0)+c|0);b=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));f=C(b*C(b*C(.5)));g=C(b/C(b+C(2)));h=C(g*g);i=C(h*h);e=b;b=(l(2,(p(C(b-f)),j(2))&-4096),q());f=C(C(g*C(f+C(C(h*C(C(i*C(.2849878668785095))+C(.6666666269302368)))+C(i*C(C(i*C(.24279078841209412))+C(.40000972151756287))))))+C(C(e-b)-f));b=C(C(k*C(.3010292053222656))+C(C(b*C(.434326171875))+C(C(f*C(.434326171875))+C(C(k*C(7.903415166765626e-7))+C(C(f+b)*C(-3168997136526741e-20))))))}e=b}b=C(e*C(2e3));if(!(C(D(b))<C(2147483648))){break c}a=~~b;break b;case 1:a=(B(v[a+24604>>2],100)|0)/128|0;break b;case 2:c=hb-16|0;hb=c;h:{i:{j:{k:{a=w[a+24648|0];if(a>>>0>=6){a=ba(8)|0;v[23516]=0;c=Q(53,c|0,5126)|0;d=v[23516];v[23516]=0;if((d|0)==1){break k}a=rc(a,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break i}d=P()|0;O()|0;wb(c);break j}hb=c+16|0;a=v[(a<<24>>24<<2)+62664>>2];break h}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}break b;case 3:v[d>>2]=0;m=v[a+24640>>2];c=hb-80|0;hb=c;a=v[a+24636>>2];v[c+40>>2]=a;v[c>>2]=m;n=c+40|0;o=v[Ne(n,c)>>2];l:{if((a|0)==v[Zp(n)+32>>2]){a=-1;if(v[Zp(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}v[d>>2]=a;hb=c+80|0;a=v[d>>2];break b;default:break d}}a=ba(8)|0;v[23516]=0;d=Q(53,d|0,10404)|0;c=v[23516];v[23516]=0;m:{if((c|0)!=1){a=rc(a,d);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}c=P()|0;O()|0;wb(d);break m}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}a=-2147483648}hb=d+16|0;return a|0}L()}function Lha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=hb-48|0;hb=c;a:{b:{c:{d:{e:{f:{g:{if(vd(v[a+24>>2])){break g}h=a+4|0;k=Fb(h);e=hb-32|0;hb=e;d=e+24|0;b=d;v[b>>2]=-1;v[b+4>>2]=-1;v[23516]=0;f=eF(37);b=v[23516];v[23516]=0;if((b|0)==1){break a}v[e+8>>2]=f;v[e+12>>2]=kb;g=hb-16|0;hb=g;i=e+8|0;b=i;l=g,m=rka(v[b>>2],v[b+4>>2],1e3,0),v[l>>2]=m;v[g+4>>2]=kb;f=ot(g+8|0,g);b=v[f+4>>2];hb=g+16|0;v[e+16>>2]=v[f>>2];v[e+20>>2]=b;b=e+16|0;l=e,m=pA(v[b>>2],v[b+4>>2]),v[l+16>>2]=m;v[e+20>>2]=kb;g=hS(d,b,Db(b));v[23516]=0;d=eF(38);f=v[23516];v[23516]=0;if((f|0)==1){break a}j=a+24|0;v[e+8>>2]=d;v[e+12>>2]=kb;d=hb-16|0;hb=d;a=v[i+4>>2];v[d>>2]=v[i>>2];v[d+4>>2]=a;f=ot(d+8|0,d);a=v[f+4>>2];hb=d+16|0;v[e+16>>2]=v[f>>2];v[e+20>>2]=a;l=e,m=pA(v[b>>2],v[b+4>>2]),v[l+16>>2]=m;v[e+20>>2]=kb;a=hS(g,b,Db(b));b=v[a>>2];a=v[a+4>>2];hb=e+32|0;if(k){d=Lb(c+32|0);v[23516]=0;v[c+16>>2]=a;R(31,d|0,c+16|0);a=v[23516];v[23516]=0;if((a|0)==1){break d}v[23516]=0;v[c+16>>2]=b;R(31,d|0,c+16|0);a=v[23516];v[23516]=0;if((a|0)==1){break e}a=0;h:{while(1){if(Fb(h)>>>0<=a>>>0){b=Cb(v[d>>2]);a=Cb(v[d+4>>2]);v[23516]=0;f=W(32,c+16|0,b|0,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break c}b=w[Jc(h,a)|0];v[23516]=0;v[c+16>>2]=b;R(31,d|0,c+16|0);b=v[23516];v[23516]=0;if((b|0)!=1){a=a+1|0;continue}break}a=P()|0;O()|0;break c}v[23516]=0;b=T(33,f|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){v[c+8>>2]=b;a=c+8|0;tA(j,a);co(a);wm(f);lc(d);break g}a=P()|0;O()|0;wm(f);break c}kb=b;v[c+16>>2]=a;v[c+20>>2]=kb;b=Lb(c+32|0);v[23516]=0;U(36,b|0,c+16|0,c+24|0);a=v[23516];v[23516]=0;if((a|0)==1){a=P()|0;O()|0;lc(b);S(a|0);L()}v[23516]=0;f=T(33,b|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break f}v[c+8>>2]=f;a=c+8|0;tA(j,a);co(a);wm(b)}hb=c+48|0;return}a=P()|0;O()|0;wm(b);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0}lc(d)}S(a|0);L()}V(0)|0;O()|0;Tb();L()}function q$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=hb-16|0;hb=j;k=Xu(g);o=tw(g);Wg(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23516]=0;g=Q(20,k|0,g<<24>>24)|0;i=v[23516];v[23516]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[23516]=0;g=Q(20,k|0,48)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[23516]=0;g=Q(20,k|0,g|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Dd();if(!JG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Dd();if(!Zj(h)){break d}g=g+1|0;continue}}e:{if(Pe(j)){h=v[f>>2];v[23516]=0;X(1151,k|0,i|0,g|0,h|0);h=v[23516];v[23516]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break e}Sl(i,g);v[23516]=0;q=T(1149,o|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Sl((i-a|0)+d|0,v[f>>2]);break e}f:{if(t[Jc(j,m)|0]<=0){break f}if(t[Jc(j,m)|0]!=(l|0)){break f}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;m=(Fb(j)-1>>>0>m>>>0)+m|0;l=0}p=t[h|0];v[23516]=0;p=Q(20,k|0,p|0)|0;n=v[23516];v[23516]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=w[g|0];if((i|0)!=46){break g}v[23516]=0;i=T(1152,o|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0}i=v[f>>2];v[23516]=0;X(1151,k|0,g|0,c|0,i|0);i=v[23516];v[23516]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;wb(j);hb=j+16|0;return}v[23516]=0;i=Q(20,k|0,i<<24>>24)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;continue}}a=P()|0;O()|0;wb(j);S(a|0);L()}function vO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;c=hb-176|0;hb=c;e=v[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=v[a+12>>2]}else{i=v[b>>2];h=Gd(i,e+l|0);d=Gd(i,e);o=A[h>>3];p=A[h+8>>3];ij(c+160|0,d,o,p);i=v[c+172>>2];v[h+8>>2]=v[c+168>>2];v[h+12>>2]=i;i=v[c+164>>2];v[h>>2]=v[c+160>>2];v[h+4>>2]=i;Wx(Gd(v[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){x=B(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=v[a>>2];e=Gd(d,j<<1);d=Gd(d,j);o=A[d>>3];p=A[d+8>>3];r=A[e>>3];s=A[e+8>>3];wi(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=v[b>>2];d=Gd(f,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=c+128|0;t=e+h|0;k=Gd(f,t);wi(g,r,s,A[k>>3],A[k+8>>3]);u=e+y|0;k=Gd(f,u);wi(c+112|0,o,p,A[k>>3],A[k+8>>3]);m=A[c+160>>3];n=A[c+168>>3];w=e+x|0;f=Gd(f,w);wi(c+96|0,m,n,A[f>>3],A[f+8>>3]);k=c+80|0;f=c+144|0;m=A[c+112>>3];n=A[c+120>>3];_k(k,f,m,n);q=c- -64|0;ij(q,f,m,n);m=A[c+96>>3];n=A[c+104>>3];_k(c+48|0,g,m,n);f=c+16|0;pm(f,-0,-1);ij(c,g,m,n);wi(c+32|0,A[c+16>>3],A[c+24>>3],A[c>>3],A[c+8>>3]);_k(f,k,A[c+48>>3],A[c+56>>3]);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;ij(f,k,A[c+48>>3],A[c+56>>3]);d=Gd(v[b>>2],t);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;_k(f,q,A[c+32>>3],A[c+40>>3]);d=Gd(v[b>>2],u);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;ij(f,q,A[c+32>>3],A[c+40>>3]);d=Gd(v[b>>2],w);f=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=f;f=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=f;e=e+1|0;continue}}}break}hb=c+176|0}function e6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-80|0;hb=e;v[e+76>>2]=c;v[e+72>>2]=b;a:{if(!c){break a}f=w[Xk(b,c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}cl(e+48|0,b,c,c-1|0);b=v[e+52>>2];v[e+72>>2]=v[e+48>>2];v[e+76>>2]=b}c=e+48|0;Rd(c);b=v[e+48>>2];Rd(e+32|0);b=Wk(b,v[e+36>>2],e+72|0);Rd(c);b:{c:{d:{e:{if((b|0)==v[e+52>>2]){b=v[e+72>>2];c=v[e+76>>2];a=qc(e- -64|0,21751);if(Mc(b,c,v[a>>2],v[a+4>>2])){a=ba(8)|0;v[23516]=0;b=Q(53,e+48|0,10501)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}b=0;c=0;if(!d){break e}b=ba(8)|0;v[23516]=0;d=Lh(e+32|0,v[e+72>>2],v[e+76>>2]);a=v[23516];v[23516]=0;f:{g:{h:{if((a|0)!=1){v[23516]=0;U(981,e+48|0,17766,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}a=0;c=rc(b,e+48|0);v[23516]=0;U(117,c|0,62944,970);c=v[23516];v[23516]=0;if((c|0)!=1){break b}c=P()|0;O()|0;wb(e+48|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}wb(d);if(!a){break c}}ca(b|0);break c}if(v[b+4>>2]!=1){a=ba(8)|0;v[23516]=0;b=Q(53,e+48|0,11620)|0;c=v[23516];v[23516]=0;if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}c=P()|0;O()|0;ca(a|0);break c}d=v[e+72>>2];f=v[e+76>>2];b=qc(e+24|0,21751);if(Mc(d,f,v[b>>2],v[b+4>>2])){a=ba(8)|0;v[23516]=0;b=Q(53,e+48|0,10501)|0;c=v[23516];v[23516]=0;if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}c=P()|0;O()|0;ca(a|0);break c}b=qc(e+16|0,10943);if(Mc(d,f,v[b>>2],v[b+4>>2])){a=v[a+8>>2];b=a;c=a>>31;break e}b=0;g=d;d=qc(e+8|0,8656);c=0;if(!Mc(g,f,v[d>>2],v[d+4>>2])){break e}b=_j(w[v[a+32>>2]+140|0]);c=0}hb=e+80|0;kb=c;return b|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function R5(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=hb+-64|0;hb=k;a:{b:{c:{j=tp(1,32);d:{e:{if(!j){a=An(ba(4)|0);v[23516]=0;U(117,a|0,92664,26);a=v[23516];v[23516]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:947;c=Xf(k+48|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[23516]=0;d=Q(53,k+32|0,d|0)|0;f=v[23516];v[23516]=0;j:{if((f|0)!=1){v[23516]=0;f=Q(958,c|0,d|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break j}v[23516]=0;Q(273,f|0,e|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;wb(d);break f}v[23516]=0;d=Q(53,k+16|0,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break g}ws(c,d)}wb(d);i=i+8|0;continue}}v[23516]=0;d=T(832,104)|0;e=v[23516];v[23516]=0;k:{l:{m:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[23516]=0;e=Q(959,f|0,e|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break m}v[k>>2]=e;e=v[dg(k+8|0,k)>>2];v[23516]=0;a=ga(990,d|0,a|0,b|0,e|0,c|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break k}i=V(0)|0;O()|0;ze(k);break l}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0}Jb(d);break f}v[j+28>>2]=a;ze(k);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;dl(c);break d}i=V(0)|0;O()|0}dl(c);_(i|0)|0;v[23516]=0;X(953,4976,j|0,g|0,h|0);a=v[23516];v[23516]=0;if((a|0)!=1){v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)!=1){a=v[j+28>>2];if(a){lb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Jb(a);v[j+20>>2]=0}Jb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[23516]=0;X(953,4976,0,g|0,h|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}$()}hb=k- -64|0;return j|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Tb()}L()}function ch(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Fb(c);v[23516]=0;R(46,a|0,d|0);d=v[23516];v[23516]=0;d:{if((d|0)!=1){e:{while(1){if(Fb(c)>>>0>b>>>0){d=t[gg(c,b)|0];v[23516]=0;R(47,a|0,((d|0)<0?65533:d&255)|0);d=v[23516];v[23516]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Kb(a);d=Fb(c);v[23516]=0;R(46,a|0,d|0);d=v[23516];v[23516]=0;f:{if((d|0)!=1){while(1){if(Fb(c)>>>0<=b>>>0){break f}d=w[gg(c,b)|0];v[23516]=0;R(47,a|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){b=b+1|0;continue}break}}break a}return;case 3:fl(a,c,49808);return;case 5:fl(a,c,50832);return;case 4:fl(a,c,51856);return;case 6:fl(a,c,52880);return;case 7:fl(a,c,53904);return;case 8:fl(a,c,54928);return;case 9:fl(a,c,55952);return;case 10:dz(a,c,56976);return;case 11:dz(a,c,49808);return;case 12:dz(a,c,53904);return;default:a=ba(8)|0;v[23516]=0;b=Q(43,a|0,11075)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}b=P()|0;O()|0;ca(a|0);S(b|0);L();case 0:break c}}e=hb-16|0;hb=e;f=Kb(a);g=e,h=et(c),v[g+8>>2]=h;g=e,h=dt(c),v[g>>2]=h;a=0;g:{h:{while(1){i:{if(!mj(e+8|0,e)){if(!a){break i}v[23516]=0;R(47,f|0,65533);a=v[23516];v[23516]=0;if((a|0)!=1){break i}break h}b=w[v[e+8>>2]];j:{k:{if(!a){if(!(b&128)){a=0;v[23516]=0;R(47,f|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break j}break h}if((b&224)==192){d=b&31;a=1;break j}if((b&240)==224){d=b&15;a=2;break j}d=65533;if((b&248)!=240){break k}d=b&7;a=3;break j}if((b&192)!=128){d=0;v[23516]=0;R(47,f|0,65533);c=v[23516];v[23516]=0;a=0;if((c|0)==1){break h}}d=b&63|d<<6;a=a-1|0;if(a){break j}}a=0;v[23516]=0;R(47,f|0,d|0);b=v[23516];v[23516]=0;d=0;if((b|0)==1){break h}}He(e+8|0);continue}break}hb=e+16|0;break g}a=P()|0;O()|0;Yc(f);S(a|0);L()}return}ia(b|0,92784,25);L()}b=P()|0;O()|0;Yc(a);S(b|0);L()}function eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;g=hb-48|0;hb=g;p=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;v[i+4>>2]=v[e+44>>2];v[i+8>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;D=v[a+8>>2];E=v[a+12>>2];while(1){if(d){f=v[g+16>>2];l=((((v[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=u[b+14>>1];h=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];o=u[b+6>>1];F=u[b+4>>1];G=u[b+2>>1];H=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=l+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((((B(u[b+8>>1],m)+B(u[b+4>>1],n)|0)+B(h,u[b+12>>1])|0)+B(j,u[b+16>>1])|0)/2|0)+((((B(u[b-8>>1],G)+B(u[b-12>>1],H)|0)+B(u[b-4>>1],F)|0)+B(u[b>>1],o)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=v[l>>2];b=(g+24|0)+(f<<3)|0;j=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;m=e<<8;e=m;e=rka(A,C,e,e>>31);n=kb;o=b;b=Wb(h,-16777216,16776704);h=rka(y,z,b,b>>31);e=h+e|0;b=kb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Wb(j,-16777216,16776704);j=rka(w,x,e,e>>31);e=h+j|0;b=kb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Tc(e,b,24);v[o+4>>2]=b-(m&t);v[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);i=i+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],i>>12);Pb(g+16|0,D,E);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}hb=g+48|0}function dk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{if(!d){break a}g=v[c>>2];if(!g){break a}b:{c:{d:{e:{f=v[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=B(d,20)+g|0;break d}f=((B(d,36318)|0)/1024|0)+g|0;break d}f:{g:{h:{if(w[a+480208|0]&16){if((f|0)==4){break h}f=d>>31;v[i+12>>2]=(f^d)-f;uc(i+12|0,1020);h=v[i+12>>2];i:{if((d|0)>0){if(h>>>0<=15){f=hb-16|0;hb=f;Ab(f+8|0,a+1074312|0,7);j=zb(v[v[f+8>>2]>>2],v[f+12>>2]);hb=f+16|0;h=v[(h<<2)+(j?37184:37248)>>2];break i}f=hb-16|0;hb=f;Ab(f+8|0,a+1074312|0,7);j=zb(v[v[f+8>>2]>>2],v[f+12>>2]);hb=f+16|0;h=v[(h>>>2<<2)+(j?37312:38336)>>2];break i}if(h>>>0<=15){f=hb-16|0;hb=f;Ab(f+8|0,a+1074312|0,7);j=zb(v[v[f+8>>2]>>2],v[f+12>>2]);hb=f+16|0;h=v[(h<<2)+(j?37248:37184)>>2];break i}f=hb-16|0;hb=f;Ab(f+8|0,a+1074312|0,7);j=zb(v[v[f+8>>2]>>2],v[f+12>>2]);hb=f+16|0;h=v[(h>>>2<<2)+(j?38336:37312)>>2]}h=rka(h,h>>31,g,g>>31)+32768|0;f=kb;f=Dc(ska(h,h>>>0<32768?f+1|0:f,65536,0),kb);v[c>>2]=f;if((f|0)!=(g|0)){break c}Ab(i,a+1074312|0,7);g=v[c>>2];if(!(zb(v[v[i>>2]>>2],v[i+4>>2])^(d|0)>0)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}Ab(i,a+1074312|0,7);if(zb(v[v[i>>2]>>2],v[i+4>>2])){break g}g=v[c>>2]}f=g-d|0;break d}f=v[c>>2];if((d|0)<0){g=rka(f,0,14317456,0);h=kb;f=rka(f,0,0-d|0,0)+14317456|0;d=kb;f=$M(uka(g,h,f,f>>>0<14317456?d+1|0:d),kb);break d}d=rka(f,f>>31,d,0);g=kb;if((g|0)>=0&d>>>0>=14317456|(g|0)>0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}d=$M(uka(rka(f,0,14317456,0),kb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),kb);v[c>>2]=d;if((d|0)>0){break a}break b}f=d+g|0}v[c>>2]=f}if((f|0)>0){break a}}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}hb=i+16|0}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=hb-48|0;hb=g;p=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;v[i+4>>2]=v[e+44>>2];v[i+8>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+32>>2];s=v[a+28>>2];w=v[a+72>>2];b=v[a+68>>2];x=b;y=b>>31;b=v[a+64>>2];z=b;A=b>>31;b=v[a+60>>2];C=b;D=b>>31;E=v[a+8>>2];F=v[a+12>>2];while(1){if(d){f=v[g+16>>2];l=(((v[g+20>>2]&2147483647)<<1|f>>>31)&-2)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=u[b+14>>1];h=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];o=u[b+6>>1];G=u[b+4>>1];H=u[b+2>>1];I=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+l|0;v[(g+8|0)+(e<<2)>>2]=(((((B(t[b+4|0],m)+B(t[b+2|0],n)|0)+B(h,t[b+6|0])|0)+B(j,t[b+8|0])<<8)/2|0)+((((B(t[b-4|0],H)+B(t[b-6|0],I)|0)+B(t[b-2|0],G)|0)+B(t[b|0],o)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=v[l>>2];b=(g+24|0)+(f<<3)|0;j=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;m=e<<8;e=m;e=rka(C,D,e,e>>31);n=kb;o=b;b=Wb(h,-16777216,16776704);h=rka(z,A,b,b>>31);e=h+e|0;b=kb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Wb(j,-16777216,16776704);j=rka(x,y,e,e>>31);e=h+j|0;b=kb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Tc(e,b,24);v[o+4>>2]=b-(m&w);v[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);i=i+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],i>>12);Pb(g+16|0,E,F);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}hb=g+48|0}function c6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=hb-80|0;hb=f;v[f+76>>2]=d;v[f+72>>2]=c;a:{if(!d){break a}g=w[Xk(c,d)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}cl(f+48|0,c,d,d-1|0);c=v[f+52>>2];v[f+72>>2]=v[f+48>>2];v[f+76>>2]=c}c=f+48|0;Rd(c);d=v[f+48>>2];Rd(f+32|0);g=Wk(d,v[f+36>>2],f+72|0);Rd(c);c=v[f+76>>2];d=v[f+72>>2];b:{c:{d:{e:{if((g|0)==v[f+52>>2]){b=qc(f- -64|0,21751);if(Mc(d,c,v[b>>2],v[b+4>>2])){a=ba(8)|0;v[23516]=0;b=Q(53,f+48|0,10501)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}d=P()|0;O()|0;wb(b);break c}if(e){b=ba(8)|0;v[23516]=0;c=Lh(f+32|0,v[f+72>>2],v[f+76>>2]);a=v[23516];v[23516]=0;f:{g:{h:{if((a|0)!=1){v[23516]=0;U(981,f+48|0,17766,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}a=0;d=rc(b,f+48|0);v[23516]=0;U(117,d|0,62944,970);d=v[23516];v[23516]=0;if((d|0)!=1){break b}d=P()|0;O()|0;wb(f+48|0);break g}d=P()|0;O()|0;break f}d=P()|0;a=1;O()|0}wb(c);if(!a){break c}}ca(b|0);break c}Kb(a);break e}e=qc(f+24|0,21751);if(Mc(d,c,v[e>>2],v[e+4>>2])){a=ba(8)|0;v[23516]=0;b=Q(53,f+48|0,10501)|0;c=v[23516];v[23516]=0;if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}d=P()|0;O()|0;wb(b);break c}d=P()|0;O()|0;ca(a|0);break c}e=qc(f+16|0,12389);if(Mc(d,c,v[e>>2],v[e+4>>2])){i:{switch(v[b+52>>2]){case 0:Fc(a,5604);break e;case 1:Fc(a,11321);break e;case 2:Fc(a,9235);break e;default:break i}}Kb(a);break e}e=c;c=qc(f+8|0,11558);if(Mc(d,e,v[c>>2],v[c+4>>2])){j:{switch(v[b+56>>2]){case 0:Fc(a,15693);break e;case 1:Fc(a,15698);break e;case 2:Fc(a,12663);break e;case 3:Fc(a,9299);break e;default:break j}}Kb(a);break e}Kb(a)}hb=f+80|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function WJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=hb+-64|0;hb=k;a:{b:{c:{d:{e:{f:{j=tp(1,28);if(!j){a=An(ba(4)|0);v[23516]=0;U(117,a|0,92664,26);a=v[23516];v[23516]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:947;c=Xf(k+48|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[23516]=0;d=Q(53,k+32|0,d|0)|0;f=v[23516];v[23516]=0;k:{if((f|0)!=1){v[23516]=0;f=Q(958,c|0,d|0)|0;l=v[23516];v[23516]=0;if((l|0)==1){break k}v[23516]=0;Q(273,f|0,e|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;wb(d);break g}v[23516]=0;d=Q(53,k+16|0,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break h}ws(c,d)}wb(d);i=i+8|0;continue}}v[23516]=0;d=T(832,80)|0;e=v[23516];v[23516]=0;l:{m:{n:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[23516]=0;e=Q(959,f|0,e|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break n}v[k>>2]=e;e=v[dg(k+8|0,k)>>2];v[23516]=0;a=ga(964,d|0,a|0,b|0,e|0,c|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break l}i=V(0)|0;O()|0;ze(k);break m}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0}Jb(d);break g}v[j+24>>2]=a;ze(k);dl(c);i=j;break d}i=V(0)|0;O()|0}dl(c);_(i|0)|0;v[23516]=0;X(953,15188,j|0,g|0,h|0);a=v[23516];v[23516]=0;if((a|0)!=1){v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Jb(vs(a))}i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Jb(a);v[j+20>>2]=0}Jb(j);break d}i=V(0)|0;O()|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[23516]=0;X(953,15188,0,g|0,h|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}$()}hb=k- -64|0;return i|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Tb()}L()}function z_(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=hb-1072|0;hb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+960|0;v[a+956>>2]=j;j=xw(j,100,11138,a+16|0);v[a+48>>2]=1140;k=a+48|0;o=pe(a+536|0,0,k);v[a+48>>2]=1140;k=pe(a+528|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+544|0;f=a+960|0;break d}j=Dd();v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;j=Ui(a+956|0,j,11138,a);if((j|0)!=-1){f=v[a+956>>2];Xe(o,f);Xe(k,Md(j<<2));h=v[k>>2];if(!gk(h)){break d}}v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)!=1){break a}j=P()|0;O()|0;break c}g=a+520|0;bd(g,d);v[23516]=0;q=T(1153,g|0)|0;g=v[23516];v[23516]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}v[23516]=0;X(1165,q|0,f|0,f+j|0,h|0);g=v[23516];v[23516]=0;if((g|0)==1){break j}p=(j|0)>0?w[f|0]==45:p;i=Kb(a+488|0);f=Kb(a+472|0);g=Kb(a+456|0);v[23516]=0;na(1192,c|0,p|0,a+520|0,a+512|0,a+508|0,a+504|0,i|0,f|0,g|0,a+452|0);c=v[23516];v[23516]=0;if((c|0)==1){break i}v[a+36>>2]=1140;c=pe(a+40|0,0,a+36|0);m=a+48|0;n=v[a+452>>2];k:{if((n|0)<(j|0)){l=((Fb(g)+(j-n<<1)|0)+Fb(f)|0)+1|0;break k}l=(Fb(g)+Fb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Xe(c,Md(l<<2));m=v[c>>2];if(m){break h}v[23516]=0;Z(1141);b=v[23516];v[23516]=0;if((b|0)!=1){break a}break g}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[23516]=0;pa(1193,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,q|0,p|0,a+512|0,v[a+508>>2],v[a+504>>2],i|0,f|0,g|0,n|0);h=v[23516];v[23516]=0;if((h|0)!=1){v[23516]=0;b=ka(1174,b|0,m|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break b}}}j=P()|0;O()|0;Sc(c)}Yc(g);Yc(f);wb(i)}Zb(a+520|0)}Sc(k);Sc(o);S(j|0);L()}Sc(c);Yc(g);Yc(f);wb(i);Zb(a+520|0);Sc(k);Sc(o);hb=a+1072|0;return b|0}L()}function hg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;i=w[a+79|0]?x[v[a>>2]+3836>>1]:i;b=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:c=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=c;c=x[a+46>>1];f=b+(c?g&c?0:f:f)|0;u[a+20>>1]=f;c=2;h=x[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;f=x[v[a>>2]+3832>>1];h=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=b+(f?g&f?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B((b^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=b+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>0){break b}}v[a+16>>2]=c;u[a+20>>1]=h}i=((b+l|0)+m|0)+i<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+28576>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+28576>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+28576>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+28576>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+28576>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+28576>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];e=a;a=b+i&65535;a=a>>>0<8191?a:8191;c=0-d^x[((a&255)<<1)+28064>>1]+1024>>>(a>>>8)<<1;u[e+72>>1]=c}return c<<16>>16}function yR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=w[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){t[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:t[a+2|0]=4;c=c&15;break b;case 1:t[a+2|0]=3;c=c&15;break b;case 2:t[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;c=c&15}t[a+4|0]=c}e=w[b+4|0];d=w[b+5|0];c=w[b+6|0];d:{if(!(c?1:e|d)){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}t[a+2|0]=15;t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;h=a,i=w[Vb(b+5|0,f+15|0)|0]|208,t[h+5|0]=i;break d;case 0:Nf(a,c,d);g=w[b+6|0]==15;break d;case 1:t[a+3|0]=2;h=a,i=rg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 2:t[a+3|0]=3;h=a,i=rg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 3:t[a+3|0]=4;h=a,i=rg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 4:t[a+3|0]=5;t[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){t[a+5|0]=d;t[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d;case 12:t[a+3|0]=13;t[a+5|0]=c>>>1;break d;case 15:if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}JA(a,c,d,1);g=(w[a+3|0]&254)==16;break d}t[a+5|0]=d;t[a+3|0]=18;break d}t[a+3|0]=31;t[a+5|0]=c>>>1;break d}t[a+3|0]=31;t[a+5|0]=c>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=c>>>2}b=w[b+3|0];l:{if(!b){break l}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break l}if(w[a+2|0]){break l}t[a+2|0]=2;t[a+4|0]=b>>>2}hb=f+16|0;return g}function Rp(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);me(e+12|0,0,127);me(e+8|0,0,127);k=a+1074312|0;Ab(e,k,1);j=v[e+12>>2];a:{if(zb(v[v[e>>2]>>2],v[e+4>>2])){i=v[e+8>>2];break a}u[b+780>>1]=0;t[b+837|0]=j;i=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=i}Ab(e,k,36);l=B(j,d+256|0);m=(l|0)/256|0;b:{if(!(!zb(v[v[e>>2]>>2],v[e+4>>2])|i|(l|0)<65024)){m=-1;if(!Wc(w[b+788|0])){break b}if(mm(w[b+790|0],w[b+791|0])|x[b+786>>1]|!(w[b+851|0]&2)){break b}v[b+88>>2]=v[b+88>>2]&-32769;break b}v[b+88>>2]=v[b+88>>2]|32768;f=qe(C(10),C(C(0-i|0)*C(.00937500037252903)));i=hb-16|0;hb=i;g=C(B(j,d+256|0)>>>0);c:{if(v[a+480180>>2]!=33554432){h=C(110);g=C(C(g/(w[a+480209|0]&128?C(10240):C(12288)))+C(.25));break c}h=C(125);g=C(C(g*C(6))/C(65024))}n=i,o=Sh(C(qe(C(2),g)*h)),v[n+12>>2]=o;me(i+12|0,120,2e4);d=v[i+12>>2];j=v[a+24620>>2];hb=i+16|0;Ab(e,k,36);g=C(C(((j|0)<d<<1?j>>>1|0:d)>>>0)*C(6.2831854820251465));d:{if(!(!zb(v[v[e>>2]>>2],v[e+4>>2])|v[a+480208>>2]&32768)){h=C(C(y[a+24620>>2])/g);g=C(C(C(f*h)+f)+C(-1));z[e>>2]=g;f=C(h*h);break d}h=C(f+f);f=C(g/C(y[a+24620>>2]));z[e>>2]=C(C(1)-h)*f;ON(e,C(2));g=C(C(h-z[e>>2])/f);z[e>>2]=g;f=C(C(1)/C(f*f))}h=C(f+C(g+C(1)));g=C(C(f+C(f+g))/h);f=C(C(-f)/h);h=C(C(1)/h);e:{if(w[b+845|0]==1){n=b,o=Sh(C(C(C(1)-h)*C(16777216))),v[n+60>>2]=o;n=b,o=Sh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Sh(C(f*C(16777216))),v[n+68>>2]=o;a=-1;break e}d=Sh(C(h*C(16777216)));v[b+60>>2]=d;n=b,o=Sh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Sh(C(f*C(16777216))),v[n+68>>2]=o;a=0;if(d){break e}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break b}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}hb=e+16|0;return m}function D_(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=hb-464|0;hb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+352|0;v[a+348>>2]=j;j=xw(j,100,11138,a+16|0);v[a+48>>2]=1140;k=a+48|0;o=pe(a+232|0,0,k);v[a+48>>2]=1140;k=pe(a+224|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+240|0;f=a+352|0;break d}j=Dd();v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;j=Ui(a+348|0,j,11138,a);if((j|0)!=-1){f=v[a+348>>2];Xe(o,f);Xe(k,Md(j));h=v[k>>2];if(!gk(h)){break d}}v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)!=1){break a}j=P()|0;O()|0;break c}g=a+216|0;bd(g,d);v[23516]=0;q=T(19,g|0)|0;g=v[23516];v[23516]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}v[23516]=0;X(1151,q|0,f|0,f+j|0,h|0);g=v[23516];v[23516]=0;if((g|0)==1){break j}p=(j|0)>0?w[f|0]==45:p;i=Kb(a+192|0);f=Kb(a+176|0);g=Kb(a+160|0);v[23516]=0;na(1190,c|0,p|0,a+216|0,a+208|0,a+207|0,a+206|0,i|0,f|0,g|0,a+156|0);c=v[23516];v[23516]=0;if((c|0)==1){break i}v[a+36>>2]=1140;c=pe(a+40|0,0,a+36|0);m=a+48|0;n=v[a+156>>2];k:{if((n|0)<(j|0)){l=((Fb(g)+(j-n<<1)|0)+Fb(f)|0)+1|0;break k}l=(Fb(g)+Fb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Xe(c,Md(l));m=v[c>>2];if(m){break h}v[23516]=0;Z(1141);b=v[23516];v[23516]=0;if((b|0)!=1){break a}break g}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[23516]=0;pa(1191,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,q|0,p|0,a+208|0,t[a+207|0],t[a+206|0],i|0,f|0,g|0,n|0);h=v[23516];v[23516]=0;if((h|0)!=1){v[23516]=0;b=ka(15,b|0,m|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break b}}}j=P()|0;O()|0;Sc(c)}wb(g);wb(f);wb(i)}Zb(a+216|0)}Sc(k);Sc(o);S(j|0);L()}Sc(c);wb(g);wb(f);wb(i);Zb(a+216|0);Sc(k);Sc(o);hb=a+464|0;return b|0}L()}function $L(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;e=B(b,872)+a|0;j=e+1074992|0;a:{b:{i=v[e+1075080>>2];if(i&131072){h=a+480180|0;e=v[h>>2];i=1;c:{d:{e:{f=v[a+480208>>2];if(f&4096){if(!(e&16777248)){break e}i=!(f&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}if(!i){break c}Ab(g+8|0,a+1074312|0,21);if(!zb(v[v[g+8>>2]>>2],v[g+12>>2])){break c}e=B(b,872)+a|0;f=e+1075811|0;t[f|0]=w[f|0]+(w[e+1075815|0]<<2)}f=B(b,872)+a|0;k=f+1075814|0;l=f+1075811|0;e=gy(a,w[k|0],w[l|0]);f:{if(uj(v[j+656>>2])){z[d>>2]=z[d>>2]+C(C(C(B(w[f+1075816|0],e)|0)*C(.05000000074505806))/C(7680));c=f+1075843|0;d=w[c|0];t[c|0]=d&159|64;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break f}t[c|0]=d|96;break f}d=v[a+480208>>2];if((d&2101248)==2101248){break a}f=v[h>>2];if(d&4096?f&67633152:0){break a}e=f&5?(w[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;Ab(g+8|0,k,21);f=v[a+480208>>2];g:{if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){d=f&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(f&131072){break h}h=v[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?f&4?6:7:6}Ab(g+8|0,k,80);if(!zb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=(0-B(w[(B(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0;dk(a,j,c,d,0);e=v[j+656>>2];c=Kp(a,v[j+88>>2],e);if(!c){break f}lb[v[v[c>>2]+92>>2]](c,d,(e?t[e+33|0]:2)<<24>>24,b)}if(!i){break a}Ab(g+8|0,a+1074312|0,21);if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}t[l|0]=w[l|0]+w[(B(b,872)+a|0)+1075815|0];break a}if(!(w[e+1075662|0]&2)){break a}a=Kp(a,i,v[j+656>>2]);if(!a){break a}lb[v[v[a>>2]+92>>2]](a,0,0,b);break a}a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1}hb=g+16|0}function _Q(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=hb-16|0;hb=l;a:{if((c|0)==(g|0)){f=fc(l+8|0,f,c);g=hb-16|0;hb=g;d=ll(d,e,b,c);v[g+12>>2]=d;b:{if((d|0)<=0){d=v[f>>2];break b}c:{if(!c){c=v[f>>2];break c}k=32-c|0;v[g+8>>2]=k;e=d;d=v[od(g+8|0,g+12|0)>>2];v[g+12>>2]=e-d;e=v[f>>2];c=-1<<c&-1>>>k-d;v[e>>2]=v[e>>2]&(c^-1)|c&v[b>>2];c=d+v[f+4>>2]|0;v[f+4>>2]=c&31;c=e+(c>>>3&536870908)|0;v[f>>2]=c;b=b+4|0;d=v[g+12>>2]}k=c;e=(d|0)/32|0;c=e<<2;dj(k,b,c);e=d-(e<<5)|0;v[g+12>>2]=e;d=c+v[f>>2]|0;v[f>>2]=d;if((e|0)<=0){break b}e=-1>>>32-e|0;v[d>>2]=v[d>>2]&(e^-1)|e&v[b+c>>2];v[f+4>>2]=v[g+12>>2]}fc(a,d,v[f+4>>2]);hb=g+16|0;break a}k=a;g=fc(l,f,g);f=hb-16|0;hb=f;d=ll(d,e,b,c);v[f+12>>2]=d;d:{if((d|0)<=0){a=v[g+4>>2];break d}e:{if(!c){a=v[g+4>>2];break e}i=32-c|0;v[f+8>>2]=i;a=d;e=f+8|0;d=v[od(e,f+12|0)>>2];v[f+12>>2]=a-d;a=v[g+4>>2];j=v[b>>2];v[f+8>>2]=d;m=32-a|0;v[f+4>>2]=m;h=v[g>>2];n=v[h>>2];e=v[Hb(e,f+4|0)>>2];i=j&(-1<<c&-1>>>i-d);v[h>>2]=(-1<<a&-1>>>m-e^-1)&n|(a>>>0>c>>>0?i<<a-c:i>>>c-a|0);j=a+e|0;a=j&31;v[g+4>>2]=a;h=h+(j>>>3&536870908)|0;v[g>>2]=h;d=d-e|0;if((d|0)>0){v[h>>2]=v[h>>2]&(-1>>>32-d^-1)|i>>>c+e;v[g+4>>2]=d;a=d}b=b+4|0;d=v[f+12>>2]}e=32-a|0;h=-1<<a;i=h^-1;while(1){if((d|0)>=32){c=v[g>>2];d=v[b>>2];v[c>>2]=i&v[c>>2]|d<<a;v[g>>2]=c+4;v[c+4>>2]=h&v[c+4>>2]|d>>>e;d=v[f+12>>2]-32|0;v[f+12>>2]=d;b=b+4|0;continue}break}if((d|0)<=0){break d}i=v[b>>2];v[f+8>>2]=e;c=v[g>>2];b=v[c>>2];j=b;b=v[od(f+12|0,f+8|0)>>2];j=j&(h&-1>>>e-b^-1);e=i&-1>>>32-d;v[c>>2]=j|e<<a;d=a+b|0;a=d&31;v[g+4>>2]=a;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<=0){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|e>>>b;a=v[f+12>>2];v[g+4>>2]=a}fc(k,v[g>>2],a);hb=f+16|0}hb=l+16|0}function iZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=hb-16|0;hb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!w[j|0]){break a}j=j+1|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=v[b+4>>2];v[r+8>>2]=v[b>>2];v[r+12>>2]=i;s=hb-16|0;hb=s;u=ji(s+8|0,v[a+8>>2]);m=j-c|0;k=0;o=0;n=hb-1040|0;hb=n;i=v[e>>2];v[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=wG(p,n+12|0,l>>>0>q>>>0?q:l,b);if((q|0)==-1){k=-1;l=0;i=v[n+12>>2];break g}t=(n+16|0)==(p|0)?0:q;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=v[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=Lr(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}v[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){v[e>>2]=o}hb=n+1040|0;ii(u);hb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{v[h>>2]=f;if(v[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=vF(f,c,j-c|0,r+8|0,v[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}v[e>>2]=c;break n}g=b}c=c+g|0;f=v[h>>2]+4|0;continue}break}v[e>>2]=c;break d}f=v[h>>2]+(k<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break k}c=v[e>>2];if((d|0)==(j|0)){j=d;continue}if(!vF(f,c,1,b,v[a+8>>2])){break m}}a=2;break c}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!w[j|0]){break b}j=j+1|0;continue}}v[e>>2]=c;a=1;break c}c=v[e>>2]}a=(c|0)!=(d|0)}hb=r+16|0;return a|0}f=v[h>>2];continue}}function Jr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=hb-128|0;hb=i;v[i+120>>2]=b;k=sG(c,d);v[i+4>>2]=1140;m=rG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Md(k);if(!j){v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Xe(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[23516]=0;h=Q(1142,a|0,i+120|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[23516]=0;b=Q(1143,a|0,i+120|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[23516]=0;n=T(1144,b|0)|0;b=v[23516];v[23516]=0;g:{if((b|0)!=1){if(g){break g}v[23516]=0;n=Q(1145,e|0,n|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[23516]=0;T(1146,a|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Fb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=t[gg(b,o)|0];j:{if(g){break j}v[23516]=0;p=Q(1145,e|0,p<<24>>24)|0;s=v[23516];v[23516]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n&255)==(p&255)){r=1;if((Fb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Sc(m);hb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Pe(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Sc(m);S(b|0)}L()}function wi(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!Uh(p)){break a}if(!Uh(m)){break a}h=gf(b);f=gf(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=Uh(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=Uh(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=gf(d);f=gf(e);b:{if(f?1:h){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Uh(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Uh(c),w?u:v);break b}if(k){break b}c:{if(gf(s)){break c}if(gf(t)){break c}if(gf(r)){break c}if(!gf(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Uh(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Uh(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=Uh(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=Uh(e),w?u:v)}m=(b*e+d*c)*N;p=(b*d-e*c)*N}pm(a,p,m)}function K9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=hb-224|0;hb=c;e=Rl(c+112|0,a);v[23516]=0;d=Q(458,c+96|0,43982)|0;a=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[23516]=0;v[c+80>>2]=19988497;v[c+84>>2]=0;U(459,e|0,d|0,c+80|0);a=v[23516];v[23516]=0;if((a|0)==1){break n}Ub(d);if(Ek(w[e|0])){break e}v[23516]=0;d=Q(458,c+80|0,13375)|0;a=v[23516];v[23516]=0;if((a|0)==1){break m}v[23516]=0;X(490,e|0,b|0,d|0,891);a=v[23516];v[23516]=0;if((a|0)==1){break l}Ub(d);v[c+76>>2]=0;v[c+72>>2]=0;v[23516]=0;d=Q(458,c+56|0,16847)|0;a=v[23516];v[23516]=0;if((a|0)==1){break k}v[23516]=0;U(892,e|0,c+76|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break j}Ub(d);v[23516]=0;d=Q(458,c+40|0,16819)|0;a=v[23516];v[23516]=0;if((a|0)==1){break i}v[23516]=0;U(892,e|0,c+72|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}Ub(d);a=v[c+76>>2];d=v[c+72>>2];o:{if(!a|d>>>0<a>>>0){break o}f=v[v[v[v[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}v[b+20>>2]=d;v[b+16>>2]=a}d=Lb(c+24|0);v[23516]=0;f=Q(458,c+8|0,14208)|0;a=v[23516];v[23516]=0;if((a|0)==1){break d}v[23516]=0;U(893,e|0,d|0,f|0);a=v[23516];v[23516]=0;if((a|0)==1){break g}Ub(f);if(nc(v[d>>2],v[d+4>>2])){break f}a=v[b+16>>2];v[23516]=0;R(846,d|0,a|0);a=v[23516];v[23516]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ub(d);break a}a=P()|0;O()|0;Ub(f);break b}v[23516]=0;R(894,b|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}lc(d)}fh(e);hb=c+224|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}lc(d)}fh(e);S(a|0);L()}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=hb-48|0;hb=g;o=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;v[j+4>>2]=v[e+44>>2];v[j+8>>2]=v[e+48>>2];f=f+1|0;continue}break}j=v[a+24>>2];p=v[a+20>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){f=v[g+16>>2];k=((((v[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=u[b+14>>1];h=u[b+12>>1];l=u[b+10>>1];m=u[b+8>>1];n=u[b+6>>1];D=u[b+4>>1];E=u[b+2>>1];F=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=k+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((((B(u[b+8>>1],l)+B(u[b+4>>1],m)|0)+B(h,u[b+12>>1])|0)+B(i,u[b+16>>1])|0)/2|0)+((((B(u[b-8>>1],E)+B(u[b-12>>1],F)|0)+B(u[b-4>>1],D)|0)+B(u[b>>1],n)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=v[k>>2];b=(g+24|0)+(f<<3)|0;i=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;l=e<<8;e=l;e=rka(y,z,e,e>>31);m=kb;n=b;b=Wb(h,-16777216,16776704);h=rka(w,x,b,b>>31);e=h+e|0;b=kb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Wb(i,-16777216,16776704);i=rka(s,t,e,e>>31);e=h+i|0;b=kb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Tc(e,b,24);v[n+4>>2]=b-(l&r);v[k>>2]=(b|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],p);v[c+4>>2]=v[c+4>>2]+B(j,v[g+12>>2]);Pb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}hb=g+48|0}function Hr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=hb-128|0;hb=i;v[i+120>>2]=b;k=sG(c,d);v[i+4>>2]=1140;m=rG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Md(k);if(!j){v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Xe(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[23516]=0;h=Q(1158,a|0,i+120|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[23516]=0;b=Q(1159,a|0,i+120|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[23516]=0;n=T(1160,b|0)|0;b=v[23516];v[23516]=0;g:{if((b|0)!=1){if(g){break g}v[23516]=0;n=Q(1161,e|0,n|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[23516]=0;T(1162,a|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Fb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=v[oj(b,o)>>2];j:{if(g){break j}v[23516]=0;p=Q(1161,e|0,p|0)|0;s=v[23516];v[23516]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n|0)==(p|0)){r=1;if((Fb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Sc(m);hb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Pe(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Sc(m);S(b|0)}L()}function j6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb+-64|0;hb=d;f=1;a:{if(Pe(c)){break a}e=w[tJ(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+48|0;Fv(e,c,0,Fb(c)-1|0);yc(c,e);wb(e)}e=d+48|0;Rd(e);g=v[d+48>>2];Rd(d+40|0);g=sJ(g,v[d+44>>2],c);Rd(e);b:{c:{d:{e:{f:{if((g|0)==v[d+52>>2]){if(re(c,21751)){a=ba(8)|0;v[23516]=0;b=Q(53,d+48|0,10501)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}if(!f){break f}a=ba(8)|0;v[23516]=0;U(972,d+48|0,17766,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){a=rc(a,d+48|0);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(d+48|0);break c}c=P()|0;O()|0;ca(a|0);break c}e=Kb(d+48|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:Be(d+32|0,c);v[23516]=0;b=fa(973,b|0,v[d+32>>2],v[d+36>>2],f|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){v[23516]=0;t[d+40|0]=b;R(974,a|0,d+40|0);a=v[23516];v[23516]=0;if((a|0)!=1){break g}}break i;case 1:Be(d+24|0,c);v[23516]=0;b=gF(b,v[d+24>>2],v[d+28>>2],f);c=kb;f=v[23516];v[23516]=0;if((f|0)!=1){v[23516]=0;v[d+40>>2]=b;v[d+44>>2]=c;R(976,a|0,d+40|0);a=v[23516];v[23516]=0;if((a|0)!=1){break g}}break i;case 2:Be(d+16|0,c);v[23516]=0;h=+za(977,b|0,v[d+16>>2],v[d+20>>2],f|0);b=v[23516];v[23516]=0;if((b|0)!=1){v[23516]=0;A[d+40>>3]=h;R(978,a|0,d+40|0);a=v[23516];v[23516]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}Be(d+8|0,c);v[23516]=0;da(979,a|0,b|0,v[d+8>>2],v[d+12>>2],f|0);a=v[23516];v[23516]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;wb(e);break c}Xc(a,e)}wb(e);break e}Kb(a)}hb=d- -64|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;g=hb-48|0;hb=g;o=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;v[j+4>>2]=v[e+44>>2];v[j+8>>2]=v[e+48>>2];f=f+1|0;continue}break}j=v[a+24>>2];p=v[a+20>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+72>>2];b=v[a+68>>2];s=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){if(d){f=v[g+16>>2];k=(((v[g+20>>2]&2147483647)<<1|f>>>31)&-2)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=u[b+14>>1];h=u[b+12>>1];l=u[b+10>>1];m=u[b+8>>1];n=u[b+6>>1];E=u[b+4>>1];F=u[b+2>>1];G=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+k|0;v[(g+8|0)+(e<<2)>>2]=(((((B(t[b+4|0],l)+B(t[b+2|0],m)|0)+B(h,t[b+6|0])|0)+B(i,t[b+8|0])<<8)/2|0)+((((B(t[b-4|0],F)+B(t[b-6|0],G)|0)+B(t[b-2|0],E)|0)+B(t[b|0],n)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=v[k>>2];b=(g+24|0)+(f<<3)|0;i=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;l=e<<8;e=l;e=rka(z,A,e,e>>31);m=kb;n=b;b=Wb(h,-16777216,16776704);h=rka(x,y,b,b>>31);e=h+e|0;b=kb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Wb(i,-16777216,16776704);i=rka(s,w,e,e>>31);e=h+i|0;b=kb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Tc(e,b,24);v[n+4>>2]=b-(l&r);v[k>>2]=(b|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],p);v[c+4>>2]=v[c+4>>2]+B(j,v[g+12>>2]);Pb(g+16|0,C,D);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}hb=g+48|0}function vba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=hb-48|0;hb=h;e=xO(h+32|0,1<<v[b+12>>2]);f=v[e>>2];while(1){c=v[a>>2];if(Qg(c,v[a+4>>2])>>>0>d>>>0){c=_e(c,d);wO(Gd(f,d),A[c>>3]);d=d+1|0;continue}break}vO(b,e);x=h,y=Cb(v[e>>2]),v[x+8>>2]=y;w=Cb(v[e+4>>2]);while(1){f=v[h+8>>2];if(Nb(f,w)){m=A[f+8>>3];k=hb-32|0;hb=k;o(+A[f>>3]);g=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;q=g&2147483647;t=c&2147483647;d=t;c=(q|0)==(d|0)&r>>>0<s>>>0|d>>>0>q>>>0;g=c?r:s;c=c?q:d;d=c;l(0,g|0);l(1,c|0);p=+n();u=c>>>20|0;i=p;a:{if((u|0)==2047){break a}c=(q|0)==(t|0)&r>>>0>s>>>0|q>>>0>t>>>0;l(0,(c?r:s)|0);c=c?q:t;l(1,c|0);m=+n();b:{if(!(d|g)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-u|0)>=65){break a}c:{if(c>>>0>=1534){p=p*1.90109156629516e-211;m=m*1.90109156629516e-211;i=5.260135901548374e210;break c}i=1;if(u>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=1.90109156629516e-211}GH(k+24|0,k+16|0,m);GH(k+8|0,k,p);i=i*K(A[k>>3]+A[k+16>>3]+A[k+8>>3]+A[k+24>>3]);break a}i=m}p=i;hb=k+32|0;wO(f,xp(p));$p(h+8|0);continue}break}uO(b,e);tO(e);g=v[e>>2];f=ik(g,v[e+4>>2])>>>1|0;c=f>>>0>1?f:1;d=1;while(1){if((c|0)!=(d|0)){cz(Gd(g,d),2);cz(Gd(g,d+f|0),0);d=d+1|0;continue}break}vO(b,e);x=h,y=Cb(v[e>>2]),v[x+24>>2]=y;f=Cb(v[e+4>>2]);while(1){g=v[h+24>>2];if(Nb(g,f)){sO(h+8|0,g);c=v[h+20>>2];v[g+8>>2]=v[h+16>>2];v[g+12>>2]=c;c=v[h+12>>2];v[g>>2]=v[h+8>>2];v[g+4>>2]=c;$p(h+24|0);continue}break}uO(b,e);tO(e);f=v[a>>2];c=Qg(f,v[a+4>>2]);b=v[e>>2];d=0;while(1){if((c|0)==(d|0)){kl(e);hb=h+48|0}else{a=Gd(b,d);x=_e(f,d),z=A[a>>3],A[x>>3]=z;d=d+1|0;continue}break}}function HW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=hb+-64|0;hb=f;xc(b);Ro(a);a:{if(!di(b,f+56|0)){break a}if(!jD(f+56|0)){break a}if(!c){l=1;break a}if(!Ob(v[b>>2],v[b+8>>2],4)){break a}Bv(a);p=f,q=Av(),v[p+32>>2]=q;c=f+32|0;zv(Rj(v[a+4>>2])+32|0,c);hr(c);k=v[Rj(v[a+4>>2])+32>>2];c=nh(v[b>>2]);if(c&1){break a}d=c-4|0;Zc(b,d);h=hb-16|0;hb=h;c=h+8|0;nv(c,b);e=w[Ib(c,0)|0];i=w[Ib(c,1)|0];c=w[Ib(c,2)|0];hb=h+16|0;h=c|(i<<8|e<<16);if(!h){break a}v[23516]=0;R(173,k|0,h|0);c=v[23516];v[23516]=0;l=1;if((c|0)==1){a=V(92664)|0;if((O()|0)==(ea(92664)|0)){_(a|0)|0;$();l=0;break a}S(a|0);L()}Zc(b,4);m=f+32|0;iD(m,b);i=v[k>>2];e=hb-32|0;hb=e;b=v[f+32>>2];t[e+24|0]=w[b|0];t[e+25|0]=w[b+1|0];t[e+26|0]=w[b+2|0];t[e+27|0]=w[b+3|0];c=Zq(e+8|0);d=b+d|0;v[c+12>>2]=d-4;v[c+8>>2]=b;Oj(c,w[d-1|0]);b=h;b:while(1){c:{d:{e:{if(!b){break e}if(Oj(c,1)){break d}d=1;while(1){g=Oj(c,2);d=g+d|0;if((g|0)==3){continue}break}v[e+4>>2]=d;uc(e+4|0,b);d=0;g=v[e+4>>2];while(1)if((d|0)==(g|0)){if(!b){break e}break d}else{b=b-1|0;p=i+b|0,q=Oj(c,8),t[p|0]=q;d=d+1|0;continue}}hb=e+32|0;break c}g=Oj(c,2);d=g+2|0;v[e+4>>2]=d;f:{if((g|0)==3){if(Oj(c,1)){g=w[Ib(e+24|0,3)|0]}else{g=7}g=Oj(c,g);while(1){j=Oj(c,3);d=j+d|0;if((j|0)==7){continue}break}v[e+4>>2]=d;break f}g=Oj(c,w[Ib(e+24|0,g)|0])}uc(e+4|0,b);d=0;o=v[e+4>>2];while(1){if((d|0)==(o|0)){continue b}j=0;n=b+g|0;if(h>>>0>n>>>0){j=w[i+n|0]}b=b-1|0;t[i+b|0]=j;d=d+1|0;continue}}break}oe(f+16|0,v[k>>2],v[k+4>>2]);Vg(f+24|0,v[f+16>>2],v[f+20>>2]);b=ce(f+8|0);b=fr(m,v[f+24>>2],v[f+28>>2],v[b>>2],v[b+4>>2]);cd(Rj(v[a+4>>2])+12|0,b);yb(b)}hb=f- -64|0;return l|0}function Fha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb-16|0;hb=g;i=nf(a,c);ke(g,v[a+36>>2]);j=a;a:{if(!i){Pc(g,a+32|0,5);c=0;if(zb(v[v[g>>2]>>2],v[g+4>>2])){break a}}e=hb-192|0;hb=e;f=Rl(e+80|0,v[a+36>>2]);v[23516]=0;a=Q(458,e- -64|0,27983)|0;c=v[23516];v[23516]=0;b:{c:{d:{e:{if((c|0)!=1){v[23516]=0;v[e>>2]=19988497;v[e+4>>2]=0;U(459,f|0,a|0,e|0);c=v[23516];v[23516]=0;if((c|0)==1){break e}Ub(a);if(!Ek(w[f|0])){break d}break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;Ub(a);break c}t[e+63|0]=0;t[e+62|0]=0;v[23516]=0;a=Q(458,e+48|0,10113)|0;c=v[23516];v[23516]=0;f:{g:{h:{i:{if((c|0)!=1){v[23516]=0;U(498,f|0,e+63|0,a|0);c=v[23516];v[23516]=0;if((c|0)==1){break i}Ub(a);if(!w[e+63|0]){break b}sf(e+63|0,50);v[23516]=0;a=Q(458,e+32|0,13256)|0;c=v[23516];v[23516]=0;if((c|0)==1){break f}v[23516]=0;U(498,f|0,e+62|0,a|0);c=v[23516];v[23516]=0;if((c|0)==1){break g}Ub(a);a=v[b>>2];c=pj(a,v[b+4>>2]);h=w[e+63|0];if(c>>>0<h>>>0){a=rz(e,v[b+12>>2]);v[23516]=0;U(499,b|0,h|0,a|0);c=v[23516];v[23516]=0;if((c|0)==1){break h}hl(a);a=v[b>>2]}k=x[wj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=w[e+62|0];n=b,o=pj(v[b>>2],v[b+4>>2])>>>0>a>>>0?a:0,t[n+16|0]=o;break b}Te(wj(v[b>>2],a),k);l=v[b>>2];v[23516]=0;R(500,e|0,c|0);m=v[23516];v[23516]=0;if((m|0)!=1){v[23516]=0;X(501,f|0,wj(l,a)|0,e|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break j}c=c+1|0;Ub(e);continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;Ub(e);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;Ub(a);break c}c=P()|0;O()|0;hl(a);break c}c=P()|0;O()|0;Ub(a);break c}c=P()|0;O()|0}fh(f);S(c|0);L()}fh(f);hb=e+192|0;c=i}Ve(j,c);hb=g+16|0}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=hb-48|0;hb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){e=v[g+16>>2];m=((((v[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+o|0;b=e>>>21&2040;j=u[b+39894>>1];i=u[b+39892>>1];n=u[b+39890>>1];l=u[b+39888>>1];b=0;e=0;while(1){if((e|0)!=2){f=m+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((B(u[f>>1],n)+B(u[f-4>>1],l)|0)+B(i,u[f+4>>1])|0)+B(j,u[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=rka(y,z,f,f>>31);l=kb;D=e;e=Wb(i,-16777216,16776704);i=rka(w,x,e,e>>31);f=i+f|0;e=kb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Wb(j,-16777216,16776704);j=rka(s,t,f,f>>31);f=l+j|0;e=kb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[D+4>>2]=e-(n&r);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Pb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function QM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=hb-16|0;hb=c;d=a+1074376|0;e=B(b,872);a:{if(v[(d+e|0)+704>>2]&134218752){break a}h=v[(a+e|0)+1075648>>2];if(!lj(h)|w[h+15|0]&2){break a}d=Fl(a,d,b,2,1)-1|0;if((d&255)>>>0>249){break a}g=v[Id(a+906300|0,d)>>2];if(!g){break a}f=B(b,872)+a|0;j=f+1075780|0;d=w[j|0];b:{if(w[f+1075782|0]==1){t[c+8|0]=64;e=w[Vb(f+1075784|0,c+8|0)|0];break b}e=255;if(w[f+1075783|0]!=13){break b}t[c+8|0]=64;e=w[Vb((B(b,872)+a|0)+1075785|0,c+8|0)|0]}i=a+1074312|0;Ab(c+8|0,i,2);if(zb(v[v[c+8>>2]>>2],v[c+12>>2])){if(d){if(Wc(d)){d=w[Ib(h+108|0,d-1|0)|0]}jm(a,b,d,x[(B(b,872)+a|0)+1075680>>1]);break a}if((e|0)==255){break a}lb[v[v[g>>2]+76>>2]](g,39,e,b);break a}k=v[h+4>>2];c:{if(!d){break c}f=w[h+35|0]?k<<2:v[(B(b,872)+a|0)+1075680>>2];l=u[(B(b,872)+a|0)+1075768>>1];Ab(c+8|0,i,28);m=c,n=f+(zb(v[v[c+8>>2]>>2],v[c+12>>2])?l<<2:l)|0,v[m+4>>2]=n;me(c+4|0,0,256);f=d;if(Wc(d)){f=w[Ib(h+108|0,d-1|0)|0]}Ab(c+8|0,i,117);if(!zb(v[v[c+8>>2]>>2],v[c+12>>2])){if(mm(w[j+2|0],w[j+3|0])){break c}}jm(a,b,f&255,x[c+4>>1])}f=w[h+35|0];Ab(c+8|0,i,101);if(zb(v[v[c+8>>2]>>2],v[c+12>>2])){a=(d|0)!=0}else{a=Wc(d)}if(a^1|(f|0)!=1?(a|(e|0)==255)==1:0){break a}d:{switch(w[h+36|0]){case 1:if((e|0)!=255){Ss(v[g+20>>2],C(C(C(e<<1)/C(-127))+C(1)));break a}Ss(v[g+20>>2],C(C(C(k<<1>>>0)/C(-127))+C(1)));break a;case 0:break d;default:break a}}if((e|0)!=255){t[c+8|0]=127;t[c+4|0]=e<<1;n=g,o=7,p=w[Vb(c+8|0,c+4|0)|0],q=b,m=v[v[g>>2]+76>>2],lb[m](n|0,o|0,p|0,q|0);break a}v[c+8>>2]=127;v[c+4>>2]=k<<1;q=g,p=7,o=w[Hb(c+8|0,c+4|0)|0],n=b,m=v[v[g>>2]+76>>2],lb[m](q|0,p|0,o|0,n|0)}hb=c+16|0}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0;g=hb-48|0;hb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){if(d){e=v[g+16>>2];m=(((v[g+20>>2]&2147483647)<<1|e>>>31)&-2)+o|0;b=e>>>21&2040;j=u[b+39894>>1];i=u[b+39892>>1];n=u[b+39890>>1];l=u[b+39888>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+m|0;v[(g+8|0)+(e<<2)>>2]=(((B(t[f|0],n)+B(t[f-2|0],l)|0)+B(i,t[f+2|0])|0)+B(j,t[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=rka(z,A,f,f>>31);l=kb;E=e;e=Wb(i,-16777216,16776704);i=rka(x,y,e,e>>31);f=i+f|0;e=kb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Wb(j,-16777216,16776704);j=rka(s,w,f,f>>31);f=l+j|0;e=kb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[E+4>>2]=e-(n&r);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Pb(g+16|0,C,D);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function Uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=hb-48|0;hb=h;k=c+484344|0;vg(k,w[b+70|0]|w[b+71|0]<<8);a:{b:{while(1){if((w[b+70|0]|w[b+71|0]<<8)>>>0<=j>>>0){break b}f=v[a+8>>2];e=zg(a);Yb(a,1);c:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Je(a)+1|0;break c}c=Ng(a)}d=Ng(a);Zc(a,e+f|0);Wd(h,a,d);f=hc(h+24|0,h);yb(h);v[23516]=0;c=W(225,k|0,j&65535,(c?c>>>0<1024?c:1024:64)|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Xb(v[k>>2],j);m=h,n=Cb(v[c>>2]),v[m>>2]=n;l=Cb(v[c+4>>2]);while(1){c=v[h>>2];if(!Nb(c,l)){break d}v[23516]=0;d=T(204,f|0)|0;e=v[23516];v[23516]=0;e:{f:{g:{if((e|0)!=1){if(!(d&128)){break g}if(d&1){v[23516]=0;e=T(204,f|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break a}t[c|0]=e}if(d&2){break f}break e}break a}t[c|0]=d;d=255}v[23516]=0;e=T(204,f|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break a}t[c+1|0]=e}i=0;e=0;if(d&4){v[23516]=0;e=T(204,f|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break a}}if(d&8){v[23516]=0;i=T(204,f|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break a}}if(d&16){v[23516]=0;d=T(204,f|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break a}t[c+5|0]=d}h:{i:{d=w[c|0];if(!d){break i}g=255;if((d|0)==97){break h}if(d>>>0>96){break i}g=d+12|0;break h}g=0}t[c|0]=g;d=w[c+5|0];j:{if((d|i)&255){Nf(c,i,d);break j}t[c+3|0]=0}if(w[c+1|0]==255){t[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){t[c+4|0]=d;t[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;t[c+4|0]=d;e=e-96>>4;t[c+2|0]=w[e+27310|0];if((e|0)!=6){break k}t[c+4|0]=d<<2}vk(h);continue}}yb(f);j=j+1|0;continue}break}break a}hb=h+48|0;return}a=P()|0;O()|0;yb(f);S(a|0);L()}function ah(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=hb-16|0;hb=c;a:{if((d|0)==189){t[a+3843|0]=e>>>7;t[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=8){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=B(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){Tn(f,g);break b}Tn(f,0)}t[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}t[a+3842|0]=e>>>6&1;b=0;while(1){if((b|0)==18){break a}kz((B(b,44)+a|0)+16|0);b=b+1|0;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=B(d&256?b+9|0:b,44)+a|0;v[c+8>>2]=a+16;b=v[a+52>>2];v[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=v[(c+8|0)+(b<<2)>>2];HO(v[a>>2],d);HO(v[a+4>>2],d);u[a+22>>1]=h;jz(a);kz(a);t[a+21|0]=f;jz(a);kz(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=v[(c+8|0)+(b<<2)>>2];u[a+20>>1]=x[a+20>>1]&768|e&255;jz(a);b=b+1|0;continue}}t[a+58|0]=(e&32)>>>5;t[a+57|0]=(e&16)>>>4;b=e>>>1&7;u[a+46>>1]=b?9-b|0:0;u[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=t[(d&31)+29168|0];a=(f+B(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:t[a+79|0]=e>>>7;t[a+80|0]=(e&64)>>>6;t[a+78|0]=(e&32)>>>5;t[a+77|0]=(e&16)>>>4;Un(a);u[a+14>>1]=x[((e&15)<<1)+29200>>1];break a;case 1:u[a+68>>1]=w[(e>>>6|0)+21736|0];IO(a);u[a+22>>1]=(e&63)<<2;break a;case 2:u[a+24>>1]=e>>>4;Un(a);u[a+26>>1]=e&15;Un(a);break a;case 3:b=e>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=e&15;Un(a);break a;case 6:break d;default:break a}}u[a+12>>1]=e&7}hb=c+16|0;return}lb[v[v[b>>2]>>2]](b,c,d,e)}function sL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}g=v[b+4>>2];c:{if(!g){while(1){g=zh(d);d=v[d+8>>2];if(!g){continue}break}break c}d=zT(g)}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(zh(d)){c=v[d+8>>2];v[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=v[d+8>>2];v[c+4>>2]=e}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){f=v[b+8>>2];v[d+8>>2]=f;i=f+(zh(b)?0:4)|0,j=d,v[i>>2]=j;f=v[b>>2];v[d>>2]=f;dm(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){dm(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=w[c+12|0];f:{g:{if(!zh(c)){if(!b){t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;lq(b);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];h:{if(!(w[b+12|0]?0:b)){d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[c+12|0]=0;i:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break i}a=b}t[a+12|0]=1;return}if(!zh(b)){break g}b=v[b+8>>2]+4|0;break f}d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[b+12|0]=1;t[c+12|0]=0;kq(c);c=v[c+8>>2];d=v[c+4>>2]}a=v[c+8>>2];t[c+12|0]=w[a+12|0];t[a+12|0]=1;t[d+12|0]=1;lq(a);return}if(!b){t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;kq(b);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];j:{if(w[d+12|0]?0:d){break j}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(zh(b)){b=v[b+8>>2]+4|0;break f}b=v[b+8>>2];break f}if(w[d+12|0]?0:d){break j}t[b+12|0]=1;t[c+12|0]=0;lq(c);c=v[c+8>>2];d=v[c>>2]}a=v[c+8>>2];t[c+12|0]=w[a+12|0];t[a+12|0]=1;t[d+12|0]=1;kq(a);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function K_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=hb-624|0;hb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=1175;h=pe(a+200|0,a+208|0,a+16|0);b=a+192|0;bd(b,e);v[23516]=0;i=T(1153,b|0)|0;b=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+191|0]=0;b=v[e+4>>2];v[23516]=0;b=qa(1183,a+616|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}if(!b){break e}b=w[14741]|w[14742]<<8|(w[14743]<<16|w[14744]<<24);t[a+183|0]=b;t[a+184|0]=b>>>8;t[a+185|0]=b>>>16;t[a+186|0]=b>>>24;b=w[14738]|w[14739]<<8|(w[14740]<<16|w[14741]<<24);v[a+176>>2]=w[14734]|w[14735]<<8|(w[14736]<<16|w[14737]<<24);v[a+180>>2]=b;v[23516]=0;X(1165,i|0,a+176|0,a+186|0,a+128|0);b=v[23516];v[23516]=0;if((b|0)==1){break g}v[a+4>>2]=1140;d=pe(a+8|0,0,a+4|0);c=a+16|0;b=v[a+196>>2];e=b-v[h>>2]|0;if((e|0)<393){break f}Xe(d,Md((e>>2)+2|0));c=v[d>>2];if(c){break f}v[23516]=0;Z(1141);b=v[23516];v[23516]=0;if((b|0)==1){break c}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(w[a+191|0]){t[c|0]=45;c=c+1|0}e=v[h>>2];while(1){if(b>>>0<=e>>>0){t[c|0]=0;v[a>>2]=g;if((CG(a+16|0,a)|0)!=1){v[23516]=0;Y(1177,8029);b=v[23516];v[23516]=0;if((b|0)!=1){break a}break c}Sc(d)}else{b=a+128|0;j=c,k=w[(a+176|0)+(nw(b,b+40|0,v[e>>2])-b>>2)|0],t[j|0]=k;c=c+1|0;e=e+4|0;b=v[a+196>>2];continue}break}}v[23516]=0;b=Q(1159,a+616|0,a+608|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+616>>2];Zb(a+192|0);Sc(h);hb=a+624|0;return b|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;Sc(d)}Zb(a+192|0);Sc(h);S(e|0);L()}L()}function R_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=hb-288|0;hb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=1175;h=pe(a+152|0,a+160|0,a+16|0);b=a+144|0;bd(b,e);v[23516]=0;i=T(19,b|0)|0;b=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+143|0]=0;b=v[e+4>>2];v[23516]=0;b=qa(1176,a+280|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}if(!b){break e}b=w[14741]|w[14742]<<8|(w[14743]<<16|w[14744]<<24);t[a+135|0]=b;t[a+136|0]=b>>>8;t[a+137|0]=b>>>16;t[a+138|0]=b>>>24;b=w[14738]|w[14739]<<8|(w[14740]<<16|w[14741]<<24);v[a+128>>2]=w[14734]|w[14735]<<8|(w[14736]<<16|w[14737]<<24);v[a+132>>2]=b;v[23516]=0;X(1151,i|0,a+128|0,a+138|0,a+118|0);b=v[23516];v[23516]=0;if((b|0)==1){break g}v[a+4>>2]=1140;d=pe(a+8|0,0,a+4|0);c=a+16|0;b=v[a+148>>2];e=b-v[h>>2]|0;if((e|0)<99){break f}Xe(d,Md(e+2|0));c=v[d>>2];if(c){break f}v[23516]=0;Z(1141);b=v[23516];v[23516]=0;if((b|0)==1){break c}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(w[a+143|0]){t[c|0]=45;c=c+1|0}e=v[h>>2];while(1){if(b>>>0<=e>>>0){t[c|0]=0;v[a>>2]=g;if((CG(a+16|0,a)|0)!=1){v[23516]=0;Y(1177,8029);b=v[23516];v[23516]=0;if((b|0)!=1){break a}break c}Sc(d)}else{b=a+118|0;j=c,k=w[((yi(b,JT(b),e)-a|0)+a|0)+10|0],t[j|0]=k;c=c+1|0;e=e+1|0;b=v[a+148>>2];continue}break}}v[23516]=0;b=Q(1143,a+280|0,a+272|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+280>>2];Zb(a+144|0);Sc(h);hb=a+288|0;return b|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;Sc(d)}Zb(a+144|0);Sc(h);S(e|0);L()}L()}function p4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-48|0;hb=c;f=Lb(a);a:{b:{c:{a=b+36|0;d:{if(Nb(v[a>>2],v[b+40>>2])){yf(c+40|0);break d}v[23516]=0;R(1042,c+24|0,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break b}v[23516]=0;d=T(1026,c+24|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break c}v[c+40>>2]=d;Vf(c+24|0)}d=v[b+36>>2];if(!Nb(d,v[b+40>>2])){a=v[c+40>>2];d=v[a>>2]}g=v[a+4>>2];v[23516]=0;R(179,f|0,Ni(d,g)|0);d=v[23516];v[23516]=0;e:{if((d|0)!=1){i=c,j=Cb(v[a>>2]),v[i+16>>2]=j;g=Cb(v[a+4>>2]);f:{g:{h:{i:{j:{k:{while(1){a=v[c+16>>2];if(!Nb(a,g)){Vk(c+40|0);hb=c+48|0;return}d=w[a+16|0];e=v[v[b+24>>2]+484360>>2];v[23516]=0;d=wj(e,d);R(1043,c|0,d|0);e=v[23516];v[23516]=0;if((e|0)!=1){v[23516]=0;R(1029,c+24|0,c|0);e=v[23516];v[23516]=0;if((e|0)==1){break k}v[23516]=0;R(181,f|0,c+24|0);e=v[23516];v[23516]=0;if((e|0)==1){break j}wb(c+24|0);xb(c);l:{if(!Pe(hx(v[f+4>>2]))){break l}e=w[a+12|0];v[23516]=0;e=Q(314,d|0,e|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break f}if(!e){break l}e=v[b+24>>2];h=v[e+1298404>>2];a=x[$b(v[d>>2],v[a+12>>2])>>1];d=v[e+484344>>2];v[23516]=0;R(1036,c|0,Xb(d,a)|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}v[23516]=0;X(237,c+24|0,0,h|0,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break g}a=c+24|0;yc(hx(v[f+4>>2]),a);wb(a);wb(c)}Mx(c+16|0);continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break i}a=P()|0;O()|0;wb(c+24|0)}xb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;wb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}Vk(c+40|0);break a}a=P()|0;O()|0;Vf(c+24|0);break a}a=P()|0;O()|0}Me(f);S(a|0);L()}function fy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-16|0;hb=e;i=_L(b,c);a:{if(!v[b+656>>2]|!(t[i+6|0]&1)){break a}f=v[i>>2];j=a+1074312|0;Ab(e+8|0,j,31);g=zb(v[v[e+8>>2]>>2],v[e+12>>2]);d=Yu(v[b+656>>2],c);if(nc(v[d>>2],v[d+4>>2])){break a}g=f+(g^1)|0;Ab(e+8|0,j,31);f=w[d+12|0];b:{c:{if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])){d:{if(!(f&2)){break d}h=w[d+14|0];k=!(v[a+480180>>2]&1048580)+x[Bb(v[d>>2],h)>>1]|0;if(!(w[b+89|0]&8)|(!(f&4)|(h|0)!=w[d+16|0])){f=l}else{Ab(e+8|0,j,70);f=zb(v[v[e+8>>2]>>2],v[e+12>>2])}if(f|(g|0)!=(k|0)){break d}g=x[Bb(v[d>>2],w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){a=v[d>>2];if((x[Bb(a,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[Bb(a,w[d+15|0])>>1];Ab(e+8|0,j,93);if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])|(c|0)!=1|v[b+88>>2]&2048){break b}t[i+6|0]=w[i+6|0]&254;break b}k=1;f=x[yj(v[d+4>>2])>>1];if(g>>>0>f>>>0){break c}break b}e:{f:{if(!(!(f&4)|w[b+669|0]&8)){if(x[i+4>>1]==65535){break f}Ab(e+8|0,j,97);if(zb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}f=w[d+12|0]}if(f&2){h=v[d>>2];f=x[Bb(h,w[d+13|0])>>1];h=x[Bb(h,w[d+14|0])>>1]+1|0;break e}f=x[yj(v[d+4>>2])>>1];k=g>>>0>f>>>0;h=f;break e}h=v[d>>2];f=x[Bb(h,w[d+15|0])>>1];h=x[Bb(h,w[d+16|0])>>1]+1|0}f=g>>>0<h>>>0?g:f}g:{if(!k|c){break g}g=v[a+480180>>2];c=v[b+88>>2];if(!(!(g&16777248)&(!(c&2048)|(g|0)==16384))){c=c|4096;v[b+88>>2]=c}if(w[yj(v[d+4>>2])+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=c|4096}g=f}Ab(e+8|0,j,31);m=i,n=zb(v[v[e+8>>2]>>2],v[e+12>>2])+g|0,v[m>>2]=n}hb=e+16|0}function Os(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-144|0;hb=g;a:{b:{c:{d:{e:{f:{g:{h:{if(!d){break h}e=v[d+4>>2];if(!e&c>>>0<=y[d>>2]|e){break h}a=ba(8)|0;v[23516]=0;b=Q(211,a|0,21751)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break g}b=P()|0;O()|0;ca(a|0);break a}if(!b){a=ba(8)|0;v[23516]=0;b=T(835,a|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break f}b=P()|0;O()|0;ca(a|0);break a}e=hb-16|0;hb=e;Vg(e+8|0,b,c);h=g+120|0;GD(h,v[e+8>>2],v[e+12>>2]);v[h+12>>2]=0;hb=e+16|0;i:{j:{if(a&2){b=Sm(g+96|0,h);v[23516]=0;b=T(836,b|0)|0;f=v[23516];v[23516]=0;e=1;if((f|0)==1){break i}if((b|0)==1){break j}e=Sm(g+72|0,h);v[23516]=0;f=T(837,e|0)|0;i=v[23516];v[23516]=0;e=1;if((i|0)==1){break e}k=(f|0)==1;if(k){break j}e=Sm(g+48|0,h);v[23516]=0;i=Q(838,e|0,d|0)|0;j=v[23516];v[23516]=0;e=1;if((j|0)==1){break d}l=(i|0)==1;if(l){break j}e=Sm(g+24|0,h);v[23516]=0;j=Q(839,e|0,d|0)|0;m=v[23516];v[23516]=0;e=1;if((m|0)==1){break c}if((j|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(f|0)==-1?-1:b;f=(j|0)==-1?-1:l?b:(i|0)==-1?-1:b}k:{if(!(a&1)){break k}b=31728;while(1){if((b|0)==32268){break k}a=v[b>>2];if(a){e=Sm(g,h);v[23516]=0;a=Q(a|0,e|0,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}e=1;if((a|0)==1){break j}f=(a|0)==-1?-1:f}b=b+12|0;continue}}if(d){e=0;if((f|0)!=-1){break j}e=Bc(v[d>>2],v[d+4>>2])>>>0>c>>>0?-1:0;break j}e=0;if((f|0)!=-1){break j}e=c>>>0>2047?1:-1}hb=g+144|0;return e}b=P()|0;O()|0;break a}ia(b|0,92944,25);L()}ia(b|0,92840,25);L()}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}S(b|0);L()}function $ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=hb-48|0;hb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){b=v[g+16>>2];l=b>>>18|0;j=((((v[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=j+(e<<1)|0;f=u[i>>1];v[(g+8|0)+(e<<2)>>2]=f+((B(l,u[i+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=rka(y,z,f,f>>31);m=kb;D=e;e=Wb(i,-16777216,16776704);i=rka(w,x,e,e>>31);f=i+f|0;e=kb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Wb(j,-16777216,16776704);j=rka(s,t,f,f>>31);f=m+j|0;e=kb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[D+4>>2]=e-(r&n);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Pb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=hb-48|0;hb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){b=v[g+16>>2];l=b>>>10&4194048;j=(((v[g+20>>2]&2147483647)<<1|b>>>31)&-2)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=e+j|0;f=t[i|0];v[(g+8|0)+(e<<2)>>2]=((B(l,t[i+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=rka(y,z,f,f>>31);m=kb;D=e;e=Wb(i,-16777216,16776704);i=rka(w,x,e,e>>31);f=i+f|0;e=kb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Wb(j,-16777216,16776704);j=rka(s,u,f,f>>31);f=m+j|0;e=kb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[D+4>>2]=e-(r&n);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Pb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=hb-48|0;hb=g;p=v[a+16>>2];m=Rf(1,2);b=kb;q=b;Pb(a,m,b);b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;D=v[a+8>>2];E=v[a+12>>2];while(1){if(d){d=d-1|0;f=((((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&2147483646)<<1)+p|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=u[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){n=(g+8|0)+(b<<2)|0;f=v[n>>2];e=(g+24|0)+(b<<3)|0;k=v[e+8>>2];j=v[e+4>>2];v[e+8>>2]=j;o=f<<8;f=o;f=rka(A,C,f,f>>31);l=kb;F=e;e=Wb(j,-16777216,16776704);j=rka(y,z,e,e>>31);f=j+f|0;e=kb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Wb(k,-16777216,16776704);k=rka(w,x,f,f>>31);f=l+k|0;e=kb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[F+4>>2]=e-(t&o);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],i>>12);h=h+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Pb(g+16|0,D,E);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}lg(a,m,q);hb=g+48|0}function x_(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;v[c>>2]=a;y=d&512;z=h<<2;while(1){if((x|0)==4){if(Fb(n)>>>0>1){f=ge(n);e=hb-16|0;hb=e;v[e+8>>2]=f;f=v[Ie(e+8|0)>>2];hb=e+16|0;B=c,C=Mi(f,Lk(n),v[c>>2]),v[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}}else{a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];h=Or(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 3:if(Pe(n)){break a}h=v[oj(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 2:if(Pe(m)|!y){break a}B=c,C=Mi(ge(m),Lk(m),v[c>>2]),v[B>>2]=C;break a;case 4:break b;default:break a}}A=v[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!Pk(g,2048,v[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=v[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){h=h-4|0;s=v[h>>2];r=p+4|0;v[c>>2]=r;v[p>>2]=s;q=q-1|0;p=r;continue}break}d:{if(!q){s=0;break d}s=Or(g,48);p=v[c>>2]}while(1){r=p+4|0;if((q|0)>0){v[p>>2]=s;q=q-1|0;p=r;continue}break}v[c>>2]=r;v[p>>2]=j}e:{if((e|0)==(h|0)){p=Or(g,48);q=v[c>>2];h=q+4|0;v[c>>2]=h;v[q>>2]=p;break e}if(Pe(l)){s=-1}else{s=t[gg(l,0)|0]}q=0;u=0;while(1){if((e|0)!=(h|0)){r=v[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;v[c>>2]=p;v[r>>2]=k;r=0;u=u+1|0;if(Fb(l)>>>0<=u>>>0){s=q;break f}s=-1;if(w[gg(l,u)|0]==127){break f}s=t[gg(l,u)|0]}h=h-4|0;q=v[h>>2];v[c>>2]=p+4;v[p>>2]=q;q=r+1|0;continue}break}h=v[c>>2]}Ir(A,h)}x=x+1|0;continue}break}}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=hb-48|0;hb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){e=v[g+16>>2];k=((((v[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+m|0;b=e>>>21&2040;i=u[b+39894>>1];h=u[b+39892>>1];l=u[b+39890>>1];j=u[b+39888>>1];b=0;e=0;while(1){if((e|0)!=2){f=k+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((B(u[f>>1],l)+B(u[f-4>>1],j)|0)+B(h,u[f+4>>1])|0)+B(i,u[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=rka(w,x,f,f>>31);j=kb;A=e;e=Wb(h,-16777216,16776704);h=rka(s,t,e,e>>31);f=h+f|0;e=kb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Wb(i,-16777216,16776704);i=rka(q,r,f,f>>31);f=j+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[A+4>>2]=e-(l&p);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],n);Pb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function xK(a){var b=C(0),c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,k=0,l=C(0),m=0,n=C(0);c=hb-16|0;hb=c;e=a+4208|0;b=xx(z[Bb(e,2)>>2]);f=v[a+16>>2]+24620|0;z[c+12>>2]=b/C(y[f>>2]);v[c+8>>2]=1056964608;b=vp(C(z[em(c+12|0,c+8|0)>>2]*C(6.2831854820251465)));b=C(K(C(C(C(b+b)+C(3))/C(5))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));b=C(C(z[Bb(e,1)>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){i=~~b>>>0;break a}i=0}t[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}t[a+4273|0]=k;l=qe(C(10),C(C(C(z[e>>2]*C(60))+C(-60))/C(20)));m=c,n=C(xx(z[Bb(e,3)>>2])/C(y[f>>2])),z[m+12>>2]=n;v[c+8>>2]=1056964608;g=z[em(c+12|0,c+8|0)>>2];m=c,n=C(xx(z[Bb(e,4)>>2])/C(y[f>>2])),z[m+12>>2]=n;v[c+8>>2]=1056964608;b=C(C(z[em(c+12|0,c+8|0)>>2]*C(6.2831854820251465))*C(.5));f=hb-16|0;hb=f;e=(p(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=un(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=un(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=un(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=un(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=un(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=C(b-b);break b}d=Uw(b,f+8|0);b=un(A[f+8>>3],d&1)}hb=f+16|0;b=C(C(C(1)-b)/C(b+C(1)));z[a+4268>>2]=b;g=vp(C(g*C(6.2831854820251465)));z[a+4264>>2]=-g;z[a+4260>>2]=C(C(l*C(K(C(C(1)-C(g*g)))))*C(K(C(C(1)-C(b*b)))))*z[(i<<2)+45776>>2];hb=c+16|0}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=hb-48|0;hb=g;p=v[a+16>>2];m=Rf(1,2);b=kb;q=b;Pb(a,m,b);b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+32>>2];s=v[a+28>>2];u=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;D=v[a+8>>2];E=v[a+12>>2];while(1){if(d){d=d-1|0;f=(((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&-2)+p|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=t[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){n=(g+8|0)+(b<<2)|0;f=v[n>>2];e=(g+24|0)+(b<<3)|0;k=v[e+8>>2];j=v[e+4>>2];v[e+8>>2]=j;o=f<<8;f=o;f=rka(A,C,f,f>>31);l=kb;F=e;e=Wb(j,-16777216,16776704);j=rka(y,z,e,e>>31);f=j+f|0;e=kb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Wb(k,-16777216,16776704);k=rka(w,x,f,f>>31);f=l+k|0;e=kb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[F+4>>2]=e-(u&o);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],i>>12);h=h+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Pb(g+16|0,D,E);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}lg(a,m,q);hb=g+48|0}function gaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-112|0;hb=c;zj(c+88|0,b,1413829443);v[23516]=0;b=T(176,v[c+88>>2])|0;d=v[23516];v[23516]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[23516]=0;U(791,c- -64|0,a+140|0,1413894985);a=v[23516];v[23516]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[23516]=0;a=Q(868,c- -64|0,13692)|0;b=v[23516];v[23516]=0;if((b|0)==1){break e}b=28591;if(a){b=Kb(c+48|0);v[23516]=0;a=T(200,c- -64|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break m}v[23516]=0;U(271,c- -64|0,b|0,a|0);a=v[23516];v[23516]=0;if((a|0)==1){break m}v[23516]=0;d=Q(52,c+16|0,b|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break l}v[23516]=0;Y(869,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break k}v[23516]=0;U(870,c+32|0,d|0,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break j}a=c+32|0;e=yc(b,a);wb(a);wb(c);wb(d);v[23516]=0;U(11,a|0,2,e|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}v[23516]=0;a=T(760,c+32|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break g}xb(c+32|0);wb(e);b=a-1>>>0<19398657?1252:28591}yb(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;wb(c)}wb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;xb(c+32|0)}wb(b);break d}a=P()|0;O()|0}yb(c- -64|0);break b}v[23516]=0;a=W(154,v[c+88>>2],v[c+96>>2],2)|0;b=v[23516];v[23516]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[23516]=0;b=T(192,c+88|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}yb(c+88|0);S(a|0);L()}yb(c+88|0);hb=c+112|0;return b|0}function IJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=C(0);e=hb-48|0;hb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=v[a+24>>2];if((b|0)==v[d+24604>>2]){break d}a=e+8|0;pc(a,d+24604|0,40);v[e+8>>2]=b;jy(d,a);break d;case 2:f=v[a+24>>2];d=f+24664|0;b=v[d+4>>2];v[e+24>>2]=v[d>>2];v[e+28>>2]=b;d=f+24656|0;b=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=b;b=v[f+24652>>2];v[e+8>>2]=v[f+24648>>2];v[e+12>>2]=b;d=hb-16|0;hb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ba(8)|0;v[23516]=0;b=Q(53,d|0,10799)|0;a=v[23516];v[23516]=0;i:{if((a|0)!=1){a=rc(c,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break g}a=P()|0;O()|0;wb(b);break i}a=P()|0;O()|0;ca(c|0)}S(a|0);L()}hb=d+16|0;break f}L()}t[e+8|0]=b;a=v[a+24>>2];if(!ox(e+8|0,a+24648|0)){break d}hy(a,e+8|0);break d;case 3:f=e+8|0;d=v[a+24>>2];pc(f,d+24604|0,40);b=hb-48|0;hb=b;j:{if((c|0)==-1){ps(f,v[Zp(b+8|0)+32>>2]);Tn(f,v[Zp(b+8|0)+36>>2]);break j}if((c|0)<=0){ps(f,0);Tn(f,0);break j}a=B(c,1e3);ps(f,a);Tn(f,a)}hb=b+48|0;if(v[d+24636>>2]==v[e+40>>2]&v[d+24640>>2]==v[e+44>>2]){break d}jy(d,e+8|0);break d;default:d=ba(8)|0;v[23516]=0;b=Q(53,e+8|0,10404)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(d,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}c=P()|0;O()|0;wb(b);break b;case 0:break e}}g=a,h=qe(C(10),C(C(C(c|0)*C(.0010000000474974513))*C(.5))),z[g+48>>2]=h}hb=e+48|0;return}c=P()|0;O()|0;ca(d|0)}S(c|0)}L()}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=hb-16|0;hb=h;a:{b:{c:{i=v[a+12>>2];j=v[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];e=v[a+68>>2];w=e;x=e>>31;e=v[a+64>>2];y=e;z=e>>31;e=v[a+60>>2];A=e;C=e>>31;while(1){e=b;if(d){b=Wb(e,-16777216,16776704);b=rka(y,z,b,b>>31);m=kb;n=b;g=(v[h+12>>2]<<1)+q|0;b=(v[h+8>>2]>>>16&65520)+p|0;g=(((((((B(u[g-4>>1],u[b+2>>1])+B(u[g-6>>1],u[b>>1])|0)+B(u[g-2>>1],u[b+4>>1])|0)+B(u[g>>1],u[b+6>>1])|0)+B(u[g+2>>1],u[b+8>>1])|0)+B(u[g+4>>1],u[b+10>>1])|0)+B(u[g+6>>1],u[b+12>>1])|0)+B(u[g+8>>1],u[b+14>>1])|0)/32768<<8;b=g;b=rka(b,b>>31,A,C);n=n+b|0;o=kb+m|0;o=b>>>0>n>>>0?o+1|0:o;b=Wb(f,-16777216,16776704);f=rka(w,x,b,b>>31);m=f+n|0;b=kb+o|0;b=f>>>0>m>>>0?b+1|0:b;f=m+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Tc(f,b,24);b=(f|0)/256|0;l=l+s|0;v[c>>2]=B(b,l>>12)+v[c>>2];k=k+r|0;v[c+4>>2]=v[c+4>>2]+B(b,k>>12);Pb(h+8|0,j,i);b=f-(g&t)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;v[a+40>>2]=k;v[a+20>>2]=l>>12;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=k>>12;hb=h+16|0}function uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;k=f,l=xj(b),v[k>>2]=l;e=hb-16|0;hb=e;h=a;c=Pd(a);a:{if(c){g=gc(h);while(1){a=c;c=a+14|0;if(tt(b,c)){g=a;c=v[a>>2];if(c){continue}break a}if(!tt(c,b)){break a}g=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=gc(h);g=a}v[e+12>>2]=a;b=v[g>>2];if(!b){i=hb-16|0;hb=i;a=gc(h);j=gh(e,tc(48),hh(i+8|0,a));a=v[j>>2];b=v[f>>2];c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+14|0]=d;t[a+15|0]=d>>>8;t[a+16|0]=d>>>16;t[a+17|0]=d>>>24;t[a+18|0]=c;t[a+19|0]=c>>>8;t[a+20|0]=c>>>16;t[a+21|0]=c>>>24;c=w[b+28|0]|w[b+29|0]<<8|(w[b+30|0]<<16|w[b+31|0]<<24);d=w[b+24|0]|w[b+25|0]<<8|(w[b+26|0]<<16|w[b+27|0]<<24);t[a+38|0]=d;t[a+39|0]=d>>>8;t[a+40|0]=d>>>16;t[a+41|0]=d>>>24;t[a+42|0]=c;t[a+43|0]=c>>>8;t[a+44|0]=c>>>16;t[a+45|0]=c>>>24;c=w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24);d=w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24);t[a+30|0]=d;t[a+31|0]=d>>>8;t[a+32|0]=d>>>16;t[a+33|0]=d>>>24;t[a+34|0]=c;t[a+35|0]=c>>>8;t[a+36|0]=c>>>16;t[a+37|0]=c>>>24;c=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);b=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a+22|0]=b;t[a+23|0]=b>>>8;t[a+24|0]=b>>>16;t[a+25|0]=b>>>24;t[a+26|0]=c;t[a+27|0]=c>>>8;t[a+28|0]=c>>>16;t[a+29|0]=c>>>24;u[a+46>>1]=0;k=gc(j),l=1,t[k+4|0]=l;hb=i+16|0;Hg(h,v[e+12>>2],g,v[e>>2]);b=_d(e);mk(e);d=1}Gg(f+8|0,v[cc(e,b)>>2],d);hb=e+16|0;a=go(v[f+8>>2]);hb=f+16|0;return a+32|0}function Sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=hb-16|0;hb=g;w=v[a+16>>2];x=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);p=v[a+128>>2];a:{if(!p){n=v[a+8>>2];s=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];o=0;break a}b=v[a+12>>2];s=b;n=v[a+8>>2];q=kg(n,b,p);r=kb;k=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Of(i,e,mf(n,b,d),kb);o=k>>>0<kb>>>0?d:0}h=a+112|0;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=(e<<1)+w|0;b=p;while(1)if((b|0)<=0){Pb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Od(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Nd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];y=v[a+32>>2];m=v[a+28>>2]+m|0;b=v[a+60>>2];e=b;j=b>>31;t=ig(h,x)<<8;b=t;b=rka(e,j,b,b>>31);z=kb;e=b;b=v[a+64>>2];j=b;A=b>>31;b=Wb(k,-16777216,16776704);j=rka(j,A,b,b>>31);e=e+j|0;b=kb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Wb(f,-16777216,16776704);e=rka(e,e>>31,f,f>>31);f=j+e|0;b=kb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Tc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(m>>12,f)+v[c>>2];l=l+y|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,f);Pb(g,n,s);b=b-(i&t)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=k;continue b}else{Od(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Nd(h,4);Pb(g+8|0,q,r);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=k;v[a+24>>2]=l>>12;hb=g+16|0}function Qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;g=hb-48|0;hb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){if(d){e=v[g+16>>2];k=(((v[g+20>>2]&2147483647)<<1|e>>>31)&-2)+m|0;b=e>>>21&2040;i=u[b+39894>>1];h=u[b+39892>>1];l=u[b+39890>>1];j=u[b+39888>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+k|0;v[(g+8|0)+(e<<2)>>2]=(((B(t[f|0],l)+B(t[f-2|0],j)|0)+B(h,t[f+2|0])|0)+B(i,t[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=rka(x,y,f,f>>31);j=kb;C=e;e=Wb(h,-16777216,16776704);h=rka(s,w,e,e>>31);f=h+f|0;e=kb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Wb(i,-16777216,16776704);i=rka(q,r,f,f>>31);f=j+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[C+4>>2]=e-(l&p);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],n);Pb(g+16|0,z,A);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function kba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,A=0;f=hb+-64|0;hb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}s=l-4|0;o=B(b,e);x=o-8|0;h:while(1){b=v[c+8>>2];h=v[c>>2];v[23516]=0;b=W(154,h|0,b|0,l|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}v[23516]=0;U(188,f+16|0,c|0,d|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}b=f+16|0;h=hc(f+40|0,b);yb(b);v[23516]=0;R(569,b|0,h|0);b=v[23516];v[23516]=0;if((b|0)==1){break e}y=Ee(f+16|0);p=v[f+16>>2];z=p-4|0;k=0;while(1){if((e|0)==(k|0)){Qc(f+16|0);yb(h);n=(p-l<<1)+n|0;continue h}v[23516]=0;g=T(562,h|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){v[23516]=0;b=T(204,h|0)|0;j=v[23516];v[23516]=0;if((j|0)==1){break f}v[f+8>>2]=b;me(f+8|0,0,89);v[23516]=0;Q(186,h|0,1)|0;b=v[23516];v[23516]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>x>>>0){break j}m=0;if(b>>>0>z>>>0){break j}while(1)if((m|0)==8){b=b+s|0;continue i}else{q=v[f+8>>2];i=w[b+y|0];r=m&1;i=r?i>>>4|0:i&15;v[f+8>>2]=q+t[(i&7)+30440|0];A=g;g=u[(q<<1)+30448>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;v[f+12>>2]=A+(i&8?0-g|0:g);me(f+8|0,0,88);me(f+12|0,-32768,32767);g=v[f+12>>2];u[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+r|0;continue}}break}k=k+1|0;continue}break}break}break f}yb(c);hb=f- -64|0;return}b=P()|0;O()|0;Qc(f+16|0);break d}b=P()|0;O()|0}yb(h);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}yb(c);S(b|0);L()}function DW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=hb-48|0;hb=f;g=vi(b)^-1;a:{if(sc(v[d>>2],v[d+4>>2])>>>0<=g>>>0){Ls(a);break a}vi(b);if((w[c+4|0]|w[c+5|0]<<8)>>>0>=60){Yb(b,4)}j=f,k=vi(b),v[j+44>>2]=k;Yb(b,4);h=vi(b);i=vi(b);if(!((h|0)>0&(i|0)>36)){Ls(a);break a}if(qq(Jd(v[e>>2],v[Bb(v[d>>2],g)>>2]),13133)){Ls(a);break a}xv(f,b,i,h);d=hc(f+24|0,f);yb(f);b=v[d>>2];v[23516]=0;b=T(176,b|0)|0;e=v[23516];v[23516]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){v[23516]=0;T(185,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break d}break b}b=w[c+4|0]|w[c+5|0]<<8;if(b>>>0<=39){v[23516]=0;Q(186,d|0,8)|0;b=v[23516];v[23516]=0;if((b|0)==1){break b}b=w[c+4|0]|w[c+5|0]<<8}if((b&65535)>>>0<=59){v[23516]=0;Q(186,d|0,16)|0;b=v[23516];v[23516]=0;if((b|0)==1){break b}}v[23516]=0;T(187,d|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break b}e:{f:{b=w[c+4|0]|w[c+5|0]<<8;g:{if(b>>>0>=120){v[23516]=0;T(187,d|0)|0;c=v[23516];v[23516]=0;b=8;break g}h:{if(b>>>0>=100){v[23516]=0;Q(186,d|0,4)|0;b=v[23516];v[23516]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}v[23516]=0;T(187,d|0)|0;c=v[23516];v[23516]=0;b=4}if((c|0)==1){break b}v[23516]=0;Q(186,d|0,b|0)|0;break e}v[23516]=0;T(187,d|0)|0}b=v[23516];v[23516]=0;if((b|0)==1){break b}v[23516]=0;b=T(187,d|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}v[23516]=0;U(188,f|0,d|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}j=hc(a,f),k=v[f+44>>2],v[j+20>>2]=k;yb(f)}yb(d);break a}}a=P()|0;O()|0;yb(d);S(a|0);L()}hb=f+48|0}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;h=hb-16|0;hb=h;a:{b:{c:{i=v[a+12>>2];k=v[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];b=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];e=v[a+44>>2];f=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=f;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];f=v[a+68>>2];s=f;w=f>>31;f=v[a+64>>2];x=f;y=f>>31;f=v[a+60>>2];z=f;A=f>>31;while(1){f=e;if(d){e=Wb(f,-16777216,16776704);e=rka(x,y,e,e>>31);g=kb;j=e;b=Wb(b,-16777216,16776704);e=rka(s,w,b,b>>31);j=j+e|0;b=kb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=v[h+12>>2]+o|0;e=(v[h+8>>2]>>>16&65520)+n|0;g=(((((((B(t[g-2|0],u[e+2>>1])+B(t[g-3|0],u[e>>1])|0)+B(t[g-1|0],u[e+4>>1])|0)+B(t[g|0],u[e+6>>1])|0)+B(t[g+1|0],u[e+8>>1])|0)+B(t[g+2|0],u[e+10>>1])|0)+B(t[g+3|0],u[e+12>>1])|0)+B(t[g+4|0],u[e+14>>1])<<8)/32768<<8;e=g;e=rka(e,e>>31,z,A);j=e+j|0;b=kb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Tc(e,b,24);b=(e|0)/256|0;m=m+q|0;v[c>>2]=B(b,m>>12)+v[c>>2];l=l+p|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,b);Pb(h+8|0,k,i);e=e-(g&r)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=b;v[a+44>>2]=f;v[a+24>>2]=l>>12;hb=h+16|0}function qV(){var a=0,b=0,c=0;a=hb-16|0;hb=a;a:{if(cb(a+12|0,a+8|0)|0){break a}b=Md((v[a+12>>2]<<2)+4|0);v[116930]=b;if(!b){break a}b=Md(v[a+8>>2]);if(b){c=v[116930];v[c+(v[a+12>>2]<<2)>>2]=0;if(!(bb(c|0,b|0)|0)){break a}}v[116930]=0}hb=a+16|0;if(!w[467712]){a=hb-16|0;hb=a;us(467360);v[116852]=-1;v[116850]=467416;v[116848]=93752;v[116840]=78692;t[467412]=0;b=a+8|0;Qr(b,467360);c=v[v[116840]+8>>2];v[23516]=0;R(c|0,467360,b|0);b=v[23516];v[23516]=0;b:{if((b|0)!=1){Zb(a+8|0);hb=a+16|0;break b}b=P()|0;O()|0;Zb(a+8|0);Bn(467360);S(b|0);L()}As(466688);v[116672]=78824;v[116670]=78804;v[116671]=0;zn(466688,467360);a=hb-16|0;hb=a;kH(467424);v[116868]=-1;v[116866]=467480;v[116864]=93752;v[116856]=78916;t[467476]=0;b=a+8|0;Qr(b,467424);c=v[v[116856]+8>>2];v[23516]=0;R(c|0,467424,b|0);b=v[23516];v[23516]=0;c:{if((b|0)!=1){Zb(a+8|0);hb=a+16|0;break c}b=P()|0;O()|0;Zb(a+8|0);Vr(467424);S(b|0);L()}OG(466776);v[116694]=79048;v[116692]=79028;v[116693]=0;zn(466776,467424);SG(467488,93896,467536);Aw(466856,467488);RG(467544,93896,467592);zw(466940,467544);SG(467600,93592,467648);Aw(467024,467600);Aw(467192,v[(v[v[116756]-12>>2]+467024|0)+24>>2]);RG(467656,93592,467704);zw(467108,467656);zw(467276,v[(v[v[116777]-12>>2]+467108|0)+24>>2]);QG(v[v[116670]-12>>2]+466680|0);PG(v[v[116692]-12>>2]+466768|0);aI(v[v[116756]-12>>2]+467024|0);aI(v[v[116777]-12>>2]+467108|0);QG(v[v[116756]-12>>2]+467024|0);PG(v[v[116777]-12>>2]+467108|0);t[467712]=1}v[116e3]=42;v[116018]=467812}function B_(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;v[c>>2]=a;z=d&512;while(1){if((x|0)==4){if(Fb(n)>>>0>1){f=et(n);e=hb-16|0;hb=e;v[e+8>>2]=f;f=v[He(e+8|0)>>2];hb=e+16|0;B=c,C=LF(f,dt(n),v[c>>2]),v[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}return}a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];p=zl(g,32);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 3:if(Pe(n)){break a}p=w[gg(n,0)|0];q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 2:if(Pe(m)|!z){break a}B=c,C=LF(et(m),dt(m),v[c>>2]),v[B>>2]=C;break a;case 4:break b;default:break a}}p=v[g+8>>2];A=v[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!qh(p,2048,t[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){r=r-1|0;q=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=q;p=p-1|0;continue}break}if(p){q=zl(g,48)}else{q=0}while(1){s=v[c>>2];v[c>>2]=s+1;if((p|0)>0){t[s|0]=q;p=p-1|0;continue}break}t[s|0]=j}d:{if((e|0)==(r|0)){p=zl(g,48);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break d}if(Pe(l)){q=-1}else{q=t[gg(l,0)|0]}p=0;u=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=v[c>>2];v[c>>2]=q+1;t[q|0]=k;s=0;u=u+1|0;if(Fb(l)>>>0<=u>>>0){q=p;break e}q=-1;if(w[gg(l,u)|0]==127){break e}q=t[gg(l,u)|0]}r=r-1|0;p=w[r|0];y=v[c>>2];v[c>>2]=y+1;t[y|0]=p;p=s+1|0;continue}}Sl(A,v[c>>2])}x=x+1|0;continue}}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=hb-16|0;hb=g;w=v[a+16>>2];x=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);p=v[a+128>>2];a:{if(!p){n=v[a+8>>2];s=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];o=0;break a}b=v[a+12>>2];s=b;n=v[a+8>>2];q=kg(n,b,p);r=kb;k=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Of(i,e,mf(n,b,d),kb);o=k>>>0<kb>>>0?d:0}h=a+112|0;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=e+w|0;b=p;while(1)if((b|0)<=0){Pb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Od(h,t[e+v[g+12>>2]|0]<<6);Nd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];y=v[a+32>>2];m=v[a+28>>2]+m|0;b=v[a+60>>2];e=b;j=b>>31;u=ig(h,x)<<8;b=u;b=rka(e,j,b,b>>31);z=kb;e=b;b=v[a+64>>2];j=b;A=b>>31;b=Wb(k,-16777216,16776704);j=rka(j,A,b,b>>31);e=e+j|0;b=kb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Wb(f,-16777216,16776704);e=rka(e,e>>31,f,f>>31);f=j+e|0;b=kb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Tc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(m>>12,f)+v[c>>2];l=l+y|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,f);Pb(g,n,s);b=b-(i&u)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=k;continue b}else{Od(h,t[e+v[g+12>>2]|0]<<6);Nd(h,4);Pb(g+8|0,q,r);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=k;v[a+24>>2]=l>>12;hb=g+16|0}function D4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-80|0;hb=e;f=Lb(a);a=0;c=v[b+24>>2];g=qj(Sb(v[c+484360>>2],w[c+484376|0]));v[23516]=0;R(179,f|0,g|0);c=v[23516];v[23516]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(g|0)){c=v[b+24>>2];d=v[c+484344>>2];h=v[c+484348>>2];c=x[$b(v[Sb(v[c+484360>>2],w[c+484376|0])>>2],a)>>1];if(Hm(d,h,c)){v[23516]=0;R(1036,e+48|0,Xb(d,c)|0);c=v[23516];v[23516]=0;c:{d:{e:{if((c|0)!=1){c=v[b+24>>2];v[23516]=0;U(1023,e- -64|0,c|0,e+48|0);c=v[23516];v[23516]=0;if((c|0)==1){break e}v[23516]=0;R(181,f|0,e- -64|0);c=v[23516];v[23516]=0;if((c|0)==1){break d}wb(e- -64|0);wb(e+48|0);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;wb(e- -64|0)}wb(e+48|0);break a}f:{switch(c-65534|0){case 0:v[23516]=0;c=Q(53,e+32|0,9269)|0;d=v[23516];v[23516]=0;g:{if((d|0)!=1){v[23516]=0;R(181,f|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break g}wb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;wb(c);break a;case 1:v[23516]=0;c=Q(53,e+16|0,9231)|0;d=v[23516];v[23516]=0;h:{if((d|0)!=1){v[23516]=0;R(181,f|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break h}wb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;wb(c);break a;default:break f}}v[23516]=0;c=Q(53,e|0,14703)|0;d=v[23516];v[23516]=0;i:{if((d|0)!=1){v[23516]=0;R(181,f|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break i}wb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;wb(c);break a}hb=e+80|0;return}a=a+1|0;continue}}a=P()|0;O()|0}Me(f);S(a|0);L()}function Kda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-48|0;hb=e;u[e+46>>1]=254;c=qj(a);g=Lb(e+32|0);a:{b:{if(c){v[23516]=0;R(630,g|0,c|0);f=v[23516];v[23516]=0;if((f|0)==1){break a}iC(g,c)}break b}c:{while(1){d:{if((b|0)==(c|0)){if(!(d&65535)){break c}c=Cb(v[a>>2]);d=Cb(v[a+4>>2]);b=hb-16|0;hb=b;c=Xz(c,d,x[e+46>>1]);v[b+8>>2]=c;if(Nb(c,d)){v[b>>2]=c;while(1){c=v[Qe(b)>>2];if(Nb(c,d)){c=x[c>>1];if((c|0)==x[e+46>>1]){continue}u[v[b+8>>2]>>1]=c;Qe(b+8|0);continue}break}c=v[b+8>>2]}hb=b+16|0;b=cc(e+24|0,c);c=v[cc(e+16|0,Cb(v[a+4>>2]))>>2];d=v[b>>2];b=v[a>>2];b=(ro(d,Cb(b))<<1)+b|0;if(Nb(d,c)){Ld(a,Mi(b+(ro(c,d)<<1)|0,v[a+4>>2],b))}Cb(b);k=e,l=Cb(v[a>>2]),v[k+8>>2]=l;d=Cb(v[a+4>>2]);break d}k=$b(v[g>>2],b),l=b-d|0,u[k>>1]=l;f=v[a+4>>2];h=v[a>>2];v[23516]=0;f=W(766,h|0,f|0,b|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}b=b+1|0;d=(x[f>>1]==254)+d|0;continue}break}while(1){b=v[e+8>>2];if(!Nb(b,d)){b=v[g>>2];d=Oc(b,v[g+4>>2]);c=x[a+28>>1];if(d>>>0<=c>>>0){break c}k=a,l=x[$b(b,c)>>1],u[k+28>>1]=l;break c}e:{c=v[a+24>>2];f=v[c+484344>>2];b=x[b>>1];if(!te(f,v[c+484348>>2],b)){break e}b=Xb(f,b);k=e,l=Cb(v[b>>2]),v[k>>2]=l;f=Cb(v[b+4>>2]);h=v[g+4>>2];c=v[g>>2];while(1){b=v[e>>2];if(!Nb(b,f)){break e}f:{if(w[b+3|0]!=12){break f}j=Oc(c,h);i=w[b+5|0];if(j>>>0<=i>>>0){break f}k=b,l=w[$b(c,i)|0],t[k+5|0]=l}vk(e);continue}}Qe(e+8|0);continue}}gd(g);hb=e+48|0;return}a=P()|0;O()|0;gd(g);S(a|0);L()}function dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=hb-48|0;hb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){b=v[g+16>>2];j=b>>>18|0;i=((((v[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=i+(e<<1)|0;f=u[h>>1];v[(g+8|0)+(e<<2)>>2]=f+((B(j,u[h+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=v[j>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=rka(w,x,f,f>>31);k=kb;A=e;e=Wb(h,-16777216,16776704);h=rka(s,t,e,e>>31);f=h+f|0;e=kb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Wb(i,-16777216,16776704);i=rka(q,r,f,f>>31);f=k+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[A+4>>2]=e-(p&l);v[j>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Pb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=hb-48|0;hb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;u=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){b=v[g+16>>2];j=b>>>10&4194048;i=(((v[g+20>>2]&2147483647)<<1|b>>>31)&-2)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=e+i|0;f=t[h|0];v[(g+8|0)+(e<<2)>>2]=((B(j,t[h+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=v[j>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=rka(w,x,f,f>>31);k=kb;A=e;e=Wb(h,-16777216,16776704);h=rka(s,u,e,e>>31);f=h+f|0;e=kb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Wb(i,-16777216,16776704);i=rka(q,r,f,f>>31);f=k+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[A+4>>2]=e-(p&l);v[j>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Pb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=hb-48|0;hb=g;n=v[a+16>>2];k=Rf(1,2);b=kb;o=b;Pb(a,k,b);b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){d=d-1|0;f=((((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&2147483646)<<1)+n|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=u[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;m=f<<8;f=m;f=rka(y,z,f,f>>31);j=kb;D=e;e=Wb(h,-16777216,16776704);h=rka(w,x,e,e>>31);f=h+f|0;e=kb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Wb(i,-16777216,16776704);i=rka(s,t,f,f>>31);f=j+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[D+4>>2]=e-(r&m);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+12>>2]);Pb(g+16|0,A,C);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}lg(a,k,o);hb=g+48|0}function Y7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=hb-16|0;hb=j;i=hb-32|0;hb=i;h=kf(i+16|0,1,0);a:{b:{c:{while(1){g=wc(h);d=g+Fb(h)|0;c=v[b>>2];f=v[b+4>>2];if(!((f|0)>0|(f|0)>=0|(d|0)==(g|0))){t[g|0]=45;e=c;c=0-c|0;g=g+1|0;f=0-(f+((e|0)!=0)|0)|0}k=d-g|0;d:{if((k|0)<=19){e=E(f);e=B(64-((e|0)==32?E(c|1)+32|0:e)|0,1233)>>>12|0;n=(e<<3)+25968|0;l=k;k=v[n+4>>2];m=61;if((l|0)<((e-((f|0)==(k|0)&c>>>0<y[n>>2]|f>>>0<k>>>0)|0)+1|0)){break d}}e:{if(!f&c>>>0<=99999999){d=Rw(g,c);break e}if((f|0)==2328306&c>>>0<=1874919423|f>>>0<2328306){d=uka(c,f,1e8,0);e=kb;l=Rw(g,d);d=rka(d,e,-1e8,0)+c|0;c=d;d=(c>>>0)/1e4|0;d=$i($i(l,d),c+B(d,-1e4)|0);break e}d=uka(c,f,1874919424,2328306);e=kb;g=Qw(g,d);d=rka(d,e,-1874919424,-2328307)+c|0;e=f+kb|0;e=c>>>0>d>>>0?e+1|0:e;c=uka(d,e,1e8,0);e=kb;f=(c>>>0)/1e4|0;l=$i($i(g,f),c+B(f,-1e4)|0);c=rka(c,e,-1e8,0)+d|0;d=(c>>>0)/1e4|0;d=$i($i(l,d),c+B(d,-1e4)|0)}m=0}v[i+12>>2]=m;v[i+8>>2]=d;if(!v[i+12>>2]){break c}c=Yg(Fb(h));v[23516]=0;R(57,h|0,c|0);c=v[23516];v[23516]=0;if((c|0)!=1){continue}break}break b}b=v[i+8>>2];c=wc(h);v[23516]=0;R(58,h|0,b-c|0);b=v[23516];v[23516]=0;f:{if((b|0)!=1){v[23516]=0;R(59,j|0,h|0);b=v[23516];v[23516]=0;if((b|0)!=1){break f}break b}break b}wb(h);hb=i+32|0;break a}a=P()|0;O()|0;wb(h);S(a|0);L()}v[23516]=0;R(56,a|0,j|0);a=v[23516];v[23516]=0;if((a|0)!=1){wb(j);hb=j+16|0;return}a=P()|0;O()|0;wb(j);S(a|0);L()}function z$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-384|0;hb=a;v[a+368>>2]=c;v[a+376>>2]=b;mw(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Kb(a+200|0);b=_c(d);v[23516]=0;R(58,d|0,b|0);b=v[23516];v[23516]=0;a:{b:{c:{if((b|0)!=1){c=Jc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=v[a+232>>2];i=v[a+236>>2];while(1){d:{v[23516]=0;b=Q(1158,a+376|0,a+368|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+196>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23516]=0;R(58,d|0,b<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+196>>2]=b+c}v[23516]=0;b=T(1160,v[a+376>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(lw(b,a+23|0,a+22|0,c,a+196|0,i,h,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23516]=0;T(1162,a+376|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}gG(a,c,v[a+196>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;Cf(a+216|0,a+32|0,v[a+28>>2],e);v[23516]=0;b=Q(1159,a+376|0,a+368|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];wb(d);wb(a+216|0);hb=a+384|0;break a}}b=P()|0;O()|0;wb(d);wb(a+216|0);S(b|0);L()}return b|0}function I$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-288|0;hb=a;v[a+272>>2]=c;v[a+280>>2]=b;qw(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Kb(a+208|0);b=_c(d);v[23516]=0;R(58,d|0,b|0);b=v[23516];v[23516]=0;a:{b:{c:{if((b|0)!=1){c=Jc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=t[a+238|0];i=t[a+239|0];while(1){d:{v[23516]=0;b=Q(1142,a+280|0,a+272|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+204>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23516]=0;R(58,d|0,b<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+204>>2]=b+c}v[23516]=0;b=T(1144,v[a+280>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(pw(b,a+23|0,a+22|0,c,a+204|0,i,h,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23516]=0;T(1146,a+280|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}gG(a,c,v[a+204>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;Cf(a+224|0,a+32|0,v[a+28>>2],e);v[23516]=0;b=Q(1143,a+280|0,a+272|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];wb(d);wb(a+224|0);hb=a+288|0;break a}}b=P()|0;O()|0;wb(d);wb(a+224|0);S(b|0);L()}return b|0}function rj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!Vd(v[a>>2],v[a+20>>2])){break a}wk(a);b:{switch(Qm(x[a+34>>1])-1|0){case 1:e=hb+-64|0;hb=e;h=v[a+20>>2];c=v[a>>2];d=Hd(x[a+34>>1]);f=h+(B(c,d)<<1)|0;while(1){c:{d:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break d}g=f+(d<<5)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];Ab(e+32|0,b+1074312|0,33);aP(e+40|0,g,h+(B(d,f)<<1)|0,i-f|0,d,(c&4)>>>2|0,zb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];Ab(e+32|0,b+1074312|0,33);aP(e+8|0,g+(d<<7)|0,h+(B(a,d)<<1)|0,f-a|0,d,(c&16)>>>4|0,zb(v[v[e+32>>2]>>2],v[e+36>>2]))}hb=e- -64|0;break c}while(1){if((c|0)!=(d|0)){u[f+(c+i<<1)>>1]=x[f+(c-d<<1)>>1];u[h+(c+j<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;continue}break}g=g+1|0;continue}break};return;case 0:break b;default:break a}}e=hb+-64|0;hb=e;h=v[a+20>>2];c=v[a>>2];d=Hd(x[a+34>>1]);f=h+B(c,d)|0;while(1){e:{f:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break f}g=f+(d<<4)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];Ab(e+32|0,b+1074312|0,33);$O(e+40|0,g,h+B(d,f)|0,i-f|0,d,(c&4)>>>2|0,zb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];Ab(e+32|0,b+1074312|0,33);$O(e+8|0,g+(d<<6)|0,h+B(a,d)|0,f-a|0,d,(c&16)>>>4|0,zb(v[v[e+32>>2]>>2],v[e+36>>2]))}hb=e- -64|0;break e}while(1){if((c|0)!=(d|0)){t[f+(c+i|0)|0]=w[f+(c-d|0)|0];t[h+(c+j|0)|0]=w[c+h|0];c=c+1|0;continue}break}g=g+1|0;continue}break}}}function f$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=hb-432|0;hb=i;v[i+424>>2]=37;v[i+428>>2]=0;m=Fr(i+424|1,13962,v[c+4>>2]);v[i+380>>2]=i+384;a=Dd();a:{if(m){j=v[c+8>>2];k=i- -64|0;v[k>>2]=g;v[k+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=j;j=Ug(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=Ug(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=1140;l=pe(i+368|0,0,i+128|0);k=i+384|0;a=k;b:{c:{d:{if((j|0)>=30){a=Dd();e:{if(m){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Ui(i+380|0,a,i+424|0,i);break e}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Ui(i+380|0,a,i+424|0,i+32|0)}if((j|0)==-1){v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)==1){break c}break d}a=v[i+380>>2];Xe(l,a)}f=a+j|0;g=Vi(a,f,c);v[i+116>>2]=1140;e=pe(i+120|0,0,i+116|0);f:{g:{if((i+384|0)==(a|0)){j=i+128|0;break g}j=Md(j<<3);if(!j){v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Xe(e,j);k=a}a=i+104|0;bd(a,c);v[23516]=0;ja(1173,k|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[23516];v[23516]=0;h:{if((a|0)!=1){Zb(i+104|0);v[23516]=0;a=ka(1174,b|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break h}Sc(e);Sc(l);hb=i+432|0;return a|0}c=P()|0;O()|0;Zb(i+104|0);break f}c=P()|0;O()|0}Sc(e);break b}L()}c=P()|0;O()|0}Sc(l);S(c|0);L()}function p$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=hb-256|0;hb=i;v[i+248>>2]=37;v[i+252>>2]=0;m=Fr(i+248|1,13962,v[c+4>>2]);v[i+204>>2]=i+208;a=Dd();a:{if(m){j=v[c+8>>2];k=i- -64|0;v[k>>2]=g;v[k+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=j;j=Ug(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=Ug(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=1140;l=pe(i+192|0,0,i+128|0);k=i+208|0;a=k;b:{c:{d:{if((j|0)>=30){a=Dd();e:{if(m){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Ui(i+204|0,a,i+248|0,i);break e}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Ui(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)==1){break c}break d}a=v[i+204>>2];Xe(l,a)}f=a+j|0;g=Vi(a,f,c);v[i+116>>2]=1140;e=pe(i+120|0,0,i+116|0);f:{g:{if((i+208|0)==(a|0)){j=i+128|0;break g}j=Md(j<<1);if(!j){v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Xe(e,j);k=a}a=i+104|0;bd(a,c);v[23516]=0;ja(1168,k|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[23516];v[23516]=0;h:{if((a|0)!=1){Zb(i+104|0);v[23516]=0;a=ka(15,b|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break h}Sc(e);Sc(l);hb=i+256|0;return a|0}c=P()|0;O()|0;Zb(i+104|0);break f}c=P()|0;O()|0}Sc(e);break b}L()}c=P()|0;O()|0}Sc(l);S(c|0);L()}function _V(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-32|0;hb=f;xc(c);while(1){a:{if(!Ob(v[c>>2],v[c+8>>2],3)){break a}d=f+24|0;Oq(d,c);i=Kc(d);h=Re(d);d=w[f+24|0];if(d>>>0>=y[a+12>>2]){break a}g=ed(v[a>>2],v[v[a+48>>2]+12>>2],d,b);d=w[i|0];if(d>>>0<=126){if(!(d|w[h|0])){t[g|0]=254;continue}t[g|0]=d+1;if(w[h|0]==255){continue}t[g+2|0]=1;t[g+4|0]=w[h|0];continue}b:{switch(d-127|0){case 1:t[g+1|0]=w[h|0]+1;continue;case 0:continue;default:break b}}e=t[h|0];t[f+23|0]=e;h=0;j=w[i|0];d=j&127;if(d>>>0<=23){h=w[d+26368|0]}c:{d:{e:{f:{g:{switch(d-2|0){case 0:case 8:case 9:if((e|0)>=0){break f}d=0-e&15;break e;case 1:t[f+16|0]=64;e=w[Vb(f+23|0,f+16|0)|0];if(w[g+2|0]>1){break d}t[g+4|0]=e;t[g+2|0]=1;continue;case 2:d=3;if((e|0)>=0){break c}d=0-e&127;break e;case 15:if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e;case 16:case 20:if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;t[f+23|0]=e;j=w[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;t[f+23|0]=e;break c;case 17:d=e&15|-48;break e;case 18:d=e&15|-64;break e;case 21:break g;default:break d}}d=164;if((e|0)==100){break e}v[f+16>>2]=e- -64;v[f+12>>2]=0;v[f+8>>2]=128;e=v[Gj(f+16|0,f+12|0,f+8|0)>>2];if(!w[g+3|0]){break d}h:{switch(w[g+2|0]){case 0:case 2:break h;default:continue}}t[g+2|0]=2;t[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;t[f+23|0]=e}d=h;if(!d){continue}}t[g+5|0]=e;t[g+3|0]=d;continue}break}hb=f+32|0}function vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=hb-48|0;hb=g;n=v[a+16>>2];k=Rf(1,2);b=kb;o=b;Pb(a,k,b);b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){d=d-1|0;f=(((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&-2)+n|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=t[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;m=f<<8;f=m;f=rka(y,z,f,f>>31);j=kb;D=e;e=Wb(h,-16777216,16776704);h=rka(w,x,e,e>>31);f=h+f|0;e=kb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Wb(i,-16777216,16776704);i=rka(s,u,f,f>>31);f=j+i|0;e=kb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Tc(f,e,24);v[D+4>>2]=e-(r&m);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+12>>2]);Pb(g+16|0,A,C);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}lg(a,k,o);hb=g+48|0}function Gq(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;t[e+15|0]=c;a:{b:{c:{d:{switch(b-2|0){case 11:t[e+14|0]=64;ae(a,1,Vb(e+15|0,e+14|0));break a;case 0:if(!(c&3|c>>>0>223?d:1)){break c}t[e+14|0]=c>>>2;ae(a,12,e+14|0);break a;case 1:if(!(c&3|c>>>0>223?d:1)){break c}t[e+14|0]=c>>>2;ae(a,13,e+14|0);break a;case 2:if(c>>>0>=240){t[e+14|0]=9;ae(a,11,e+14|0);break a}b=0;while(1){if((b|0)==10){break c}f=w[b+43920|0];e:{if(d){if(c>>>0>f>>>0){break e}break b}if((c|0)==(f|0)){break b}}b=b+1|0;continue};case 3:f:{if(d){t[e+14|0]=c&15;t[e+13|0]=9;c=w[Vb(e+14|0,e+13|0)|0];t[e+15|0]=c;break f}if(c&240|(c&14)>>>0>9){break c}}t[e+14|0]=c&15;ae(a,8,e+14|0);break a;case 24:g:{if(d){t[e+15|0]=0;break g}if(c){break c}}ae(a,8,e+15|0);break a;case 7:t[e+15|0]=(c|0)==255?64:c>>>2|0;ae(a,2,e+15|0);break a;case 9:if(!c){break c}b=c&15;if(!b){t[e+14|0]=c>>>4;ae(a,3,e+14|0);break a}d=c&240;if(!d){ae(a,4,e+15|0);break a}if((b|0)==15){t[e+14|0]=c>>>4;ae(a,5,e+14|0);break a}if((d|0)!=240){break c}t[e+14|0]=c&15;ae(a,6,e+14|0);break a;case 18:if((c&240)!=128){break c}t[e+14|0]=c<<2&60|2;ae(a,2,e+14|0);break a;case 17:break d;default:break c}}h:{switch((c>>>4|0)-8|0){case 0:t[e+14|0]=c<<2&60|2;ae(a,2,e+14|0);break a;case 2:t[e+14|0]=c&15;ae(a,5,e+14|0);break a;case 3:break h;default:break c}}t[e+14|0]=c&15;ae(a,6,e+14|0);break a}t[e+14|0]=0;ae(a,0,e+14|0);break a}t[e+14|0]=b;ae(a,11,e+14|0)}hb=e+16|0}function Wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;g=hb-16|0;hb=g;s=v[a+16>>2];t=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=kg(k,l,n);p=kb;b=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Of(i,e,mf(k,l,d),kb);m=b>>>0<kb>>>0?d:0}h=a+112|0;f=v[a+48>>2];w=v[a+24>>2];x=v[a+20>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=(e<<1)+s|0;b=n;while(1)if((b|0)<=0){Pb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Od(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Nd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];b=v[a+60>>2];e=b;j=b>>31;r=ig(h,t)<<8;b=r;b=rka(e,j,b,b>>31);y=kb;e=b;b=v[a+64>>2];j=b;z=b>>31;b=Wb(q,-16777216,16776704);j=rka(j,z,b,b>>31);e=e+j|0;b=kb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Wb(f,-16777216,16776704);e=rka(e,e>>31,f,f>>31);f=j+e|0;b=kb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Tc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(f,x)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(f,w);Pb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=q;continue b}else{Od(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Nd(h,4);Pb(g+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+48>>2]=f;v[a+44>>2]=q;hb=g+16|0}
function y$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-352|0;hb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Kb(a+208|0);b=a+16|0;bd(b,d);v[23516]=0;b=T(1153,b|0)|0;c=v[23516];v[23516]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23516]=0;X(1165,b|0,84e3,84026,a+224|0);b=v[23516];v[23516]=0;if((b|0)==1){break d}Zb(a+16|0);c=Kb(a+192|0);b=_c(c);v[23516]=0;R(58,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break b}b=Jc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23516]=0;d=Q(1158,a+344|0,a+336|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=Fb(c);if((g|0)==(d+b|0)){v[23516]=0;R(58,c|0,d<<1);b=v[23516];v[23516]=0;if((b|0)==1){break b}b=_c(c);v[23516]=0;R(58,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break b}b=Jc(c,0);v[a+188>>2]=d+b}v[23516]=0;d=T(1160,v[a+344>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break e}if(mn(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23516]=0;T(1162,a+344|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;Zb(a+16|0);break a}v[23516]=0;R(58,c|0,v[a+188>>2]-b|0);b=v[23516];v[23516]=0;f:{if((b|0)==1){break f}b=Ic(c);d=Dd();v[a>>2]=f;if((eG(b,d,a)|0)!=1){v[e>>2]=4}v[23516]=0;b=Q(1159,a+344|0,a+336|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];wb(c);wb(h);hb=a+352|0;return b|0}}b=P()|0;O()|0;wb(c)}wb(h);S(b|0);L()}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;h=hb-16|0;hb=h;a:{b:{c:{i=v[a+12>>2];j=v[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];f=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];b=v[a+44>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;r=v[a+72>>2];e=v[a+68>>2];s=e;t=e>>31;e=v[a+64>>2];w=e;x=e>>31;e=v[a+60>>2];y=e;z=e>>31;while(1){e=b;if(d){b=Wb(e,-16777216,16776704);b=rka(w,x,b,b>>31);k=kb;l=b;g=(v[h+12>>2]<<1)+o|0;b=(v[h+8>>2]>>>16&65520)+n|0;g=(((((((B(u[g-4>>1],u[b+2>>1])+B(u[g-6>>1],u[b>>1])|0)+B(u[g-2>>1],u[b+4>>1])|0)+B(u[g>>1],u[b+6>>1])|0)+B(u[g+2>>1],u[b+8>>1])|0)+B(u[g+4>>1],u[b+10>>1])|0)+B(u[g+6>>1],u[b+12>>1])|0)+B(u[g+8>>1],u[b+14>>1])|0)/32768<<8;b=g;b=rka(b,b>>31,y,z);l=l+b|0;m=kb+k|0;m=b>>>0>l>>>0?m+1|0:m;b=Wb(f,-16777216,16776704);f=rka(s,t,b,b>>31);k=f+l|0;b=kb+m|0;b=f>>>0>k>>>0?b+1|0:b;f=k+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Tc(f,b,24);b=(f|0)/256|0;v[c>>2]=B(b,q)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,p);Pb(h+8|0,j,i);b=f-(g&r)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;v[a+48>>2]=f;v[a+44>>2]=e;hb=h+16|0}function $D(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-96|0;hb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){vc(a,9769);break j}if(!(b&65535)){d=hb-16|0;hb=d;e=vc(d,4402);Xc(c+80|0,e);xb(e);hb=d+16|0;v[23516]=0;v[c+24>>2]=b>>>24;R(107,c- -64|0,c+24|0);d=v[23516];v[23516]=0;k:{l:{m:{n:{if((d|0)!=1){v[23516]=0;v[c+8>>2]=b>>>16&255;R(108,c+48|0,c+8|0);b=v[23516];v[23516]=0;if((b|0)==1){break n}v[23516]=0;X(109,a|0,c+80|0,c- -64|0,c+48|0);a=v[23516];v[23516]=0;if((a|0)==1){break m}xb(c+48|0);xb(c- -64|0);ac(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;xb(c+48|0)}xb(c- -64|0)}break a}d=hb-16|0;hb=d;e=vc(d,4126);Xc(c+80|0,e);xb(e);hb=d+16|0;v[23516]=0;v[c+44>>2]=b>>>24;R(107,c- -64|0,c+44|0);d=v[23516];v[23516]=0;if((d|0)==1){break i}v[23516]=0;v[c+40>>2]=b>>>16&255;R(108,c+48|0,c+40|0);d=v[23516];v[23516]=0;if((d|0)==1){break h}v[23516]=0;v[c+20>>2]=b>>>8&255;R(108,c+24|0,c+20|0);d=v[23516];v[23516]=0;if((d|0)==1){break g}v[23516]=0;v[c+4>>2]=b&255;R(108,c+8|0,c+4|0);b=v[23516];v[23516]=0;if((b|0)==1){break f}v[23516]=0;la(110,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[23516];v[23516]=0;if((a|0)==1){break e}xb(c+8|0);xb(c+24|0);xb(c+48|0);xb(c- -64|0);ac(c+80|0)}hb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;xb(c+8|0)}xb(c+24|0)}xb(c+48|0)}xb(c- -64|0)}ac(c+80|0);S(b|0);L()}function H$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-272|0;hb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Kb(a+208|0);b=a+16|0;bd(b,d);v[23516]=0;b=T(19,b|0)|0;c=v[23516];v[23516]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23516]=0;X(1151,b|0,84e3,84026,a+224|0);b=v[23516];v[23516]=0;if((b|0)==1){break d}Zb(a+16|0);c=Kb(a+192|0);b=_c(c);v[23516]=0;R(58,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break b}b=Jc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23516]=0;d=Q(1142,a+264|0,a+256|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=Fb(c);if((g|0)==(d+b|0)){v[23516]=0;R(58,c|0,d<<1);b=v[23516];v[23516]=0;if((b|0)==1){break b}b=_c(c);v[23516]=0;R(58,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break b}b=Jc(c,0);v[a+188>>2]=d+b}v[23516]=0;d=T(1144,v[a+264>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break e}if(on(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23516]=0;T(1146,a+264|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;Zb(a+16|0);break a}v[23516]=0;R(58,c|0,v[a+188>>2]-b|0);b=v[23516];v[23516]=0;f:{if((b|0)==1){break f}b=Ic(c);d=Dd();v[a>>2]=f;if((eG(b,d,a)|0)!=1){v[e>>2]=4}v[23516]=0;b=Q(1143,a+264|0,a+256|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];wb(c);wb(h);hb=a+272|0;return b|0}}b=P()|0;O()|0;wb(c)}wb(h);S(b|0);L()}function QX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Kb(a);a=w[b+11|0];g=v[b+4>>2];v[23516]=0;k=zk(g,a);R(113,h|0,k|0);a=v[23516];v[23516]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=w[qd(b)+a|0];d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(e-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(e-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}v[23516]=0;Q(114,h|0,Jd(c,g)|0)|0;j=v[23516];v[23516]=0;g=e;if((j|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;i=e;break d;case 3:f=-1;j:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break d}v[23516]=0;Q(114,h|0,Jd(c,i)|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}i=(B(i,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}j=(e|0)!=125;f=-1;e=125;if(j){break d}}f=0;v[23516]=0;Q(115,h|0,e|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;v[23516]=0;a=T(116,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){v[23516]=0;U(117,a|0,41988,25);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ca(b|0);break b}a=P()|0;O()|0}xb(h);S(a|0)}L()}function Sy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-16|0;hb=h;f=v[c+656>>2];a:{if(!uj(f)){i=v[c+704>>2];f=hb-16|0;hb=f;v[f+12>>2]=d;g=0;b:{if(!d){break b}j=v[b+480180>>2];if(j&20){e=b+1074312|0;Ab(f,e,73);d=zb(v[v[f>>2]>>2],v[f+4>>2])?d&65535:d;if(w[b+480208|0]&16){Ab(f,e,73);e=zb(v[v[f>>2]>>2],v[f+4>>2])?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=v[((d>>>0)%768<<2)+34112>>2]<<6>>>e|0;break b}if(!d){v[f+12>>2]=1;d=1}g=229079296/(d>>>0)|0;break b}g=227001280/(d>>>0)|0;if(Am(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}uc(f+12|0,16777215);if(j&17408){g=Bc(uka(rka(i?i:8363,0,3506176,0),kb,(v[f+12>>2]<<8)+e|0,0),kb);break b}if(jj(b)){d=v[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(w[b+480208|0]&16){g=Bc(uka(rka(i?i:8363,0,7012352,0),kb,(v[f+12>>2]<<8)+e|0,0),kb);break b}g=Bc(uka(-1485242368,13,(v[f+12>>2]<<8)+e|0,0),kb)}d=g;hb=f+16|0;f=v[c+656>>2];break a}d=v[c+700>>2]}v[h+12>>2]=d;c=u[c+774>>1];c:{if(!c){break c}c=f?B(t[f+33|0],c):c;if(!c){break c}d=Oe(ni(+(c|0)/393216)*+(d>>>0));v[h+12>>2]=d}d:{if(!f){break d}c=v[f+40>>2];if(!c){break d}e=(c|0)/2|0;f=v[b+1074420>>2];d=rka(f,f>>31,d,d>>31);f=e+d|0;e=kb+(e>>31)|0;k=h,l=Dc(ska(f,d>>>0>f>>>0?e+1|0:e,c,c>>31),kb),v[k+12>>2]=l}uc(h+12|0,2147483647);c=v[h+12>>2];b=Rf(c,v[b+24620>>2]<<4);v[a+8>>2]=c;v[a>>2]=b;v[a+4>>2]=kb;hb=h+16|0}function gz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{e=a;b:{c:{h=a+62|0;f=Ib(h,b);a=t[f|0];if((a|0)==-1){break c}if((a|0)>=0){break b}a=a&127;d=$b(e+26|0,a);g=x[d>>1];if((g|0)!=65535&(b|0)!=(g|0)){break c}u[d>>1]=b;t[f|0]=a;break b}l=e+8|0;i=e+26|0;d=255;a=0;g=255;while(1){if((a|0)!=18){j=$b(i,a);k=x[j>>1];if((k|0)==65535){u[j>>1]=b;t[f|0]=a;break b}else{if(!(w[Ib(l,a)|0]&32)){g=t[Ib(h,k)|0]<0?a:g;d=a}a=a+1|0;continue}}break}if((d&255)!=255){a=(g&255)==255?d:g;d=$b(i,a&255);m=Ib(h,x[d>>1]),n=255,t[m|0]=n;u[d>>1]=b;t[f|0]=a}a=gl(e,b)}g=a&255;if((g|0)==255){break a}if(gk(v[e>>2])){break a}d=Jd(e+318|0,g);a=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=a;t[d+9|0]=a>>>8;t[d+10|0]=a>>>16;t[d+11|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=a;t[d+5|0]=a>>>8;t[d+6|0]=a>>>16;t[d+7|0]=a>>>24;f=EO(g);h=f+3|0;a=0;while(1){if((a|0)==2){ah(v[e>>2],v[e+4>>2],b,jt(g)|192,w[Ib(c,10)|0])}else{d=a?h:f;ah(v[e>>2],v[e+4>>2],b,(d|32)&65535,w[Ib(c,a)|0]);ah(v[e>>2],v[e+4>>2],b,(d|64)&65535,w[Ib(c,a+2|0)|0]);ah(v[e>>2],v[e+4>>2],b,(d|96)&65535,w[Ib(c,a+4|0)|0]);ah(v[e>>2],v[e+4>>2],b,(d|128)&65535,w[Ib(c,a+6|0)|0]);ah(v[e>>2],v[e+4>>2],b,(d|224)&65535,w[Ib(c,a+8|0)|0]);a=a+1|0;continue}break}}}function zR(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=hb-16|0;hb=j;a:{if((b|0)==(c|0)){break a}v[j+12>>2]=-1953789045;Uz(b,c,j+12|0);c=c-b|0;e=c>>2;v[j+8>>2]=e;f=sc(v[a>>2],v[a+4>>2]);g=11;b:{if(c>>>0>2488){break b}g=7;if(c>>>0>268){break b}g=5;if(c>>>0>152){break b}g=3;if(c>>>0>24){break b}g=e-1>>>1|0}c=f+1|0;v[j+4>>2]=c;n=v[Vc(j+4|0,j+8|0)>>2];k=e-g>>>1|0;d=(k<<2)+b|0;h=v[d>>2];i=B(Gt(v[((e<<2)+b|0)-4>>2]^(h^v[b>>2])),1664525);v[d>>2]=i+h;g=g+k|0;d=(g<<2)+b|0;f=f+i|0;v[d>>2]=f+v[d>>2];v[b>>2]=f;i=v[a>>2];a=1;while(1)if((a|0)==(c|0)){while(1)if(c>>>0>=n>>>0){c=n;while(1){if(e+n>>>0<=c>>>0){break a}d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=v[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=B(Gt(v[((c-1>>>0)%(e>>>0)<<2)+b>>2]+(h+v[i>>2]|0)|0),1566083941);v[d>>2]=a^h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a-f|0;v[d>>2]=a^v[d>>2];v[i>>2]=a;c=c+1|0;continue}}else{d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=v[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=B(Gt(v[((c-1>>>0)%(e>>>0)<<2)+b>>2]^(h^v[i>>2])),1664525);v[d>>2]=a+h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a+f|0;v[d>>2]=a+v[d>>2];v[i>>2]=a;c=c+1|0;continue}}else{d=a-1|0;l=((a+k>>>0)%(e>>>0)<<2)+b|0;m=v[l>>2];h=(a>>>0)%(e>>>0)|0;o=(h<<2)+b|0;f=B(Gt(v[((d>>>0)%(e>>>0)<<2)+b>>2]^(m^v[o>>2])),1664525);v[l>>2]=f+m;l=((a+g>>>0)%(e>>>0)<<2)+b|0;m=v[l>>2];f=v[Bb(i,d)>>2]+(f+h|0)|0;v[l>>2]=f+m;v[o>>2]=f;a=a+1|0;continue}}hb=j+16|0}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;h=hb-16|0;hb=h;a:{b:{c:{i=v[a+12>>2];k=v[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];b=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];e=v[a+44>>2];f=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=f;p=v[a+72>>2];f=v[a+68>>2];q=f;r=f>>31;f=v[a+64>>2];s=f;w=f>>31;f=v[a+60>>2];x=f;y=f>>31;while(1){f=e;if(d){e=Wb(f,-16777216,16776704);e=rka(s,w,e,e>>31);g=kb;j=e;b=Wb(b,-16777216,16776704);e=rka(q,r,b,b>>31);j=j+e|0;b=kb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=v[h+12>>2]+m|0;e=(v[h+8>>2]>>>16&65520)+l|0;g=(((((((B(t[g-2|0],u[e+2>>1])+B(t[g-3|0],u[e>>1])|0)+B(t[g-1|0],u[e+4>>1])|0)+B(t[g|0],u[e+6>>1])|0)+B(t[g+1|0],u[e+8>>1])|0)+B(t[g+2|0],u[e+10>>1])|0)+B(t[g+3|0],u[e+12>>1])|0)+B(t[g+4|0],u[e+14>>1])<<8)/32768<<8;e=g;e=rka(e,e>>31,x,y);j=e+j|0;b=kb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Tc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(b,o)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,n);Pb(h+8|0,k,i);e=e-(g&p)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=b;v[a+44>>2]=f;hb=h+16|0}function cka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Kb(a);k=Fb(b);v[23516]=0;R(300,h|0,k|0);a=v[23516];v[23516]=0;a:{b:{if((a|0)!=1){a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=t[gg(b,a)|0];g=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(g-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(g-123|0){case 2:m=1;e=i+1|0;f=0;if(d>>>0<=i>>>0){i=e;break d}v[23516]=0;Q(301,h|0,Jd(c,i)|0)|0;g=v[23516];v[23516]=0;i=e;if((g|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(g-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}v[23516]=0;Q(301,h|0,Jd(c,j)|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(B(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}g=(e|0)!=125;f=-1;e=125;if(g){break d}}f=0;v[23516]=0;Q(302,h|0,e|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;v[23516]=0;a=T(116,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){v[23516]=0;U(117,a|0,41988,25);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ca(b|0);break b}a=P()|0;O()|0}wb(h);S(a|0)}L()}function zN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-32|0;hb=e;f=v[b+64>>2];a:{b:{h=v[b+60>>2];g=x[b+68>>1];if(!((h|0)==-1&(g|0)==65535)){c:{if((f|0)==-1){break c}f=a+1074312|0;Ab(e+24|0,f,68);if(zb(v[v[e+24>>2]>>2],v[e+28>>2])){break c}Ab(e+16|0,f,103);if(i=zb(v[v[e+16>>2]>>2],v[e+20>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}Ab(e+8|0,f,49);if(i=zb(v[v[e+8>>2]>>2],v[e+12>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}f=v[b+64>>2];break b}if((g|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((h|0)==-1){v[b+60>>2]=0}g=Oc(v[c>>2],v[c+4>>2]);f=x[b+68>>1];if(g>>>0<=f>>>0){f=x[c+28>>1];u[b+68>>1]=f}d:{if(x[b+72>>1]==(f&65535)){break d}c=a+1074312|0;Ab(e+24|0,c,26);if(zb(v[v[e+24>>2]>>2],v[e+28>>2])){break d}Ab(e+16|0,c,68);if(zb(v[v[e+16>>2]>>2],v[e+20>>2])|v[a+480180>>2]==1){break d}c=x[a+480188>>1];f=0;while(1){if((c|0)==(f|0)){break d}t[(B(f,872)+b|0)+1457|0]=0;f=f+1|0;continue}}v[b+52>>2]=v[b+60>>2];if(d){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((f|0)!=-1){break b}c=0;break a}v[b+52>>2]=f;u[b+74>>1]=x[b+72>>1];e:{if(!v[b+20>>2]){break e}c=v[a+480180>>2];if((c|0)==32){Ab(e+24|0,a+1074312|0,103);if(zb(v[v[e+24>>2]>>2],v[e+28>>2])){break e}c=v[a+480180>>2]}if((c|0)==2){break e}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[Xb(v[a+484344>>2],x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}hb=e+32|0;return c}function jZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=hb-16|0;hb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!v[b>>2]){break a}b=b+4|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=hb-16|0;hb=r;s=ji(r+8|0,v[a+8>>2]);i=f;j=g-f|0;m=0;o=hb-16|0;hb=o;k=v[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=Tw(j>>>0<4?o+12|0:i,v[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}pc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!v[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){v[e>>2]=k}hb=o+16|0;ii(s);hb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:v[h>>2]=f;while(1){i:{if(v[e>>2]==(c|0)){break i}b=fw(f,v[c>>2],v[a+8>>2]);if((b|0)==-1){break i}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;continue}break};v[e>>2]=c;break g;case 1:break c;default:break h}}f=m+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=v[e>>2];b=d;continue}b=fw(n+12|0,0,v[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-v[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=w[c|0];i=v[h>>2];v[h>>2]=i+1;t[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=v[e>>2]+4|0;v[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!v[b>>2]){break b}b=b+4|0;continue}}c=v[e>>2]}q=(c|0)!=(d|0)}hb=n+16|0;return q|0}f=v[h>>2];continue}}function Xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0;g=hb-16|0;hb=g;s=v[a+16>>2];u=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=kg(k,l,n);p=kb;b=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Of(i,e,mf(k,l,d),kb);m=b>>>0<kb>>>0?d:0}h=a+112|0;f=v[a+48>>2];w=v[a+24>>2];x=v[a+20>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=e+s|0;b=n;while(1)if((b|0)<=0){Pb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Od(h,t[e+v[g+12>>2]|0]<<6);Nd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];b=v[a+60>>2];e=b;j=b>>31;r=ig(h,u)<<8;b=r;b=rka(e,j,b,b>>31);y=kb;e=b;b=v[a+64>>2];j=b;z=b>>31;b=Wb(q,-16777216,16776704);j=rka(j,z,b,b>>31);e=e+j|0;b=kb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Wb(f,-16777216,16776704);e=rka(e,e>>31,f,f>>31);f=j+e|0;b=kb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Tc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(f,x)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(f,w);Pb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=q;continue b}else{Od(h,t[e+v[g+12>>2]|0]<<6);Nd(h,4);Pb(g+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+48>>2]=f;v[a+44>>2]=q;hb=g+16|0}function ny(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=Zq(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(c,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(c,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1),67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(c,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Mb(Mb(Mb(Mb(c,o,1),n,1),m,1),l,1);g=k;f=j;e=i;d=h}Mb(c,g,1)}Mb(Mb(Mb(c,f,1),e,1),d,1)}}function mI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-16|0;hb=h;g=v[a+32>>2];f=ts(g);if(!f){f=ss(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ba(8)|0;v[23516]=0;c=Q(53,h|0,6003)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(b,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(c);break b}if(c>>>0>=120){b=ba(8)|0;v[23516]=0;c=Q(53,h|0,11354)|0;a=v[23516];v[23516]=0;if((a|0)!=1){a=rc(b,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(c);break b}a=P()|0;O()|0;ca(b|0);break b}f=zy(g,65535);j=(f|0)==65535?255:f;u[h>>1]=j;f=g+B(j,872)|0;i=f+1074992|0;Vn(i,g,65535,1024);c=c+1|0;t[f+1075794|0]=c;t[f+1075791|0]=c;u[f+1075778>>1]=0;km(i);Pp(v[a+32>>2],i,b+1|0,0,1,1);v[f+1075688>>2]=65536;$s(v[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=pl(du(e*128,-128,128)+128),v[l>>2]=m;l=f+1075680|0,m=pl(du(d*256,0,256)),v[l>>2]=m;c=v[a+32>>2];i=c+1074478|0;b=i;c=b+(x[c+480212>>1]<<1)|0;g=x[h>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=x[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=x[f>>1];if((k|0)==(g|0)){continue}u[b>>1]=k;b=b+2|0;g=x[h>>1];continue}}l=v[a+32>>2],m=st(i,c),u[l+480212>>1]=m;hb=h+16|0;return j|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function uia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-80|0;hb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=hb-16|0;hb=e;f=vc(e,4454);Xc(d- -64|0,f);xb(f);hb=e+16|0;v[23516]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=rka(e,e>>31,1e4,0)+14780|0;b=kb;b=ska(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(95,d+48|0,d+44|0);g=v[23516];v[23516]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[23516]=0;v[d+28>>2]=(e+B(f,-12)|0)+1;R(97,d+32|0,d+28|0);e=v[23516];v[23516]=0;if((e|0)==1){break j}v[23516]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(97,d+16|0,d+12|0);b=v[23516];v[23516]=0;if((b|0)==1){break i}v[23516]=0;da(411,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}xb(d+16|0);xb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;xb(d+16|0)}xb(d+32|0)}xb(d+48|0)}break a}Qf(d- -64|0,4434);v[23516]=0;R(412,d+48|0,d+78|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}v[23516]=0;U(143,a|0,d- -64|0,d+48|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}}xb(d+48|0);ac(d- -64|0);hb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;xb(d+48|0)}ac(d- -64|0);S(b|0);L()}function xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0,A=0,C=0;i=hb-16|0;hb=i;jd(d,32);g=i+8|0;cQ(g,w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24),w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24),v[b>>2]);g=gc(g);cQ(i,w[a+40|0]|w[a+41|0]<<8|(w[a+42|0]<<16|w[a+43|0]<<24),w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24),v[c>>2]);a=0;g=v[g>>2];if(g-838861>>>0>=4294128436){a=v[gc(i)>>2];v[d>>2]=B(g,320);u[d+34>>1]=1;a:{m=Jg(d);if(!m){break a}l=g<<2;e=+(l>>>0);q=+(a>>>0)/e;r=+(g>>>0)/e;s=1/+y[d>>2];t=+y[i>>2];z=+y[i+8>>2];g=0;b:while(1){if((g|0)==(l|0)){break a}n=+(g>>>0);o=0;p=0;a=v[b+20>>2];if(Vd(v[b>>2],a)){e=n*r+z;c:{if(e<4294967296&e>=0){f=~~e>>>0;break c}f=0}k=x[b+34>>1];j=Hd(k);h=B(f,j);e=e-+(f>>>0);d:{if(k&1){f=x[a+(h<<1)>>1];a=x[a+(h+j<<1)>>1];break d}f=w[a+h|0]<<8;a=w[a+(h+j|0)|0]<<8}p=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}a=v[c+20>>2];if(Vd(v[c>>2],a)){e=n*q+t;e:{if(e<4294967296&e>=0){f=~~e>>>0;break e}f=0}k=x[c+34>>1];j=Hd(k);h=B(f,j);e=e-+(f>>>0);f:{if(k&1){f=x[a+(h<<1)>>1];a=x[a+(h+j<<1)>>1];break f}f=w[a+h|0]<<8;a=w[a+(h+j|0)|0]<<8}o=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}f=0;a=g;while(1)if((f|0)==80){g=g+1|0;continue b}else{e=s*+(a>>>0);A=v[d+20>>2]+(a<<1)|0,C=Iz(p*(1-e)+o*e),u[A>>1]=C;a=a+l|0;f=f+1|0;continue}}}a=(m|0)!=0}hb=i+16|0;return a|0}function NA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=hb-16|0;hb=j;a:{if(b&4){break a}c=w[a+14|0];b:{if(c>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|c>>>0<=w[a+13|0]){break a}e=v[a>>2];d=v[a+4>>2];if(Qd(e,d)>>>0<=c>>>0){break a}e=x[Lc(e,d,c)>>1];d=Lc(v[a>>2],v[a+4>>2],w[a+14|0]-1|0);c=w[a+14|0];if(x[d>>1]<(e-1|0)){c=x[Lc(v[a>>2],v[a+4>>2],c)>>1]-1&65535;e=Xp(a,c,64,64);d=cc(j+8|0,qm(Cb(v[a>>2]),w[a+14|0]));k=ql(j,c,e&255);m=hb-32|0;hb=m;c=v[d>>2];d=v[a>>2];c=(Nt(c,Cb(d))<<2)+d|0;h=v[a+4>>2];c:{d:{if(h>>>0<y[Db(a)>>2]){if((c|0)!=(h|0)){break d}zS(a,k);break c}d=Db(a);f=Tf(m+8|0,pg(a,sc(v[a>>2],h)+1|0),c-v[a>>2]>>2,d);v[23516]=0;R(768,f|0,k|0);d=v[23516];v[23516]=0;if((d|0)!=1){d=v[f+4>>2];i=f+4|0;aq(v[a>>2],c,i);e=v[a+4>>2];g=f+8|0;while(1){if((c|0)!=(e|0)){xm(v[g>>2],x[c>>1]|x[c+2>>1]<<16);v[g>>2]=v[g>>2]+4;c=c+4|0;continue}break}oc(a,i);oc(a+4|0,g);oc(Db(a),zc(f));v[f>>2]=v[f+4>>2];c=d;Sf(f);break c}a=P()|0;O()|0;Sf(f);S(a|0);L()}f=hb-16|0;hb=f;i=v[a+4>>2];d=(i-(c+4|0)|0)+c|0;g=eh(f,a,h-d>>2);l=v[g+4>>2];e=d;while(1){if(e>>>0>=h>>>0){ic(g);tq(c,d,i);hb=f+16|0}else{xm(l,x[e>>1]|x[e+2>>1]<<16);l=l+4|0;v[g+4>>2]=l;e=e+4|0;continue}break}t[c+2|0]=w[k+2|0];u[c>>1]=x[k>>1]}Cb(c);hb=m+32|0;break a}t[a+14|0]=c-1}if((b|0)!=16777216){t[a+17|0]=255}hb=j+16|0}function Fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=Ib(h,d),j=w[f+4|0]+1|0,t[i|0]=j;i=$b(g,d),j=(w[f+6|0]|w[f+7|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;i=$b(f,d+12|0),j=(w[g+6|0]|w[g+7|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}hA(a+484|0,b+48|0,0);hA(a+590|0,b+68|0,0);hA(a+696|0,b+88|0,5);v[b>>2]=w[a+806|0]|w[a+807|0]<<8;d=t[a+808|0];b:{if((d|0)<0){t[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(t[a|0]&1){t[b+31|0]=d+1;break b}if(!d){break b}t[b+31|0]=d+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=w[a+810|0];break d}d=t[a+809|0];if((d|0)>=0){u[b+28>>1]=(d&255)+1}d=t[a+810|0];if((d|0)<0){break c}}t[b+30|0]=d+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;i=b,j=w[Vb(e+15|0,e+14|0)|0]>>>1|0,v[i+4>>2]=j}c=w[a+813|0]|w[a+814|0]<<8;if(c>>>0<=256){v[b+8>>2]=c;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];u[e+12>>1]=w[a+820|0]|w[a+821|0]<<8;u[e+10>>1]=100;i=b,j=w[Rc(e+12|0,e+10|0)|0],t[i+20|0]=j;u[e+8>>1]=w[a+822|0]|w[a+823|0]<<8;u[e+6>>1]=256;i=b,j=x[Rc(e+8|0,e+6|0)>>1]>>>2|0,t[i+19|0]=j;c=w[a+824|0];Ij(b,c&127,c>>>7|0);a=w[a+825|0];Hj(b,a&127,a>>>7|0);hb=e+16|0}function mZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=hb-16|0;hb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{while(1){c=v[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[c|0];j=i&255;d:{if((i|0)>=0){u[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=w[c+1|0];if((i&192)!=128){break a}u[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=w[c+2|0];i=w[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=w[c+3|0];i=w[c+2|0];c=w[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;u[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=i<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[a+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];hb=a+16|0;return b|0}function Pn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-16|0;hb=d;h=a+1074312|0;Ab(d+8|0,h,96);i=b,j=(k=0,l=v[b+660>>2],m=zb(v[v[d+8>>2]>>2],v[d+12>>2]),m?k:l)+c|0,v[i+660>>2]=j;g=v[a+480180>>2];e=v[b+84>>2];if(!(!(g&18)|e>>>0>c>>>0|(!(w[b+88|0]&2)|!e))){f=c;c=v[b+80>>2];c=((f-c>>>0)%(e-c>>>0)|0)+c|0}c=c>>>(v[b+88>>2]&1&(g|0)==16384)|0;a:{b:{if(!Wc(w[b+788|0])){Ab(d+8|0,h,114);if(!zb(v[v[d+8>>2]>>2],v[d+12>>2])){break b}}e=v[b+656>>2];c:{if(!e){break c}g=w[b+788|0];if(!Wc(g)){break c}e=x[$b(e+236|0,g-1|0)>>1];if(!e|e>>>0>x[a+480190>>1]){break a}}d:{if(w[a+480210|0]&32){f=c;c=v[b+660>>2];v[b+660>>2]=f+c;f=0;break d}f=0}v[b>>2]=f;v[b+4>>2]=c;if((!(w[b+88|0]&2)|c>>>0<y[b+84>>2])&c>>>0<y[b+76>>2]){break a}Ab(d+8|0,h,57);e:{if(!zb(v[v[d+8>>2]>>2],v[d+12>>2])){c=v[a+480180>>2];if((c|0)!=16){break e}}v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break a}if(!(c&1048581)){Ab(d+8|0,h,27);if(zb(v[v[d+8>>2]>>2],v[d+12>>2])){if(w[a+480208|0]&4){c=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=c;break a}v[b>>2]=0;v[b+4>>2]=0;break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;if(!(w[a+480208|0]&4)){break a}a=v[b+76>>2];if(a>>>0<5){break a}v[b>>2]=0;v[b+4>>2]=a-2;break a}if(!(w[b+88|0]&2)|(c|0)!=1){break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;break a}if(!(v[a+480180>>2]&268582928)|c>>>0>=y[b+76>>2]){break a}v[b>>2]=0;v[b+4>>2]=c}hb=d+16|0}function eha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];b=Qt(c,v[a+4>>2]);if(b>>>0<=63){g=hb-32|0;hb=g;f=64-b|0;c=v[Db(a)>>2];d=v[a+4>>2];a:{if(f>>>0<=(c-d|0)/33>>>0){b=hb-16|0;hb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(f,33);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);hb=b+16|0}else{xS(a);a=a+33|0;v[b+4>>2]=a;continue}break}break a}i=Db(a);c=g+8|0;h=Qt(v[a>>2],d)+f|0;d=hb-16|0;hb=d;v[d+12>>2]=h;e=hb-16|0;hb=e;v[e+12>>2]=130150524;v[e+8>>2]=2147483647;b=v[Hb(e+12|0,e+8|0)>>2];hb=e+16|0;b:{if(b>>>0>=h>>>0){e=yS(a);if(e>>>0<b>>>1>>>0){v[d+8>>2]=e<<1;b=v[Vc(d+8|0,d+12|0)>>2]}hb=d+16|0;break b}rd();L()}e=Qt(v[a>>2],v[a+4>>2]);og(c+12|0,i);if(b){if(b>>>0>=130150525){Zf(11191);L()}d=tc(B(b,33))}else{d=0}v[c>>2]=d;e=d+B(e,33)|0;v[c+8>>2]=e;v[c+4>>2]=e;j=zc(c),k=d+B(b,33)|0,v[j>>2]=k;b=hb-16|0;hb=b;v[b>>2]=v[c+8>>2];d=v[c+8>>2];v[b+8>>2]=c+8;v[b+4>>2]=d+B(f,33);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){xS(d);d=v[b>>2]+33|0;v[b>>2]=d;continue}break}Kd(b);hb=b+16|0;b=c+4|0;f=v[a>>2];d=v[a+4>>2]-f|0;e=v[b>>2]+B((d|0)/-33|0,33)|0;v[b>>2]=e;if((d|0)>0){pc(e,f,d)}oc(a,b);oc(a+4|0,c+8|0);oc(Db(a),zc(c));v[c>>2]=v[c+4>>2];b=v[c+4>>2];a=v[c+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;v[c+8>>2]=a;continue}break}a=v[c>>2];if(a){zc(c);Jb(a)}}hb=g+32|0;return}if((b|0)!=64){Ld(a,c+2112|0)}}function B$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=hb-368|0;hb=a;v[a+352>>2]=c;v[a+360>>2]=b;mw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=_c(d);v[23516]=0;R(58,d|0,b|0);b=v[23516];v[23516]=0;a:{b:{c:{if((b|0)!=1){c=Jc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23516]=0;b=Q(1158,a+360|0,a+352|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23516]=0;R(58,d|0,b<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+180>>2]=b+c}v[23516]=0;b=T(1160,v[a+360>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(lw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23516]=0;T(1162,a+360|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=jG(c,v[a+180>>2],e),z[j>>2]=k;Cf(a+200|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1159,a+360|0,a+352|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];wb(d);wb(a+200|0);hb=a+368|0;break a}}b=P()|0;O()|0;wb(d);wb(a+200|0);S(b|0);L()}return b|0}function Xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-48|0;hb=e;jd(b,2);f=e+16|0;ok(f,2,a+1|0);d=e+32|0;Cc(d,f);xe(b+43|0,d);wb(d);a:{b:{c:{d:{switch(w[a|0]){case 0:f=v[b+4>>2];d=v[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b>>2]=d;v[e+32>>2]=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);v[e+16>>2]=d-1;d=e+32|0;f=v[Hb(d,e+16|0)>>2];v[b+4>>2]=f;v[e+32>>2]=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);d=v[Hb(d,b)>>2];v[b+8>>2]=d;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}f=e+16|0;Jh(f,a+16|0);d=v[e+16>>2];v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);Jh(f,a+20|0);d=v[e+16>>2];v[e+36>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);Jh(f,a+24|0);d=v[e+16>>2];d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+40>>2]=d;v[e+8>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;vl(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;g=b,h=w[Vb(e+32|0,e+16|0)|0]<<2,u[g+30>>1]=h;d=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);v[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(w[a|0]==2){d=d&65535;v[b>>2]=d;break e}if(y[b>>2]>=65536){v[b>>2]=65535}d=v[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}v[b>>2]=a}hb=e+48|0}function K$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=hb-272|0;hb=a;v[a+256>>2]=c;v[a+264>>2]=b;qw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=_c(d);v[23516]=0;R(58,d|0,b|0);b=v[23516];v[23516]=0;a:{b:{c:{if((b|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[23516]=0;b=Q(1142,a+264|0,a+256|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23516]=0;R(58,d|0,b<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=b+c}v[23516]=0;b=T(1144,v[a+264>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(pw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23516]=0;T(1146,a+264|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=jG(c,v[a+188>>2],e),z[j>>2]=k;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1143,a+264|0,a+256|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];wb(d);wb(a+208|0);hb=a+272|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function A$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-368|0;hb=a;v[a+352>>2]=c;v[a+360>>2]=b;mw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=_c(d);v[23516]=0;R(58,d|0,b|0);b=v[23516];v[23516]=0;a:{b:{c:{if((b|0)!=1){c=Jc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23516]=0;b=Q(1158,a+360|0,a+352|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23516]=0;R(58,d|0,b<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+180>>2]=b+c}v[23516]=0;b=T(1160,v[a+360>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(lw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23516]=0;T(1162,a+360|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=hG(c,v[a+180>>2],e),A[j>>3]=k;Cf(a+200|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1159,a+360|0,a+352|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];wb(d);wb(a+200|0);hb=a+368|0;break a}}b=P()|0;O()|0;wb(d);wb(a+200|0);S(b|0);L()}return b|0}function J$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-272|0;hb=a;v[a+256>>2]=c;v[a+264>>2]=b;qw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=_c(d);v[23516]=0;R(58,d|0,b|0);b=v[23516];v[23516]=0;a:{b:{c:{if((b|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[23516]=0;b=Q(1142,a+264|0,a+256|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23516]=0;R(58,d|0,b<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=b+c}v[23516]=0;b=T(1144,v[a+264>>2])|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}if(pw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23516]=0;T(1146,a+264|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=hG(c,v[a+188>>2],e),A[j>>3]=k;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1143,a+264|0,a+256|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];wb(d);wb(a+208|0);hb=a+272|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function VH(a){var b=0,c=0,d=0,e=0;ye(v[a+80>>2],v[a+20>>2]);while(1){c=v[a+28>>2];if((b|0)<v[a+24>>2]){ye(v[a+80>>2],v[c+(b<<2)>>2]);b=b+1|0;continue}break}ye(v[a+80>>2],c);a:{if(!v[a+396>>2]){break a}c=0;while(1){if(v[a+264>>2]<=(c|0)){break a}e=v[a+396>>2]+B(c,24)|0;d=v[e+16>>2];if(d){b=0;while(1){if((b|0)<v[(v[a+124>>2]+B(w[e+13|0],2096)|0)+4>>2]){ye(v[a+80>>2],v[(b<<2)+d>>2]);b=b+1|0;d=v[e+16>>2];continue}break}ye(v[a+80>>2],d)}ye(v[a+80>>2],v[e+20>>2]);c=c+1|0;continue}}d=v[a+124>>2];if(d){c=0;while(1){if((c|0)<v[a+120>>2]){b=B(c,2096)+d|0;ye(v[a+80>>2],v[b+8>>2]);ye(v[a+80>>2],v[b+28>>2]);ye(v[a+80>>2],v[b+32>>2]);ye(v[a+80>>2],v[b+2084>>2]);b=v[b+2088>>2];ye(v[a+80>>2],b?b-4|0:0);c=c+1|0;d=v[a+124>>2];continue}break}ye(v[a+80>>2],d)}ye(v[a+80>>2],v[a+260>>2]);ye(v[a+80>>2],v[a+396>>2]);c=v[a+404>>2];if(c){b=0;while(1){if((b|0)<v[a+400>>2]){ye(v[a+80>>2],v[(B(b,40)+c|0)+4>>2]);b=b+1|0;c=v[a+404>>2];continue}break}ye(v[a+80>>2],c)}c=0;b=0;while(1){if(!(v[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;ye(v[a+80>>2],v[d+800>>2]);ye(v[a+80>>2],v[d+928>>2]);ye(v[a+80>>2],v[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;ye(v[a+80>>2],v[b+1068>>2]);ye(v[a+80>>2],v[b+1076>>2]);ye(v[a+80>>2],v[b+1084>>2]);ye(v[a+80>>2],v[b+1092>>2]);ye(v[a+80>>2],v[b+1100>>2]);c=c+1|0;continue}break}}function GO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=hb-16|0;hb=h;c=v[a>>2];a:{if(gk(c)){i=hb-16|0;hb=i;e=tc(3848);d=e+808|0;c=e+16|0;while(1){v[c+16>>2]=0;v[c+20>>2]=0;v[c+36>>2]=0;t[c+42|0]=1;u[c+40>>1]=257;v[c+24>>2]=0;v[c+28>>2]=0;u[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){v[d>>2]=0;v[d+4>>2]=0;v[d+68>>2]=0;v[d+72>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;u[d+20>>1]=511;v[d+16>>2]=-1;u[d+14>>1]=1;u[d+6>>1]=0;u[d+8>>1]=0;u[d+10>>1]=0;u[d+12>>1]=0;t[d+73|0]=0;t[d+74|0]=0;t[d+75|0]=0;t[d+76|0]=0;t[d+77|0]=0;t[d+78|0]=0;t[d+79|0]=0;t[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}v[e+3832>>2]=0;v[e+3836>>2]=0;c=e+3837|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;t[c+4|0]=0;t[c+5|0]=0;t[c+6|0]=0;t[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}Un((e+B(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+B(f,44)|0)+16|0;c=v[(f<<2)+29088>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+B(c,84)|0;KO(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+B(c,84)|0;KO(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{v[(e+B(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}JO(e,b)}else{td((e+B(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=v[If(i+8|0,e)>>2];hb=i+16|0;v[h+8>>2]=b;b=h+8|0;tA(a,b);co(b);break a}JO(c,b)}FO(a);hb=h+16|0}function tz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;if(b&5){if((b|0)==1){d=rka(v[a+24>>2],0,8363,0)+4136|0;c=kb;h=a,i=Bc(uka(d,d>>>0<4136?c+1|0:c,8272,0),kb),v[h+24>>2]=i}d=hb-16|0;hb=d;g=d+8|0;c=hb-16|0;hb=c;f=v[a+24>>2];a:{if(!f){zo(g);break a}pB(c+8|0,Wb(pl(xp(+(f>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);f=v[c+8>>2];t[c+7|0]=v[c+12>>2];ae(g,f,c+7|0)}hb=c+16|0;hB(d,a+36|0,a+37|0);gB(d,g);hb=d+16|0}if(b&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(b&7){u[a+32>>1]=64;c=x[a+34>>1];if(c&8){d=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=d;c=c&16?c|6:c&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=c&65511}b:{if(!(b&4)){break b}c=x[a+34>>1];if(!(c&32)){u[a+28>>1]=128;u[a+34>>1]=c|32}sf(a+40|0,15);sf(a+41|0,63);if(!w[a+41|0]){break b}d=w[a+40|0];if(!d){break b}c=w[a+39|0];if(c){c=Bl(Bc(((d<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}t[a+39|0]=c}c:{d:{if((b|0)!=4){if((b|0)==16777216){break c}if((b|0)!=32|w[a+38|0]!=2){break d}t[a+38|0]=3;break d}if(w[a+38|0]!=4){break d}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}e:{if(!(!(w[a+35|0]&2)|b&16777218)){v[e+24>>2]=0;v[e+8>>2]=0;v[e+16>>2]=0;v[e+20>>2]=0;v[e>>2]=0;v[e+4>>2]=0;vl(a,0,e);break e}if(!(w[a+35|0]&2)|(b|0)!=2){break e}a=a+68|0;b=Ib(a,8);t[b|0]=w[b|0]&3;a=Ib(a,9);t[a|0]=w[a|0]&3}hb=e+32|0}function Zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;f=hb-16|0;hb=f;s=v[a+16>>2];u=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];e=v[a>>2];b=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=kg(k,l,n);p=kb;g=v[a+76>>2];e=v[a>>2];b=v[a+4>>2];Of(e,b,mf(k,l,d),kb);m=g>>>0<kb>>>0?d:0}h=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[f>>2]=e;v[f+4>>2]=b;while(1){if(d){d=d-1|0;v[f+8>>2]=e;v[f+12>>2]=0;m=m-1|0;g=m;o=g?o:0;p=g?p:0;r=(((b&2147483647)<<1|e>>>31)&-2)+s|0;g=n;b:{c:while(1){d:{if((g|0)<=0){Pb(h,v[a+120>>2],v[a+124>>2]);g=v[a+116>>2];if(!g){break b}q=((v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31)&-2;e=0;b=0;break d}q=((v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31)&-2;b=0;e=0;while(1)if((b|0)==2){Od(h,(e|0)/8<<16>>16);Nd(h,4);Pb(f+8|0,o,p);g=g-1|0;continue c}else{e=(t[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){e=(t[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}break}Od(h,(e|0)/8<<16>>16);Nd(h,g);v[h>>2]=v[h>>2];v[h+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;g=ig(h,u);v[c>>2]=B(j>>12,g)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(g,i>>12);Pb(f,k,l);c=c+8|0;e=v[f>>2];b=v[f+4>>2];continue}break}v[a>>2]=e;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;hb=f+16|0}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;c=nf(a,c);ke(g,v[a+36>>2]);a:{if(!c){b:{Pc(g,a+32|0,5);if(!zb(v[v[g>>2]>>2],v[g+4>>2])){break b}break a}}e=hb-160|0;hb=e;h=Rl(e+48|0,v[a+36>>2]);v[23516]=0;f=Q(458,e+32|0,43987)|0;d=v[23516];v[23516]=0;c:{d:{e:{f:{if((d|0)!=1){v[23516]=0;v[e+16>>2]=19988497;v[e+20>>2]=0;U(459,h|0,f|0,e+16|0);d=v[23516];v[23516]=0;if((d|0)==1){break f}Ub(f);if(!Ek(w[h|0])){break e}break c}d=P()|0;O()|0;break d}d=P()|0;O()|0;Ub(f);break d}k=e,l=vf(v[b>>2],v[b+4>>2]),u[k+30>>1]=l;u[e+28>>1]=65535;v[23516]=0;f=Q(458,e+16|0,10124)|0;d=v[23516];v[23516]=0;g:{if((d|0)!=1){v[23516]=0;d=W(488,h|0,e+28|0,f|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break g}Ub(f);if(d){u[e+30>>1]=x[e+28>>1]}Bf(e+30|0,4e3);f=x[e+30>>1];h:{if(vf(v[b>>2],v[b+4>>2])>>>0>=f>>>0){break h}v[23516]=0;R(224,b|0,f|0);d=v[23516];v[23516]=0;if((d|0)!=1){break h}d=P()|0;O()|0;break d}d=0;i:{while(1){if((d|0)==(f|0)){break c}i=v[b>>2];v[23516]=0;R(489,e|0,d|0);j=v[23516];v[23516]=0;if((j|0)!=1){v[23516]=0;X(490,h|0,Xb(i,d)|0,e|0,491);i=v[23516];v[23516]=0;if((i|0)==1){break i}d=d+1|0;Ub(e);continue}break}d=P()|0;O()|0;break d}d=P()|0;O()|0;Ub(e);break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;Ub(f)}fh(h);S(d|0);L()}fh(h);hb=e+160|0;e=c}Ve(a,e);hb=g+16|0}function GP(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-240|0;hb=e;if(!w[94224]){if(!w[94100]){c=hb-16|0;hb=c;Kb(94076);v[23522]=0;t[94092]=0;v[23524]=0;v[23516]=0;b=ha(27)|0;a=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){v[c+8>>2]=b;b=c+8|0;Yt(94088,_d(b));hT(b);t[94092]=0;break f}a=Ea(92664,93236)|0;b=O()|0;if((ea(92664)|0)==(b|0)){_(a|0)|0;v[23516]=0;Z(28);c=v[23516];v[23516]=0;if((c|0)==1){break d}L()}if((ea(93236)|0)!=(b|0)){break c}_(a|0)|0;v[23516]=0;t[94092]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){a=P()|0;O()|0;break c}if(w[94092]){break e}}v[23516]=0;Y(29,94072);b=v[23516];v[23516]=0;if((b|0)!=1){break e}a=P()|0;O()|0;break c}hb=c+16|0;break a}a=P()|0;O()|0;v[23516]=0;Z(18);c=v[23516];v[23516]=0;if((c|0)==1){break b}}co(94096);hT(94088);wb(94076);S(a|0);L()}V(0)|0;O()|0;Tb();L()}t[94100]=1}c=hb+-64|0;hb=c;b=c+16|0;g=hb-16|0;hb=g;h=qP(g+8|0);j=e+120|0;while(1){if((i|0)==12){hb=g+16|0}else{f=hb-48|0;hb=f;a=v[h+4>>2];d=v[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=lP(nP(f+8|0,32));break g}d=E(a);d=nP(f+8|0,(a<<d+1?32:31)-d|0);while(1){k=lP(d);if(a>>>0<=k>>>0){continue}break}a=v[h>>2]+k|0}hb=f+48|0;l=Bb(b,i),m=a,v[l>>2]=m;i=i+1|0;continue}break}b=zP(c,b,CP(b));xP(j,b);wm(b);hb=c- -64|0;pc(94104,pc(e,j,120),116);t[94224]=1}hb=e+240|0}function M4(a){a=a|0;var b=0,c=0,d=0,e=0;e=hb-160|0;hb=e;d=Fc(e,11636);v[23516]=0;b=d+12|0;Q(53,b|0,10974)|0;c=v[23516];v[23516]=0;a:{b:{if((c|0)==1){break a}v[23516]=0;b=d+24|0;Q(53,b|0,11466)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;b=d+36|0;Q(53,b|0,10966)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;b=d+48|0;Q(53,b|0,8272)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;b=d+60|0;Q(53,b|0,10951)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;b=d+72|0;Q(53,b|0,8338)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;b=d+84|0;Q(53,b|0,5623)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;b=d+96|0;Q(53,b|0,12040)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;b=d+108|0;Q(53,b|0,11409)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;b=d+120|0;Q(53,b|0,12241)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;b=d+132|0;Q(53,b|0,5475)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;b=d+144|0;Q(53,b|0,7295)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;W(1033,a|0,d|0,13)|0;a=v[23516];v[23516]=0;if((a|0)==1){break b}b=d+156|0;while(1){b=wb(b-12|0);if((d|0)!=(b|0)){continue}break}hb=e+160|0;return}b=d+156|0}a=P()|0;O()|0;while(1){b=wb(b-12|0);if((d|0)!=(b|0)){continue}break}S(a|0);L()}function E$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Zi(d);i=hp(d,a+224|0);gp(a+208|0,d,a+332|0);d=Kb(a+192|0);c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23516]=0;g=Q(1158,a+344|0,a+336|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23516]=0;R(58,d|0,g<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=g+c}v[23516]=0;g=T(1160,v[a+344>>2])|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(mn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23516]=0;T(1162,a+344|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=oG(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=kb;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1159,a+344|0,a+336|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];wb(d);wb(a+208|0);hb=a+352|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function C$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Zi(d);i=hp(d,a+224|0);gp(a+208|0,d,a+332|0);d=Kb(a+192|0);c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23516]=0;g=Q(1158,a+344|0,a+336|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23516]=0;R(58,d|0,g<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=g+c}v[23516]=0;g=T(1160,v[a+344>>2])|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(mn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23516]=0;T(1162,a+344|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=kG(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=kb;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1159,a+344|0,a+336|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];wb(d);wb(a+208|0);hb=a+352|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[Db(a)>>2]){c=hb-16|0;hb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=v[c+4>>2];v[23516]=0;R(670,a|0,b|0);a=v[23516];v[23516]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+56;ic(c);hb=c+16|0;break a}a=P()|0;O()|0;ic(c);S(a|0);L()}return}h=hb-32|0;hb=h;i=Db(a);f=h+8|0;g=cq(v[a>>2],v[a+4>>2])+1|0;d=hb-16|0;hb=d;v[d+12>>2]=g;e=hb-16|0;hb=e;v[e+12>>2]=76695844;v[e+8>>2]=2147483647;c=v[Hb(e+12|0,e+8|0)>>2];hb=e+16|0;b:{if(c>>>0>=g>>>0){e=bR(a);if(e>>>0<c>>>1>>>0){v[d+8>>2]=e<<1;c=v[Vc(d+8|0,d+12|0)>>2]}hb=d+16|0;break b}rd();L()}e=cq(v[a>>2],v[a+4>>2]);og(f+12|0,i);if(c){if(c>>>0>=76695845){Zf(11191);L()}d=tc(B(c,56))}else{d=0}v[f>>2]=d;e=d+B(e,56)|0;v[f+8>>2]=e;v[f+4>>2]=e;j=zc(f),k=d+B(c,56)|0,v[j>>2]=k;c=v[f+8>>2];v[23516]=0;R(670,c|0,b|0);b=v[23516];v[23516]=0;c:{if((b|0)!=1){v[f+8>>2]=v[f+8>>2]+56;e=v[a>>2];b=v[a+4>>2];d=f+4|0;while(1){if((b|0)!=(e|0)){b=b-56|0;c=nl(v[d>>2]-56|0,b);nl(c+12|0,b+12|0);Pz(c+24|0,b+24|0);u[c+52>>1]=x[b+52>>1];g=v[b+48>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=g;g=v[b+40>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=g;v[d>>2]=v[d>>2]-56;continue}break}oc(a,d);oc(a+4|0,f+8|0);oc(Db(a),zc(f));v[f>>2]=v[f+4>>2];aR(f);hb=h+32|0;break c}a=P()|0;O()|0;aR(f);S(a|0);L()}}function Jda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=hb-48|0;hb=d;l=a+480190|0;c=x[l>>1];t[d+32|0]=0;lO(b,c+1|0,d+32|0);a:{j=a+480192|0;if(!x[j>>1]){break a}h=Lb(d+32|0);p=d,q=Cb(v[a+484344>>2]),v[p+24>>2]=q;o=Cb(v[a+484348>>2]);m=a+480188|0;while(1){i=v[d+24>>2];if(!Nb(i,o)){c=x[a+480190>>1];while(1)if(c){Ab(d+8|0,v[b>>2],c);if(!zb(v[v[d+8>>2]>>2],v[d+12>>2])){e=f;f=B(c,104)+a|0;f=e+Vd(v[f+484380>>2],v[f+484400>>2])|0}c=c-1|0;continue}else{dc(h);break a}}b:{if(!Nb(v[i>>2],v[i+4>>2])){break b}c=x[m>>1];v[23516]=0;t[d+8|0]=0;U(767,h|0,c|0,d+8|0);c=v[23516];v[23516]=0;if((c|0)!=1){p=d,q=Cb(v[i>>2]),v[p+16>>2]=q;k=0;c:while(1){f=0;if(y[i+12>>2]<=k>>>0){break b}while(1){if(x[m>>1]<=f>>>0){k=k+1|0;continue c}d:{c=v[d+16>>2];if(!Wc(w[c|0])){break d}e:{f:{c=w[c+1|0];if(c){g=x[j>>1];break f}g=x[j>>1];c=w[Ib(v[h>>2],f)|0];if(c){break f}c=1;break e}p=Ib(v[h>>2],f),q=c,t[p|0]=q;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break d}e=v[((e<<2)+a|0)+900380>>2];g:{if(!e){break g}e=x[$b(e+236|0,w[v[d+16>>2]]-1|0)>>1];if(e>>>0>x[l>>1]){break g}n=d+8|0;Ab(n,v[b>>2],e);We(n,1)}c=c+1|0;continue}}f=f+1|0;Wz(d+16|0);continue}}}a=P()|0;O()|0;dc(h);S(a|0);L()}uM(d+24|0);continue}}hb=d+48|0;return f&65535}function bG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Zi(d);i=hp(d,a+224|0);gp(a+208|0,d,a+332|0);d=Kb(a+192|0);c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23516]=0;g=Q(1158,a+344|0,a+336|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23516]=0;R(58,d|0,g<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=g+c}v[23516]=0;g=T(1160,v[a+344>>2])|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(mn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23516]=0;T(1162,a+344|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=lG(c,v[a+188>>2],e,b),v[k>>2]=l;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1159,a+344|0,a+336|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];wb(d);wb(a+208|0);hb=a+352|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function F$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Zi(d);i=hp(d,a+224|0);gp(a+208|0,d,a+332|0);d=Kb(a+192|0);c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23516]=0;g=Q(1158,a+344|0,a+336|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23516]=0;R(58,d|0,g<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=g+c}v[23516]=0;g=T(1160,v[a+344>>2])|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(mn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23516]=0;T(1162,a+344|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=pG(c,v[a+188>>2],e,b),v[k>>2]=l;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1159,a+344|0,a+336|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];wb(d);wb(a+208|0);hb=a+352|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function D$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Zi(d);i=hp(d,a+224|0);gp(a+208|0,d,a+332|0);d=Kb(a+192|0);c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23516]=0;g=Q(1158,a+344|0,a+336|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23516]=0;R(58,d|0,g<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=g+c}v[23516]=0;g=T(1160,v[a+344>>2])|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(mn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23516]=0;T(1162,a+344|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=nG(c,v[a+188>>2],e,b),u[k>>1]=l;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1159,a+344|0,a+336|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];wb(d);wb(a+208|0);hb=a+352|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function nZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=hb-16|0;hb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;c=v[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<=0){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;continue}break}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];hb=a+16|0;return f|0}function qe(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),k=0;f=(p(b),j(2));d=iF(f);a:{b:{c:{d:{c=(p(a),j(2));e:{if(c-2139095040>>>0>=2164260864){if(d){break e}break c}if(!d){break d}}i=C(1);if((c|0)==1065353216){break b}e=f<<1;if(!e){break b}d=e>>>0<4278190081;e=c<<1;a=C(a+b);if(!(d&e>>>0<=4278190080)){break a}if((e|0)==2130706432){break b}a=((f^-1)>>>31|0)==(e>>>0<2130706432|0)?C(0):C(b*b);break a}if(iF(c)){i=C(a*a);if((c|0)<0){i=(hF(f)|0)==1?C(-i):i}if((f|0)>=0){break b}a=BH(C(C(1)/i));break a}if((c|0)<0){e=hF(f);if(!e){a=LJ(a);break a}c=c&2147483647;e=((e|0)==1)<<16}if(c>>>0>8388607){break c}c=((p(C(a*C(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;d=f>>>15&240;g=+(l(2,c-(f&-8388608)|0),q())*A[d+93280>>3]+-1;h=g*g;h=((g*.288457581109214+-.36092606229713164)*(h*h)+((g*.480898481472577+-.7213474675006291)*h+(g*1.4426950408774342+(A[d+93288>>3]+ +(f>>23)))))*+b;o(+h);d=j(1)|0;j(0)|0;f:{d=d&2147450880;if((d|0)==1079967744|d>>>0<1079967744){break f}if(h>127.99999995700433){a=QD(e);break a}if(!(h<=-150)){break f}a=vD(e);break a}k=h;g=A[160];h=g+h;g=k-(h-g);k=(A[161]*g+A[162])*(g*g)+(A[163]*g+1);o(+h);j(1)|0;c=j(0)|0;f=e+c|0;f=f<<15;d=((c&31)<<3)+1024|0;e=v[d>>2];c=e;d=v[d+4>>2]+f|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=C(k*+n())}a=i}return a}function N$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-240|0;hb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Zi(d);ip(a+208|0,d,a+223|0);d=Kb(a+192|0);c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23516]=0;g=Q(1142,a+232|0,a+224|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23516]=0;R(58,d|0,g<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=g+c}v[23516]=0;g=T(1144,v[a+232>>2])|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(on(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,84e3)){break c}v[23516]=0;T(1146,a+232|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=oG(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=kb;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1143,a+232|0,a+224|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];wb(d);wb(a+208|0);hb=a+240|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function L$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-240|0;hb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Zi(d);ip(a+208|0,d,a+223|0);d=Kb(a+192|0);c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23516]=0;g=Q(1142,a+232|0,a+224|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23516]=0;R(58,d|0,g<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=g+c}v[23516]=0;g=T(1144,v[a+232>>2])|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(on(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,84e3)){break c}v[23516]=0;T(1146,a+232|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=kG(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=kb;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1143,a+232|0,a+224|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];wb(d);wb(a+208|0);hb=a+240|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;h=hb-16|0;hb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+32>>2];o=v[a+28>>2];p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(s,t,e,e>>31);g=kb;f=Wb(f,-16777216,16776704);k=rka(q,r,f,f>>31);e=k+e|0;f=kb+g|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=(v[h+12>>2]<<1)+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(u[e+4>>1],u[g+10>>1])+B(u[e+2>>1],u[g+8>>1])|0)+B(u[e+6>>1],u[g+12>>1])|0)+B(u[e+8>>1],u[g+14>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+2>>1])+B(u[e-6>>1],u[g>>1])|0)+B(u[e-2>>1],u[g+4>>1])|0)+B(u[e>>1],u[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;k=rka(e,e>>31,w,x);e=A+k|0;f=kb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;j=j+o|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+n|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Pb(h+8|0,y,z);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;hb=h+16|0}function CK(a){var b=0,c=C(0),d=0,e=0,f=0,g=C(0),h=0,i=0,k=C(0),m=0,n=0,o=C(0);d=hb-16|0;hb=d;b=v[v[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=qe(C(10),C(C(C(z[Bb(e,0)>>2]*C(120))+C(-60))/C(20))),z[n+4232>>2]=o;k=C(C(b>>>0)/C(1e3));n=a,o=qe(C(10),C(C(-1)/C(k*C(C(z[Bb(e,1)>>2]*C(499.989990234375))+C(.009999999776482582))))),z[n+4236>>2]=o;n=a,o=qe(C(10),C(C(-1)/C(k*C(C(z[Bb(e,2)>>2]*C(2950))+C(50))))),z[n+4240>>2]=o;v[d+12>>2]=1325400064;c=C(qe(C(10),C(C(C(z[Bb(e,3)>>2]*C(60))+C(-60))/C(20)))*C(2147483648));b=(p(c),j(2));g=C(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){b=hb-16|0;z[b+12>>2]=-1;g=C(z[b+12>>2]/C(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=LJ(c);break a}b=(p(C(c*C(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),q())*A[h+3568>>3]+-1;m=i*i;c=C((A[479]*m+(A[480]*i+A[481]))*m+(+(f>>23)*A[478]+A[h+3576>>3]+i))}g=c}z[d+8>>2]=C(C(g*C(67108864))/C(.6931471824645996))+C(67108864);n=a,o=C(z[em(d+12|0,d+8|0)>>2]*C(4.656612873077393e-10)),z[n+4244>>2]=o;n=a,o=C(C(C(-1)/C(C(z[Bb(e,4)>>2]*C(99))+C(1)))+C(1)),z[n+4248>>2]=o;c=C(C(C(z[Bb(e,5)>>2]*C(4))*k)+C(2));c:{if(C(D(c))<C(2147483648)){h=~~c;break c}h=-2147483648}v[a+4252>>2]=h;hb=d+16|0}function wW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=hb-1088|0;hb=f;a=Ih(a);Rb(a+20|0,0,1040);v[a+1064>>2]=0;v[a+1068>>2]=0;v[a+1060>>2]=c;t[a+1084|0]=d;d=a+1072|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1080>>2]=0;i=a+1064|0;d=c;a:{b:{c:while(1){if(Hd(x[d+34>>1])>>>0<=g>>>0){break a}v[a+1064>>2]=0;v[a+1068>>2]=0;d=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(y[c>>2]<=d>>>0){break j}d=v[b+8>>2];e=v[b>>2];v[23516]=0;d=W(154,e|0,d|0,2)|0;e=v[23516];v[23516]=0;if((e|0)==1){break i}if(!d){break j}v[23516]=0;d=T(192,b|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break h}if(!d){break e}v[23516]=0;U(188,f|0,b|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break g}d=gr(f+24|0,f);e=cd(a,d);pc(e+20|0,d+20|0,1040);yb(d);yb(f);v[a+1076>>2]=0;v[a+1080>>2]=0;h=v[a+1060>>2];d=v[h+20>>2];if(Qm(x[h+34>>1])>>>0>=2){v[23516]=0;R(193,e|0,d+(g<<1)|0);d=v[23516];v[23516]=0;if((d|0)!=1){break e}break f}v[23516]=0;R(194,e|0,d+g|0);d=v[23516];v[23516]=0;if((d|0)==1){break f}break e}g=g+1|0;d=v[a+1060>>2];continue c}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=V(30656)|0;if((O()|0)!=(ea(30656)|0)){break b}_(d|0)|0;v[23516]=0;Z(18);d=v[23516];v[23516]=0;if((d|0)==1){break d}}d=v[i>>2];continue}break}break}d=P()|0;O()|0}yb(a);S(d|0);L()}hb=f+1088|0;return a|0}function l$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-16|0;hb=k;l=Hw(g);g=ow(g);Wg(k,g);a:{b:{if(Pe(k)){v[23516]=0;X(1165,l|0,a|0,c|0,d|0);g=v[23516];v[23516]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[23516]=0;j=Q(1171,l|0,h<<24>>24)|0;h=v[23516];v[23516]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23516]=0;h=Q(1171,l|0,48)|0;i=v[23516];v[23516]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[23516]=0;h=Q(1171,l|0,h|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}Sl(j,c);i=0;v[23516]=0;o=T(1163,g|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Ir((j-a<<2)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[Jc(k,h)|0]){break e}if(t[Jc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=o;h=(Fb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[23516]=0;n=Q(1171,l|0,n|0)|0;m=v[23516];v[23516]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;wb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;wb(k);hb=k+16|0}function mG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-240|0;hb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Zi(d);ip(a+208|0,d,a+223|0);d=Kb(a+192|0);c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23516]=0;g=Q(1142,a+232|0,a+224|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23516]=0;R(58,d|0,g<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=g+c}v[23516]=0;g=T(1144,v[a+232>>2])|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(on(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,84e3)){break c}v[23516]=0;T(1146,a+232|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=lG(c,v[a+188>>2],e,b),v[j>>2]=k;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1143,a+232|0,a+224|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];wb(d);wb(a+208|0);hb=a+240|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function O$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-240|0;hb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Zi(d);ip(a+208|0,d,a+223|0);d=Kb(a+192|0);c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23516]=0;g=Q(1142,a+232|0,a+224|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23516]=0;R(58,d|0,g<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=g+c}v[23516]=0;g=T(1144,v[a+232>>2])|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(on(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,84e3)){break c}v[23516]=0;T(1146,a+232|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=pG(c,v[a+188>>2],e,b),v[j>>2]=k;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1143,a+232|0,a+224|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];wb(d);wb(a+208|0);hb=a+240|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function M$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-240|0;hb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Zi(d);ip(a+208|0,d,a+223|0);d=Kb(a+192|0);c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)!=1){c=Jc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23516]=0;g=Q(1142,a+232|0,a+224|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23516]=0;R(58,d|0,g<<1);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=_c(d);v[23516]=0;R(58,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}c=Jc(d,0);v[a+188>>2]=g+c}v[23516]=0;g=T(1144,v[a+232>>2])|0;h=v[23516];v[23516]=0;if((h|0)==1){break d}if(on(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,84e3)){break c}v[23516]=0;T(1146,a+232|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=nG(c,v[a+188>>2],e,b),u[j>>1]=k;Cf(a+208|0,a+16|0,v[a+12>>2],e);v[23516]=0;b=Q(1143,a+232|0,a+224|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];wb(d);wb(a+208|0);hb=a+240|0;break a}}b=P()|0;O()|0;wb(d);wb(a+208|0);S(b|0);L()}return b|0}function LH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=C(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=ee(a,k),v[p>>2]=q;g=d+1076|0;p=g,q=ee(a,k),v[p>>2]=q;i=ee(a,c&-4);v[d+1084>>2]=i;a:{h=v[h>>2];if(!h){break a}g=v[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=C(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))/j);p=i+(e<<2)|0,r=C(Ze(f)),z[p>>2]=r;p=i+(g<<2)|0,r=C(-C(Bi(f))),z[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+C(C(C(e<<2)*C(3.1415927410125732))/j);p=h+l|0,r=C(Ze(f)),z[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=C(-C(Bi(f))),z[p>>2]=r;f=+C(C(C(C(m|0)*C(3.1415927410125732))/j)*C(.5));p=g+l|0,r=C(C(Ze(f))*C(.5)),z[p>>2]=r;p=g+n|0,r=C(C(Bi(f))*C(.5)),z[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=ee(a,k);v[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=C(Bi((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=C(Bi(+C(j*j)*1.5707963705062866)),z[p>>2]=r;b=b+1|0;continue}break}b=ee(a,c>>2&-2);v[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-am(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=_l(a)>>>c<<2,u[p>>1]=q;a=a+1|0;continue}break}return 1}bc(a,3);return 0}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;h=hb-16|0;hb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+32>>2];o=v[a+28>>2];p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(s,w,e,e>>31);g=kb;f=Wb(f,-16777216,16776704);k=rka(q,r,f,f>>31);e=k+e|0;f=kb+g|0;f=e>>>0<k>>>0?f+1|0:f;C=e;e=v[h+12>>2]+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(t[e+2|0],u[g+10>>1])+B(t[e+1|0],u[g+8>>1])|0)+B(t[e+3|0],u[g+12>>1])|0)+B(t[e+4|0],u[g+14>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+2>>1])+B(t[e-3|0],u[g>>1])|0)+B(t[e-1|0],u[g+4>>1])|0)+B(t[e|0],u[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;k=rka(e,e>>31,x,y);e=C+k|0;f=kb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;j=j+o|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+n|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Pb(h+8|0,z,A);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;hb=h+16|0}function _g(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;v[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=v[a+480180>>2];if(!Am(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=x[((B(a,-12)+e&255)<<1)+33424>>1]<<4>>>a|0;break a}if(!d){v[f+12>>2]=8363;d=8363}if(jj(a)){a=((e&255)>>>0)/12|0;b=rka(v[(B(a,-12)+e<<6&960)+37312>>2]<<a,0,d,0);a=kb;c=a>>>21|0;h=f,i=Bc((a&2097151)<<11|b>>>21,c),v[h>>2]=i;uc(f,2147483647);e=v[f>>2];break a}if(w[a+480208|0]&16){a=e&255;e=x[((a>>>0)%12<<1)+33424>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;uc(f+12|0,-1>>>a|0);e=Bc(uka(rka(x[((B(a,-12)+e&255)<<1)+33424>>1],0,267616,0),kb,v[f+12>>2]<<a,0),kb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{Ab(f,a+1074312|0,76);b=zb(v[v[f>>2]>>2],v[f+4>>2])?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)>1?a:1;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(B(c,-12)+a<<3&248)|0;v[f>>2]=d+8;me(f,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)>-8?a:-8;e=B(b,x[(((a|0)<95?a:95)<<1)+33920>>1])+B(x[(v[f>>2]<<1)+33904>>1],16-b|0)<<1>>>c|0;break a}if(!((c&255)>>>0<16&b-25>>>0<=83)){a=((e&255)>>>0)/12|0;e=x[(B((c&240)>>>4|0,12)+(B(a,-12)+e&255)<<1)+33024>>1]<<5>>>a|0;break a}e=x[(b<<1)+32798>>1]<<2}hb=f+16|0;return e}function SI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;c=hb+-64|0;hb=c;d=v[a>>2];a=v[d>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];g=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=g;Ef(c+48|0,c+32|0,f);a=v[d+4>>2];f=v[a+8>>2];g=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=hb-32|0;hb=a;a:{b:{c:{d:{k=v[c+4>>2];if(k>>>0>=g>>>0){l=v[c+20>>2];if(l>>>0<g>>>0){break d}if(f>>>0>y[c+8>>2]){break c}m=v[c+28>>2];if(f>>>0>v[c+24>>2]-m>>>0){break b}n=b+12|0;o=v[c+16>>2];p=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}q=B(h,k);r=B(h+m|0,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=Bb(v[b>>2],d);i=se(mg(A[(d+q<<3)+p>>3])*134217728);j=e;e=(v[e>>2]>>1)+ym(i)|0;s=e;e=ks(n)+e&-4096;v[j>>2]=s-e;A[a+24>>3]=+(e|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;j=(d+r<<1)+o|0;i=se(A[Eg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){e=~~i;break f}e=-2147483648}t=j,w=$c(e),u[t>>1]=w;d=d+1|0;continue}}}aa(7192,9074,77,8754);L()}aa(7157,9074,78,8754);L()}aa(5900,9074,79,8754);L()}aa(5870,9074,80,8754);L()}hb=a+32|0;hb=c- -64|0}function YI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=hb+-64|0;hb=c;d=v[a>>2];a=v[d>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];g=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=g;Ef(c+48|0,c+32|0,f);a=v[d+4>>2];f=v[a+8>>2];g=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=hb-32|0;hb=a;a:{b:{c:{d:{l=v[c+4>>2];if(l>>>0>=g>>>0){if(y[c+20>>2]<g>>>0){break d}if(f>>>0>y[c+8>>2]){break c}m=v[c+28>>2];if(f>>>0>v[c+24>>2]-m>>>0){break b}n=b+12|0;o=v[c+16>>2];p=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}q=h+m|0;r=B(h,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=Bb(v[b>>2],d);i=se(mg(A[(d+r<<3)+p>>3])*134217728);j=e;e=(v[e>>2]>>1)+ym(i)|0;k=e;e=ks(n)+e&-4096;v[j>>2]=k-e;A[a+24>>3]=+(e|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;j=q<<1;k=(d<<2)+o|0;i=se(A[Eg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){e=~~i;break f}e=-2147483648}s=j+v[k>>2]|0,t=$c(e),u[s>>1]=t;d=d+1|0;continue}}}aa(7192,9074,77,8754);L()}aa(7157,9074,78,8754);L()}aa(5900,9074,79,8754);L()}aa(5870,9074,80,8754);L()}hb=a+32|0;hb=c- -64|0}function w_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=hb-496|0;hb=a;g=a+488|0;bd(g,d);v[23516]=0;m=T(1153,g|0)|0;g=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Fb(f)){g=v[oj(f,0)>>2];v[23516]=0;h=Q(1171,m|0,45)|0;k=v[23516];v[23516]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Kb(a+456|0);g=Kb(a+440|0);h=Kb(a+424|0);v[23516]=0;na(1192,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[23516];v[23516]=0;if((c|0)==1){break f}v[a+4>>2]=1140;c=pe(a+8|0,0,a+4|0);j=Fb(f);l=v[a+420>>2];h:{if((j|0)>(l|0)){i=((Fb(h)+(j-l<<1)|0)+Fb(g)|0)+1|0;break h}i=(Fb(h)+Fb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Xe(c,Md(i<<2));j=v[c>>2];if(j){break e}v[23516]=0;Z(1141);b=v[23516];v[23516]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=wc(f);f=Fb(f);v[23516]=0;pa(1193,j|0,a+4|0,a|0,o|0,i|0,i+(f<<2)|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[23516];v[23516]=0;if((f|0)!=1){v[23516]=0;b=ka(1174,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Sc(c)}Yc(h);Yc(g);wb(k)}Zb(a+488|0);S(f|0);L()}Sc(c);Yc(h);Yc(g);wb(k);Zb(a+488|0);hb=a+496|0;return b|0}function lM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;f=a+484376|0;while(1){a:{c=Sb(v[a+484360>>2],w[f|0]);e=b&65535;if(Oc(v[c>>2],v[c+4>>2])>>>0>e>>>0){if(!zq(c,e)){break a}c=Sb(v[a+484360>>2],w[a+484376|0])}if(Oc(v[c>>2],v[c+4>>2])>>>0>e>>>0){e=a+1074312|0;f=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(f|0)){kM(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){Rn(a+1298264|0,1);v[a+1074456>>2]=v[a+480200>>2];v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];v[a+480208>>2]=v[a+480208>>2]&-769;Ny(a+1074376|0);u[a+1074450>>1]=0;v[a+1074392>>2]=-2;b=a+1074428|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074376>>2]=0;v[a+1074380>>2]=0}else{Vn((B(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;Ab(d+8|0,e,23);if(zb(v[v[d+8>>2]>>2],v[d+12>>2])){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;c=c+872|0;continue}break}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}hb=d+16|0;return}b=b+1|0;continue}}function VR(a,b){var c=0;a:{b:{c:{d:{if(le(a,16824)){break d}if(le(a,17593)){break d}if(le(a,13615)){break d}if(le(a,13777)){break d}if(!le(a,14346)){break c}}u[b+10>>1]=4;v[b>>2]=12072;break b}e:{f:{if(le(a,17588)){break f}if(le(a,13625)){break f}if(!le(a,16809)){break e}}t[b+12|0]=1;v[b>>2]=8420;u[b+10>>1]=4;return 1}g:{if(!le(a,14392)){if(!le(a,14397)){break g}}u[b+10>>1]=8;v[b>>2]=8198;break b}h:{if(!le(a,15479)){if(!le(a,15484)){break h}}v[b>>2]=17196;u[b+10>>1]=t[a+2|0]-48;break b}i:{if(!le(a,27050)){if(!le(a,27055)){break i}}v[b+4>>2]=1;v[b>>2]=17002;u[b+10>>1]=w[a|0]==56?8:4;return 1}if(!(Qb(a,15585,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=8538;a=t[a+3|0];u[b+8>>1]=1088;u[b+10>>1]=a-48;break b}j:{if(Qb(a,13705,3)){if(Qb(a,13839,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+15|0]=1;t[b+13|0]=1;v[b>>2]=8297;u[b+10>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!Qb(a+1|0,13863,3)){t[b+14|0]=1;v[b>>2]=8602;u[b+10>>1]=t[a|0]-48;return 1}if((w[a+1|0]-48&255)>>>0>9){break k}c=a+2|0;if(Qb(c,14195,2)){if(Qb(c,13867,2)){break k}}t[b+14|0]=1;v[b>>2]=8602;u[b+10>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}c=0;if(Qb(a,13481,3)|(w[a+3|0]-49&255)>>>0>8){break a}v[b>>2]=8447;u[b+10>>1]=t[a+3|0]-48}c=1}return c}function v$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-16|0;hb=k;l=Xu(g);g=tw(g);Wg(k,g);a:{b:{if(Pe(k)){v[23516]=0;X(1151,l|0,a|0,c|0,d|0);g=v[23516];v[23516]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[23516]=0;j=Q(20,l|0,h<<24>>24)|0;h=v[23516];v[23516]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23516]=0;h=Q(20,l|0,48)|0;i=v[23516];v[23516]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[23516]=0;h=Q(20,l|0,h|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}Sl(j,c);i=0;v[23516]=0;o=T(1149,g|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Sl((j-a|0)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[Jc(k,h)|0]){break e}if(t[Jc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Fb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[23516]=0;n=Q(20,l|0,n|0)|0;m=v[23516];v[23516]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;wb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;wb(k);hb=k+16|0}function ur(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{e=hb-96|0;hb=e;i=v[c>>2];g=hb-32|0;hb=g;f=e- -64|0;j=Kb(f+16|0);v[f>>2]=v[c>>2];v[f+4>>2]=v[c+4>>2];v[f+8>>2]=v[c+8>>2];v[f+12>>2]=v[c+12>>2];v[23516]=0;c=Q(52,g|0,c+16|0)|0;h=v[23516];v[23516]=0;b:{c:{d:{if((h|0)!=1){v[23516]=0;R(56,g+16|0,c|0);h=v[23516];v[23516]=0;if((h|0)==1){break d}f=g+16|0;yc(j,f);wb(f);wb(c);hb=g+32|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;wb(c)}bm(f);S(a|0);L()}v[23516]=0;U(d|0,e|0,b|0,(i&2?16:10)|0);b=v[23516];v[23516]=0;e:{f:{g:{h:{i:{j:{if((b|0)!=1){c=e+16|0;b=hb-16|0;hb=b;k:{if(!(v[e+64>>2]&32)){break k}k=b,l=ge(e),v[k+8>>2]=l;k=b,l=uh(e),v[k>>2]=l;while(1){if(!mj(b+8|0,b)){break k}d=v[b+8>>2];f=w[d|0];if((f-97&255)>>>0<=25){t[d|0]=f-32}He(b+8|0);continue}}Xc(c,e);hb=b+16|0;v[23516]=0;X(73,e+32|0,c|0,v[e+64>>2],v[e+68>>2]);b=v[23516];v[23516]=0;if((b|0)==1){break j}v[23516]=0;U(74,e+48|0,e+32|0,e- -64|0);b=v[23516];v[23516]=0;if((b|0)==1){break i}v[23516]=0;R(56,a|0,e+48|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}wb(e+48|0);wb(e+32|0);wb(e+16|0);wb(e);bm(e- -64|0);hb=e+96|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;wb(e+48|0)}wb(e+32|0)}wb(e+16|0);wb(e)}bm(e- -64|0);S(a|0);L()}}function L3(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-80|0;hb=e;a:{b:{c:{d:{c=a+36|0;e:{if(Nb(v[c>>2],v[a+40>>2])){yf(e+72|0);break e}d=e+32|0;yn(d,a);v[23516]=0;d=T(1026,d|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break d}v[e+72>>2]=d;Vf(e+32|0)}c=(k=c,l=v[e+72>>2],m=Nb(v[a+36>>2],v[a+40>>2]),m?k:l);d=v[a+8>>2];if((d|0)==-1){f=v[c+4>>2];d=f-24|0;g=v[c>>2];i=Ni(g,f);j=A[d>>3];f=0;while(1){if((f|0)==(i|0)){c=d;break c}c=ff(g,f);if(h+A[c>>3]>b){break c}f=f+1|0;h=h+j;continue}}c=ff(v[c>>2],d);break b}f=P()|0;O()|0;Vf(e+32|0);break a}b=b-h}d=x[c+12>>1];f=v[a+24>>2];v[23516]=0;R(1059,f|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){f:{d=v[a+24>>2];f=w[a+64|0];c=dM(MR(e+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[23516]=0;g=v[c+12>>2];v[e+16>>2]=v[c+8>>2];v[e+20>>2]=g;g=v[c+20>>2];v[e+24>>2]=v[c+16>>2];v[e+28>>2]=g;g=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=g;X(1060,e+56|0,d|0,(f?7:1)|0,e+8|0);c=v[23516];v[23516]=0;if((c|0)==1){break f}c=eM(v[e+60>>2]);d=t[c+26|0]&1;f=v[(d?c+8|0:c+12|0)>>2];d=x[(d?c+20|0:c+22|0)>>1];b=A[c>>3];Ci(e+56|0);c=v[a+24>>2];u[c+1074450>>1]=d;u[c+1074448>>1]=d;v[c+1074428>>2]=f;v[c+1074392>>2]=-2;b=h+b;A[a+16>>3]=b;Vk(e+72|0);hb=e+80|0;return+b}}f=P()|0;O()|0;Vk(e+72|0)}S(f|0);L()}function FG(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=v[a+4>>2];h:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break h}c=md(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=v[a+4>>2];i:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break i}c=md(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(B(e,10)+c|0)-48|0;d=(e|0)<214748364;c=v[a+4>>2];j:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break j}c=md(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=rka(e,d,10,0);c=b+c|0;d=kb;d=b>>>0>c>>>0?d+1|0:d;b=c;e=b-48|0;d=d-(b>>>0<48)|0;b=v[a+4>>2];l:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break l}c=md(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];m:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break m}b=md(a)}if(b-48>>>0<10){continue}break}}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){v[a+4>>2]=v[a+4>>2]-1}kb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}v[a+4>>2]=v[a+4>>2]-1;break b}if(v[a+116>>2]<0){break a}}v[a+4>>2]=v[a+4>>2]-1}kb=-2147483648;return 0}function A_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=hb-192|0;hb=a;g=a+184|0;bd(g,d);v[23516]=0;m=T(19,g|0)|0;g=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Fb(f)){g=w[gg(f,0)|0];v[23516]=0;h=Q(20,m|0,45)|0;k=v[23516];v[23516]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Kb(a+160|0);g=Kb(a+144|0);h=Kb(a+128|0);v[23516]=0;na(1190,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[23516];v[23516]=0;if((c|0)==1){break f}v[a+4>>2]=1140;c=pe(a+8|0,0,a+4|0);j=Fb(f);l=v[a+124>>2];h:{if((j|0)>(l|0)){i=((Fb(h)+(j-l<<1)|0)+Fb(g)|0)+1|0;break h}i=(Fb(h)+Fb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Xe(c,Md(i));j=v[c>>2];if(j){break e}v[23516]=0;Z(1141);b=v[23516];v[23516]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=Ic(f);f=Fb(f);v[23516]=0;pa(1191,j|0,a+4|0,a|0,o|0,i|0,f+i|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[23516];v[23516]=0;if((f|0)!=1){v[23516]=0;b=ka(15,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Sc(c)}wb(h);wb(g);wb(k)}Zb(a+184|0);S(f|0);L()}Sc(c);wb(h);wb(g);wb(k);Zb(a+184|0);hb=a+192|0;return b|0}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;f=hb-16|0;hb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){h=v[f+8>>2];o=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+l|0;e=(h>>>16&65520)+b|0;p=u[e+14>>1];q=u[e+12>>1];r=u[e+10>>1];s=u[e+8>>1];t=u[e+6>>1];w=u[e+4>>1];x=u[e+2>>1];y=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+o|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],x)+B(u[e-12>>1],y)|0)+B(u[e-4>>1],w)|0)+B(u[e>>1],t)|0)+B(u[e+4>>1],s)|0)+B(u[e+8>>1],r)|0)+B(u[e+12>>1],q)|0)+B(u[e+16>>1],p)|0)/32768;h=h+1|0;continue}break}k=k+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;hb=f+16|0}function oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=hb-16|0;hb=l;k=hb-32|0;hb=k;h=k+28|0;f=k+24|0;g=hb-16|0;hb=g;a:{b:{if(!nc(b,v[cc(g+8|0,Yf(a))>>2])){e=x[c>>1];i=v[c+4>>2];j=sd(b);m=x[j>>1];j=v[j+4>>2];if(!el(e,i,m,j)){break b}}v[g+8>>2]=b;e=cc(g,Cb(v[a>>2]));c:{f=v[g+8>>2];if(!nc(f,v[e>>2])){f=v[az(g+8|0)>>2];e=sd(f);j=x[e>>1];m=v[e+4>>2];e=x[c>>1];i=v[c+4>>2];if(!el(j,m,e,i)){break c}}if(!v[b>>2]){v[h>>2]=b;break a}v[h>>2]=f;b=f+4|0;break a}b=$y(a,h,e,i);break a}if(el(m,j,e,i)){d:{f=_y(b);if(!nc(f,v[cc(g+8|0,Yf(a))>>2])){e=x[c>>1];i=v[c+4>>2];j=sd(f);if(!el(e,i,x[j>>1],v[j+4>>2])){break d}}if(!v[b+4>>2]){v[h>>2]=b;b=b+4|0;break a}v[h>>2]=f;b=f;break a}b=$y(a,h,e,i);break a}v[h>>2]=b;v[f>>2]=b;b=f}hb=g+16|0;f=b;b=v[b>>2];if(!b){b=hb-16|0;hb=b;g=gc(a);h=k+8|0;e=gh(h,tc(36),hh(b+8|0,g));g=v[e>>2]+16|0;i=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=i;nl(g+8|0,d);o=gc(e),p=1,t[o+4|0]=p;hb=b+16|0;Hg(a,v[k+28>>2],f,v[k+8>>2]);b=_d(h);eO(h);n=1}Gg(l,v[cc(k+8|0,b)>>2],n);hb=k+32|0;if(!w[gc(l)|0]){a=sd(v[l>>2])+8|0;dO(a);v[a>>2]=v[d>>2];v[a+4>>2]=v[d+4>>2];b=Db(d);o=Db(a),p=v[b>>2],v[o>>2]=p;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[cc(l+8|0,v[l>>2])>>2];hb=l+16|0;return a|0}function pka(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}f=d;if(!f){break i}e=E(f)-E(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;ib=a-B(b,c)|0;jb=0;kb=0;return b}f=d;if(!a){break g}if(!f){break f}g=f-1|0;if(g&f){break f}ib=a;jb=e&g;a=e>>>qka(f)|0;kb=0;return a}f=c-1|0;if(!(f&c)){break e}h=(E(c)+33|0)-E(e)|0;g=0-h|0;break c}h=e+1|0;g=63-e|0;break c}ib=0;a=(e>>>0)/(f>>>0)|0;jb=e-B(a,f)|0;kb=0;return a}e=E(f)-E(e)|0;if(e>>>0<31){break d}break b}ib=a&f;jb=0;if((c|0)==1){break a}d=a;c=qka(c);a=c&31;if((c&63)>>>0>=32){e=0;a=b>>>a|0}else{e=b>>>a|0;a=((1<<a)-1&b)<<32-a|d>>>a}kb=e;return a}h=e+1|0;g=63-e|0}i=a;e=h&63;f=e&31;if((e&63)>>>0>=32){e=0;k=b>>>f|0}else{e=b>>>f|0;k=((1<<f)-1&b)<<32-f|i>>>f}f=e;e=g&63;a=e&31;if((e&63)>>>0>=32){e=i<<a;a=0}else{e=(1<<a)-1&i>>>32-a|b<<a;a=i<<a}b=e;if(h){e=d-1|0;g=c-1|0;e=(g|0)!=-1?e+1|0:e;i=e;while(1){j=k;e=f<<1|j>>>31;f=j<<1;j=e;f=b>>>31|f;e=i-((f>>>0>g>>>0)+e|0)>>31;l=e;m=c&e;k=f-m|0;f=j-((d&e)+(f>>>0<m>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;j=0;l=l&1;n=l;h=h-1|0;if(h){continue}break}}ib=k;jb=f;e=b<<1|a>>>31;a=l|a<<1;kb=e|j;return a}ib=a;jb=b;a=0;b=0}kb=b;return a}function bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=hb-16|0;hb=e;q=v[a+16>>2];r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){j=v[a+8>>2];k=v[a+12>>2];f=v[a>>2];g=v[a+4>>2];i=0;break a}j=v[a+8>>2];k=v[a+12>>2];m=kg(j,k,l);n=kb;b=v[a+76>>2];f=v[a>>2];g=v[a+4>>2];Of(f,g,mf(j,k,d),kb);i=b>>>0<kb>>>0?d:0}h=a+112|0;s=v[a+24>>2];u=v[a+20>>2];v[e>>2]=f;v[e+4>>2]=g;while(1){if(d){b=v[e+4>>2];f=v[e>>2];v[e+8>>2]=f;v[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;p=(((b&2147483647)<<1|f>>>31)&-2)+q|0;f=l;b:{c:while(1){d:{if((f|0)<=0){Pb(h,v[a+120>>2],v[a+124>>2]);f=v[a+116>>2];if(!f){break b}o=((v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31)&-2;g=0;b=0;break d}o=((v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Od(h,(g|0)/8<<16>>16);Nd(h,4);Pb(e+8|0,m,n);f=f-1|0;continue c}else{g=(t[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}break}Od(h,(g|0)/8<<16>>16);Nd(h,f);v[h>>2]=v[h>>2];v[h+4>>2]=0}f=v[c>>2];b=ig(h,r);v[c>>2]=f+B(b,u);v[c+4>>2]=v[c+4>>2]+B(b,s);Pb(e,j,k);c=c+8|0;continue}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;hb=e+16|0}function pY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(Tg(a,v[b+8>>2],e)){cw(b,c,d);return}a:{if(Tg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;if(v[b+44>>2]!=4){f=a+16|0;h=f+(v[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}u[b+52>>1]=0;$v(v[f>>2],v[f+4>>2],b,c,c,1,e);if(w[b+54|0]){break d}e:{if(!w[b+53|0]){break e}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break c}g=1;if(w[a+8|0]&2){break e}break c}g=1;if(!(t[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}v[b+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];h=a+16|0;yr(v[h>>2],v[a+20>>2],b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=v[a+8>>2];if(!(!(a&2)&v[b+36>>2]!=1)){while(1){if(w[b+54|0]){break a}yr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}yr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|v[b+36>>2]==1&v[b+24>>2]==1){break a}yr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function sr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{e=hb-96|0;hb=e;i=v[c>>2];g=hb-32|0;hb=g;f=e- -64|0;j=Kb(f+16|0);v[f>>2]=v[c>>2];v[f+4>>2]=v[c+4>>2];v[f+8>>2]=v[c+8>>2];v[f+12>>2]=v[c+12>>2];v[23516]=0;c=Q(3,g|0,c+16|0)|0;h=v[23516];v[23516]=0;b:{c:{d:{if((h|0)!=1){v[23516]=0;R(69,g+16|0,c|0);h=v[23516];v[23516]=0;if((h|0)==1){break d}f=g+16|0;Gb(j,f);xb(f);xb(c);hb=g+32|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;xb(c)}Lj(f);S(a|0);L()}v[23516]=0;U(d|0,e|0,b|0,(i&2?16:10)|0);b=v[23516];v[23516]=0;e:{f:{g:{h:{i:{j:{if((b|0)!=1){d=e+16|0;c=hb-16|0;hb=c;k:{if(!(v[e+64>>2]&32)){break k}b=Pj(e);v[c+8>>2]=b;f=ov(e);while(1){if(!Nb(b,f)){break k}g=w[b|0];if((g-97&255)>>>0<=25){t[b|0]=g-32}b=v[He(c+8|0)>>2];continue}}Xc(d,e);hb=c+16|0;v[23516]=0;X(80,e+32|0,d|0,v[e+64>>2],v[e+68>>2]);b=v[23516];v[23516]=0;if((b|0)==1){break j}v[23516]=0;U(81,e+48|0,e+32|0,e- -64|0);b=v[23516];v[23516]=0;if((b|0)==1){break i}v[23516]=0;R(69,a|0,e+48|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}xb(e+48|0);xb(e+32|0);xb(e+16|0);xb(e);Lj(e- -64|0);hb=e+96|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;xb(e+48|0)}xb(e+32|0)}xb(e+16|0);xb(e)}Lj(e- -64|0);S(a|0);L()}}function h$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-384|0;hb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=Fr(f+376|1,21751,v[c+4>>2]);v[f+332>>2]=f+336;a=Dd();a:{if(h){g=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=g;g=Ug(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;g=Ug(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=1140;i=pe(f+320|0,0,f+80|0);j=f+336|0;a=j;b:{c:{d:{if((g|0)>=30){a=Dd();e:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Ui(f+332|0,a,f+376|0,f);break e}A[f+16>>3]=e;g=Ui(f+332|0,a,f+376|0,f+16|0)}if((g|0)==-1){v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)==1){break c}break d}a=v[f+332>>2];Xe(i,a)}k=a+g|0;l=Vi(a,k,c);v[f+68>>2]=1140;h=pe(f+72|0,0,f+68|0);f:{g:{if((f+336|0)==(a|0)){g=f+80|0;break g}g=Md(g<<3);if(!g){v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Xe(h,g);j=a}a=f+56|0;bd(a,c);v[23516]=0;ja(1173,j|0,l|0,k|0,g|0,f+68|0,f- -64|0,a|0);a=v[23516];v[23516]=0;h:{if((a|0)!=1){Zb(f+56|0);v[23516]=0;a=ka(1174,b|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break h}Sc(h);Sc(i);hb=f+384|0;return a|0}c=P()|0;O()|0;Zb(f+56|0);break f}c=P()|0;O()|0}Sc(h);break b}L()}c=P()|0;O()|0}Sc(i);S(c|0);L()}function r$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-208|0;hb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=Fr(f+200|1,21751,v[c+4>>2]);v[f+156>>2]=f+160;a=Dd();a:{if(h){g=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=g;g=Ug(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;g=Ug(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=1140;i=pe(f+144|0,0,f+80|0);j=f+160|0;a=j;b:{c:{d:{if((g|0)>=30){a=Dd();e:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Ui(f+156|0,a,f+200|0,f);break e}A[f+16>>3]=e;g=Ui(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)==1){break c}break d}a=v[f+156>>2];Xe(i,a)}k=a+g|0;l=Vi(a,k,c);v[f+68>>2]=1140;h=pe(f+72|0,0,f+68|0);f:{g:{if((f+160|0)==(a|0)){g=f+80|0;break g}g=Md(g<<1);if(!g){v[23516]=0;Z(1141);a=v[23516];v[23516]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Xe(h,g);j=a}a=f+56|0;bd(a,c);v[23516]=0;ja(1168,j|0,l|0,k|0,g|0,f+68|0,f- -64|0,a|0);a=v[23516];v[23516]=0;h:{if((a|0)!=1){Zb(f+56|0);v[23516]=0;a=ka(15,b|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break h}Sc(h);Sc(i);hb=f+208|0;return a|0}c=P()|0;O()|0;Zb(f+56|0);break f}c=P()|0;O()|0}Sc(h);break b}L()}c=P()|0;O()|0}Sc(i);S(c|0);L()}function Yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=hb-16|0;hb=f;q=v[a+16>>2];r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){l=v[a+8>>2];m=v[a+12>>2];e=v[a>>2];b=v[a+4>>2];h=0;break a}l=v[a+8>>2];m=v[a+12>>2];o=kg(l,m,n);p=kb;h=v[a+76>>2];e=v[a>>2];b=v[a+4>>2];Of(e,b,mf(l,m,d),kb);h=h>>>0<kb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[f>>2]=e;v[f+4>>2]=b;b:while(1){if(d){d=d-1|0;v[f+8>>2]=e;v[f+12>>2]=0;h=h-1|0;o=h?o:0;p=h?p:0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Pb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){k=(v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31;Od(g,(u[(k<<1|2)+e>>1]+u[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Nd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;e=ig(g,r);v[c>>2]=B(j>>12,e)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Pb(f,l,m);c=c+8|0;e=v[f>>2];b=v[f+4>>2];continue b}else{k=(v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31;Od(g,(u[(k<<1|2)+e>>1]+u[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Nd(g,4);Pb(f+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=e;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;hb=f+16|0}function W2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=hb+-64|0;hb=c;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[c+40>>2]=v[a+20>>2];f=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=f;Ef(c+48|0,c+32|0,e);a=v[d+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=hb-32|0;hb=a;a:{b:{c:{d:{g=v[c+4>>2];if(f>>>0<=g>>>0){if(f>>>0>y[c+20>>2]){break d}if(y[c+8>>2]<e>>>0){break c}h=v[c+28>>2];if(v[c+24>>2]-h>>>0<e>>>0){break b}k=b+12|0;l=v[c+16>>2];m=v[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}n=b+h|0;o=B(b,g);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{r=a,s=+(ym(se(mg(A[(d+o<<3)+m>>3])*134217728))+hd(js(k),21)|0)*7.450580596923828e-9,A[r+24>>3]=s;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;p=n<<1;q=(d<<2)+l|0;i=se(A[Eg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){j=~~i;break f}j=-2147483648}r=v[q>>2]+p|0,t=$c(j),u[r>>1]=t;d=d+1|0;continue}}}aa(7192,9074,77,8754);L()}aa(7157,9074,78,8754);L()}aa(5900,9074,79,8754);L()}aa(5870,9074,80,8754);L()}hb=a+32|0;hb=c- -64|0}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;f=hb-16|0;hb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){h=v[f+8>>2];o=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+l|0;e=(h>>>16&65520)+b|0;p=u[e+14>>1];q=u[e+12>>1];r=u[e+10>>1];s=u[e+8>>1];w=u[e+6>>1];x=u[e+4>>1];y=u[e+2>>1];z=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+o|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],y)+B(t[e-6|0],z)|0)+B(t[e-2|0],x)|0)+B(t[e|0],w)|0)+B(t[e+2|0],s)|0)+B(t[e+4|0],r)|0)+B(t[e+6|0],q)|0)+B(t[e+8|0],p)<<8)/32768;h=h+1|0;continue}break}k=k+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;hb=f+16|0}function L2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=hb+-64|0;hb=c;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[c+40>>2]=v[a+20>>2];f=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=f;Ef(c+48|0,c+32|0,e);a=v[d+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=hb-32|0;hb=a;a:{b:{c:{d:{g=v[c+4>>2];if(f>>>0<=g>>>0){h=v[c+20>>2];if(f>>>0>h>>>0){break d}if(y[c+8>>2]<e>>>0){break c}i=v[c+28>>2];if(v[c+24>>2]-i>>>0<e>>>0){break b}l=b+12|0;m=v[c+16>>2];n=v[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}o=B(b,g);p=B(b+i|0,h);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{r=a,s=+(ym(se(mg(A[(d+o<<3)+n>>3])*134217728))+hd(js(l),21)|0)*7.450580596923828e-9,A[r+24>>3]=s;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;q=(d+p<<1)+m|0;j=se(A[Eg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(j)<2147483648){k=~~j;break f}k=-2147483648}r=q,t=$c(k),u[r>>1]=t;d=d+1|0;continue}}}aa(7192,9074,77,8754);L()}aa(7157,9074,78,8754);L()}aa(5900,9074,79,8754);L()}aa(5870,9074,80,8754);L()}hb=a+32|0;hb=c- -64|0}function nf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-96|0;hb=c;d=v[a+36>>2];Kl(v[v[d>>2]-12>>2]+d|0,0);d=a+32|0;Pc(c+56|0,d,4);if(!zb(v[v[c+56>>2]>>2],v[c+60>>2])){Ov(a)}a:{if(!v[a+8>>2]){break a}Pc(c+56|0,d,6);if(zb(v[v[c+56>>2]>>2],v[c+60>>2])){break a}Pc(c+88|0,d,7);if(zb(v[v[c+88>>2]>>2],v[c+92>>2])){break a}h=v[a+36>>2];e=v[a+92>>2];g=B(v[a+28>>2],v[a+8>>2]);f=g+v[a+88>>2]|0;e=Sg(c+72|0,f,f>>>0<g>>>0?e+1|0:e);f=v[e+12>>2];v[c+32>>2]=v[e+8>>2];v[c+36>>2]=f;f=v[e+4>>2];v[c+24>>2]=v[e>>2];v[c+28>>2]=f;Uj(h,c+24|0)}Pc(c+56|0,d,5);e=0;b:{if(!zb(v[v[c+56>>2]>>2],v[c+60>>2])){break b}f=Ni(v[a+52>>2],v[a+56>>2]);d=0;while(1){if((d|0)==(f|0)){break b}h=(v[a+108>>2]+d>>>0)%(f>>>0)|0;i=ff(v[a+52>>2],h);g=v[i>>2];c:{j=v[a+40>>2];if(ad(j,v[a+44>>2])>>>0<=g>>>0){break c}g=Fk(c+56|0,Ib(j,g),x[i+20>>1]);i=_v(b,g);Ub(g);if(!i){break c}v[a+108>>2]=(h+1>>>0)%(f>>>0);e=ff(v[a+52>>2],h);d=e;b=v[d+12>>2];d=v[d+8>>2];if(!(b|d)){break b}e=v[a+36>>2];b=v[a+20>>2]+b|0;f=v[a+16>>2];d=f+d|0;b=Sg(c+40|0,d,d>>>0<f>>>0?b+1|0:b);d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;Uj(e,c+8|0);e=ff(v[a+52>>2],h);break b}d=d+1|0;continue}}hb=c+96|0;return e}function mja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=hb-288|0;hb=f;_f(b);a:{if(!Ob(v[a>>2],v[a+8>>2],1)){break a}while(1){d=f+32|0;ln(f+8|0,d,rq(d));k=v[a>>2];g=v[a+8>>2];d=hb-32|0;hb=d;Vg(d+16|0,v[f+8>>2],v[f+12>>2]);e=v[v[k>>2]+28>>2];l=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=l;lb[e|0](d+24|0,k,g,d+8|0);Vg(f+16|0,v[d+24>>2],v[d+28>>2]);hb=d+32|0;v[f+28>>2]=v[f+20>>2];o=f,p=c-Fb(b)|0,v[o+4>>2]=p;d=v[Hb(f+28|0,f+4|0)>>2];if(!d){break a}t[f+16|0]=0;k=f+32|0;m=k+d|0;d=f+16|0;l=yi(k,m,d);o=f,p=uh(b),v[o+16>>2]=p;e=v[hj(f,d)>>2];g=hb-32|0;hb=g;v[g+24>>2]=e;o=g,p=ge(b),v[o+8>>2]=p;h=En(g+24|0,g+8|0);b:{c:{d=k;i=vh(d,l);if(!i){break c}if(!Ms(b,d)){e=Fb(b);j=_c(b);d:{if(i>>>0<=j-e>>>0){j=wc(b);if((e|0)==(h|0)){break d}n=h+j|0;Xh(i+n|0,n,e-h|0);break d}im(b,j,(e+i|0)-j|0,e,h,0,i);j=v[b>>2]}e=e+i|0;th(b,e);t[g+8|0]=0;$d(e+j|0,g+8|0);e=h+j|0;while(1){if((d|0)==(l|0)){break c}$d(e,d);d=d+1|0;e=e+1|0;continue}}d=Th(g+8|0,d,l);h=Ic(d);i=Fb(d);v[23516]=0;fa(363,b|0,e|0,h|0,h+i|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){wb(d);break b}a=P()|0;O()|0;wb(d);S(a|0);L()}ge(b)}hb=g+32|0;Yb(a,l-k|0);if(l>>>0>=m>>>0){continue}break}Yb(a,1)}hb=f+288|0}function pZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=hb-16|0;hb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{while(1){j=v[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=w[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=w[j+2|0];i=w[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=w[j+3|0];m=w[j+2|0];k=w[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}v[f>>2]=c;v[a+12>>2]=i+j;f=v[a+8>>2]+4|0;v[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];hb=a+16|0;return b|0}function g7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=C(0),r=0,s=0,t=0,u=C(0),w=0;i=hb-16|0;hb=i;a:{if(!ai(a+44|0)){break a}n=v[a+44>>2];j=Ec(n,0);k=Ec(n,1);n=v[a+56>>2];t=Ec(n,0);n=Ec(n,1);u=z[Bb(a+4208|0,1)>>2];v[i+12>>2]=d;s=v[a+4220>>2];q=C(C(1)/C(s>>>0));w=v[a+4216>>2];o=d;f=n;g=t;while(1){if(!o){si(a,b,c,t,n,d);break a}h=v[a+4224>>2];b:{if(s>>>0>h>>>0){v[i+8>>2]=s-h;r=v[Hb(i+12|0,i+8|0)>>2];m=0;c:{if(u<C(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break c}p=C(h>>>0);z[g>>2]=q*C(z[j>>2]*p);z[f>>2]=q*C(z[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){z[g>>2]=z[j>>2];z[f>>2]=z[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;v[i+12>>2]=o;break b}m=w-h|0;v[i+4>>2]=m;l=v[Hb(i+12|0,i+4|0)>>2];e=0;d:{if(u<C(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break d}p=C(m>>>0);z[g>>2]=q*C(z[j>>2]*p);z[f>>2]=q*C(z[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){v[g>>2]=0;v[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;v[i+12>>2]=o;e=h+l|0;l=e>>>0<w>>>0?e:0}v[a+4224>>2]=l;continue}}hb=i+16|0}function Iaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=hb-16|0;hb=l;v[l+8>>2]=b;q=tf(a);while(1){if(Fg(b,c)){b=v[cc(l,q)>>2];k=sd(v[l+8>>2]);o=hb-16|0;hb=o;p=0;m=hb-16|0;hb=m;i=hb-32|0;hb=i;g=i+28|0;d=i+24|0;e=hb-16|0;hb=e;a:{b:{if(!nc(b,v[cc(e+8|0,Yf(a))>>2])){f=w[k|0];j=v[k+4>>2];h=sd(b);n=w[h|0];h=v[h+4>>2];if(!Gn(f,j,n,h)){break b}}v[e+8>>2]=b;f=cc(e,Cb(v[a>>2]));c:{d=v[e+8>>2];if(!nc(d,v[f>>2])){d=v[az(e+8|0)>>2];f=sd(d);h=w[f|0];n=v[f+4>>2];f=w[k|0];j=v[k+4>>2];if(!Gn(h,n,f,j)){break c}}if(!v[b>>2]){v[g>>2]=b;break a}v[g>>2]=d;b=d+4|0;break a}b=Ay(a,g,f,j);break a}if(Gn(n,h,f,j)){d:{d=_y(b);if(!nc(d,v[cc(e+8|0,Yf(a))>>2])){f=w[k|0];j=v[k+4>>2];h=sd(d);if(!Gn(f,j,w[h|0],v[h+4>>2])){break d}}if(!v[b+4>>2]){v[g>>2]=b;b=b+4|0;break a}v[g>>2]=d;b=d;break a}b=Ay(a,g,f,j);break a}v[g>>2]=b;v[d>>2]=b;b=d}hb=e+16|0;d=b;b=v[b>>2];if(!b){b=hb-16|0;hb=b;e=gc(a);g=i+8|0;e=gh(g,tc(28),hh(b+8|0,e));Lz(v[e>>2]+16|0,k);r=gc(e),s=1,t[r+4|0]=s;hb=b+16|0;Hg(a,v[i+28>>2],d,v[i+8>>2]);b=_d(g);mk(g);p=1}Gg(m+8|0,v[cc(i+8|0,b)>>2],p);hb=i+32|0;hb=m+16|0;cc(o+8|0,v[m+8>>2]);hb=o+16|0;b=v[Ig(l+8|0)>>2];continue}else{hb=l+16|0}break}}function jQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];e=xh(c,v[a+4>>2]);if(e>>>0<b>>>0){g=hb-32|0;hb=g;f=b-e|0;b=v[Db(a)>>2];c=v[a+4>>2];a:{if(f>>>0<=b-c>>8>>>0){b=hb-16|0;hb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(f<<8);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){ic(b);hb=b+16|0}else{TP(a);a=a+256|0;v[b+4>>2]=a;continue}break}break a}i=Db(a);b=g+8|0;e=a;h=xh(v[a>>2],c)+f|0;c=hb-16|0;hb=c;v[c+12>>2]=h;d=hb-16|0;hb=d;v[d+12>>2]=16777215;v[d+8>>2]=2147483647;a=v[Hb(d+12|0,d+8|0)>>2];hb=d+16|0;b:{if(a>>>0>=h>>>0){d=Cz(e);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;break b}rd();L()}d=xh(v[e>>2],v[e+4>>2]);og(b+12|0,i);if(a){if(a>>>0>=16777216){Zf(11191);L()}c=tc(a<<8)}else{c=0}v[b>>2]=c;d=c+(d<<8)|0;v[b+8>>2]=d;v[b+4>>2]=d;j=zc(b),k=c+(a<<8)|0,v[j>>2]=k;a=hb-16|0;hb=a;v[a>>2]=v[b+8>>2];c=v[b+8>>2];v[a+8>>2]=b+8;v[a+4>>2]=c+(f<<8);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){TP(c);c=v[a>>2]+256|0;v[a>>2]=c;continue}break}Kd(a);hb=a+16|0;Cd(e,b);e=v[b+4>>2];a=v[b+8>>2];while(1){if((a|0)!=(e|0)){a=a-256|0;v[b+8>>2]=a;continue}break}a=v[b>>2];if(a){zc(b);Jb(a)}}hb=g+32|0;return}if(b>>>0<e>>>0){Ld(a,c+(b<<8)|0)}}function Dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;jd(b,0);Fo(b);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=Oe(ni(+(f+1408|0)/1536)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[Vb(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=w[a+6|0]|w[a+7|0]<<8;if(d>>>0<=256){u[b+28>>1]=d;u[b+34>>1]=x[b+34>>1]|32}v[b>>2]=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+4>>2]=w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24);v[b+8>>2]=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);d=w[a+20|0]|w[a+21|0]<<8;if(d&16){u[b+34>>1]=x[b+34>>1]|2;d=w[a+20|0]|w[a+21|0]<<8}if(d&32){u[b+34>>1]=x[b+34>>1]|4;d=w[a+20|0]|w[a+21|0]<<8}if(d&256){u[b+34>>1]=x[b+34>>1]|8;d=w[a+20|0]|w[a+21|0]<<8}if(d&512){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+39872|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[Vb(e+13|0,e+12|0)|0],u[g+32>>1]=h}v[b+12>>2]=w[a+27|0]|w[a+28|0]<<8|(w[a+29|0]<<16|w[a+30|0]<<24);v[b+16>>2]=w[a+31|0]|w[a+32|0]<<8|(w[a+33|0]<<16|w[a+34|0]<<24);hb=e+16|0}function yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=hb-16|0;hb=i;e=v[b+1298304>>2];if(!vd(e)){d=hb-16|0;hb=d;c=tc(12);v[23516]=0;e=T(927,c|0)|0;f=v[23516];v[23516]=0;a:{if((f|0)!=1){c=v[If(d+8|0,e)>>2];hb=d+16|0;break a}a=P()|0;O()|0;Jb(c);S(a|0);L()}v[i+8>>2]=c;c=b+1298304|0;d=i+8|0;CM(c,_d(d));ty(d);e=v[c>>2]}f=hb-48|0;hb=f;c=f+16|0;rM(c,a);v[23516]=0;U(8,f+32|0,0,c|0);c=v[23516];v[23516]=0;b:{c:{if((c|0)!=1){xb(f+16|0);m=f,n=Cb(v[e>>2]),v[m+8>>2]=n;l=Cb(v[e+4>>2]);c=0;e=0;d:{while(1){e:{h=v[f+8>>2];if(!Nb(h,l)){if(!e){break e}c=v[e+4>>2];if(!c){break e}v[23516]=0;W(c|0,e|0,b|0,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break e}break d}j=0;d=v[h>>2];if(v[d+32>>2]==v[a+16>>2]){j=v[d+36>>2]==v[a+20>>2]}v[23516]=0;R(928,f+16|0,d+8|0);d=v[23516];v[23516]=0;if((d|0)==1){break d}g=hb-16|0;hb=g;k=f+16|0;Be(g+8|0,k);Be(g,f+32|0);d=ZM(v[g+8>>2],v[g+12>>2],v[g>>2],v[g+4>>2]);hb=g+16|0;wb(k);f:{if(!(!j|(d|0)!=0)){e=v[h>>2];c=3;break f}if((c|0)<2&j){e=v[h>>2];c=2;break f}d=!d&(c|0)<=0;e=d?v[h>>2]:e;c=d?1:c}Ie(f+8|0);continue}break}wb(f+32|0);hb=f+48|0;break b}e=P()|0;O()|0;wb(f+32|0);break c}e=P()|0;O()|0;xb(f+16|0)}S(e|0);L()}hb=i+16|0}function rW(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-32|0;hb=d;if(!Qb(a,13735,4)){jd(b,32);Fo(b);_h(d,1,a+4|0);c=d+16|0;Cc(c,d);xe(b+43|0,c);wb(c);u[b+30>>1]=w[a+19|0]<<2;Bf(b+30|0,256);u[b+32>>1]=w[a+17|0];Bf(b+32|0,64);u[b+28>>1]=(w[a+47|0]&127)<<2;Bf(b+28|0,256);if(t[a+47|0]<0){u[b+34>>1]=x[b+34>>1]|32}c=w[a+18|0];if(c&16){u[b+34>>1]=x[b+34>>1]|2;c=w[a+18|0]}if(c&32){u[b+34>>1]=x[b+34>>1]|8;c=w[a+18|0]}if(c&64){u[b+34>>1]=x[b+34>>1]|4;c=w[a+18|0]}if(c<<24>>24<0){u[b+34>>1]=x[b+34>>1]|16}c=w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24);v[b+24>>2]=c?c>>>0>256?c:256:8363;v[b>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[b+4>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[b+8>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);v[b+12>>2]=w[a+64|0]|w[a+65|0]<<8|(w[a+66|0]<<16|w[a+67|0]<<24);v[b+16>>2]=w[a+68|0]|w[a+69|0]<<8|(w[a+70|0]<<16|w[a+71|0]<<24);wk(b);t[b+38|0]=w[(w[a+79|0]&7)+39872|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=w[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}u[b+34>>1]=c|x[b+34>>1]}c=w[a+72|0]|w[a+73|0]<<8|(w[a+74|0]<<16|w[a+75|0]<<24)}hb=d+32|0;return c|0}function vG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=hb-16|0;hb=l;f=w[a|0];a:{if(!f){g=a;break a}g=a;b:{while(1){if(!Nk(f<<24>>24)){break b}f=w[g+1|0];g=g+1|0;if(f){continue}break}break a}c:{f=f&255;switch(f-43|0){case 0:case 2:break c;default:break a}}m=(f|0)==45?-1:0;g=g+1|0}d:{if(!((c|16)!=16|w[g|0]!=48)){o=1;if((w[g+1|0]&223)==88){g=g+2|0;j=16;break d}g=g+1|0;j=c?c:8;break d}j=c?c:10}p=j>>31;c=0;while(1){e:{f=-48;i=t[g|0];f:{if((i-48&255)>>>0<10){break f}f=-87;if((i-97&255)>>>0<26){break f}f=-55;if((i-65&255)>>>0>25){break e}}i=f+i|0;if((i|0)>=(j|0)){break e}rf(l,j,p,0,0,k,h,0,0);f=1;g:{if(v[l+8>>2]|v[l+12>>2]){break g}q=rka(k,h,j,p);n=kb;r=i>>31;s=r^-1;if((n|0)==(s|0)&(i^-1)>>>0<q>>>0|n>>>0>s>>>0){break g}h=n+r|0;f=i+q|0;h=f>>>0<i>>>0?h+1|0:h;k=f;o=1;f=c}g=g+1|0;c=f;continue}break}if(b){v[b>>2]=o?g:a}h:{i:{j:{if(c){v[115992]=68;a=d&1;m=a?0:m;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|m)){v[115992]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}v[115992]=68;break h}a=m;b=a^k;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}hb=l+16|0;kb=e;return d}function _da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-48|0;hb=k;if(vf(v[b>>2],v[b+4>>2])>>>0>c>>>0){while(1){i=m&65535;if(i>>>0<=c>>>0){g=ag(v[b>>2],i);e=v[g>>2];if(Nb(e,v[g+4>>2])){n=k+24|0;e=Cb(e);o=Cb(v[ag(v[b>>2],i)+4>>2]);f=JP(k,d);l=hb-16|0;hb=l;v[l+8>>2]=e;while(1){if(Nb(e,o)){j=hb-16|0;hb=j;if(!(w[e+5|0]|w[e+3|0]!=4)){g=j+8|0;Ab(g,v[f>>2],x[f+14>>1]);We(g,0);t[e+3|0]=0}h=w[e+2|0];if(!(w[e+4|0]|(h|0)!=11)){g=j+8|0;Ab(g,v[f>>2],x[f+14>>1]);We(g,0);t[e+2|0]=0;h=0}a:{b:{if(!w[e|0]){Ab(j+8|0,v[f>>2],x[f+14>>1]);if(zb(v[v[j+8>>2]>>2],v[j+12>>2])){break b}h=w[e+2|0]}i=w[e+3|0];g=j+8|0;Ab(g,v[f>>2],x[f+14>>1]);We(g,(i|0)==4|(h|0)==11);h=w[e+3|0];break a}h=w[e+3|0];g=w[e+2|0];if(!(h|(g|0)==11)){t[e+5|0]=0;h=4;t[e+3|0]=4;break a}if(g|(h|0)==4){break a}t[e+4|0]=0;t[e+2|0]=11}c:{d:{e:{if(!(!w[f+16|0]|h)){t[e+3|0]=17;i=0;h=125;break e}i=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(w[e+5|0]){break c}i=1;h=6}t[e+5|0]=h}t[f+16|0]=i}u[f+14>>1]=(x[f+14>>1]+1>>>0)%x[f+12>>1];hb=j+16|0;e=v[vk(l+8|0)>>2];continue}break}HP(n,f);hb=l+16|0;Ue(n);Ue(f)}m=m+1|0;continue}break}}HP(a,d);hb=k+48|0}function G3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=hb-2144|0;hb=b;Rb(b+96|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[23516]=0;b=Q(53,b+80|0,10472)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}c=P()|0;O()|0;wb(b);break b}g=v[c>>2];d=v[c+12>>2];c=v[c+8>>2];v[b+72>>2]=c;v[b+76>>2]=d;e=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=e;v[b+68>>2]=f;v[b+64>>2]=g;e=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=e;h=OI(b+16|0);if(h){v[b+48>>2]=c;v[b+52>>2]=d;c=v[b+52>>2];v[b+8>>2]=v[b+48>>2];v[b+12>>2]=c;v[b+44>>2]=f;v[b+40>>2]=g;c=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=c;c=JI(b)}else{c=0}v[b+56>>2]=c;v[b+60>>2]=0;d=0;c=2048;while(1){if(c){e=lb[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=a;a=fc(b+32|0,b+96|0,d);a=Os(c,v[a>>2],v[a+4>>2],h?b+56|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[23516]=0;b=Q(53,b+80|0,8086)|0;c=v[23516];v[23516]=0;if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}c=P()|0;O()|0;wb(b);break b}c=P()|0;O()|0;ca(a|0);break b}hb=b+2144|0;return a|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function zd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb+-64|0;hb=d;v[a+480180>>2]=b;b=pq(a);oq(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;Ps(a+8|0,b);b=1;while(1){c=b&65535;if(c>>>0>x[a+480192>>1]){v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;oy(a,4);e=hb+-64|0;hb=e;b=a+484344|0;Rs(b);f=sk(v[b>>2],v[b+4>>2]);c=Sx(e+8|0,b);v[23516]=0;U(834,b|0,f|0,c|0);b=v[23516];v[23516]=0;a:{if((b|0)!=1){$k(c);hb=e- -64|0;break a}a=P()|0;O()|0;$k(c);S(a|0);L()}TO(a+484360|0);_f(a+1298308|0);fA(a+1298320|0);_f(a+1298332|0);c=Rb(d,0,64);b=KM(c);d=Gb(a+1298344|0,b);Gb(d+12|0,b+12|0);Gb(d+24|0,b+24|0);Gb(d+36|0,b+36|0);Gb(d+48|0,b+48|0);v[d+60>>2]=v[b+60>>2];uy(b);Gc(a+1298408|0);Gc(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}hb=c- -64|0;return}c=((c<<2)+a|0)+900380|0;e=v[c>>2];if(e){Jb(Ot(e))}v[c>>2]=0;b=b+1|0;continue}}function kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;h=hb-16|0;hb=h;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+72>>2];b=v[a+68>>2];o=b;p=b>>31;b=v[a+64>>2];q=b;r=b>>31;b=v[a+60>>2];s=b;t=b>>31;w=v[a+8>>2];x=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(q,r,e,e>>31);g=kb;f=Wb(f,-16777216,16776704);i=rka(o,p,f,f>>31);e=i+e|0;f=kb+g|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=(v[h+12>>2]<<1)+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(u[e+4>>1],u[g+10>>1])+B(u[e+2>>1],u[g+8>>1])|0)+B(u[e+6>>1],u[g+12>>1])|0)+B(u[e+8>>1],u[g+14>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+2>>1])+B(u[e-6>>1],u[g>>1])|0)+B(u[e-2>>1],u[g+4>>1])|0)+B(u[e>>1],u[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;i=rka(e,e>>31,s,t);e=y+i|0;f=kb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Pb(h+8|0,w,x);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;hb=h+16|0}function lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;h=hb-16|0;hb=h;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+72>>2];b=v[a+68>>2];o=b;p=b>>31;b=v[a+64>>2];q=b;r=b>>31;b=v[a+60>>2];s=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(q,r,e,e>>31);g=kb;f=Wb(f,-16777216,16776704);i=rka(o,p,f,f>>31);e=i+e|0;f=kb+g|0;f=e>>>0<i>>>0?f+1|0:f;z=e;e=v[h+12>>2]+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(t[e+2|0],u[g+10>>1])+B(t[e+1|0],u[g+8>>1])|0)+B(t[e+3|0],u[g+12>>1])|0)+B(t[e+4|0],u[g+14>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+2>>1])+B(t[e-3|0],u[g>>1])|0)+B(t[e-1|0],u[g+4>>1])|0)+B(t[e|0],u[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;i=rka(e,e>>31,s,w);e=z+i|0;f=kb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Pb(h+8|0,x,y);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;hb=h+16|0}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=hb-16|0;hb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+32>>2];p=v[a+28>>2];q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];t=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(t,w,e,e>>31);k=kb;C=e;e=(v[h+12>>2]<<1)+n|0;g=v[h+8>>2]>>>21&2040;l=(((B(u[e>>1],u[g+39890>>1])+B(u[e-2>>1],u[g+39888>>1])|0)+B(u[e+2>>1],u[g+39892>>1])|0)+B(u[e+4>>1],u[g+39894>>1])|0)/16384<<8;e=l;m=rka(e,e>>31,x,y);g=C+m|0;e=kb+k|0;e=g>>>0<m>>>0?e+1|0:e;f=Wb(f,-16777216,16776704);k=rka(r,s,f,f>>31);g=k+g|0;f=kb+e|0;f=g>>>0<k>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;j=j+p|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+o|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Pb(h+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;hb=h+16|0}function rea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=hb-16|0;hb=f;u[f+12>>1]=c;u[f+14>>1]=b;u[f+10>>1]=d;h=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(h>>>0<=b>>>0){break a}if(!c|qj(a)>>>0>=h>>>0){break a}Bf(f+12|0,h-b&65535);p=f,q=ul(v[a>>2],v[a+4>>2]),u[p+8>>1]=q;g=x[f+12>>1];mS(a,g+x[ie(f+14|0,f+8|0)>>1]|0);c=v[a>>2];e=a;if(Oc(c,v[a+4>>2])>>>0<b>>>0){tg(e,b);c=v[e>>2]}a=Cb(c);c=hb-16|0;hb=c;v[c+8>>2]=a;a=v[WO(c+8|0,b)>>2];hb=c+16|0;a=v[cc(f,a)>>2];i=f+10|0;l=hb-32|0;hb=l;b=a;a=v[e>>2];d=(ro(b,Cb(a))<<1)+a|0;a=g;b:{if(!a){break b}b=v[Db(e)>>2];g=v[e+4>>2];if(a>>>0<=b-g>>1>>>0){b=a;c=g-d>>1;if(c>>>0<a>>>0){Ao(e,a-c|0,i);b=c;if((d|0)==(g|0)){break b}}m=hb-16|0;hb=m;c=g;o=v[e+4>>2];g=(o-((a<<1)+d|0)|0)+d|0;n=$h(m,e,c-g>>1);j=v[n+4>>2];k=g;while(1){if(c>>>0<=k>>>0){ic(n);tq(d,g,o);hb=m+16|0}else{Ki(j,x[k>>1]);j=j+2|0;v[n+4>>2]=j;k=k+2|0;continue}break}Lt(d,b,((d>>>0<=i>>>0?y[e+4>>2]>i>>>0?a:0:0)<<1)+i|0);break b}b=Db(e);b=Jj(l+8|0,Kj(e,Oc(v[e>>2],g)+a|0),d-v[e>>2]>>1,b);AC(b,a,i);d=UO(e,b,d);Li(b)}Cb(d);hb=l+32|0;if(Oc(v[e>>2],v[e+4>>2])>>>0<=h>>>0){break a}tg(e,h)}hb=f+16|0}function Kia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;jd(b,32);lo(b);f=b,g=ne((w[a+50|0]|w[a+51|0]<<8)<<16>>16)>>>2|0,u[f+32>>1]=g;if((ne((w[a+32|0]|w[a+33|0]<<8)<<16>>16)|0)>0){u[b+34>>1]=x[b+34>>1]|32;c=ne((w[a+32|0]|w[a+33|0]<<8)<<16>>16);e=c>>>24|0;d=(c<<8&-256)+2047|0;c=e&255;f=b,g=Bc(uka(d,d>>>0<2047?c+1|0:c,4095,0),kb),u[f+28>>1]=g}c=_b(w[a+38|0]|w[a+39|0]<<8|(w[a+40|0]<<16|w[a+41|0]<<24));v[b>>2]=c;d=_b(w[a+42|0]|w[a+43|0]<<8|(w[a+44|0]<<16|w[a+45|0]<<24));v[b+4>>2]=d;e=_b(w[a+42|0]|w[a+43|0]<<8|(w[a+44|0]<<16|w[a+45|0]<<24))+_b(w[a+46|0]|w[a+47|0]<<8|(w[a+48|0]<<16|w[a+49|0]<<24))|0;v[b+8>>2]=e;if((Eb(w[a+34|0]|w[a+35|0]<<8)|0)==16){v[b+8>>2]=e>>>1;v[b+4>>2]=d>>>1;v[b>>2]=c>>>1}a:{b:{if(_b(w[a+42|0]|w[a+43|0]<<8|(w[a+44|0]<<16|w[a+45|0]<<24))){c=x[b+34>>1];break b}c=x[b+34>>1];if(_b(w[a+46|0]|w[a+47|0]<<8|(w[a+48|0]<<16|w[a+49|0]<<24))>>>0>=3){break b}c=c&-3;break a}c=c|2}u[b+34>>1]=c;f=b,g=c&65531|Eb(w[a+30|0]|w[a+31|0]<<8)<<1&4,u[f+34>>1]=g;f=b,g=Eb(w[a+36|0]|w[a+37|0]<<8)<<1,v[f+24>>2]=g;c=ne((w[a+52|0]|w[a+53|0]<<8)<<16>>16);if(c){sl(b,+(c|0)/96);c=ne((w[a+52|0]|w[a+53|0]<<8)<<16>>16)}t[b+37|0]=c<<4}function H8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-16|0;hb=h;if(!w[a+4242|0]){Fx(a);a:{if(!w[a+4240|0]){break a}e=mM(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;Ds(a)}f=a+4256|0;b:{if(w[a+4244|0]){if(A[f>>3]>1){v[f>>2]=0;v[f+4>>2]=1072693248}break b}i=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Dx(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=Bi(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=A[a+4280>>3]*e+A[a+4272>>3]*(1-e)}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];PN(h+8|0,1);g=gj(a);f:{if(!g){break f}f=v[a+4236>>2];if(w[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|nk(A[h+8>>3]*127)<<16,j=v[v[g>>2]+68>>2],lb[j](k|0,l|0)|0;break f}lb[v[v[g>>2]+44>>2]](g,f,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4264>>3]*+(d>>>0)+A[a+4256>>3]}g=a;a=v[a+44>>2];si(g,b,c,Ec(a,0),Ec(a,1),d);hb=h+16|0}function CS(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;t[d+15|0]=c;a:{if(b>>>0>=22){t[d+14|0]=0;ae(a,0,d+14|0);break a}e=w[b+26848|0];b:{c:{switch(b-8|0){case 0:t[d+15|0]=c<<1;break b;case 4:t[d+15|0]=c+1>>>1;break b;case 5:t[d+15|0]=B(c>>>4|0,10)+(c&15);break b;case 6:d:{switch((c>>>4|0)-1|0){default:e=0;break b;case 0:t[d+13|0]=c&15;t[d+12|0]=14;f=d,g=w[Vb(d+13|0,d+12|0)|0]<<4|15,t[f+15|0]=g;e=29;break b;case 1:t[d+11|0]=c&15;t[d+10|0]=14;f=d,g=w[Vb(d+11|0,d+10|0)|0]|240,t[f+15|0]=g;e=29;break b;case 3:t[d+15|0]=c&15|48;break b;case 4:t[d+15|0]=c<<4^128;e=35;break b;case 5:t[d+15|0]=c&15|176;break b;case 6:t[d+15|0]=c&15|64;break b;case 8:e=15;t[d+15|0]=c&15;break b;case 9:t[d+15|0]=(c<<3&120)+8&240;e=24;break b;case 10:t[d+15|0]=(c&15)+1>>>1;e=24;break b;case 14:break d;case 11:case 12:case 13:break b}}e=10;break b;case 8:if(c>>>0<=223){b=c>>>2|0;t[d+15|0]=(b>>>0<15?b:15)<<4;break b}if(c>>>0<=239){t[d+15|0]=c<<2&48|15;break b}t[d+15|0]=c<<4|15;break b;case 9:break c;default:break b}}if(c>>>0<=223){b=c>>>2|0;t[d+15|0]=b>>>0<15?b:15;break b}if(c>>>0>239){break b}t[d+15|0]=c>>>2&3|240}ae(a,e,d+15|0)}hb=d+16|0}function Oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;g=hb-16|0;hb=g;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(r,s,e,e>>31);h=kb;f=Wb(f,-16777216,16776704);k=rka(p,q,f,f>>31);e=k+e|0;f=kb+h|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=v[g+12>>2]+l|0;h=v[g+8>>2]>>>21&2040;h=(((B(t[e|0],u[h+39890>>1])+B(t[e-1|0],u[h+39888>>1])|0)+B(t[e+1|0],u[h+39892>>1])|0)+B(t[e+2|0],u[h+39894>>1])<<8)/16384<<8;e=h;k=rka(e,e>>31,w,x);e=A+k|0;f=kb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;j=j+n|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+m|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Pb(g+8|0,y,z);e=f-(h&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;hb=g+16|0}function aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=hb-16|0;hb=e;o=v[a+16>>2];p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){j=v[a+8>>2];k=v[a+12>>2];f=v[a>>2];g=v[a+4>>2];i=0;break a}j=v[a+8>>2];k=v[a+12>>2];m=kg(j,k,l);n=kb;b=v[a+76>>2];f=v[a>>2];g=v[a+4>>2];Of(f,g,mf(j,k,d),kb);i=b>>>0<kb>>>0?d:0}h=a+112|0;q=v[a+24>>2];r=v[a+20>>2];v[e>>2]=f;v[e+4>>2]=g;b:while(1){if(d){b=v[e+4>>2];f=v[e>>2];v[e+8>>2]=f;v[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;f=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Pb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){g=(v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31;Od(h,(u[(g<<1|2)+f>>1]+u[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Nd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}f=v[c>>2];b=ig(h,p);v[c>>2]=f+B(b,r);v[c+4>>2]=v[c+4>>2]+B(b,q);Pb(e,j,k);c=c+8|0;continue b}else{g=(v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31;Od(h,(u[(g<<1|2)+f>>1]+u[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Nd(h,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;hb=e+16|0}function p9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=hb-16|0;hb=j;c=nf(a,c);ke(j,v[a+36>>2]);a:{b:{if(!c){Pc(j,a+32|0,5);d=-1;if(!zb(v[v[j>>2]>>2],v[j+4>>2])){break b}break a}d=v[c+16>>2]}e=v[a+36>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){d=hb-16|0;hb=d;v[d+8>>2]=0;yp(e,d+8|0);z[b>>2]=z[d+8>>2];hb=d+16|0;break c}f=hb-16|0;hb=f;v[f+12>>2]=d;v[f+8>>2]=4;h=v[Hb(f+12|0,f+8|0)>>2];k=hb-16|0;hb=k;dG(k+8|0,e);d=v[k+12>>2];if(pr(-1,2147483647,h,0)^1){i=pr(h,0,0,-2147483648)^1}else{i=0}if(i){d:{e=hb-48|0;hb=e;i=d+v[v[d>>2]-12>>2]|0;g=v[i+16>>2]&-3;Kl(i,g);e:{f:{if(Sd(w[Zl(e+40|0,d,1)|0])){i=v[(d+v[v[d>>2]-12>>2]|0)+24>>2];v[23516]=0;dF(e+24|0,i,h);h=v[23516];v[23516]=0;g:{if((h|0)!=1){g=aE(e+24|0,Sg(e+8|0,-1,-1))?g|4:g;break g}h=V(0)|0;O()|0;_(h|0)|0;g=g|1;Wl(d+v[v[d>>2]-12>>2]|0,g);if(v[(d+v[v[d>>2]-12>>2]|0)+20>>2]&1){v[23516]=0;Z(103);a=v[23516];v[23516]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break f}S(a|0);L()}$()}Ii(d+v[v[d>>2]-12>>2]|0,g)}hb=e+48|0;break d}V(0)|0;O()|0;Tb()}L()}}hb=k+16|0;v[b>>2]=0;hb=f+16|0}f=c}Ve(a,f);hb=j+16|0}function X2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=hb+-64|0;hb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Ef(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+8>>2];e=v[a+4>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=hb-32|0;hb=a;a:{b:{c:{d:{g=v[b+4>>2];if(g>>>0>=e>>>0){if(y[b+20>>2]<e>>>0){break d}if(d>>>0>y[b+8>>2]){break c}h=v[b+28>>2];if(d>>>0>v[b+24>>2]-h>>>0){break b}k=v[b+16>>2];l=v[b>>2];e:while(1){if((d|0)==(f|0)){break a}m=f+h|0;n=B(f,g);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{A[a+24>>3]=A[(c+n<<3)+l>>3];v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;o=m<<1;p=(c<<2)+k|0;i=se(A[Eg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){j=~~i;break f}j=-2147483648}q=v[p>>2]+o|0,r=$c(j),u[q>>1]=r;c=c+1|0;continue}}}aa(7192,9074,77,8754);L()}aa(7157,9074,78,8754);L()}aa(5900,9074,79,8754);L()}aa(5870,9074,80,8754);L()}hb=a+32|0;hb=b- -64|0}function Hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=hb-16|0;hb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];t=u[e+2>>1];w=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+m|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)+B(u[e+4>>1],q)|0)+B(u[e+8>>1],p)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;hb=f+16|0}function N2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=hb+-64|0;hb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Ef(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+8>>2];e=v[a+4>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=hb-32|0;hb=a;a:{b:{c:{d:{g=v[b+4>>2];if(g>>>0>=e>>>0){h=v[b+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>y[b+8>>2]){break c}i=v[b+28>>2];if(d>>>0>v[b+24>>2]-i>>>0){break b}l=v[b+16>>2];m=v[b>>2];e:while(1){if((d|0)==(f|0)){break a}n=B(f,g);o=B(f+i|0,h);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{A[a+24>>3]=A[(c+n<<3)+m>>3];v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;p=(c+o<<1)+l|0;j=se(A[Eg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(j)<2147483648){k=~~j;break f}k=-2147483648}q=p,r=$c(k),u[q>>1]=r;c=c+1|0;continue}}}aa(7192,9074,77,8754);L()}aa(7157,9074,78,8754);L()}aa(5900,9074,79,8754);L()}aa(5870,9074,80,8754);L()}hb=a+32|0;hb=b- -64|0}function q8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=hb+-64|0;hb=b;g=Lb(a);v[23516]=0;Y(929,g|0);a=v[23516];v[23516]=0;a:{if((a|0)!=1){a=44752;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==45064){hb=b- -64|0;return g|0}k:{h=Ns(44);if(h){d=v[a>>2];e=v[a+4>>2];v[23516]=0;e=Q(53,b+32|0,e|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break k}v[23516]=0;R(930,b+48|0,e|0);c=v[23516];v[23516]=0;if((c|0)==1){break j}c=v[a+8>>2];v[23516]=0;c=Q(53,b|0,c|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break i}v[23516]=0;R(930,b+16|0,c|0);f=v[23516];v[23516]=0;if((f|0)==1){break h}v[23516]=0;d=fa(931,h|0,d|0,b+48|0,b+16|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break g}Ub(b+16|0);wb(c);Ub(b+48|0);wb(e);v[b+60>>2]=d;v[23516]=0;R(932,g|0,b+60|0);e=v[23516];v[23516]=0;if((e|0)==1){break b}v[d+32>>2]=v[a+12>>2];v[d+36>>2]=v[a+16>>2];t[d+40|0]=w[a+20|0];t[d+41|0]=w[d+41|0]&253|w[a+21|0]<<1}a=a+24|0;continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ub(b+16|0)}wb(c)}Ub(b+48|0)}wb(e)}Jb(h);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}lc(g);S(a|0);L()}function Aja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=hb-1072|0;hb=d;v[d+1068>>2]=c;o=d,p=Je(b),t[o+8|0]=p;t[d+4|0]=1;c=d+8|0;g=w[ef(c,d+4|0)|0];f=nB(c,b);l=wq(f);v[23516]=0;c=T(200,b|0)|0;e=v[23516];v[23516]=0;a:{if((e|0)!=1){v[d+4>>2]=c;v[d>>2]=536870911;uc(d+1068|0,v[Hb(d+4|0,d)>>2]<<3);v[23516]=0;m=v[d+1068>>2];k=Q(340,a|0,m|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){v[23516]=0;c=8;h=Q(162,f|0,8)|0;a=v[23516];v[23516]=0;b:{if((a|0)!=1){c:{o=Ib(v[k>>2],0),p=h,t[o|0]=p;i=1;a=g;while(1){c=c&255;n=c>>>0>9?c:9;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}v[23516]=0;j=Q(162,f|0,c|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=Ib(v[k>>2],i),p=h,t[o|0]=p;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=wq(f);v[23516]=0;Q(153,b|0,((a-l|0)+3&-4)+l|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break b}}}c=P()|0;O()|0;dc(k);break a}yb(f);hb=d+1072|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0}yb(f);S(c|0);L()}function G_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=hb-448|0;hb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=1175;b=pe(a+24|0,a+32|0,a+20|0);h=a+16|0;bd(h,e);v[23516]=0;h=T(1153,h|0)|0;i=v[23516];v[23516]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[23516]=0;c=qa(1183,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(Fe(g)){td(v[g>>2],0);xd(g,0);break d}td(g,0);Xd(g,0)}if(w[a+15|0]){v[23516]=0;c=Q(1171,h|0,45)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}v[23516]=0;R(47,g|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}}v[23516]=0;c=Q(1171,h|0,48)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}d=v[a+20>>2];h=d-4|0;e=v[b>>2];while(1){if(!((c|0)!=v[e>>2]|e>>>0>=h>>>0)){e=e+4|0;continue}break}v[23516]=0;W(1188,g|0,e|0,d|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break c}break a}v[23516]=0;c=Q(1159,a+440|0,a+432|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+440>>2];Zb(a+16|0);Sc(b);hb=a+448|0;return c|0}}}c=P()|0;O()|0;Zb(a+16|0);Sc(b);S(c|0);L()}function yn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-80|0;hb=c;g=Lb(a);a=v[b+24>>2];a:{b:{if(pj(v[a+484360>>2],v[a+484364>>2])){c:{d:{e:while(1){if(pj(v[a+484360>>2],v[a+484364>>2])>>>0<=f>>>0){break d}d=dM(NR(c+40|0,1),f&255,0,0);v[23516]=0;e=v[d+12>>2];v[c+16>>2]=v[d+8>>2];v[c+20>>2]=e;e=v[d+20>>2];v[c+24>>2]=v[d+16>>2];v[c+28>>2]=e;e=v[d+4>>2];v[c+8>>2]=v[d>>2];v[c+12>>2]=e;X(1060,c- -64|0,a|0,0,c+8|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}j=c,k=Cb(v[c+64>>2]),v[j+32>>2]=k;d=Cb(v[c+68>>2]);while(1){a=v[c+32>>2];if(!Nb(a,d)){f=f+1|0;Ci(c- -64|0);a=v[b+24>>2];continue e}h=A[a>>3];e=v[a+16>>2];i=x[a+24>>1];a=c+40|0;v[a+16>>2]=f;v[a+12>>2]=i;v[a+8>>2]=e;A[a>>3]=h;v[23516]=0;R(1079,g|0,a|0);a=v[23516];v[23516]=0;if((a|0)!=1){pz(c+32|0);continue}break}break}a=P()|0;O()|0;Ci(c- -64|0);break b}hb=c+80|0;return}a=P()|0;O()|0;break b}b=ba(8)|0;v[23516]=0;d=Q(53,c+40|0,7270)|0;a=v[23516];v[23516]=0;if((a|0)!=1){a=rc(b,d);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(d);break b}a=P()|0;O()|0;ca(b|0)}Vf(g);S(a|0)}L()}function Jaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=hb-16|0;hb=i;v[i+8>>2]=b;o=tf(a);while(1){if(Fg(b,c)){b=v[cc(i,o)>>2];j=sd(v[i+8>>2]);m=hb-16|0;hb=m;n=0;k=hb-16|0;hb=k;h=hb-32|0;hb=h;f=h+28|0;d=h+24|0;e=hb-16|0;hb=e;a:{b:{if(!nc(b,v[cc(e+8|0,Yf(a))>>2])){g=w[j|0];l=w[sd(b)|0];if(!Hn(g,l)){break b}}v[e+8>>2]=b;g=cc(e,Cb(v[a>>2]));c:{d=v[e+8>>2];if(!nc(d,v[g>>2])){d=v[az(e+8|0)>>2];l=w[sd(d)|0];g=w[j|0];if(!Hn(l,g)){break c}}if(!v[b>>2]){v[f>>2]=b;break a}v[f>>2]=d;b=d+4|0;break a}b=By(a,f,g);break a}if(Hn(l,g)){d:{d=_y(b);if(!nc(d,v[cc(e+8|0,Yf(a))>>2])){g=w[j|0];if(!Hn(g,w[sd(d)|0])){break d}}if(!v[b+4>>2]){v[f>>2]=b;b=b+4|0;break a}v[f>>2]=d;b=d;break a}b=By(a,f,g);break a}v[f>>2]=b;v[d>>2]=b;b=d}hb=e+16|0;d=b;b=v[b>>2];if(!b){b=hb-16|0;hb=b;e=gc(a);f=h+8|0;e=gh(f,tc(24),hh(b+8|0,e));VM(v[e>>2]+16|0,v[j>>2],v[j+4>>2]);p=gc(e),q=1,t[p+4|0]=q;hb=b+16|0;Hg(a,v[h+28>>2],d,v[h+8>>2]);b=_d(f);mk(f);n=1}Gg(k+8|0,v[cc(h+8|0,b)>>2],n);hb=h+32|0;hb=k+16|0;cc(m+8|0,v[k+8>>2]);hb=m+16|0;b=v[Ig(i+8|0)>>2];continue}else{hb=i+16|0}break}}function $R(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;a:{if((d&255)>>>0<=4){while(1){d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!hf(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!hf(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){d=hf(a,f+13|0);if(d){g=w[f+13|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!d){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!hf(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){d=hf(a,f+11|0);if(d){g=w[f+11|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!d){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}hb=f+16|0}function zV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=hb-32|0;hb=g;t[g+12|0]=0;m=KB(g+16|0,d,g+12|0);f=v[m>>2];v[g+12>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=w[a|0];if(!(!i|(k|0)!=(e&255))){v[g+8>>2]=w[a+1|0];i=a+2|0;j=Hb(g+8|0,g+12|0);b:{k=b-2|0;if(!k){break b}j=v[j>>2];if(!(j&255)){break b}i=w[i|0];while(1){if(!(j&255)){break a}t[f|0]=i;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;j=j-1|0;continue}}t[f|0]=e;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;t[f|0]=k;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=v[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=t[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;t[c|0]=k;e=e-1|0;c=c+1|0;continue}break}dc(m);hb=g+32|0;return}n=w[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;t[l|0]=w[l|0]|B(f&n,257)>>>(h-j&7);l=b+1|0;b=d>>>0>l>>>0?l:0;j=j+1|0;h=(d>>>0<=l>>>0)+h|0;f=(f<<8|f)>>>1&255;continue}}}function M9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=hb-32|0;hb=j;e=b;b=v[a>>2];f=B(Ks(e,Cb(b)),6)+b|0;a:{if(!c){break a}b=v[Db(a)>>2];g=v[a+4>>2];if((b-g|0)/6>>>0>=c>>>0){b=c;e=(g-f|0)/6|0;if(e>>>0<c>>>0){FA(a,c-e|0,d);b=e;if((f|0)==(g|0)){break a}}k=hb-16|0;hb=k;m=v[a+4>>2];h=B((m-(B(c,6)+f|0)|0)/6|0,6)+f|0;l=yq(k,a,(g-h|0)/6|0);i=v[l+4>>2];e=h;while(1){if(e>>>0>=g>>>0){ic(l);if((f|0)!=(h|0)){e=h-f|0;dj(m+B((e|0)/-6|0,6)|0,f,e)}hb=k+16|0}else{Ut(i,e);i=i+6|0;v[l+4>>2]=i;e=e+6|0;continue}break}e=f;a=B(e>>>0<=d>>>0?y[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[e|0]=c;t[e+1|0]=c>>>8;t[e+2|0]=c>>>16;t[e+3|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[e+4|0]=c;t[e+5|0]=c>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=Db(a);e=US(j+8|0,BA(a,lk(v[a>>2],g)+c|0),(f-v[a>>2]|0)/6|0,b);TS(e,c,d);b=v[e+4>>2];d=e+4|0;RS(v[a>>2],f,d);h=v[a+4>>2];c=e+8|0;while(1){if((f|0)!=(h|0)){Ut(v[c>>2],f);v[c>>2]=v[c>>2]+6;f=f+6|0;continue}break}oc(a,d);oc(a+4|0,c);oc(Db(a),zc(e));v[e>>2]=v[e+4>>2];f=b;SS(e)}Cb(f);hb=j+32|0}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=hb-16|0;hb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+m|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)|0)+B(t[e+2|0],q)|0)+B(t[e+4|0],p)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;hb=f+16|0}function h8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=0,x=0,y=0,A=C(0);i=v[a+44>>2];h=Ec(i,0);i=Ec(i,1);j=v[a+56>>2];n=Ec(j,0);j=Ec(j,1);k=a+4208|0;g=sc(v[k>>2],v[a+4212>>2]);o=B(v[v[a+16>>2]+1074404>>2],w[a+4233|0]);e=o<<1;if(g>>>0<e>>>0){ak(k,e)}l=w[a+4232|0];a:{if(l){e=v[a+4220>>2];k=v[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=z[i>>2];e=e>>>0<o>>>0?e:0;g=e-o|0;g=((g|0)<0?e:g)<<1;x=Bb(k,g);f=z[Bb(k,g|1)>>2];s=z[h>>2];t=z[x>>2];p=C(s+t);z[n>>2]=p;q=C(r+f);z[j>>2]=q;f=C(0);m=C(0);b:{c:{switch(u|0){case 0:f=z[a+4224>>2];m=C(q*f);f=C(p*f);break b;case 1:case 2:f=z[a+4224>>2];m=C(p*f);f=C(q*f);break b;case 3:break c;default:break b}}f=C(C(C(C(s+r)*C(.5))+t)*z[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;i=i+4|0;h=h+4|0;g=e<<1;y=Bb(k,g),A=C(D(f))<C(1.0000000195414814e-24)?C(0):f,z[y>>2]=A;y=Bb(k,g|1),A=C(D(m))<C(1.0000000195414814e-24)?C(0):m,z[y>>2]=A;e=e+1|0;v[a+4220>>2]=e;l=l+1|0;continue}}e=h;h=d<<2;lh(e,e+h|0,n);lh(i,i+h|0,j)}h=a;a=v[a+56>>2];si(h,b,c,Ec(a,0),Ec(a,1),d)}function JA(a,b,c,d){t[a+5|0]=c;a:{b:{switch((b|64)+-64|0){case 0:t[a+3|0]=c?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(d){break a}t[a+5|0]=B(c>>>4|0,10)+(c&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=d?32:31;return;case 29:t[a+3|0]=d?33:0;return;case 27:t[a+3|0]=d?34:0;return;case 30:t[a+3|0]=d?35:0;return;case 31:t[a+3|0]=d?36:0;return;case 50:t[a+3|0]=d?25:0;return;case 51:t[a+3|0]=d?30:0;return;default:break b}}t[a+3|0]=0}}function M7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),t=0,u=0,w=0,x=0,y=0,A=C(0);a:{j=v[a+4272>>2];if(!j){break a}if(!ai(a+44|0)){break a}f=v[a+44>>2];l=Ec(f,0);m=Ec(f,1);u=v[a+4252>>2]-1|0;i=v[a+4268>>2];k=v[a+4256>>2];n=d;f=v[a+56>>2];q=Ec(f,0);o=q;r=Ec(f,1);p=r;while(1){if(n){e=z[m>>2];f=i<<1;h=Bb(k,f);g=z[l>>2];z[h>>2]=g;y=Bb(k,f|1),A=e,z[y>>2]=A;s=z[a+4276>>2];e=C(C(D(BK(C(C(C(D(g))+C(D(e)))*C(536870912)),31,5)))*C(4.656612873077393e-10));e=C(C(C(s-e)*z[(e>=s?4236:4240)+a>>2])+e);z[a+4276>>2]=e;g=z[a+4244>>2];e=C(C(C(C(g-(e<g?g:e))*z[a+4248>>2])+C(.9999998807907104))*C(2147483648));b:{if(e<C(4294967296)&e>=C(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=z[Bb(k,t)>>2];h=f<<5;w=h;x=h|-2147483648;h=f>>>0<67108864;e=C(z[a+4232>>2]*C(C((h?w:x)>>>(h?31:32-(f>>>26|0)|0)>>>0)*C(4.656612873077393e-10)));z[o>>2]=g*e;y=p,A=C(z[Bb(k,t|1)>>2]*e),z[y>>2]=A;i=((i?0:j)+i|0)-1|0;v[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{si(a,b,c,q,r,d)}break}}}function LX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;f=Lb(a);a=0;a:{b:{c:{d:{e:{while(1){if((Jv(b,c,a)|0)==-1){break b}e=Jv(b,c,a);v[23516]=0;X(120,d|0,b|0,a|0,e-a|0);e=v[23516];v[23516]=0;if((e|0)!=1){v[23516]=0;R(121,d+16|0,d|0);e=v[23516];v[23516]=0;if((e|0)==1){break e}v[23516]=0;R(122,f|0,d+16|0);e=v[23516];v[23516]=0;if((e|0)==1){break d}xb(d+16|0);xb(d);a=Jv(b,c,a)+zk(v[c+4>>2],w[c+11|0])|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;xb(d+16|0)}xb(d);break a}f:{g:{h:{i:{j:{k:{if(nc(v[f>>2],v[f+4>>2])){v[23516]=0;X(120,d+16|0,b|0,a|0,-1);c=v[23516];v[23516]=0;if((c|0)==1){break j}c=zk(v[d+20>>2],w[d+27|0]);xb(d+16|0);if(!c){break k}}v[23516]=0;X(120,d|0,b|0,a|0,-1);a=v[23516];v[23516]=0;if((a|0)==1){break i}v[23516]=0;R(121,d+16|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}v[23516]=0;R(122,f|0,d+16|0);a=v[23516];v[23516]=0;if((a|0)==1){break g}xb(d+16|0);xb(d)}hb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break f}a=P()|0;O()|0;xb(d+16|0)}xb(d)}Il(f);S(a|0);L()}function hia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-48|0;hb=d;i=a+484344|0;j=a+480280|0;k=a+906300|0;while(1){a:{if(Ob(v[b>>2],v[b+8>>2],9)){e=d+44|0;eo(b,e);c=zg(b);b:{if(!Qb(e,14083,4)){break b}if(!Qb(d+44|0,13735,4)){break b}if(!Qb(d+44|0,13911,4)){break b}if(!Qb(d+44|0,13916,4)){break b}if(Ob(v[b>>2],v[b+8>>2],c)){break a}}wg(b,8)}hb=d+48|0;return l|0}Wd(d,b,c);e=hc(d+24|0,d);yb(d);c=j;c:{d:{e:{if(!Qb(d+44|0,13594,4)){while(1){if((c|0)==(i|0)){break c}v[23516]=0;f=T(155,e|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break e}t[c+8|0]=f;c=c+32|0;continue}}if(w[d+44|0]!=70){break d}f=w[d+45|0];h=(f|0)==88;f:{if(!h){if((f-48&255)>>>0>9){break d}c=t[d+46|0];if((c|0)>47){break f}break d}c=t[d+46|0];if((c|0)<48){break d}}if(c>>>0>57){break d}g=t[d+47|0];if((g|0)<48|(g|0)>57){break d}c=(g+(h?-16:B(f,100)+48|0)|0)+B(c,10)&255;if(c>>>0>249){break c}v[23516]=0;R(447,e|0,Id(k,c)|0);c=v[23516];v[23516]=0;if((c|0)!=1){break c}}a=P()|0;O()|0;yb(e);S(a|0);L()}if(Qb(d+44|0,13610,4)){break c}v[a+1074308>>2]=0;l=1}yb(e);continue}}function O5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23516]=0;Y(991,a|0);e=v[23516];v[23516]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[23516]=0;Y(967,b|0);e=v[23516];v[23516]=0;if((e|0)==1){break e}e=0;v[23516]=0;Y(992,c|0);f=v[23516];v[23516]=0;if((f|0)==1){break e}a=Rb(c,0,d);if(!w[b|0]){break b}if(xi(b,7226)|(d|0)!=8){break d}v[a+4>>2]=993;v[a>>2]=994;break c}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,12312,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();return 0}if(!(xi(b,11277)|(d|0)!=64)){v[a+60>>2]=995;v[a+56>>2]=996;v[a+52>>2]=997;v[a+48>>2]=998;v[a+44>>2]=999;v[a+40>>2]=1e3;v[a+36>>2]=1001;v[a+32>>2]=1002;v[a+28>>2]=1003;v[a+24>>2]=1004;v[a+20>>2]=1005;v[a+16>>2]=1006;v[a+12>>2]=1007;v[a+8>>2]=1008;v[a+4>>2]=1009;v[a>>2]=1010;break c}if(!(xi(b,15289)|(d|0)!=24)){v[a+20>>2]=1011;v[a+16>>2]=1012;v[a+12>>2]=1013;v[a+8>>2]=1014;v[a+4>>2]=1015;v[a>>2]=1016;break c}if(xi(b,15090)|(d|0)!=4){break b}v[a>>2]=1017}e=1}return e|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function EM(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=hb-32|0;hb=g;b=lt(g);d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);c=(f<<5)+a|0;e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;t[c+4|0]=d;t[c+5|0]=d>>>8;t[c+6|0]=d>>>16;t[c+7|0]=d>>>24;d=w[b+28|0]|w[b+29|0]<<8|(w[b+30|0]<<16|w[b+31|0]<<24);e=w[b+24|0]|w[b+25|0]<<8|(w[b+26|0]<<16|w[b+27|0]<<24);t[c+24|0]=e;t[c+25|0]=e>>>8;t[c+26|0]=e>>>16;t[c+27|0]=e>>>24;t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24);e=w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24);t[c+16|0]=e;t[c+17|0]=e>>>8;t[c+18|0]=e>>>16;t[c+19|0]=e>>>24;t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);b=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c+8|0]=b;t[c+9|0]=b>>>8;t[c+10|0]=b>>>16;t[c+11|0]=b>>>24;t[c+12|0]=d;t[c+13|0]=d>>>8;t[c+14|0]=d>>>16;t[c+15|0]=d>>>24;hb=g+32|0;f=f+1|0;continue}break}}function cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0;g=hb-16|0;hb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];u=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(r,s,e,e>>31);i=kb;f=Wb(f,-16777216,16776704);h=rka(p,q,f,f>>31);e=h+e|0;f=kb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=v[g+12>>2]+l|0;e=t[h|0];z=i;i=((B(t[h+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=rka(e,e>>31,u,w);e=z+h|0;f=kb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;k=k+n|0;v[c>>2]=B(e,k>>12)+v[c>>2];j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Pb(g+8|0,x,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=j>>12;hb=g+16|0}function RH(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0;a:{if(w[b+21|0]){p=B(d,g);j=v[e>>2];l=v[f>>2];m=v[b>>2];b:{while(1){if((h|0)>0){if(v[a+1396>>2]<=9){Uk(a)}g=v[a+1392>>2];k=u[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=w[k+v[b+8>>2]|0];v[a+1392>>2]=i>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;k=(g|0)>=0?k:-1;break c}k=$l(a,b)}if((k|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((k|0)<0){if(!w[a+1376|0]){b=0;if(v[a+1384>>2]){break b}}bc(a,21);return 0}g=0;n=B(d,l);m=((m+n|0)+j|0)>(p|0)?(p-n|0)+j|0:m;n=(m|0)>0?m:0;k=B(k,v[b>>2]);o=C(0);d:{if(w[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=C(o+z[v[b+28>>2]+(g+k<<2)>>2]);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=o+z[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+C(z[v[b+28>>2]+(g+k<<2)>>2]+C(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}break}v[e>>2]=j;v[f>>2]=l;b=1}return b}bc(a,21);return 0}aa(7512,13226,1887,6554);L()}function GN(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=rka(c,c>>31,5e4,0);e=kb;b=v[Vc(d+12|0,d+8|0)>>2];c=Dc(ska(c,e,b,b>>31),kb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=rka(c,c>>31,1e4,0);e=kb;b=v[Vc(d+12|0,d+8|0)>>2];c=Dc(ska(c,e,b,b>>31),kb);break a;case 1:break b}}f=60/(+y[b+44>>2]/1e4*(+(rka(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(kb>>>0)*4294967296))*+y[a+24620>>2];c:{d:{c=v[a+484344>>2];e=x[b+70>>1];if(!te(c,v[a+484348>>2],e)){break d}c=Xb(c,e);if(!Nb(v[c+24>>2],v[c+28>>2])){break d}c=c+24|0;break c}c=a+480248|0}e=v[c>>2];c=v[c+4>>2];if(!nc(e,c)){f=f*+y[Bb(e,y[b+48>>2]%(sc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(D(f)<2147483648){c=~~f;break e}c=-2147483648}f=A[b+8>>3]+(f-+(c>>>0));A[b+8>>3]=f;if(f>=1){A[b+8>>3]=f+-1;c=c+1|0;break a}if(!(A[a+1074384>>3]<=-1)){break a}A[b+8>>3]=f+1;c=c-1|0}b=rka(v[a+480244>>2],0,c,0)+32768|0;a=kb;a=b>>>0<32768?a+1|0:a;a=Bc((a&65535)<<16|b>>>16,a>>>16|0);hb=d+16|0;return a?a:1}function w9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=C(0);h=u[d>>1];j=u[d+2>>1];a:{if((h|0)>(j|0)){break a}k=v[b>>2];g=sc(k,v[b+4>>2]);if(!g){break a}i=u[e>>1];if((i|0)<(h|0)|(i|0)>(j|0)|(g-1&65535)>>>0>(j-i&65535)>>>0|y[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(g|0)){break b}i=Bb(k,f);f=f+1|0;if(!(z[i>>2]<C(0))){continue}break}return 0}i=(f|0)!=(g|0);f=0;if(i){break a}l=z[c>>2];if(l<=C(0)){break a}u[a+28>>1]=h;u[a>>1]=1;m=a,n=vL(g),u[m+30>>1]=n;z[a+32>>2]=D(l);ak(a+4|0,(j-h|0)+1|0);lh(Cb(v[b>>2]),Cb(v[b+4>>2]),qm(Cb(v[a+4>>2]),u[e>>1]-u[d>>1]|0));c=v[a+4>>2];g=u[a+30>>1];h=u[a+28>>1];b=u[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;j=Bb(c,b+g|0);m=Bb(c,b),o=C(z[j>>2]/z[a+32>>2]),z[m>>2]=o;b=u[e>>1];continue}else{c=u[a+30>>1];e=u[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=v[a+4>>2];d=u[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=Bb(b,f-h|0);m=Bb(b,f-e|0),o=C(z[a+32>>2]*z[g>>2]),z[m>>2]=o;f=f+1|0;continue}else{zp(a)}break}}break}f=1}return f|0}function M_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=hb-160|0;hb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=1175;b=pe(a+24|0,a+32|0,a+20|0);h=a+16|0;bd(h,e);v[23516]=0;h=T(19,h|0)|0;i=v[23516];v[23516]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[23516]=0;c=qa(1176,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}_f(g);if(w[a+15|0]){v[23516]=0;c=Q(20,h|0,45)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}v[23516]=0;R(45,g|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}}v[23516]=0;c=Q(20,h|0,48)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}d=v[a+20>>2];h=d-1|0;e=v[b>>2];c=c&255;while(1){if(!((c|0)!=w[e|0]|e>>>0>=h>>>0)){e=e+1|0;continue}break}v[23516]=0;W(1182,g|0,e|0,d|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break c}break a}v[23516]=0;c=Q(1143,a+152|0,a+144|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];Zb(a+16|0);Sc(b);hb=a+160|0;return c|0}}}c=P()|0;O()|0;Zb(a+16|0);Sc(b);S(c|0);L()}function bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;g=hb-16|0;hb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(r,s,e,e>>31);i=kb;f=Wb(f,-16777216,16776704);h=rka(p,q,f,f>>31);e=h+e|0;f=kb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(v[g+12>>2]<<1)+l|0;e=u[h>>1];z=i;i=e+((B(u[h+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=rka(e,e>>31,t,w);e=z+h|0;f=kb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;k=k+n|0;v[c>>2]=B(e,k>>12)+v[c>>2];j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Pb(g+8|0,x,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=j>>12;hb=g+16|0}function Qy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;f=a+1074312|0;Ab(e+8|0,f,77);a:{if(j=zb(v[v[e+8>>2]>>2],v[e+12>>2]),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{if(d){g=w[c+841|0];if(!g){break c}d=g-1|0;t[c+841|0]=d;if(d&255){break b}Ab(e+8|0,f,16);if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])&v[a+480180>>2]!=2){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[c+764>>2]=a;break a}Ab(e+8|0,f,17);d:{if(zb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480180>>2]&3){break d}g=b+616|0;i=x[a+480188>>1];while(1){if((h&65535)>>>0>=i>>>0){break d}if(w[g+841|0]?(c|0)!=(g|0):0){break a}g=g+872|0;h=h+1|0;continue}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;e:{if((d|0)==-1){break e}f:{if(v[b+60>>2]==-1){break f}Ab(e+8|0,f,68);if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}v[b+60>>2]=d}v[b+64>>2]=d;Ab(e+8|0,f,103);if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])){break e}u[b+68>>1]=65535}if(v[a+480180>>2]!=2){break a}d=x[a+480188>>1];a=0;while(1){if((a|0)==(d|0)){break a}f=B(a,872)+b|0;v[f+1380>>2]=v[c+764>>2];t[f+1457|0]=w[c+841|0];a=a+1|0;continue}}hb=e+16|0}function PQ(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-80|0;hb=c;v[c+72>>2]=0;v[c+76>>2]=0;b=c- -64|0;v[b>>2]=0;v[b+4>>2]=0;v[c+56>>2]=0;v[c+60>>2]=0;v[c+48>>2]=0;v[c+52>>2]=0;wz(a,xz(a),c+48|0);b=qc(c+40|0,14276);cf(ue(a,0),v[b>>2],v[b+4>>2]);b=qc(c+32|0,14380);cf(ue(a,1),v[b>>2],v[b+4>>2]);b=qc(c+24|0,5499);cf(ue(a,3),v[b>>2],v[b+4>>2]);b=qc(c+16|0,15803);cf(ue(a,4),v[b>>2],v[b+4>>2]);b=qc(c+8|0,9294);cf(ue(a,8),v[b>>2],v[b+4>>2]);e=ue(a+288|0,0);b=hb-16|0;hb=b;d=e;e=qc(b+8|0,4935);cf(d,v[e>>2],v[e+4>>2]);hb=b+16|0;e=a+800|0;b=0;a=hb-80|0;hb=a;a:{b:{while(1){if((b|0)==128){break a}v[a+76>>2]=b<<3;c:{d:{if(b>>>0<=15){vu(a+32|0,4087);v[23516]=0;R(290,a+16|0,a+76|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}v[23516]=0;U(291,a+48|0,a+32|0,a+16|0);d=v[23516];v[23516]=0;if((d|0)!=1){d=a+48|0;Be(a- -64|0,d);cf(ue(e,b),v[a+64>>2],v[a+68>>2]);wb(d);wb(a+16|0);Ub(a+32|0);break d}b=P()|0;O()|0;wb(a+16|0);break b}d=qc(a+8|0,21751);cf(ue(e,b),v[d>>2],v[a+12>>2])}b=b+1|0;continue}break}b=P()|0;O()|0}Ub(a+32|0);S(b|0);L()}hb=a+80|0;hb=c+80|0}function Vn(a,b,c,d){var e=0;e=hb-16|0;hb=e;t[a+841|0]=0;v[a+708>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;v[a+800>>2]=0;v[a+696>>2]=0;v[a+668>>2]=0;u[a+804>>1]=0;v[a+88>>2]=v[a+88>>2]|6144;Ab(e+8|0,b+1074312|0,23);if(zb(v[v[e+8>>2]>>2],v[e+12>>2])){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&224;Zn(a+788|0);v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;t[a+845|0]=0;t[a+838|0]=0;t[a+821|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+836>>1]=32512;t[a+819|0]=0;t[a+820|0]=0;u[a+842>>1]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|d;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0;hb=e+16|0}function MH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-208|0;hb=d;v[d+8>>2]=1;v[d+12>>2]=0;h=b<<2;a:{if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;g=4;e=2;while(1){f=b;b=(b+g|0)+4|0;v[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;g=f;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){e=1;b=1;f=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){Xw(a,c,b,d+16|0);bs(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=f-a>>>0){as(a,c,e,v[d+12>>2],b,0,d+16|0);break d}Xw(a,c,b,d+16|0)}if((b|0)==1){$r(d+8|0,1);b=0;break c}$r(d+8|0,g);b=1}e=v[d+8>>2]|1;v[d+8>>2]=e;a=a+4|0;if(f>>>0>a>>>0){continue}break}f=v[d+12>>2]}as(a,c,e,f,b,0,d+16|0);e=v[d+8>>2];g=v[d+12>>2];if(!(g?1:(b|0)!=1|(e|0)!=1)){break a}while(1){e:{if((b|0)<=1){f=FH(e,g);bs(d+8|0,f);b=b+f|0;break e}g=d+8|0;$r(g,2);v[d+8>>2]=v[d+8>>2]^7;bs(g,1);h=a-4|0;e=d+16|0;f=b-2|0;as(h-v[e+(f<<2)>>2]|0,c,v[d+8>>2],v[d+12>>2],b-1|0,1,e);$r(g,1);b=v[d+8>>2]|1;v[d+8>>2]=b;as(h,c,b,v[d+12>>2],f,1,e);b=f}a=a-4|0;g=v[d+12>>2];e=v[d+8>>2];if(g|((b|0)!=1|(e|0)!=1)){continue}break}}hb=d+208|0}function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=hb-16|0;hb=g;o=v[a+16>>2];l=Rf(1,2);b=kb;p=b;Pb(a,l,b);f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+32>>2];r=v[a+28>>2];s=v[a+72>>2];b=v[a+68>>2];t=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){b=e;if(d){m=u[(v[g+12>>2]<<1)+o>>1]<<8;e=m;e=rka(e,e>>31,z,A);k=kb;h=e;e=Wb(b,-16777216,16776704);n=rka(x,y,e,e>>31);h=h+n|0;e=kb+k|0;e=h>>>0<n>>>0?e+1|0:e;f=Wb(f,-16777216,16776704);k=rka(t,w,f,f>>31);h=k+h|0;f=kb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;j=j+r|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+q|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Pb(g+8|0,C,D);e=f-(s&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;lg(a,l,p);hb=g+16|0}function YN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=hb-32|0;hb=f;n=bz(v[a+24>>2],w[a+32|0]);o=qj(n);a:{while(1){b:{u[b>>1]=m;d=m&65535;if(d>>>0>=o>>>0){break b}c:{if(!zq(n,d)){break c}d=v[a>>2];h=ud(d,v[a+4>>2]);e=x[b>>1];if(h>>>0<=e>>>0){v[c>>2]=0;break a}k=Jd(d,e);ml(f+16|0,v[k>>2]);tm(f+8|0,v[k>>2],v[k+4>>2]);i=f+24|0;d=v[f+16>>2];g=v[f+20>>2];e=ll(v[f+8>>2],v[f+12>>2],d,g);j=hb-16|0;hb=j;v[j+12>>2]=e;d:{if(g){h=32-g|0;v[j+8>>2]=h;l=h;h=v[Hb(j+8|0,j+12|0)>>2];l=-1<<g&-1>>>l-h&v[d>>2];if(l){fc(i,d,qka(l));break d}if((e|0)==(h|0)){v[i>>2]=d;v[i+4>>2]=g;tP(i,e);break d}e=e-h|0;d=d+4|0}while(1){if(e>>>0>=32){g=v[d>>2];if(g){fc(i,d,qka(g));break d}else{e=e-32|0;v[j+12>>2]=e;d=d+4|0;continue}}break}if(!e){fc(i,d,0);break d}g=v[d>>2]&-1>>>32-e;if(!g){fc(i,d,e);break d}fc(i,d,qka(g))}hb=j+16|0;tm(f,v[k>>2],v[k+4>>2]);if(!(v[f+24>>2]==v[f>>2]&v[f+28>>2]==v[f+4>>2])){break c}v[c>>2]=0;break a}m=x[b>>1]+1|0;continue}break}u[b>>1]=65535;v[c>>2]=-1}hb=f+32|0;return(m&65535)>>>0<o>>>0|0}function u8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0;c=hb-32|0;hb=c;a:{d=v[a+20>>2];b:{if(!d){break b}v[d+148>>2]=-1;h=c,i=lb[v[v[a>>2]+40>>2]](a)|0,v[h+16>>2]=i;v[c+8>>2]=1073741822;f=v[Hb(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=v[a+20>>2];d=0;v[23516]=0;R(288,e+4|0,b+4|0);b=v[23516];v[23516]=0;c:{d:{if((b|0)!=1){b=v[a+20>>2];oe(c+8|0,v[b+4>>2],v[b+8>>2]);v[c>>2]=0;v[c+4>>2]=0;e=v[c+12>>2];b=c+16|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=e;e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;e=hb-16|0;hb=e;v[e+8>>2]=0;SK(b,e+8|0);hb=e+16|0;b=v[v[a>>2]+184>>2];v[23516]=0;R(b|0,a|0,-1);b=v[23516];v[23516]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=v[v[a>>2]+188>>2];v[23516]=0;Y(d|0,a|0);d=v[23516];v[23516]=0;if((d|0)!=1){break b}break d}b=v[v[a>>2]+48>>2];v[23516]=0;g=C(Za(b|0,a|0,d|0));b=v[23516];v[23516]=0;if((b|0)!=1){z[c+8>>2]=g;d=d+1|0;SK(c+16|0,c+8|0);continue}break}d=V(92664)|0;break c}d=V(92664)|0;break c}d=V(92664)|0}if((O()|0)!=(ea(92664)|0)){break a}_(d|0)|0;Gc(v[a+20>>2]+4|0);$()}hb=c+32|0;return}S(d|0);L()}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=hb-16|0;hb=g;o=v[a+16>>2];l=Rf(1,2);b=kb;p=b;Pb(a,l,b);f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+32>>2];r=v[a+28>>2];s=v[a+72>>2];b=v[a+68>>2];u=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){b=e;if(d){m=t[v[g+12>>2]+o|0]<<16;e=m;e=rka(e,e>>31,z,A);k=kb;h=e;e=Wb(b,-16777216,16776704);n=rka(x,y,e,e>>31);h=h+n|0;e=kb+k|0;e=h>>>0<n>>>0?e+1|0:e;f=Wb(f,-16777216,16776704);k=rka(u,w,f,f>>31);h=k+h|0;f=kb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;j=j+r|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+q|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Pb(g+8|0,C,D);e=f-(s&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;lg(a,l,p);hb=g+16|0}function ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-32|0;hb=h;e=b;b=v[a>>2];b=(ro(e,Cb(b))<<1)+b|0;a:{b:{f=v[a+4>>2];if(f>>>0<y[Db(a)>>2]){if((b|0)!=(f|0)){break b}d=hb-16|0;hb=d;a=$h(d,a,1);qo(v[a+4>>2],w[c|0]|w[c+1|0]<<8);v[a+4>>2]=v[a+4>>2]+2;ic(a);hb=d+16|0;break a}d=Db(a);d=Jj(h+8|0,Kj(a,Oc(v[a>>2],f)+1|0),b-v[a>>2]>>1,d);v[23516]=0;R(295,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)!=1){c=v[d+4>>2];f=d+4|0;aq(v[a>>2],b,f);g=v[a+4>>2];e=d+8|0;while(1){if((b|0)!=(g|0)){qo(v[e>>2],w[b|0]|w[b+1|0]<<8);v[e>>2]=v[e>>2]+2;b=b+2|0;continue}break}oc(a,f);oc(a+4|0,e);oc(Db(a),zc(d));v[d>>2]=v[d+4>>2];b=c;Li(d);break a}a=P()|0;O()|0;Li(d);S(a|0);L()}i=hb-16|0;hb=i;j=v[a+4>>2];e=(j-(b+2|0)|0)+b|0;k=$h(i,a,f-e>>1);g=v[k+4>>2];d=e;while(1){if(d>>>0>=f>>>0){ic(k);while(1){if((b|0)!=(e|0)){e=e-2|0;j=cV(j-2|0,e);continue}break}hb=i+16|0}else{qo(g,w[d|0]|w[d+1|0]<<8);g=g+2|0;v[k+4>>2]=g;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&y[a+4>>2]>c>>>0)<<1)+c|0;c=w[a|0];t[b+1|0]=w[a+1|0];t[b|0]=c}Cb(b);hb=h+32|0}function _ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;p=v[a+16>>2];q=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){k=v[a+8>>2];m=v[a+12>>2];f=v[a>>2];b=v[a+4>>2];h=0;break a}b=v[a+12>>2];m=b;k=v[a+8>>2];n=kg(k,b,l);o=kb;h=v[a+76>>2];f=v[a>>2];b=v[a+4>>2];Of(f,b,mf(k,m,d),kb);h=h>>>0<kb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[e>>2]=f;v[e+4>>2]=b;b:while(1){if(d){d=d-1|0;v[e+8>>2]=f;v[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=(b<<1)+p|0;b=l;while(1)if((b|0)<=0){Pb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Od(g,u[f+(v[e+12>>2]<<1)>>1]/4<<16>>16);Nd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;f=ig(g,q);v[c>>2]=B(j>>12,f)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(f,i>>12);Pb(e,k,m);c=c+8|0;f=v[e>>2];b=v[e+4>>2];continue b}else{Od(g,u[f+(v[e+12>>2]<<1)>>1]/4<<16>>16);Nd(g,4);Pb(e+8|0,n,o);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;hb=e+16|0}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){e=(v[f+12>>2]<<1)+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;k=k+n|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;hb=f+16|0}function fP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0;i=hb-16|0;hb=i;if(uj(v[a+656>>2])){e=w[a+797|0];g=Wc(e);f=w[a+799|0];Ab(i+8|0,d+1074312|0,34);d=g?e:f;a:{if(!zb(v[v[i+8>>2]>>2],v[i+12>>2])){break a}e=d&255;if(!e|e>>>0>120){break a}d=w[Ib(v[a+656>>2]+108|0,e-1|0)|0]}l=C(C(v[a+704>>2])*b);e=v[v[a+656>>2]+44>>2];f=((d&255)+c<<16)-3997696>>16;b:{c:{c=v[a+852>>2]+u[a+772>>1]|0;if(c){h=v[e+36>>2];if(h){break c}}b=hm(e,c+f<<16>>16);break b}k=h+1|0;j=Nx(c,k);d=Dn(c,k);b=C(1);g=u[e+28>>1];c=f+j<<16>>16;d:{if((g|0)>(c|0)){break d}f=v[e+4>>2];if((c|0)>(sc(f,v[e+8>>2])+g<<16)-65536>>16){break d}if(!d){b=z[Bb(f,c-g|0)>>2];break b}e:{f:{g:{switch(x[e>>1]-1|0){case 2:h=v[e+16>>2];if(!sc(h,v[e+20>>2])){break f}b=z[Bb(h,d-1|0)>>2];break e;case 0:break g;default:break f}}j=v[e+16>>2];if(!sc(j,v[e+20>>2])){break f}b=z[Bb(j,(d+B(h,Dn(c,x[e+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=qe(C(hm(e,(c<<16)+65536>>16)/hm(e,c)),C(C(d|0)/C(k|0)))}b=C(b*z[Bb(f,c-g|0)>>2])}}m=a,n=tj(C(C(l*b)*C(16))),v[m+700>>2]=n}hb=i+16|0}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;jd(c,0);u[d+14>>1]=w[a+36|0]|w[a+37|0]<<8;u[d+12>>1]=32767;g=c,h=(x[Rc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,u[g+28>>1]=h;u[d+10>>1]=w[a+38|0]|w[a+39|0]<<8;u[d+8>>1]=32767;g=c,h=(x[Rc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,u[g+30>>1]=h;u[c+32>>1]=64;v[c>>2]=w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24);v[c+4>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[c+8>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[c+24>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);e=w[b+166|0];if(e>>>0<=4){t[c+38|0]=w[e+42890|0]}e=w[b+167|0]|w[b+168|0]<<8;t[c+39|0]=e;f=(w[b+171|0]|w[b+172|0]<<8)>>>4|0;t[c+41|0]=f;b=(w[b+169|0]|w[b+170|0]<<8)>>>2|0;t[c+40|0]=b;if((b|f)&255){t[c+39|0]=e^-1}b=w[a+40|0]|w[a+41|0]<<8;if(b&4){u[c+34>>1]=x[c+34>>1]|1;b=w[a+40|0]|w[a+41|0]<<8}if(b&8){u[c+34>>1]=x[c+34>>1]|2;b=w[a+40|0]|w[a+41|0]<<8}if(b&16){u[c+34>>1]=x[c+34>>1]|4;b=w[a+40|0]|w[a+41|0]<<8}if(b&32){u[c+34>>1]=x[c+34>>1]|32}hb=d+16|0}function XI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=hb+-64|0;hb=c;f=v[a>>2];a=v[f>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Ef(c+48|0,c+32|0,g);a=v[f+4>>2];f=v[a+8>>2];g=v[a+4>>2];e=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=e;e=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=e;v[c+8>>2]=v[a+8>>2];e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;a:{b:{c:{d:{e=v[c+4>>2];if(g>>>0<=e>>>0){if(g>>>0>y[c+20>>2]){break d}if(f>>>0>y[c+8>>2]){break c}j=v[c+28>>2];if(f>>>0>v[c+24>>2]-j>>>0){break b}k=b+12|0;l=v[c+16>>2];m=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=h+j|0;o=B(e,h);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=Bb(v[b>>2],a);i=d;d=v[(a+o<<2)+m>>2]+(v[d>>2]>>1)|0;p=d;d=ks(k)+d&-4096;v[i>>2]=p-d;i=v[(a<<2)+l>>2]+(n<<1)|0;d=hd(d|2048,12);d=(d|0)<32767?d:32767;u[i>>1]=(d|0)>-32768?d:-32768;a=a+1|0;continue}}}aa(7192,9074,33,8787);L()}aa(7157,9074,34,8787);L()}aa(5900,9074,35,8787);L()}aa(5870,9074,36,8787);L()}hb=c- -64|0}function RI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=hb+-64|0;hb=c;f=v[a>>2];a=v[f>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Ef(c+48|0,c+32|0,g);a=v[f+4>>2];f=v[a+8>>2];g=v[a+4>>2];e=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=e;e=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=e;v[c+8>>2]=v[a+8>>2];e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;a:{b:{c:{d:{e=v[c+4>>2];if(g>>>0<=e>>>0){i=v[c+20>>2];if(g>>>0>i>>>0){break d}if(f>>>0>y[c+8>>2]){break c}j=v[c+28>>2];if(f>>>0>v[c+24>>2]-j>>>0){break b}k=b+12|0;l=v[c+16>>2];m=v[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=B(e,h);o=B(h+j|0,i);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=Bb(v[b>>2],a);p=d;d=v[(a+n<<2)+m>>2]+(v[d>>2]>>1)|0;q=d;d=ks(k)+d&-4096;v[p>>2]=q-d;d=hd(d|2048,12);d=(d|0)<32767?d:32767;u[(a+o<<1)+l>>1]=(d|0)>-32768?d:-32768;a=a+1|0;continue}}}aa(7192,9074,33,8787);L()}aa(7157,9074,34,8787);L()}aa(5900,9074,35,8787);L()}aa(5870,9074,36,8787);L()}hb=c- -64|0}function Cia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;d=Gh(b,c);n=e,o=Eb(w[a|0]|w[a+1|0]<<8),u[n+14>>1]=o;u[e+12>>1]=64;Mg(d,x[Rc(e+14|0,e+12|0)>>1]);n=d,o=Eb(w[a+14|0]|w[a+15|0]<<8),t[n+13|0]=o;n=d,o=Eb(w[a+16|0]|w[a+17|0]<<8),t[n+14|0]=o;n=d,o=Eb(w[a+20|0]|w[a+21|0]<<8),t[n+15|0]=o;n=d,o=Eb(w[a+22|0]|w[a+23|0]<<8),t[n+16|0]=o;h=v[d>>2];j=v[d+4>>2];b=w[d+12|0]&-2|nc(h,j)^1;t[d+12|0]=b;b=Eb(w[a+12|0]|w[a+13|0]<<8)>>>3&2|b&-3;t[d+12|0]=b;n=d,o=Eb(w[a+12|0]|w[a+13|0]<<8)>>>3&4|b&251,t[n+12|0]=o;b=4096;a:{b:{switch(c-1|0){case 0:i=-128;b=127;break a;case 1:break b;default:break a}}i=-1616;b=1616}b=b-i|0;l=b;c=b>>>1&32767;b=0;while(1){if(Qd(h,j)>>>0<=b>>>0){hb=e+16|0}else{d=Bb(h,b);u[d>>1]=k;m=d;g=(b<<2)+a|0;f=ne((w[g+28|0]|w[g+29|0]<<8)<<16>>16)+i|0;d=f>>31;d=d<<6|f>>>26;f=c+(f<<6)|0;d=f>>>0<c>>>0?d+1|0:d;n=m,o=rg(Dc(ska(f,d,l,0),kb)),t[n+2|0]=o;n=e,o=Eb(w[g+26|0]|w[g+27|0]<<8),u[n+10>>1]=o;u[e+8>>1]=1;b=b+1|0;k=x[ie(e+10|0,e+8|0)>>1]+k|0;continue}break}}function QH(a,b,c,d,e){var f=C(0),g=0,h=C(0),i=0,j=C(0),k=C(0);if(!(a&3)){b=(c<<2)+b|0;c=b+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){d=c-4|0;h=z[d>>2];j=z[b>>2];k=z[c>>2];z[b>>2]=j+k;g=b-4|0;f=z[g>>2];z[g>>2]=f+z[d>>2];j=C(j-k);f=C(f-h);z[c>>2]=C(j*z[e>>2])-C(z[e+4>>2]*f);z[d>>2]=C(f*z[e>>2])+C(j*z[e+4>>2]);d=c-12|0;j=z[d>>2];g=b-8|0;f=z[g>>2];i=g;g=c-8|0;k=z[g>>2];z[i>>2]=f+k;i=b-12|0;h=z[i>>2];z[i>>2]=h+z[d>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+32>>2])-C(z[e+36>>2]*h);z[d>>2]=C(h*z[e+32>>2])+C(f*z[e+36>>2]);d=c-20|0;j=z[d>>2];g=b-16|0;f=z[g>>2];i=g;g=c-16|0;k=z[g>>2];z[i>>2]=f+k;i=b-20|0;h=z[i>>2];z[i>>2]=h+z[d>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+64>>2])-C(z[e+68>>2]*h);z[d>>2]=C(h*z[e+64>>2])+C(f*z[e+68>>2]);d=c-28|0;j=z[d>>2];g=b-24|0;f=z[g>>2];i=g;g=c-24|0;k=z[g>>2];z[i>>2]=f+k;i=b-28|0;h=z[i>>2];z[i>>2]=h+z[d>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+96>>2])-C(z[e+100>>2]*h);z[d>>2]=C(h*z[e+96>>2])+C(f*z[e+100>>2]);a=a-1|0;c=c-32|0;b=b-32|0;e=e+128|0;continue}break}return}aa(15892,13226,2423,9240);L()}function Rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;h=hb-16|0;hb=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(r,s,e,e>>31);i=kb;z=e;e=(v[h+12>>2]<<1)+n|0;g=v[h+8>>2]>>>21&2040;j=(((B(u[e>>1],u[g+39890>>1])+B(u[e-2>>1],u[g+39888>>1])|0)+B(u[e+2>>1],u[g+39892>>1])|0)+B(u[e+4>>1],u[g+39894>>1])|0)/16384<<8;e=j;k=rka(e,e>>31,t,w);g=z+k|0;e=kb+i|0;e=g>>>0<k>>>0?e+1|0:e;f=Wb(f,-16777216,16776704);i=rka(p,q,f,f>>31);g=i+g|0;f=kb+e|0;f=g>>>0<i>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Pb(h+8|0,x,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;hb=h+16|0}function T7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=hb-160|0;hb=e;d=e+24|0;f=d+56|0;c=As(f);v[d>>2]=78212;v[c>>2]=78232;v[d+56>>2]=78272;v[d>>2]=78252;h=f;f=d+4|0;zn(h,f);v[d>>2]=78212;v[c>>2]=78232;c=us(f);v[c>>2]=77696;Kb(c+32|0);v[c+44>>2]=0;v[c+48>>2]=16;c=v[v[d>>2]-12>>2];v[23516]=0;f=ha(60)|0;h=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}v[23516]=0;U(61,e+16|0,c+d|0,f|0);c=v[23516];v[23516]=0;if((c|0)==1){break f}Zb(e+16|0);c=hb-16|0;hb=c;v[c+8>>2]=17;hb=c+16|0;dm(v[v[d>>2]-12>>2]+d|0,v[c+8>>2]);i=A[b>>3];v[23516]=0;b=_a(62,d|0,+i)|0;c=v[23516];v[23516]=0;if((c|0)==1){break e}v[23516]=0;R(63,e|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break d}v[23516]=0;R(59,g|0,e|0);c=v[23516];v[23516]=0;if((c|0)==1){break c}wb(e);up(b);hb=e+160|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;wb(e)}up(d);S(a|0);L()}v[23516]=0;R(56,a|0,g|0);a=v[23516];v[23516]=0;if((a|0)!=1){wb(g);hb=g+16|0;return}a=P()|0;O()|0;wb(g);S(a|0);L()}function Gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){e=v[f+12>>2]+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;k=k+n|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;hb=f+16|0}function wz(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a|0]=e;t[a+1|0]=e>>>8;t[a+2|0]=e>>>16;t[a+3|0]=e>>>24;t[a+4|0]=d;t[a+5|0]=d>>>8;t[a+6|0]=d>>>16;t[a+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[a+24|0]=e;t[a+25|0]=e>>>8;t[a+26|0]=e>>>16;t[a+27|0]=e>>>24;t[a+28|0]=d;t[a+29|0]=d>>>8;t[a+30|0]=d>>>16;t[a+31|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[a+16|0]=e;t[a+17|0]=e>>>8;t[a+18|0]=e>>>16;t[a+19|0]=e>>>24;t[a+20|0]=d;t[a+21|0]=d>>>8;t[a+22|0]=d>>>16;t[a+23|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+8|0]=e;t[a+9|0]=e>>>8;t[a+10|0]=e>>>16;t[a+11|0]=e>>>24;t[a+12|0]=d;t[a+13|0]=d>>>8;t[a+14|0]=d>>>16;t[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function Xj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=hb-32|0;hb=i;v[i+16>>2]=c;v[i+24>>2]=b;c=i+8|0;bd(c,d);b=0;v[23516]=0;j=T(19,c|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Zb(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(Yj(i+24|0,i+16|0)){break b}c:{if((kn(j,t[g|0])|0)==37){b=g+1|0;if((h|0)==(b|0)){break b}d:{e:{c=kn(j,t[b|0]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+2|0)==(h|0)){break b}k=c;c=kn(j,t[g+2|0])}l=i,m=lb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,c,k)|0,v[l+24>>2]=m;g=b+2|0;break c}b=v[j+8>>2];if(qh(b,8192,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(qh(b,8192,t[g|0])){continue}}break}while(1){if(!jp(i+24|0,i+16|0)){break c}b=Rk(v[i+24>>2]);if(!qh(v[j+8>>2],8192,b)){break c}Yl(i+24|0);continue}}if((rw(j,Rk(v[i+24>>2]))|0)==(rw(j,t[g|0])|0)){g=g+1|0;Yl(i+24|0);break c}v[e>>2]=4}b=v[e>>2];continue}break}v[e>>2]=4}if(Yj(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}hb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Zb(i+8|0);S(a|0);L()}function Cc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=v[b>>2];e=hb-48|0;hb=e;f=v[b+4>>2];b=w[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Kb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){t[e+32|0]=0;a=yi(c,c+d|0,e+32|0);v[23516]=0;W(51,f|0,c|0,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}if((b-3&255)>>>0>1){break h}v[23516]=0;b=W(51,f|0,c|0,c+d|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break g}c=ge(b);d=uh(b);g=ge(b);a=hb-32|0;hb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=g;while(1){if(mj(a+24|0,a+16|0)){c=a+8|0;d=a+24|0;g=t[v[d>>2]];t[v[c>>2]]=g?g:32;He(d);He(c);continue}break}hb=a+32|0;v[23516]=0;c=Q(52,e+16|0,b|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break f}v[23516]=0;d=Q(53,e|0,17922)|0;a=v[23516];v[23516]=0;if((a|0)==1){break e}v[23516]=0;U(54,e+32|0,c|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break d}a=e+32|0;yc(b,a);wb(a);wb(d);wb(c)}hb=e+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;wb(d)}wb(c)}wb(f);S(a|0);L()}}function G$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-32|0;hb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=lb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}bd(g,d);v[23516]=0;b=T(1153,g|0)|0;a=v[23516];v[23516]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);bd(g,d);v[23516]=0;a=T(1154,g|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break g}Zb(g);v[23516]=0;R(1155,g|0,a|0);d=v[23516];v[23516]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23516]=0;R(1156,g|12,a|0);a=v[23516];v[23516]=0;if((a|0)==1){break f}v[23516]=0;d=g+24|0;a=ua(1157,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23516];v[23516]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Yc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Zb(g);break d}b=P()|0;O()|0;Zb(g);break d}b=P()|0;O()|0;Yc(g);break d}b=P()|0;O()|0;while(1){d=Yc(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}hb=g+32|0;return b|0}
function R$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-32|0;hb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=lb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}bd(g,d);v[23516]=0;b=T(19,g|0)|0;a=v[23516];v[23516]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);bd(g,d);v[23516]=0;a=T(1136,g|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break g}Zb(g);v[23516]=0;R(1137,g|0,a|0);d=v[23516];v[23516]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23516]=0;R(1138,g|12,a|0);a=v[23516];v[23516]=0;if((a|0)==1){break f}v[23516]=0;d=g+24|0;a=ua(1139,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23516];v[23516]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=wb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Zb(g);break d}b=P()|0;O()|0;Zb(g);break d}b=P()|0;O()|0;wb(g);break d}b=P()|0;O()|0;while(1){d=wb(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}hb=g+32|0;return b|0}function ni(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;o(+a);b=j(1)|0;e=j(0)|0;f=b>>>20&2047;a:{if(f-969>>>0>=63){if(f>>>0<=968){return a+1}b:{if(f>>>0<1033){break b}c=0;if(!e&(b|0)==-1048576){break a}if((f|0)==2047){return a+1}if((b|0)>0|(b|0)>=0){return xr(3.105036184601418e231)}if(b>>>0<3230714880){break b}return xr(1.2882297539194267e-231)}b=b<<1|e>>>31;e=e<<1;f=(b|0)==-2129002496&(e|0)!=0|b>>>0>2165964800?0:f}c=A[177];g=c+a;a=a-(g-c);c=a*a;h=c*c*(a*A[182]+A[181]);c=c*(a*A[180]+A[179]);a=a*A[178];o(+g);j(1)|0;e=j(0)|0;d=e<<4&2032;a=h+(c+(a+A[d+1464>>3]));d=d+1472|0;i=v[d>>2];b=v[d+4>>2];d=i;i=0;d=d+i|0;b=(e<<13)+b|0;b=d>>>0<i>>>0?b+1|0:b;if(!f){c:{if(!(e&-2147483648)){l(0,d|0);l(1,b+-1048576|0);c=+n();a=c*a+c;a=a+a;break c}e=hb-16|0;l(0,d|0);l(1,b+1071644672|0);c=+n();g=c*a;a=g+c;if(a<1){b=e;v[b+8>>2]=0;v[b+12>>2]=1048576;A[b+8>>3]=A[b+8>>3]*2.2250738585072014e-308;h=a+1;a=h+(g+(c-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,b|0);c=+n();c=c*a+c}return c}function lka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-144|0;hb=f;v[23516]=0;l=T(274,a|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){m=c+480192|0;while(1){a:{if((j&65535)>>>0>=l>>>0){yb(a);hb=f+144|0;return}v[23516]=0;R(293,a|0,f+8|0);e=v[23516];v[23516]=0;if((e|0)!=1){b:{e=Eb(x[f+8>>1]);if(!e|e>>>0>x[m>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Gh(e,b);g=w[f+11|0];c:{if(!g){break c}h=w[f+10|0];if(h&1){t[e+12|0]=w[e+12|0]|1}if(h&2){t[e+12|0]=w[e+12|0]|4}if(!(h&4)){break c}t[e+12|0]=w[e+12|0]|2}t[f+4|0]=g;t[f+7|0]=31;h=w[Vb(f+4|0,f+7|0)|0];v[23516]=0;h=h+1&255;R(294,e|0,h|0);g=v[23516];v[23516]=0;if((g|0)==1){break a}t[e+13|0]=w[f+13|0];t[e+14|0]=w[f+14|0];g=w[f+12|0];t[e+15|0]=g;t[e+16|0]=g;g=v[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;n=Eb(x[i+8>>1]);k=Bb(g,e);u[k>>1]=n;i=Eb(x[i+10>>1]);u[f+4>>1]=d?i+128>>>2|0:i;Bf(f+4|0,64);t[k+2|0]=w[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=P()|0;O()|0;yb(a);S(b|0);L()}function Sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=hb-16|0;hb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;w=v[a+8>>2];x=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(p,q,e,e>>31);h=kb;f=Wb(f,-16777216,16776704);i=rka(n,o,f,f>>31);e=i+e|0;f=kb+h|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=v[g+12>>2]+l|0;h=v[g+8>>2]>>>21&2040;h=(((B(t[e|0],u[h+39890>>1])+B(t[e-1|0],u[h+39888>>1])|0)+B(t[e+1|0],u[h+39892>>1])|0)+B(t[e+2|0],u[h+39894>>1])<<8)/16384<<8;e=h;i=rka(e,e>>31,r,s);e=y+i|0;f=kb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Pb(g+8|0,w,x);e=f-(h&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;hb=g+16|0}function Ky(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;h=B(c,872)+b|0;a:{if(d){Ab(g+8|0,a+1074312|0,90);if(!zb(v[v[g+8>>2]>>2],v[g+12>>2])){t[(B(c,872)+b|0)+1427|0]=d}t[(B(c,872)+b|0)+1428|0]=d;break a}d=w[h+1428|0]}f=v[a+480180>>2];if(!e){i=Ts(f)}h=h+616|0;b:{c:{if((f|0)!=268435456){if((f|0)!=16777216){break c}f=v[(B(c,872)+b|0)+1272>>2];if(!f|!v[f+44>>2]){break c}a=d&255;if(!(a>>>0<240|e)){cN(b,c,240-a|0);break b}if(!(a>>>0<224|e)){bN(h,224-a|0);break b}aN(h,0-a|0);break b}v[(B(c,872)+b|0)+1324>>2]=65535}e=d&255;d:{if(!(e>>>0>223&i)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}Hy(a,h,f);break b}if(v[a+480180>>2]==524288){break d}Gy(a,h,f);break b}if(v[a+480180>>2]!=524288){break b}}f:{if(!(t[(B(c,872)+b|0)+1467|0]&1)){break f}if(v[a+1074416>>2]==1){Ab(g+8|0,a+1074312|0,6);if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){break f}}d=v[a+480180>>2];if(d&32832){break f}if(!(v[a+480208>>2]&2)|(d|0)!=8){break b}}dk(a,h,(B(c,872)+b|0)+1316|0,0-(e<<2)|0,0)}hb=g+16|0}function PA(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;t[d+15|0]=c;e=a;a:{b:{c:{switch(b-14|0){case 0:b=14;if(!c){break b}d:{if((c|0)!=15){if((c|0)!=240){break d}t[d+15|0]=239;break b}t[d+15|0]=254;break b}if(c>>>0>=16){t[d+15|0]=c|15;break b}t[d+15|0]=c|240;break b;case 1:t[d+15|0]=c^128;b=15;break b;case 6:case 7:if(c>>>0>=16){t[d+15|0]=c>>>4|240;break b}t[d+15|0]=c|224;break b;case 8:t[d+15|0]=((c^-1)&254)>>>1;b=22;break b;case 9:t[d+15|0]=c&15|128;b=23;break b;case 17:f=d,g=rg(c<<1),t[f+15|0]=g;b=31;break b;case 19:a=32;b=33;e:{f:{switch(c>>>4|0){default:b=0;break b;case 8:a=64;break e;case 10:a=176;break e;case 11:a=224;break e;case 12:case 13:b=c?33:0;break b;case 14:g:{switch(c&15){case 0:t[d+15|0]=119;break b;case 1:t[d+15|0]=119;break b;case 2:t[d+15|0]=121;break b;case 3:break g;default:break b}}t[d+15|0]=123;break b;case 3:break e;case 5:break f;case 0:break b}}a=48}t[d+15|0]=c&15|a;break b;default:break c}}a=0;if(b>>>0>35){break a}}a=w[b+26784|0]}ae(e,a,d+15|0);hb=d+16|0}function Cw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;p=a;i=hb-1040|0;hb=i;q=v[115992];a:{b:{a=i+16|0;l=x[((b>>>0>149?0:b)<<1)+91600>>1]+89776|0;c=v[v[116018]+20>>2];if(c){j=v[c+4>>2];c=v[c>>2];e=v[c>>2]+1794895138|0;h=Vl(v[c+8>>2],e);f=Vl(v[c+12>>2],e);d=Vl(v[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}r=d>>>2|0;s=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+s<<2)|0;o=Vl(v[d>>2],e);d=Vl(v[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|w[c+(d+o|0)|0]){break c}d=xi(l,c+d|0);if(!d){f=c+(r+n<<2)|0;h=Vl(v[f>>2],e);e=Vl(v[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=w[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=Og(g);d:{if(c>>>0>=1024){pc(a,g,1023);t[a+1023|0]=0;g=68;break d}pc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=21751}break a}wa();L()}if(!w[a|0]){v[i>>2]=b;a=i+16|0;xw(a,1024,13043,i)}v[115992]=q;Fc(p,a);hb=i+1040|0}function JJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{b:{c:{d:{e:{f:{g:{d=a+36|0;h:{if(Nb(v[d>>2],v[a+40>>2])){yf(c+24|0);break h}e=c+8|0;yn(e,a);v[23516]=0;e=T(1026,e|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break g}v[c+24>>2]=e;Vf(c+8|0)}e=(h=d,i=v[c+24>>2],j=Nb(v[a+36>>2],v[a+40>>2]),j?h:i);if((b|0)==-1){f=v[e>>2];g=4194304;d=0;break e}if((b|0)>=0){d=b;f=v[e>>2];if((Ni(f,v[e+4>>2])|0)>(b|0)){break e}}b=ba(8)|0;v[23516]=0;d=Q(53,c+8|0,10935)|0;a=v[23516];v[23516]=0;if((a|0)==1){break f}a=rc(b,d);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}a=P()|0;O()|0;wb(d);break d}a=P()|0;O()|0;Vf(c+8|0);break c}a=P()|0;O()|0;ca(b|0);break d}v[a+8>>2]=b;b=v[a+24>>2];v[b+480208>>2]=v[b+480208>>2]&-4194305|g;Dj(b+484360|0,w[ff(f,d)+16|0]);b=ff(v[e>>2],d);d=v[b+8>>2];b=v[b+12>>2];v[23516]=0;+ya(1057,a|0,b|0,d|0);b=v[23516];v[23516]=0;if((b|0)!=1){break a}a=P()|0;O()|0}Vk(c+24|0)}S(a|0)}L()}v[a+16>>2]=0;v[a+20>>2]=0;Vk(c+24|0);hb=c+32|0}function $ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;p=v[a+16>>2];q=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){k=v[a+8>>2];m=v[a+12>>2];f=v[a>>2];b=v[a+4>>2];h=0;break a}b=v[a+12>>2];m=b;k=v[a+8>>2];n=kg(k,b,l);o=kb;h=v[a+76>>2];f=v[a>>2];b=v[a+4>>2];Of(f,b,mf(k,m,d),kb);h=h>>>0<kb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[e>>2]=f;v[e+4>>2]=b;b:while(1){if(d){d=d-1|0;v[e+8>>2]=f;v[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=b+p|0;b=l;while(1)if((b|0)<=0){Pb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Od(g,t[f+v[e+12>>2]|0]<<6);Nd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;f=ig(g,q);v[c>>2]=B(j>>12,f)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(f,i>>12);Pb(e,k,m);c=c+8|0;f=v[e>>2];b=v[e+4>>2];continue b}else{Od(g,t[f+v[e+12>>2]|0]<<6);Nd(g,4);Pb(e+8|0,n,o);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;hb=e+16|0}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;e=hb-16|0;hb=e;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){f=v[e+8>>2];o=((((v[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=u[b+14>>1];q=u[b+12>>1];r=u[b+10>>1];s=u[b+8>>1];t=u[b+6>>1];w=u[b+4>>1];x=u[b+2>>1];y=u[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+o|0;v[(f<<2)+e>>2]=(((((B(u[b+8>>1],r)+B(u[b+4>>1],s)|0)+B(u[b+12>>1],q)|0)+B(u[b+16>>1],p)|0)/2|0)+((((B(u[b-8>>1],x)+B(u[b-12>>1],y)|0)+B(u[b-4>>1],w)|0)+B(u[b>>1],t)|0)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;v[c>>2]=v[c>>2]+B(v[e>>2],h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g>>12);Pb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;hb=e+16|0}function Wj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=hb-32|0;hb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;bd(b,d);c=0;v[23516]=0;j=T(1153,b|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){Zb(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(Ok(i+24|0,i+16|0)){break b}c:{if((jn(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}d:{e:{b=jn(j,v[c>>2]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=jn(j,v[g+8>>2])}l=i,m=lb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if(Pk(j,8192,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(Pk(j,8192,v[g>>2])){continue}}break}while(1){if(!Tr(i+24|0,i+16|0)){break c}if(!Pk(j,8192,Qk(v[i+24>>2]))){break c}rn(i+24|0);continue}}if((zl(j,Qk(v[i+24>>2]))|0)==(zl(j,v[g>>2])|0)){g=g+4|0;rn(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(Ok(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}hb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Zb(i+8|0);S(a|0);L()}function Mw(a,b,c,d){var e=0,f=0,g=0,h=0;g=hb-32|0;hb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(a|(b|0)!=134217728){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Hf(g+16|0,a,b,c,e,h-15233|0);vm(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(b|(a|0)!=134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}hb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function Ly(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;h=B(c,872)+b|0;a:{if(d){Ab(g+8|0,a+1074312|0,90);if(!zb(v[v[g+8>>2]>>2],v[g+12>>2])){t[(B(c,872)+b|0)+1428|0]=d}t[(B(c,872)+b|0)+1427|0]=d;break a}d=w[h+1427|0]}f=v[a+480180>>2];if(!e){i=Ts(f)}h=h+616|0;b:{c:{if((f|0)!=268435456){if((f|0)!=16777216){break c}f=v[(B(c,872)+b|0)+1272>>2];if(!f|!v[f+44>>2]){break c}a=d&255;if(!(a>>>0<240|e)){cN(b,c,a-240|0);break b}if(!(a>>>0<224|e)){bN(h,a-224|0);break b}aN(h,a);break b}v[(B(c,872)+b|0)+1324>>2]=1}e=d&255;d:{if(!(e>>>0>223&i)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}Iy(a,h,f);break b}if(v[a+480180>>2]==524288){break d}Jy(a,h,f);break b}if(v[a+480180>>2]!=524288){break b}}f:{if(!(t[(B(c,872)+b|0)+1467|0]&1)){break f}if(v[a+1074416>>2]==1){Ab(g+8|0,a+1074312|0,6);if(zb(v[v[g+8>>2]>>2],v[g+12>>2])){break f}}d=v[a+480180>>2];if(d&32832){break f}if(!(v[a+480208>>2]&2)|(d|0)!=8){break b}}dk(a,h,(B(c,872)+b|0)+1316|0,e<<2,0)}hb=g+16|0}function qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;jd(b,32);g=b,h=_b(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24)),v[g>>2]=h;f=_b(w[a+10|0]|w[a+11|0]<<8|(w[a+12|0]<<16|w[a+13|0]<<24));v[b+4>>2]=f;g=b,h=_b(w[a+14|0]|w[a+15|0]<<8|(w[a+16|0]<<16|w[a+17|0]<<24))+f|0,v[g+8>>2]=h;if(!(d?0:c)){c=_b(w[a+46|0]|w[a+47|0]<<8|(w[a+48|0]<<16|w[a+49|0]<<24))}v[b+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Eb(w[a+42|0]|w[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}sl(b,+(c|0)*.0006510416666666666);t[e+15|0]=w[a+9|0];t[e+14|0]=64;g=b,h=w[Vb(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}hb=e+16|0}function Cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-32|0;hb=h;e=b;b=v[a>>2];b=jo(e,Cb(b))+b|0;e=qU(c,d);a:{if((e|0)<=0){break a}f=v[Db(a)>>2];g=v[a+4>>2];if((f-g|0)>=(e|0)){v[h+8>>2]=d;j=g-b|0;if((j|0)<(e|0)){v[h+8>>2]=c;fB(h+8|0,j);f=v[h+8>>2];l=hb-16|0;hb=l;i=Gk(l,a,e-j|0);k=hb-16|0;hb=k;v[k+8>>2]=f;while(1){if(Nb(f,d)){nd(v[i+4>>2],w[f|0]);f=He(k+8|0);v[i+4>>2]=v[i+4>>2]+1;f=v[f>>2];continue}break}hb=k+16|0;ic(i);hb=l+16|0;if((j|0)<=0){break a}}f=hb-16|0;hb=f;j=v[a+4>>2];d=(j-(b+e|0)|0)+b|0;i=Gk(f,a,g-d|0);e=v[i+4>>2];a=d;while(1){if(a>>>0>=g>>>0){ic(i);tq(b,d,j);hb=f+16|0}else{nd(e,w[a|0]);e=e+1|0;v[i+4>>2]=e;a=a+1|0;continue}break}lh(c,v[h+8>>2],b);break a}f=Db(a);g=Ql(h+8|0,Ol(a,ad(v[a>>2],g)+e|0),b-v[a>>2]|0,f);e=hb-32|0;hb=e;v[e+24>>2]=c;c=Mv(e+8|0,g+8|0,qU(c,d));d=v[c>>2];while(1){if(v[c+4>>2]!=(d|0)){nd(d,w[v[e+24>>2]]);d=v[c>>2]+1|0;v[c>>2]=d;He(e+24|0);continue}break}Kd(c);hb=e+32|0;b=pU(a,g,b);Pl(g)}Cb(b);hb=h+32|0}function mp(a,b,c,d,e,f){var g=C(0),h=0,i=C(0),j=0,k=C(0),l=C(0);b=(c<<2)+b|0;c=b+(d<<2)|0;a=a>>2;d=f<<2;while(1){if((a|0)>0){f=c-4|0;i=z[f>>2];k=z[b>>2];l=z[c>>2];z[b>>2]=k+l;h=b-4|0;g=z[h>>2];z[h>>2]=g+z[f>>2];k=C(k-l);g=C(g-i);z[c>>2]=C(k*z[e>>2])-C(z[e+4>>2]*g);z[f>>2]=C(g*z[e>>2])+C(k*z[e+4>>2]);f=c-12|0;k=z[f>>2];h=b-8|0;g=z[h>>2];j=h;h=c-8|0;l=z[h>>2];z[j>>2]=g+l;j=b-12|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=c-20|0;k=z[f>>2];h=b-16|0;g=z[h>>2];j=h;h=c-16|0;l=z[h>>2];z[j>>2]=g+l;j=b-20|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=c-28|0;k=z[f>>2];h=b-24|0;g=z[h>>2];j=h;h=c-24|0;l=z[h>>2];z[j>>2]=g+l;j=b-28|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);e=d+e|0;a=a-1|0;c=c-32|0;b=b-32|0;continue}break}}function U2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb+-64|0;hb=c;f=v[a>>2];a=v[f>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Ef(c+48|0,c+32|0,g);a=v[f+4>>2];f=v[a+8>>2];g=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a:{b:{c:{d:{d=v[c+4>>2];if(g>>>0<=d>>>0){if(g>>>0>y[c+20>>2]){break d}if(f>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(f>>>0>v[c+24>>2]-h>>>0){break b}i=b+12|0;j=v[c+16>>2];k=v[c>>2];b=0;e:while(1){if((b|0)==(f|0)){break a}l=b+h|0;m=B(b,d);a=0;while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{e=v[(a+m<<2)+k>>2];n=js(i);o=v[(a<<2)+j>>2]+(l<<1)|0;e=hd((hd(n,21)+e|0)+2048|0,12);e=(e|0)<32767?e:32767;u[o>>1]=(e|0)>-32768?e:-32768;a=a+1|0;continue}}}aa(7192,9074,33,8787);L()}aa(7157,9074,34,8787);L()}aa(5900,9074,35,8787);L()}aa(5870,9074,36,8787);L()}hb=c- -64|0}function Kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-2608|0;hb=f;d=nB(f,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[23516]=0;Y(323,d|0);a=v[23516];v[23516]=0;a:{b:{if((a|0)!=1){if((u[d+1068>>1]|u[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}v[23516]=0;j=Q(162,d|0,1)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=0;d:{while(1){v[23516]=0;k=Q(162,d|0,1)|0;e=v[23516];v[23516]=0;if((e|0)==1){break d}a=u[(d+B(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+B(a,6)|0;h=w[e+1072|0];if(u[e+1068>>1]<0){break e}if(u[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;t[b+g|0]=i;g=g+1|0;continue}break}a=V(30656)|0;break b}a=V(30656)|0;break b}a=V(30656)|0}if((O()|0)==(ea(30656)|0)){_(a|0)|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0}yb(d);S(a|0);L()}a=wq(d);yb(d);hb=f+2608|0;return a|0}function vX(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb+-64|0;hb=b;e=Kb(a);v[23516]=0;a=ha(124)|0;c=v[23516];v[23516]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}v[23516]=0;c=Q(1,b+32|0,8992)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}v[23516]=0;a=ha(124)|0;d=v[23516];v[23516]=0;e:{f:{g:{h:{if((d|0)==1){break h}v[23516]=0;v[b+12>>2]=a;R(130,b+16|0,b+12|0);a=v[23516];v[23516]=0;if((a|0)==1){break h}v[23516]=0;U(2,b+48|0,c|0,b+16|0);a=v[23516];v[23516]=0;if((a|0)==1){break g}d=b+48|0;a=Gb(e,d);xb(d);xb(b+16|0);xb(c);v[23516]=0;c=ha(126)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}if(!c){break e}v[23516]=0;Q(131,a|0,17596)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break e}break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;xb(b+16|0)}xb(c);break a}v[23516]=0;c=ha(125)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}if(!c){break d}v[23516]=0;Q(131,a|0,16898)|0;a=v[23516];v[23516]=0;if((a|0)==1){break b}}hb=b- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(e);S(a|0);L()}function L1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=hb-32|0;hb=h;f=kf(h+16|0,1,0);a:{b:{while(1){j=h+8|0;d=wc(f);m=d;n=Fb(f)+d|0;i=x[b>>1];d=0;c:{if((c|0)==10){tx(j,m,n,i);break c}e=i;k=B(c,c);l=B(k,c);o=B(k,k);d:{while(1){e=e&65535;g=d|1;if(e>>>0<c>>>0){break d}g=d|2;if(e>>>0<k>>>0){break d}g=d|3;if(e>>>0<l>>>0){break d}if(e>>>0<o>>>0){g=d+4|0}else{d=d+4|0;e=(e>>>0)/(o>>>0)|0;continue}break}}d=g;if((d|0)>(n-m|0)){v[j+4>>2]=61;v[j>>2]=n;break c}l=d+m|0;e=l;while(1){d=i&65535;i=(d|0)/(c|0)|0;e=e-1|0;t[e|0]=w[(d-B(c,i)|0)+4898|0];if(i&65535){continue}break}v[j+4>>2]=0;v[j>>2]=l}if(!v[h+12>>2]){break b}d=Yg(Fb(f));v[23516]=0;R(57,f|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){continue}break}break a}c=v[h+8>>2];b=wc(f);v[23516]=0;R(58,f|0,c-b|0);b=v[23516];v[23516]=0;e:{if((b|0)!=1){v[23516]=0;R(70,a|0,f|0);a=v[23516];v[23516]=0;if((a|0)!=1){break e}break a}break a}wb(f);hb=h+32|0;return}a=P()|0;O()|0;wb(f);S(a|0);L()}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;e=hb-16|0;hb=e;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){f=v[e+8>>2];o=(((v[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=u[b+14>>1];q=u[b+12>>1];r=u[b+10>>1];s=u[b+8>>1];w=u[b+6>>1];x=u[b+4>>1];y=u[b+2>>1];z=u[b>>1];f=0;while(1){if((f|0)!=2){b=f+o|0;v[(f<<2)+e>>2]=(((((B(t[b+4|0],r)+B(t[b+2|0],s)|0)+B(t[b+6|0],q)|0)+B(t[b+8|0],p)<<8)/2|0)+((((B(t[b-4|0],y)+B(t[b-6|0],z)|0)+B(t[b-2|0],x)|0)+B(t[b|0],w)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;v[c>>2]=v[c>>2]+B(v[e>>2],h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g>>12);Pb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;hb=e+16|0}function J2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=hb+-64|0;hb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Ef(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a:{b:{c:{d:{d=v[c+4>>2];if(f>>>0<=d>>>0){h=v[c+20>>2];if(f>>>0>h>>>0){break d}if(e>>>0>y[c+8>>2]){break c}i=v[c+28>>2];if(e>>>0>v[c+24>>2]-i>>>0){break b}j=b+12|0;k=v[c+16>>2];l=v[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}m=B(b,d);n=B(b+i|0,h);a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=hd((v[(a+m<<2)+l>>2]+hd(js(j),21)|0)+2048|0,12);g=(g|0)<32767?g:32767;u[(a+n<<1)+k>>1]=(g|0)>-32768?g:-32768;a=a+1|0;continue}}}aa(7192,9074,33,8787);L()}aa(7157,9074,34,8787);L()}aa(5900,9074,35,8787);L()}aa(5870,9074,36,8787);L()}hb=c- -64|0}function qZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=hb-16|0;hb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=v[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=v[a+8>>2];if((g-f|0)<=0){break a}v[a+8>>2]=f+1;t[f|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}c=v[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if((f|0)<4){break b}v[a+8>>2]=c+1;t[c|0]=b>>>18|240;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>12&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;continue}break}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];hb=a+16|0;return c|0}function y7(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;v[23516]=0;g=Q(13,d+24|0,a|0)|0;c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=d+16|0;bd(c,v[v[a>>2]-12>>2]+a|0);v[23516]=0;c=T(66,c|0)|0;e=v[23516];v[23516]=0;e:{f:{if((e|0)!=1){Zb(d+16|0);e=Jm(d+8|0,a);f=v[v[a>>2]-12>>2];v[23516]=0;f=a+f|0;h=T(14,f|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break f}e=v[e>>2];v[23516]=0;c=Sa(67,c|0,e|0,f|0,h|0,+b)|0;e=v[23516];v[23516]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!Qu(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[23516]=0;R(16,a+c|0,5);c=v[23516];v[23516]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;Zb(d+16|0);break e}c=V(0)|0;O()|0}tk(g);break c}tk(g);break b}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[23516]=0;Y(17,a+c|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}$()}hb=d+32|0;return a|0}a=P()|0;O()|0;v[23516]=0;Z(18);d=v[23516];v[23516]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}
function Hx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);d=hb-48|0;hb=d;a:{b=v[a+20>>2];b:{if(!b){break b}e=v[b+4>>2];b=v[b+8>>2];if(ad(e,b)>>>0<4){break b}oe(d+16|0,e,b);b=ce(d+8|0);e=sU(d+24|0,v[d+16>>2],v[d+20>>2],v[b>>2],v[b+4>>2]);v[23516]=0;b=T(155,e|0)|0;f=v[23516];v[23516]=0;c:{if((f|0)!=1){if(b){break c}b=v[v[a>>2]+40>>2];v[23516]=0;f=T(b|0,a|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break a}b=v[a+20>>2];if(ad(v[b+4>>2],v[b+8>>2])-4>>>0<f<<2>>>0){break c}c=v[v[a>>2]+176>>2];b=0;v[23516]=0;R(c|0,a|0,-1);c=v[23516];v[23516]=0;if((c|0)==1){break a}while(1){if((b|0)==(f|0)){b=v[v[a>>2]+180>>2];v[23516]=0;Y(b|0,a|0);a=v[23516];v[23516]=0;if((a|0)!=1){break c}break a}v[23516]=0;g=C(Ca(470,e|0));c=v[23516];v[23516]=0;d:{if((c|0)==1){break d}c=v[v[a>>2]+44>>2];v[23516]=0;Ba(c|0,a|0,b|0,C(fm(g)?g:C(0)));c=v[23516];v[23516]=0;if((c|0)==1){break d}b=b+1|0;continue}break}break a}break a}yb(e)}hb=d+48|0;return}a=P()|0;O()|0;yb(e);S(a|0);L()}function dJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;v[a+4>>2]=b;v[a>>2]=94104;e=(b>>>0)/48|0;d=((0-b|0)!=(B(e,-48)|0))+e|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){g=-1<<c}else{g=(1<<c)-1&-1>>>32-c|-1<<c}c=0;v[a+24>>2]=c;f=f?g&65536:0;v[a+28>>2]=f;g=0-c|0;h=uka(c,f,d,0);c=65536-(f+((c|0)!=0)|0)|0;f=kb;if((c|0)==(f|0)&g>>>0>h>>>0|c>>>0>f>>>0){d=d+1|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}v[a+24>>2]=0;v[a+28>>2]=f?c&65536:0}v[a+16>>2]=d-((b>>>0)%(d>>>0)|0);b=e>>>0<63;d=63-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+48>>2]=b?c:-1;v[a+52>>2]=b?d:-1;d=64-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+40>>2]=e?c:0;v[a+44>>2]=e?d:0;c=e+1|0;e=c&31;if((c&63)>>>0>=32){d=-1<<e}else{d=(1<<e)-1&-1>>>32-e|-1<<e}v[a+32>>2]=0;v[a+36>>2]=b?d&65536:0;return a}function Nf(a,b,c){t[a+5|0]=c;a:{b:{switch(b|0){case 0:if(!c){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;t[a+5|0]=B(c>>>4|0,10)+(c&15);return;case 14:t[a+3|0]=19;return;case 15:if(c>>>0<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 37:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function xga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-48|0;hb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;c=f+44|0;eo(b,c);a:{if(!pP(c)){break a}d=w[f+46|0];g=w[f+47|0];e=w[f+45|0];t[a+4|0]=1;h=e>>>3&3;c=(h|0)!=3;e=(e>>>1^-1)&3;g=g>>>0<192;u[a+2>>1]=x[(B(c,6)+(e<<1)|0)+27544>>1]<<g;i=B(B(w[(e+B(c,3)|0)+27320|0],x[((B(c,90)+B(e,30)|0)+(d>>>3&30)|0)+27328>>1]),1e3);d=d>>>1|0;d=B(((i>>>0)/x[(B(h,6)+(d&6)|0)+27520>>1]|0)+(d&1)|0,e?1:4);u[a>>1]=d;e=w[(g|c<<1)+27556|0];if(e+8>>>0>(d&65535)>>>0){break a}c=hb-32|0;hb=c;v[c+28>>2]=e+4;v[c+8>>2]=36;g=v[b>>2];h=v[b+8>>2];d=v[Hb(c+28|0,c+8|0)>>2];if(!Ob(g,h,d)){d=$e(b)}h=c+8|0;Xq(h,f);g=fc(c+16|0,v[c+8>>2],d);jc(c,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);Xq(h,f);Rb(v[c+8>>2]+d|0,0,36-d|0);Yb(b,v[c+28>>2]);hb=c+32|0;b=2;c=e>>>0>2?e:2;while(1){if((b|0)!=(c|0)){d=b+f|0;b=b+1|0;if(!w[d|0]){continue}break a}break}b=e+f|0;if(Qb(b,9595,4)){b=Qb(b,11096,4)}else{b=0}t[a+5|0]=!b}hb=f+48|0;return a|0}function Ux(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;d=w[a+2|0];if(!(!d|(d|0)==255)){v[e+12>>2]=d+1;v[e+8>>2]=10;Mg(b,v[od(e+12|0,e+8|0)>>2]);i=w[a+3|0];t[b+15|0]=i;t[b+16|0]=i;j=w[a+4|0];t[b+13|0]=j;l=w[a+5|0];t[b+14|0]=l;g=511;d=0;a:{b:{switch(c-1|0){case 1:d=4096;g=128;break a;case 0:break b;default:break a}}d=32768;g=1024}o=g>>>1|d;c=v[b>>2];k=Qd(c,v[b+4>>2]);d=0;c:{while(1){if((d|0)==(k|0)){d:{c=w[b+12|0]&-2|t[a|0]&1;t[b+12|0]=c;if(w[a|0]&2){break d}c=c&251;break c}}else{m=Bb(c,d);h=(d<<2)+a|0;f=(w[h+6|0]|w[h+7|0]<<8)>>>4|0;u[m>>1]=f;e:{if(d){n=x[Bb(c,d-1|0)>>1];if(f>>>0>=n>>>0){break e}f=n+1|0}else{f=0}p=Bb(c,d),q=f,u[p>>1]=q}v[e+12>>2]=(((w[h+8|0]|w[h+9|0]<<8)<<16>>16)+o|0)/(g|0);v[e+8>>2]=0;v[e+4>>2]=64;p=m,q=v[Gj(e+12|0,e+8|0,e+4|0)>>2],t[p+2|0]=q;d=d+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}t[b+12|0]=c;t[b+12|0]=(j>>>0<=l>>>0?w[a|0]&4:0)?c&-3|(k>>>0>=j>>>0)<<1:c&253}hb=e+16|0}function kx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=hb+-64|0;hb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Ef(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(d>>>0>v[c+24>>2]-g>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=B(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{l=se(mg(A[(a+k<<3)+i>>3])*134217728);m=v[(a<<2)+h>>2]+(j<<2)|0,n=C(+(ym(l)|0)*7.450580596923828e-9),z[m>>2]=n;a=a+1|0;continue}}}aa(7192,9074,77,8754);L()}aa(7157,9074,78,8754);L()}aa(5900,9074,79,8754);L()}aa(5870,9074,80,8754);L()}hb=c- -64|0}function pq(a){var b=0,c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(x[a+480192>>1]){break a}c=Cb(v[a+484344>>2]);v[e+8>>2]=c;a=Cb(v[a+484348>>2]);while(1){if(!Nb(c,a)){d=1;break a}if(!(!Nb(v[c>>2],v[c+4>>2])|v[c+12>>2]==64)){break a}c=v[uM(e+8|0)>>2];continue}}d=16777216;break a}d=32;f=x[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(t[b+480281|0]&1){break a}c=c+1|0;if(x[b+480286>>1]==64){continue}break}break a}d=2}hb=e+16|0;return d}function jx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=hb+-64|0;hb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Ef(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){g=v[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=B(b,f);l=B(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=(a+l<<2)+i|0,n=C(+(ym(se(mg(A[(a+k<<3)+j>>3])*134217728))|0)*7.450580596923828e-9),z[m>>2]=n;a=a+1|0;continue}}}aa(7192,9074,77,8754);L()}aa(7157,9074,78,8754);L()}aa(5900,9074,79,8754);L()}aa(5870,9074,80,8754);L()}hb=c- -64|0}function ux(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;o(+a);e=j(1)|0;c=j(0)|0;a:{b:{d=e>>>20&2047;if(d-969>>>0<63){k=d;break b}if(d>>>0<=968){return a+1}if(d>>>0<1033){break b}b=0;if(!c&(e|0)==-1048576){break a}if((d|0)==2047){return a+1}if((e|0)<0){return xr(1.2882297539194267e-231)}return xr(3.105036184601418e231)}b=A[170];f=A[169]*a+b;b=f-b;b=b*A[172]+(b*A[171]+a);a=b*b;g=a*a*(b*A[176]+A[175]);a=a*(b*A[174]+A[173]);o(+f);j(1)|0;h=j(0)|0;c=h<<4&2032;b=g+(a+(A[c+1464>>3]+b));d=c+1472|0;c=h<<13;e=0;i=v[d>>2]+e|0;c=c+v[d+4>>2]|0;c=e>>>0>i>>>0?c+1|0:c;d=i;if(!k){c:{if(!(h&-2147483648)){l(0,d|0);l(1,c-1058013184|0);a=+n();a=(a*b+a)*5.486124068793689e303;break c}e=hb-16|0;l(0,d|0);l(1,c+1071644672|0);g=+n();f=g*b;a=f+g;if(a<1){v[e+8>>2]=0;v[e+12>>2]=1048576;A[e+8>>3]=A[e+8>>3]*2.2250738585072014e-308;b=a+1;a=b+(f+(g-a)+(a+(1-b)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,c|0);a=+n();b=a*b+a}return b}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;n=v[a+16>>2];o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);k=v[a+128>>2];a:{if(!k){i=v[a+8>>2];j=v[a+12>>2];g=v[a>>2];b=v[a+4>>2];h=0;break a}i=v[a+8>>2];j=v[a+12>>2];l=kg(i,j,k);m=kb;h=v[a+76>>2];g=v[a>>2];b=v[a+4>>2];Of(g,b,mf(i,j,d),kb);h=h>>>0<kb>>>0?d:0}f=a+112|0;p=v[a+24>>2];q=v[a+20>>2];v[e>>2]=g;v[e+4>>2]=b;b:while(1){if(d){b=v[e+4>>2];v[e+8>>2]=v[e>>2];v[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(b<<1)+n|0;b=k;while(1)if((b|0)<=0){Pb(f,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Od(f,u[(v[e+12>>2]<<1)+g>>1]/4<<16>>16);Nd(f,b);v[f>>2]=v[f>>2];v[f+4>>2]=0}g=v[c>>2];b=ig(f,o);v[c>>2]=g+B(b,q);v[c+4>>2]=v[c+4>>2]+B(b,p);Pb(e,i,j);c=c+8|0;continue b}else{Od(f,u[(v[e+12>>2]<<1)+g>>1]/4<<16>>16);Nd(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;hb=e+16|0}function a9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=Mj(d,v[a+4>>2]);if(c>>>0<b>>>0){g=hb-32|0;hb=g;e=b-c|0;b=v[Db(a)>>2];c=v[a+4>>2];a:{if(e>>>0<=b-c>>11>>>0){b=hb-16|0;hb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);hb=b+16|0}else{eL(a);a=a+2048|0;v[b+4>>2]=a;continue}break}break a}h=Db(a);i=g+8|0;b=a;f=Mj(v[a>>2],c)+e|0;c=hb-16|0;hb=c;v[c+12>>2]=f;d=hb-16|0;hb=d;v[d+12>>2]=2097151;v[d+8>>2]=2147483647;a=v[Hb(d+12|0,d+8|0)>>2];hb=d+16|0;b:{if(a>>>0>=f>>>0){d=Kx(b);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;break b}rd();L()}d=gL(i,a,Mj(v[b>>2],v[b+4>>2]),h);c=d;a=hb-16|0;hb=a;v[a>>2]=v[c+8>>2];f=v[c+8>>2];v[a+8>>2]=c+8;v[a+4>>2]=f+(e<<11);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){eL(c);c=v[a>>2]+2048|0;v[a>>2]=c;continue}break}Kd(a);hb=a+16|0;Cd(b,d);fL(d)}hb=g+32|0;return}if(b>>>0<c>>>0){Ld(a,d+(b<<11)|0)}}function V2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=hb+-64|0;hb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Ef(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{g=v[c+4>>2];if(g>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=b+h|0;l=B(b,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=v[(a<<2)+i>>2]+(k<<1)|0;f=hd(v[(a+l<<2)+j>>2]+2048|0,12);f=(f|0)<32767?f:32767;u[m>>1]=(f|0)>-32768?f:-32768;a=a+1|0;continue}}}aa(7192,9074,33,8787);L()}aa(7157,9074,34,8787);L()}aa(5900,9074,35,8787);L()}aa(5870,9074,36,8787);L()}hb=c- -64|0}function gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0;g=hb-16|0;hb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;u=v[a+8>>2];w=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(p,q,e,e>>31);i=kb;f=Wb(f,-16777216,16776704);h=rka(n,o,f,f>>31);e=h+e|0;f=kb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=v[g+12>>2]+l|0;e=t[h|0];x=i;i=((B(t[h+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=rka(e,e>>31,r,s);e=x+h|0;f=kb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Pb(g+8|0,u,w);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;hb=g+16|0}function K2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=hb+-64|0;hb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Ef(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{g=v[c+4>>2];if(g>>>0>=e>>>0){h=v[c+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}i=v[c+28>>2];if(d>>>0>v[c+24>>2]-i>>>0){break b}j=v[c+16>>2];k=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=B(b,g);m=B(b+i|0,h);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=hd(v[(a+l<<2)+k>>2]+2048|0,12);f=(f|0)<32767?f:32767;u[(a+m<<1)+j>>1]=(f|0)>-32768?f:-32768;a=a+1|0;continue}}}aa(7192,9074,33,8787);L()}aa(7157,9074,34,8787);L()}aa(5900,9074,35,8787);L()}aa(5870,9074,36,8787);L()}hb=c- -64|0}function IP(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;t[e+15|0]=c;f=b&15;b=w[f+27248|0];a:{b:{switch(f|0){case 0:b=c?d>>>0<51?0:b:0;break a;case 5:c:{d:{f=c&15;e:{if(!((f|0)!=2&(c&240)!=32)){c=159;t[e+15|0]=159;b=20;break e}if((f|0)==12){break d}}if(d>>>0<51){break a}if((c&240)==192){break c}break a}if(d>>>0<51){break a}}t[e+15|0]=0;b=25;break a;case 7:b=d>>>0<52?0:b;break a;case 10:c=c&240;if(!c){break a}t[e+15|0]=c;break a;case 11:t[e+15|0]=B(c&15,17);break a;case 12:t[e+15|0]=c>>>2;break a;case 13:t[e+15|0]=B(c>>>4|0,10)+(c&15);break a;case 14:f:{switch((c>>>4|0)-1|0){case 0:t[e+15|0]=c|240;b=2;break a;case 1:t[e+15|0]=c|240;b=3;break a;case 7:if(d>>>0<52){break a}t[e+15|0]=c&15|96;case 11:case 12:b=20;break a;case 8:b=15;t[e+15|0]=c&15;break a;case 9:t[e+15|0]=c<<4|15;b=11;break a;case 10:break f;default:break a}}t[e+15|0]=c|240;b=11;break a;case 15:break b;default:break a}}b=c>>>0>47?17:b}ae(a,b,e+15|0);hb=e+16|0}function fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=hb-16|0;hb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;t=v[a+8>>2];w=v[a+12>>2];while(1){b=e;if(d){e=Wb(b,-16777216,16776704);e=rka(p,q,e,e>>31);i=kb;f=Wb(f,-16777216,16776704);h=rka(n,o,f,f>>31);e=h+e|0;f=kb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(v[g+12>>2]<<1)+l|0;e=u[h>>1];x=i;i=e+((B(u[h+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=rka(e,e>>31,r,s);e=x+h|0;f=kb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Pb(g+8|0,t,w);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;hb=g+16|0}function Oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;jd(b,32);lo(b);f=b,g=Eb(w[a+40|0]|w[a+41|0]<<8)>>>2|0,u[f+32>>1]=g;c=x[b+34>>1];if((ne((w[a+38|0]|w[a+39|0]<<8)<<16>>16)|0)>0){c=c|32;u[b+34>>1]=c;d=ne((w[a+38|0]|w[a+39|0]<<8)<<16>>16);e=(d<<8&-256)+2047|0;d=d>>>24|0;f=b,g=Bc(uka(e,e>>>0<2047?d+1|0:d,4095,0),kb),u[f+28>>1]=g}f=b,g=_b(w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24)),v[f>>2]=g;f=b,g=_b(w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24)),v[f+4>>2]=g;f=b,g=_b(w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24))+_b(w[a+66|0]|w[a+67|0]<<8|(w[a+68|0]<<16|w[a+69|0]<<24))|0,v[f+8>>2]=g;c=c&-3|((Eb(w[a+44|0]|w[a+45|0]<<8)|0)!=0)<<1;u[b+34>>1]=c;f=b,g=c&65531|Eb(w[a+44|0]|w[a+45|0]<<8)<<1&4,u[f+34>>1]=g;f=b,g=_b(w[a+54|0]|w[a+55|0]<<8|(w[a+56|0]<<16|w[a+57|0]<<24))<<1,v[f+24>>2]=g;c=ne((w[a+42|0]|w[a+43|0]<<8)<<16>>16);if(c){sl(b,+(c|0)/96);c=ne((w[a+42|0]|w[a+43|0]<<8)<<16>>16)}t[b+37|0]=c<<4}function w7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0),u=C(0),x=C(0),y=C(0),A=0,B=0,E=0,F=0,G=0,H=C(0);g=hb-16|0;hb=g;m=v[a+4240>>2];a:{if(!m){break a}if(!ai(a+44|0)){break a}n=z[a+4220>>2];e=v[a+44>>2];F=g,G=Ec(e,0),v[F+8>>2]=G;F=g,G=Ec(e,1),v[F+12>>2]=G;e=v[a+56>>2];o=Ec(e,0);v[g>>2]=o;p=Ec(e,1);v[g+4>>2]=p;y=C(C(1)-n);q=v[a+4208>>2];A=w[a+4264|0];e=d;b:while(1){if(e){k=v[a+4244>>2];B=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;v[a+4244>>2]=(f|0)==(m|0)?0:f;e=e-1|0;continue b}else{h=(A?1-l|0:f)&255;j=v[((h<<2)+a|0)+4248>>2];E=v[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=v[s>>2];v[s>>2]=i+4;j=k-j|0;t=z[Bb(q,h+((j>>31&E)+j<<1)|0)>>2];u=z[i>>2];x=C(C(t*z[a+4224>>2])+C(u*z[a+4260>>2]));F=Bb(q,f+B|0),H=C(D(x))<C(1.0000000195414814e-24)?C(0):x,z[F>>2]=H;h=g+r|0;i=v[h>>2];v[h>>2]=i+4;z[i>>2]=C(u*y)+C(n*t);l=l+1|0;f=f+1|0;continue}}break}si(a,b,c,o,p,d)}hb=g+16|0}function jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=Qt(c,d);d=b&63;if(e>>>0>d>>>0){c=DS(c,d);d=0;g=hb-16|0;hb=g;t[a+12|0]=0;Gc(a);e=hb-32|0;hb=e;if(Vh(a)>>>0<=14){f=Db(a);f=Tf(e+8|0,15,sc(v[a>>2],v[a+4>>2]),f);Cd(a,f);Sf(f)}hb=e+32|0;h=0-w[c+1|0]|0;while(1){a:{if((d|0)==15){break a}e=c+(d<<1)|0;f=w[e+1|0];if(!f){break a}t[g+7|0]=64;h=f+(h<<16>>16)|0;f=ql(g+8|0,h&65535,w[Vb(e+2|0,g+7|0)|0]);b:{if(y[a+4>>2]<y[Db(a)>>2]){zS(a,f);break b}i=hb-32|0;hb=i;e=Db(a);e=Tf(i+8|0,pg(a,sc(v[a>>2],v[a+4>>2])+1|0),sc(v[a>>2],v[a+4>>2]),e);xm(v[e+8>>2],x[f>>1]|x[f+2>>1]<<16);v[e+8>>2]=v[e+8>>2]+4;Cd(a,e);Sf(e);hb=i+32|0}d=d+1|0;continue}break}d=w[c+32|0];t[a+14|0]=d>>>4;t[a+13|0]=d&15;c=w[c+31|0];d=c&15;t[a+15|0]=d;t[a+16|0]=d;if(c&16){t[a+12|0]=w[a+12|0]|4}if(c&32){t[a+12|0]=w[a+12|0]|2}hb=g+16|0}c:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break c}c=w[a+12|0]&-2|nc(v[a>>2],v[a+4>>2])^1;a=a+12|0}t[a|0]=c}function ww(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=v[b>>2];d=(c^-1)&-2139062144;b:{if(d&c-16843009|d&(c^1027423549)-16843009){break b}while(1){c=v[b+4>>2];b=b+4|0;d=(c^-1)&-2139062144;if(d&c-16843009){break b}if(!(d&(c^1027423549)-16843009)){continue}break}}c=c&255;if(!c|(c|0)==61){break a}while(1){c:{c=b+1|0;d=w[b+1|0];if((d|0)==61){break c}b=c;if(d){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;d:{if(w[g+a|0]){break d}f=v[116930];if(!f){break d}b=v[f>>2];if(!b){break d}while(1){e:{c=a;d=b;i=0;h=g;e=0;f:{if(!g){break f}e=w[c|0];g:{if(!e){break g}while(1){h:{j=w[d|0];if(!j){break h}h=h-1|0;if(!h|(e|0)!=(j|0)){break h}d=d+1|0;e=w[c+1|0];c=c+1|0;if(e){continue}break g}break}i=e}e=(i&255)-w[d|0]|0}if(!e){b=b+g|0;if(w[b|0]==61){break e}}b=v[f+4>>2];f=f+4|0;if(b){continue}break d}break}k=b+1|0}return k}function pw(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=hb-16|0;hb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Fb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Fb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=yi(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+84e3|0];d:{e:{switch((f&-2)-22|0){case 2:b=v[e>>2];if((b|0)!=(d|0)&(w[b-1|0]&95)!=(w[c|0]&127)){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:t[c|0]=80;break d;default:break e}}a=g&95;if((a|0)!=w[c|0]){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Fb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}hb=m+16|0;return a}function wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=hb-16|0;hb=g;m=v[a+16>>2];j=Rf(1,2);b=kb;n=b;Pb(a,j,b);f=v[a+48>>2];o=v[a+24>>2];p=v[a+20>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];t=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){k=u[(v[g+12>>2]<<1)+m>>1]<<8;e=k;e=rka(e,e>>31,x,y);i=kb;h=e;e=Wb(b,-16777216,16776704);l=rka(t,w,e,e>>31);h=h+l|0;e=kb+i|0;e=h>>>0<l>>>0?e+1|0:e;f=Wb(f,-16777216,16776704);i=rka(r,s,f,f>>31);h=i+h|0;f=kb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,p)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,o);Pb(g+8|0,z,A);e=f-(q&k)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;lg(a,j,n);hb=g+16|0}function n6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-80|0;hb=e;v[e+72>>2]=c;a=dg(a,e+72|0);c=yf(a+4|0);h=yf(a+24|0);i=yf(a+32|0);j=Lb(a+36|0);v[a+56>>2]=3;k=Lb(a+68|0);v[23516]=0;R(961,a|0,d|0);f=v[23516];v[23516]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];g=v[b+4>>2];l=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=l;v[e+32>>2]=f;v[e+36>>2]=g;b=ce(e+24|0);f=v[b+4>>2];b=v[b>>2];g=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=g;v[23516]=0;g=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=g;X(950,e+48|0,e+8|0,b|0,f|0);b=v[23516];v[23516]=0;if((b|0)==1){break d}v[23516]=0;U(962,a|0,e+48|0,d|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}yb(e+48|0);v[23516]=0;Y(963,a|0);b=v[23516];v[23516]=0;if((b|0)==1){break b}ze(e+72|0);hb=e+80|0;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(e+48|0);break a}b=P()|0;O()|0}Me(k);Vf(j);os(i);fj(h);ej(c);ze(a);ze(e+72|0);S(b|0);L()}function zha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=hb-32|0;hb=e;b=hb-32|0;hb=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;c=tc(64);v[23516]=0;d=T(855,c|0)|0;f=v[23516];v[23516]=0;a:{b:{c:{if((f|0)!=1){c=If(b+8|0,d);d=v[c>>2];v[23516]=0;R(856,d|0,a|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}a=v[c>>2];v[23516]=0;a=W(857,a|0,b+22|0,b+16|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}d:{if(!a){yf(b+24|0);break d}a=v[c>>2];v[23516]=0;R(858,a|0,15);a=v[23516];v[23516]=0;if((a|0)==1){break c}dg(b+24|0,c)}qg(c);hb=b+32|0;b=v[b+24>>2];break a}a=P()|0;O()|0;Jb(c);break b}a=P()|0;O()|0;qg(c)}S(a|0);L()}v[e+24>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}v[23516]=0;c=Q(1,e+8|0,(a<<2)+32352|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;U(495,b|0,a|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break g}xb(c);a=a+1|0;continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;xb(c)}qg(e+24|0);S(a|0);L()}hb=e+32|0;return b|0}function zp(a){a=a|0;var b=0,c=0,d=C(0),e=C(0),f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=C(0);b=v[a+36>>2];if(!b){Gc(a+16|0);return}a:{b:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Gc(c);return}ak(c,b);b=u[a+28>>1];d=C(hm(a,(b<<16)+65536>>16)/hm(a,b));c=v[a+36>>2]+1|0;d=qe(d,C(C(1)/C(c>>>0)));a=v[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}e=qe(d,C(b>>>0));n=Bb(a,b-1|0),o=e,z[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;f=x[a+30>>1];if(f>>>0>1e3/(b>>>0)>>>0){Gc(c);return}ak(c,B(b,f));h=x[a+30>>1];j=Dn(u[a+28>>1],h);i=v[a+36>>2];d=C(C(1)/C(i+1>>>0));c=0;c:while(1){if((c&65535)>>>0>=f>>>0){break a}b=Dn(c+j<<16>>16,h)<<16;e=hm(a,b+65536>>16);b=b>>16;e=qe(C(e/hm(a,b)),d);k=B(b,v[a+36>>2]);l=v[a+16>>2];b=1;while(1){g=b&65535;if(i>>>0<g>>>0){c=c+1|0;continue c}else{m=qe(e,C(g>>>0));n=Bb(l,(g+k|0)-1|0),o=m,z[n>>2]=o;b=b+1|0;continue}}};case 0:Gc(a+16|0);return;default:break b}}Gc(a+16|0);v[a+36>>2]=0}}function xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=hb-16|0;hb=g;m=v[a+16>>2];j=Rf(1,2);b=kb;n=b;Pb(a,j,b);f=v[a+48>>2];o=v[a+24>>2];p=v[a+20>>2];e=v[a+44>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];u=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){k=t[v[g+12>>2]+m|0]<<16;e=k;e=rka(e,e>>31,x,y);i=kb;h=e;e=Wb(b,-16777216,16776704);l=rka(u,w,e,e>>31);h=h+l|0;e=kb+i|0;e=h>>>0<l>>>0?e+1|0:e;f=Wb(f,-16777216,16776704);i=rka(r,s,f,f>>31);h=i+h|0;f=kb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Tc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,p)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,o);Pb(g+8|0,z,A);e=f-(q&k)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;lg(a,j,n);hb=g+16|0}function X8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=0,s=0,t=0,u=C(0),w=C(0),x=C(0),y=C(0),A=0,B=0,E=0,F=C(0);r=v[a+4220>>2];if(r){f=v[a+44>>2];k=Ec(f,0);l=Ec(f,1);g=v[a+56>>2];s=Ec(g,0);j=v[a+4208>>2];A=v[a+4228>>2];f=d;t=Ec(g,1);m=t;g=s;while(1){if(f){h=v[a+4224>>2];e=h-A|0;e=(v[a+4220>>2]&e>>31)+e<<1;B=Bb(j,e);n=z[Bb(j,e|1)>>2];u=z[a+4244>>2];o=z[B>>2];w=z[a+4252>>2];p=z[l>>2];x=z[a+4248>>2];q=z[k>>2];y=z[a+4256>>2];i=C(C(n*u)+C(C(o*w)+C(C(p*x)+C(q*y))));e=h<<1;E=Bb(j,e),F=C(D(i))<C(1.0000000195414814e-24)?C(0):i,z[E>>2]=F;i=C(C(o*u)+C(C(n*w)+C(C(q*x)+C(p*y))));E=Bb(j,e|1),F=C(D(i))<C(1.0000000195414814e-24)?C(0):i,z[E>>2]=F;h=h+1|0;v[a+4224>>2]=(h|0)==(r|0)?0:h;z[g>>2]=C(q*z[a+4240>>2])+C(o*z[a+4236>>2]);z[m>>2]=C(p*z[a+4240>>2])+C(n*z[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{si(a,b,c,s,t,d)}break}}}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=(v[f+12>>2]<<1)+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;hb=f+16|0}function KG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Ne(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=hu(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(XG(v[a+36>>2],d,i,f,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=hu(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Nr(Kf(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break a}}d=Kf(t[c+23|0]);v[a+48>>2]=d;break a}d=Kf(t[c+23|0]);break a}d=-1}hb=c+32|0;return d}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;n=v[a+16>>2];o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);k=v[a+128>>2];a:{if(!k){i=v[a+8>>2];j=v[a+12>>2];g=v[a>>2];b=v[a+4>>2];h=0;break a}i=v[a+8>>2];j=v[a+12>>2];l=kg(i,j,k);m=kb;h=v[a+76>>2];g=v[a>>2];b=v[a+4>>2];Of(g,b,mf(i,j,d),kb);h=h>>>0<kb>>>0?d:0}f=a+112|0;p=v[a+24>>2];q=v[a+20>>2];v[e>>2]=g;v[e+4>>2]=b;b:while(1){if(d){b=v[e+4>>2];v[e+8>>2]=v[e>>2];v[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=b+n|0;b=k;while(1)if((b|0)<=0){Pb(f,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Od(f,t[v[e+12>>2]+g|0]<<6);Nd(f,b);v[f>>2]=v[f>>2];v[f+4>>2]=0}g=v[c>>2];b=ig(f,o);v[c>>2]=g+B(b,q);v[c+4>>2]=v[c+4>>2]+B(b,p);Pb(e,i,j);c=c+8|0;continue b}else{Od(f,t[v[e+12>>2]+g|0]<<6);Nd(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;hb=e+16|0}function Iu(a){var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;a:{if(w[a+3|0]!=19){break a}t[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=w[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}t[a+3|0]=0;break a}t[a+3|0]=2;t[a+5|0]=b|240;break a}t[a+3|0]=3;t[a+5|0]=b|240;break a}t[a+5|0]=b&15|16;break a}t[a+5|0]=b&3|48;break a}t[a+5|0]=b&15|32;break a}t[a+5|0]=b&15|176;break a}t[a+5|0]=b&3|64;break a}t[a+3|0]=15;t[a+5|0]=b&15;break a}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;break a}t[a+3|0]=0;break a}b=b&15;if(b){t[a+3|0]=11;v[c+12>>2]=b;v[c+8>>2]=14;d=a,e=w[od(c+12|0,c+8|0)|0]|240,t[d+5|0]=e;break a}t[a+3|0]=0;break a}if((b|0)!=192){break a}t[a|0]=254;t[a+3|0]=0;break a}if((b|0)!=208){break a}t[a+3|0]=0}hb=c+16|0}function lZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=t[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((w[a+1|0]&192)==128){break b}break a}g=f&255;c:{d:{if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4;break b}if((f&224)!=128){break a}}g=3;if((h&192)!=128){break a}}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function LG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Ne(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=hu(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(XG(v[a+36>>2],d,i,f,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=hu(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Nr(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break a}}d=v[c+20>>2];v[a+48>>2]=d;break a}d=v[c+20>>2];break a}d=-1}hb=c+32|0;return d}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=v[f+12>>2]+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Pb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;hb=f+16|0}function Bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;u[e+12>>1]=0;v[e+8>>2]=0;j=8;n=B(c,d)<<1;while(1){if((d|0)!=(l|0)){h=(l<<1)+b|0;o=n+h|0;while(1){if(h>>>0<o>>>0){u[e+6>>1]=0;$R(a,e+15|0,e+12|0,j,e+6|0);g=x[e+6>>1];c=j;while(1){a:{if(!(c&255)){break a}f=x[e+12>>1]<<1;i=f&254;u[e+12>>1]=i;if(i){f=(f&65534)>>>0>255}else{if(!hf(a,e+5|0)){break a}f=w[e+5|0];u[e+12>>1]=f<<1&254|1;f=f>>>7|0}c=c-1|0;g=f|g<<1;continue}break}c=1;i=g&65535;b:{if(i>>>0<4){break b}f=15;while(1){c=f;m=f&255;if(i>>>m&1){break b}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+x[e+8>>1]|0;u[e+6>>1]=f;u[h>>1]=f;v[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);h=(d<<1)+h|0;j=(c+j&254)>>>1|0;c=-32768;k=v[e+8>>2];c:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break c}}v[e+8>>2]=c}k=f;continue}break}l=l+1|0;continue}break}hb=e+16|0}function hs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb+-64|0;hb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Ef(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){g=v[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=B(b,f);l=B(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[(a+l<<2)+i>>2]=C(v[(a+k<<2)+j>>2])*C(7.450580596923828e-9);a=a+1|0;continue}}}aa(7192,9074,33,8787);L()}aa(7157,9074,34,8787);L()}aa(5900,9074,35,8787);L()}aa(5870,9074,36,8787);L()}hb=c- -64|0}function oZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=t[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((w[a+1|0]&192)==128){break b}break a}g=b&255;c:{d:{if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];b=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((b&224)==160){break c}break a}if((b&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>4294967284){break a}f=w[a+3|0];h=w[a+2|0];b=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0<48){break e}break a;case 4:if((b&240)==128){break e}break a;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}break b}if((b&224)!=128){break a}}f=3;if((h&192)!=128){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function Cu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=hb-560|0;hb=f;u[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=v[e>>2];b:{if(b){c=cP(f,c);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);e=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=e;t[b+8|0]=e>>>8;t[b+9|0]=e>>>16;t[b+10|0]=e>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;ky(b+48|0,c+48|0);ky(b+68|0,c+68|0);ky(b+88|0,c+88|0);pc(b+108|0,c+108|0,448);d=b;Ot(c);break b}b=Ns(556);if(!b){v[e>>2]=0;break a}d=cP(b,c);v[e>>2]=d}g=a,h=x[ie(a+480192|0,f+558|0)>>1],u[g+480192>>1]=h}hb=f+560|0;return d|0}function GW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=hb-32|0;hb=j;d=Sm(j+8|0,a);c=hb-48|0;hb=c;k=-1;a:{if(!bD(d,c+8|0)){break a}k=0;if(!fD(c+8|0)){break a}n=v[d+12>>2];b:{if(!ol(d,w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24))){break b}while(1){c:{if((w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))>>>0>m>>>0){if(eg(d,5)){break c}}g=l&1;break b}g=0;h=1;d:{if((w[c+12|0]|w[c+13|0]<<8)>>>0>=64){f=Fq(d);a=f&63;e:{if(!(f&64)){break e}e=6;while(1){i=Fq(d);a=(i&127)<<e|a;if(!(i&128)){break e}i=e>>>0<25;e=e+7|0;if(i){continue}break}}e=f>>>7|0;f=e?-2147483648:a;if(((e?(a|0)>=0?0-a|0:f:f)|0)<=0){break d}}while(1){e=Fq(d);if(e){f=g>>>0>4;a=f&h;if(!((h^1)&1|f)){a=(Np(e<<24>>24)&255)==w[g+13133|0]}h=a;g=g+1|0;continue}break}dd(d,4);l=(g|0)==5?h&1?1:l:l}m=m+1|0;continue}}ol(d,n);if(!g){break a}k=we(d,b,eD(c+8|0),0)}hb=c+48|0;hb=j+32|0;return k|0}function is(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb+-64|0;hb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Ef(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(d>>>0>v[c+24>>2]-g>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=B(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[v[(a<<2)+h>>2]+(j<<2)>>2]=C(v[(a+k<<2)+i>>2])*C(7.450580596923828e-9);a=a+1|0;continue}}}aa(7192,9074,33,8787);L()}aa(7157,9074,34,8787);L()}aa(5900,9074,35,8787);L()}aa(5870,9074,36,8787);L()}hb=c- -64|0}function kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;d=v[b>>2];e=ik(d,v[b+4>>2]);a:{if(e>>>0<c>>>0){i=hb-32|0;hb=i;f=c-e|0;e=v[Db(b)>>2];d=v[b+4>>2];b:{if(f>>>0<=e-d>>4>>>0){h=hb-16|0;hb=h;d=qt(h,b,f);e=v[d+4>>2];f=v[d+8>>2];while(1){if((e|0)==(f|0)){ic(d);hb=h+16|0}else{ou(e);e=e+16|0;v[d+4>>2]=e;continue}break}break b}e=Db(b);e=RP(i+8|0,SP(b,ik(v[b>>2],d)+f|0),ik(v[b>>2],v[b+4>>2]),e);d=hb-16|0;hb=d;v[d>>2]=v[e+8>>2];h=v[e+8>>2];v[d+8>>2]=e+8;v[d+4>>2]=h+(f<<4);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){ou(f);f=v[d>>2]+16|0;v[d>>2]=f;continue}break}Kd(d);hb=d+16|0;Cd(b,e);d=v[e+4>>2];f=v[e+8>>2];while(1){if((d|0)!=(f|0)){f=f-16|0;v[e+8>>2]=f;continue}break}d=v[e>>2];if(d){Vo(e);Jb(d)}}hb=i+32|0;break a}if(c>>>0<e>>>0){Ld(b,d+(c<<4)|0)}}if(Ob(v[a>>2],v[a+8>>2],c<<4)){c=v[b>>2];ec(g+8|0,c,ik(c,v[b+4>>2])<<4);pd(g,a,v[g+8>>2],v[g+12>>2])}hb=g+16|0}function mba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;l=hb-16|0;hb=l;d=v[cc(l+8|0,Cb(v[a+4>>2]))>>2];i=hb-32|0;hb=i;e=d;d=v[a>>2];h=(ro(e,Cb(d))<<1)+d|0;g=st(b,c);a:{if((g|0)<=0){break a}e=v[Db(a)>>2];d=v[a+4>>2];if((g|0)<=e-d>>1){f=d-h|0;j=f>>1;b:{if((j|0)>=(g|0)){e=c;break b}v[i+8>>2]=b;v[i+8>>2]=v[i+8>>2]+(j<<1);e=v[i+8>>2];NO(a,e,c,g-j|0);if((f|0)<=0){break a}}m=hb-16|0;hb=m;j=v[a+4>>2];f=(j-((g<<1)+h|0)|0)+h|0;g=$h(m,a,d-f>>1);k=v[g+4>>2];c=f;while(1){if(c>>>0>=d>>>0){ic(g);tq(h,f,j);hb=m+16|0}else{Ki(k,x[c>>1]);k=k+2|0;v[g+4>>2]=k;c=c+2|0;continue}break}Qn(b,e,h);break a}f=Db(a);f=Jj(i+8|0,Kj(a,Oc(v[a>>2],d)+g|0),h-v[a>>2]>>1,f);d=hb-16|0;hb=d;e=Io(d,f+8|0,st(b,c));c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){Ki(c,x[b>>1]);c=v[e>>2]+2|0;v[e>>2]=c;b=b+2|0;continue}break}Kd(e);hb=d+16|0;h=UO(a,f,h);Li(f)}Cb(h);hb=i+32|0;hb=l+16|0;return a|0}function Lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;v[e+12>>2]=1;a:{if($n(a)){c=v[a>>2];j=Uf(c,v[a+4>>2]);v[e+8>>2]=j;k=v[Hb(e+12|0,e+8|0)>>2];while(1){if(k){k=k-1|0;if((b|0)!=(c|0)){f=Cb(v[b>>2]);g=Cb(v[b+4>>2]);d=hb-16|0;hb=d;h=xB(f,g);b:{if(h>>>0<=Om(c)>>>0){v[d+8>>2]=g;l=v[c>>2];i=Oc(l,v[c+4>>2]);m=i>>>0>=h>>>0;if(m){i=g}else{v[d+8>>2]=f;WO(d+8|0,i);i=v[d+8>>2]}f=Mi(f,i,l);if(!m){YO(c,v[d+8>>2],g,h-Oc(v[c>>2],v[c+4>>2])|0);break b}Ld(c,f);break b}XO(c);Tz(c,Kj(c,h));YO(c,f,g,h)}hb=d+16|0;To(c+12|0,b+12|0);u[c+28>>1]=x[b+28>>1]}c=c+32|0;continue}break}if(!j){oz(a,1-j|0,b);break a}OO(a,v[a>>2]+32|0);break a}if(v[a>>2]){RO(a);c=v[a>>2];$n(a);Jb(c);n=Db(a),o=0,v[n>>2]=o;v[a>>2]=0;v[a+4>>2]=0}c=_p(a,1);if(Kh(134217727)>>>0<c>>>0){rd();L()}d=MP(c);v[a>>2]=d;v[a+4>>2]=d;n=Db(a),o=d+(c<<5)|0,v[n>>2]=o;oz(a,1,b)}hb=e+16|0}function wF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=hb-32|0;hb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;Hf(g+16|0,a,b,c,e,f-16129|0);vm(g,a,b,c,e,16257-f|0);b=v[g+8>>2];e=(v[g+12>>2]&33554431)<<7|b>>>25;h=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;f=v[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}hb=g+32|0;return l(2,d&-2147483648|e),q()}function Ul(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;v[a+4>>2]=0;if(Sd(w[Zl(d+8|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23516]=0;b=T(102,b|0)|0;c=v[23516];v[23516]=0;d:{if((c|0)!=1){if(!nc(b,-1)){break d}break b}break c}v[a+4>>2]=v[a+4>>2]+1;continue}}if(v[a+4>>2]>=(b|0)){break a}e:{while(1){c=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23516]=0;c=T(102,c|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break e}if(nc(c,-1)){break b}c=v[a+4>>2]+1|0;v[a+4>>2]=c;if((b|0)>(c|0)){continue}break}c=0;break a}}b=V(0)|0;O()|0;_(b|0)|0;c=1;Wl(v[v[a>>2]-12>>2]+a|0,1);f:{g:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23516]=0;Z(103);a=v[23516];v[23516]=0;if((a|0)!=1){break f}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break g}S(a|0);L()}$();break a}V(0)|0;O()|0;Tb()}L()}c=2}Ii(v[v[a>>2]-12>>2]+a|0,c)}hb=d+16|0;return a|0}function B9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=v[a>>2];d=sk(e,v[a+4>>2]);if(d>>>0<b>>>0){h=hb-32|0;hb=h;a:{b:{e=b-d|0;b=v[Db(a)>>2];f=v[a+4>>2];c:{if(e>>>0<=(b-f|0)/52>>>0){Rx(a,e,c);break c}d=Db(a);f=zL(a,sk(v[a>>2],f)+e|0);g=sk(v[a>>2],v[a+4>>2]);b=h+8|0;og(b+12|0,d);if(f){d=yL(f)}else{d=0}v[b>>2]=d;g=d+B(g,52)|0;v[b+8>>2]=g;v[b+4>>2]=g;i=zc(b),j=d+B(f,52)|0,v[i>>2]=j;v[23516]=0;U(899,b|0,e|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}f=v[a>>2];c=v[a+4>>2];e=b+4|0;while(1){if((c|0)!=(f|0)){c=c-52|0;d=nl(v[e>>2]-52|0,c);v[d+20>>2]=v[c+20>>2];g=v[c+16>>2];v[d+12>>2]=v[c+12>>2];v[d+16>>2]=g;mQ(d+24|0,c+24|0);Xc(d+36|0,c+36|0);v[d+48>>2]=v[c+48>>2];v[e>>2]=v[e>>2]-52;continue}break}oc(a,e);oc(a+4|0,b+8|0);oc(Db(a),zc(b));v[b>>2]=v[b+4>>2];xL(b)}hb=h+32|0;break a}a=P()|0;O()|0;xL(b);S(a|0);L()}return}if(b>>>0<d>>>0){AL(a,e+B(b,52)|0)}}function yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;u[e+12>>1]=0;v[e+8>>2]=0;n=B(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){t[e+7|0]=0;_R(a,e+15|0,e+12|0,e+7|0);g=w[e+7|0];f=x[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!hf(a,e+6|0)){break c}f=w[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}u[e+12>>1]=f;break b}l=l+1|0;continue a}u[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+w[e+8|0]|0;t[e+7|0]=f;t[i|0]=f;v[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=v[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}v[e+8>>2]=c}j=f;continue}}break}hb=e+16|0}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=hb-16|0;hb=e;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){f=v[e+8>>2];m=((((v[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=u[b+14>>1];o=u[b+12>>1];p=u[b+10>>1];q=u[b+8>>1];r=u[b+6>>1];s=u[b+4>>1];t=u[b+2>>1];w=u[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+m|0;v[(f<<2)+e>>2]=(((((B(u[b+8>>1],p)+B(u[b+4>>1],q)|0)+B(u[b+12>>1],o)|0)+B(u[b+16>>1],n)|0)/2|0)+((((B(u[b-8>>1],t)+B(u[b-12>>1],w)|0)+B(u[b-4>>1],s)|0)+B(u[b>>1],r)|0)/2|0)|0)/16384;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g);Pb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;hb=e+16|0}function Wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=hb-144|0;hb=g;wo(a);a:{b:{if(!eg(a,64)){break b}c:{d:{if(!ol(a,60)){break d}if(!LQ(a,14226)){break d}c=15;d=450;break c}wo(a);if(!eg(a,128)){break b}b=0;if(!ol(a,124)){break a}if(!LQ(a,15489)){break a}c=31;d=930}wo(a);b=0;e:{while(1){if((b&65535)>>>0>=c>>>0){break e}b=b+1|0;if(JQ(a)>>>0<=131072){continue}break}b=0;break a}dd(a,4);if(!eg(a,2)){break b}b=0;e=hb-16|0;hb=e;c=hb-16|0;hb=c;Nm(c+8|0,e+8|0);f=v[c+12>>2];id(c,a,v[c+8>>2],f);h=v[c+4>>2];if((f|0)==(h|0)){dd(a,v[c+12>>2])}hb=c+16|0;if((f|0)==(h|0)){i=Eb(x[e+8>>1])}hb=e+16|0;if(i>>>0<178){break a}b=-1;if(!eg(a,d)){break a}dd(a,d);d=hb-16|0;hb=d;e=g+8|0;JR(d+8|0,e);c=v[d+12>>2];id(d,a,v[d+8>>2],c);f=v[d+4>>2];if((f|0)==(c|0)){dd(a,v[d+12>>2])}hb=d+16|0;a=(c|0)==(f|0);if(!a){Zz(e)}if(!a){break a}b=KQ(w[g+8|0]);break a}b=-1}hb=g+144|0;return b|0}function LN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=hb-16|0;hb=c;d=Kb(a);while(1){b:{c:{d:{if(Fb(g)>>>0>f>>>0){b=v[oj(g,f)>>2];if(b>>>0>=2097152){v[23516]=0;R(49,d|0,63);a=v[23516];v[23516]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;t[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=w[c+10|0]|64}else{a=w[c+10|0]}v[23516]=0;R(49,d|0,a&255);a=v[23516];v[23516]=0;if((a|0)!=1){break c}break b}hb=c+16|0;break a}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=w[j|0];v[23516]=0;R(49,d|0,a|i&255);h=v[23516];v[23516]=0;a=e;break e}v[23516]=0;a=a-1|0;R(49,d|0,w[a+(c+10|0)|0]|128);h=v[23516];v[23516]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;O()|0;xb(d);S(a|0);L()}}function O6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0),x=C(0);h=hb-16|0;hb=h;if(ai(a+44|0)){f=v[a+44>>2];g=Ec(f,0);v[h+8>>2]=g;f=Ec(f,1);v[h+12>>2]=f;j=v[a+56>>2];m=Ec(j,0);v[h>>2]=m;j=Ec(j,1);v[h+4>>2]=j;a:{if(z[Bb(a+4208|0,2)>>2]!=C(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=v[e>>2];v[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=z[n>>2];l=z[i>>2];r=z[a+4236>>2];s=z[a+4232>>2];t=z[a+4228>>2];u=z[a+4220>>2];w=z[a+4224>>2];i=e+4240|0;o=z[i>>2];z[n>>2]=o;z[i>>2]=l;i=e+4264|0;x=z[i>>2];e=e+4256|0;p=z[e>>2];z[i>>2]=p;l=C(C(C(C(t*q)+C(C(u*l)+C(w*o)))-C(s*p))-C(r*x));z[e>>2]=l;k=h+k|0;e=v[k>>2];v[k>>2]=e+4;z[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;pc(m,e,g);pc(j,f,g);f=v[a+56>>2];m=Ec(f,0);j=Ec(f,1)}si(a,b,c,m,j,d)}hb=h+16|0}function Mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=ud(d,v[a+4>>2]);if(c>>>0<b>>>0){f=hb-32|0;hb=f;c=b-c|0;b=v[Db(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=hb-16|0;hb=d;b=At(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);hb=d+16|0}else{oQ(a);a=a+12|0;v[b+4>>2]=a;continue}break}break a}b=Db(a);b=Bk(f+8|0,$m(a,ud(v[a>>2],d)+c|0),ud(v[a>>2],v[a+4>>2]),b);e=hb-16|0;hb=e;d=nQ(e,b+8|0,c);c=v[d>>2];while(1){if(v[d+4>>2]!=(c|0)){oQ(c);c=v[d>>2]+12|0;v[d>>2]=c;continue}break}Kd(d);hb=e+16|0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;mQ(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Db(a),zc(b));v[b>>2]=v[b+4>>2];a=v[b+4>>2];while(1){c=v[b+8>>2];if((c|0)!=(a|0)){c=c-12|0;v[b+8>>2]=c;pQ(c);continue}break}a=v[b>>2];if(a){Vo(b);Jb(a)}}hb=f+32|0;return}if(b>>>0<c>>>0){qQ(a,d+B(b,12)|0)}}function Saa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;b=v[a+4>>2];if(Sd(w[b+223884|0])){NN(b+223860|0);b=v[a+4>>2]}v[a+24>>2]=0;v[a+28>>2]=0;v[b>>2]=0;c=v[a>>2];v[b+40>>2]=v[c+480196>>2];v[b+44>>2]=v[c+480204>>2];v[b+80>>2]=v[c+480200>>2];c=x[c+480188>>1];v[f+8>>2]=0;v[f+12>>2]=0;d=f+8|0;u[d+4>>1]=65280;v[d>>2]=0;e=hb-16|0;hb=e;v[e+12>>2]=c;b=a+8|0;a:{if(Zm(b)>>>0>=c>>>0){g=v[b>>2];h=Qg(g,v[b+4>>2]);v[e+8>>2]=h;i=v[Hb(e+12|0,e+8|0)>>2];while(1){if(i){v[g>>2]=v[d>>2];u[g+4>>1]=x[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){WM(b,c-h|0,d);break a}Ld(b,v[b>>2]+(c<<3)|0);break a}dO(b);qO(b,dr(b,c));WM(b,c,d)}hb=e+16|0;b=0;while(1){c=v[a>>2];if(x[c+480188>>1]<=b>>>0){hb=f+16|0}else{d=B(b,872);Vn((d+v[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+v[a+4>>2]|0;u[c+1432>>1]=0;t[c+1418|0]=0;t[c+1415|0]=0;t[c+1413|0]=0;b=b+1|0;continue}break}}function lw(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break a}f=0;t[b|0]=0;a=v[e>>2];v[e>>2]=a+1;t[a|0]=46;if(!Fb(h)){break b}a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Fb(h)){break c}if(!w[b|0]){break a}f=0;a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;v[k>>2]=0;return 0}f=-1;a=nw(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=w[(a>>2)+84e3|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=v[e>>2];if((a|0)!=(d|0)){f=-1;if((w[a-1|0]&95)!=(w[c|0]&127)){break b}}v[e>>2]=a+1;t[a|0]=g;return 0}t[c|0]=80;break d}d=g&95;if((d|0)!=w[c|0]){break d}t[c|0]=d|128;if(!w[b|0]){break d}t[b|0]=0;if(!Fb(h)){break d}b=v[j>>2];if((b-i|0)>159){break d}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c}b=v[e>>2];v[e>>2]=b+1;t[b|0]=g;f=0;if((a|0)>84){break b}v[k>>2]=v[k>>2]+1}return f}return-1}function G2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb+-64|0;hb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Ef(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){g=v[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(d>>>0>v[c+24>>2]-h>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=B(b,f);l=B(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[(a+l<<2)+i>>2]=A[(a+k<<3)+j>>3];a=a+1|0;continue}}}aa(7192,9074,77,8754);L()}aa(7157,9074,78,8754);L()}aa(5900,9074,79,8754);L()}aa(5870,9074,80,8754);L()}hb=c- -64|0}function lP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;b=v[a>>2];cc(g+8|0,b);a:{b:{c:{d:{e:{if(vd(v[b+16>>2])){while(1){if(c>>>0>31){break e}v[23516]=0;d=ha(41)|0;e=v[23516];v[23516]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=V(93236)|0;if((O()|0)!=(ea(93236)|0)){break c}_(c|0)|0;t[b+20|0]=0;v[23516]=0;Y(29,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break d}$();break e}t[b+20|0]=0}if(!w[b+20|0]){d=v[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=v[d+2496>>2];e=d+(b<<2)|0;i=v[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=v[d+(h<<2)>>2];b=i^(b&2147483647|v[e>>2]&-2147483648)>>>1^B(b&1,-1727483681);v[e>>2]=b;v[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}hb=g+16|0;break a}c=P()|0;O()|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)==1){break b}}S(c|0);L()}V(0)|0;O()|0;Tb();L()}return v[a+28>>2]&f}function cA(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=hb-32|0;hb=i;LR(a,b);h=hb-16|0;hb=h;jd(c,1);g=Eb(w[b+22|0]|w[b+23|0]<<8)<<1;v[c>>2]=g;t[c+37|0]=w[b+24|0]<<4;t[h+15|0]=w[b+25|0];t[h+14|0]=64;l=c,m=w[Vb(h+15|0,h+14|0)|0]<<2,u[l+30>>1]=m;f=Eb(w[b+26|0]|w[b+27|0]<<8);a=f<<1;k=Eb(w[b+28|0]|w[b+29|0]<<8);j=k<<1;a=k>>>0>=2?a+j>>>0<=g>>>0?a:f+j>>>0>g>>>0?a:f:a;a:{b:{switch(g|0){case 2:v[c>>2]=0;break a;case 0:break a;default:break b}}v[c+4>>2]=a;f=a+j|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}u[c+34>>1]=x[c+34>>1]|2}hb=h+16|0;xl(i,3,b);a=i+16|0;Cc(a,i);c=Ac(d,a);wb(a);d=0;while(1){if((d|0)!=32){a=c+d|0;if((w[a|0]-1&255)>>>0<=30){t[a|0]=32}d=d+1|0;continue}break}a=eA(b);hb=i+32|0;return a}function RE(a,b,c,d,e,f,g,h){var i=0,j=0,k=C(0);i=hb-96|0;hb=i;iy(v[a+24>>2]);t[v[a+24>>2]+1298420|0]=v[a+52>>2]!=0;v[i+92>>2]=f;v[i+88>>2]=e;v[i+84>>2]=d;v[i+80>>2]=c;a:{d=i+80|0;c=0;while(1){b:{if((c|0)!=4){if(v[(c<<2)+d>>2]){break b}}else{c=4}break a}c=c+1|0;continue}}v[i+40>>2]=b;v[i+36>>2]=c;v[i+32>>2]=d;e=v[a+32>>2];k=z[a+48>>2];v[i+8>>2]=b;c=v[i+36>>2];v[i>>2]=v[i+32>>2];v[i+4>>2]=c;d=hb-16|0;hb=d;v[d+8>>2]=v[i+8>>2];c=v[i+4>>2];v[d>>2]=v[i>>2];v[d+4>>2]=c;c=$I(i+48|0);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=h;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=k;v[c>>2]=g;hb=d+16|0;while(1){if(b){d=v[a+24>>2];v[i+24>>2]=b;v[i+28>>2]=0;v[i+16>>2]=134217727;v[i+20>>2]=0;d=bJ(d,v[Qq(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|j)){a=v[a+24>>2];v[a+480208>>2]=v[a+480208>>2]&-513}hb=i+96|0;return j}function FX(){var a=0,b=0,c=0,d=0;c=hb-32|0;hb=c;a:{a=Fc(c+16|0,14901);if(!Fb(a)){break a}b:{if((Cg(a,14732)|0)!=-1){b=Cg(a,14732);v[23516]=0;X(128,c|0,a|0,b+1|0,-1);b=v[23516];v[23516]=0;if((b|0)==1){break b}yc(a,c);wb(c)}if((Cg(a,16896)|0)!=-1){b=Cg(a,16896);v[23516]=0;X(128,c|0,a|0,b+1|0,-1);b=v[23516];v[23516]=0;if((b|0)==1){break b}yc(a,c);wb(c)}if((Cg(a,13945)|0)!=-1){b=Cg(a,13945);v[23516]=0;X(128,c|0,a|0,0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break b}yc(a,c);wb(c)}if((Cg(a,13794)|0)!=-1){b=Cg(a,13794);v[23516]=0;X(128,c|0,a|0,0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break b}yc(a,c);wb(c)}if((Cg(a,13837)|0)!=-1){b=Cg(a,13837);v[23516]=0;X(128,c|0,a|0,0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break b}yc(a,c);wb(c)}v[23516]=0;b=T(129,a|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;wb(a);S(c|0);L()}wb(a);hb=c+32|0;return b|0}function Q2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb+-64|0;hb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Ef(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(d>>>0>v[c+24>>2]-g>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=B(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{z[v[(a<<2)+h>>2]+(j<<2)>>2]=A[(a+k<<3)+i>>3];a=a+1|0;continue}}}aa(7192,9074,77,8754);L()}aa(7157,9074,78,8754);L()}aa(5900,9074,79,8754);L()}aa(5870,9074,80,8754);L()}hb=c- -64|0}function $l(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Uk(a);a:{b:{c:{f=v[b+32>>2];d:{if(!f){e=v[b+2084>>2];if(e){break d}break b}c=v[b+4>>2];if((c|0)<9){break c}e=v[b+2084>>2];if(!e){break c}}h=v[a+1392>>2];j=_l(h);d=v[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=y[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}v[a+1392>>2]=h>>>b;b=d-b|0}v[a+1396>>2]=b;return c}if(w[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=w[v[b+8>>2]+d|0];if((c|0)==255){break f}g=v[a+1392>>2];if(v[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=v[a+1396>>2];if((e|0)>=(c|0)){v[a+1392>>2]=g>>>c;v[a+1396>>2]=e-w[v[b+8>>2]+d|0];return d}v[a+1396>>2]=0;break b}d=d+1|0;continue}break}bc(a,21);v[a+1396>>2]=0}return-1}aa(11414,13226,1705,5448);L()}function AW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-96|0;hb=d;xc(b);Ro(a);a:{if(!lv(b,d+56|0)){break a}if(!aD(d+56|0)){break a}b:{if(!c){break b}if(!Ob(v[b>>2],v[b+8>>2],_b(v[d+60>>2])-28|0)){break a}Bv(a);g=d,h=Av(),v[g+32>>2]=h;e=d+32|0;zv(Rj(v[a+4>>2])+32|0,e);hr(e);c=v[Rj(v[a+4>>2])+32>>2];v[23516]=0;R(189,e|0,b|0);b=v[23516];v[23516]=0;c:{if((b|0)==1){break c}b=v[d+32>>2];e=v[d+60>>2];f=v[d+68>>2];v[23516]=0;b=fa(190,b|0,_b(e)-28|0,c|0,_b(f)|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}e=0;if(!b){break a}oe(d+16|0,v[c>>2],v[c+4>>2]);Vg(d+24|0,v[d+16>>2],v[d+20>>2]);b=ce(d+8|0);b=fr(d+32|0,v[d+24>>2],v[d+28>>2],v[b>>2],v[b+4>>2]);cd(Rj(v[a+4>>2])+12|0,b);yb(b);break b}a=Ea(92664,26232)|0;b=O()|0;d:{if((ea(92664)|0)==(b|0)){break d}if((ea(26232)|0)==(b|0)){break d}S(a|0);L()}_(a|0)|0;$();e=0;break a}e=1}hb=d+96|0;return e|0}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;e=hb-16|0;hb=e;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){f=v[e+8>>2];m=(((v[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=u[b+14>>1];o=u[b+12>>1];p=u[b+10>>1];q=u[b+8>>1];r=u[b+6>>1];s=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];f=0;while(1){if((f|0)!=2){b=f+m|0;v[(f<<2)+e>>2]=(((((B(t[b+4|0],p)+B(t[b+2|0],q)|0)+B(t[b+6|0],o)|0)+B(t[b+8|0],n)<<8)/2|0)+((((B(t[b-4|0],w)+B(t[b-6|0],x)|0)+B(t[b-2|0],s)|0)+B(t[b|0],r)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g);Pb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;hb=e+16|0}function Sda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=hb-32|0;hb=g;d=hb-16|0;hb=d;c=a+33|0;v[b>>2]=w[c+206|0]|w[c+207|0]<<8;OL(c,b+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);OL(c,b+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);f=b+236|0;while(1){if((e|0)==96){if(w[c+208|0]){t[b+31|0]=w[c+209|0]+1;f=w[b+31|0];a:{b:{if(!f){e=1;break b}e=16;if(f>>>0<17){break a}}t[b+31|0]=e}u[d+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[d+12>>1]=127;i=b,j=w[Rc(d+14|0,d+12|0)|0]+1|0,t[i+30|0]=j}t[b+33|0]=w[c+212|0];hb=d+16|0}else{i=$b(f,e+12|0),j=w[c+e|0],u[i>>1]=j;e=e+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){f=$b(e,h+12|0);d=w[c+h|0];u[f>>1]=d>>>0<(w[a+27|0]|w[a+28|0]<<8)>>>0?d:0;h=h+1|0;continue}break}xl(g,3,a+4|0);c=g+16|0;Cc(c,g);Ac(b+492|0,c);wb(c);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}hb=g+32|0}function bQ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;f=hb-16|0;hb=f;n=v[a+20>>2];g=x[a+34>>1]&65;v[f+8>>2]=g;v[f>>2]=g^65;g=b;i=a+24|0;o=d+1298224|0;e=d+1074992|0;j=jj(d);p=a+4|0;q=a+12|0;r=a+8|0;s=a+16|0;t=d+480180|0;while(1){if((e|0)!=(o|0)){if(v[e+104>>2]==(a|0)){if(v[e+16>>2]){v[e+16>>2]=g}if(y[e+4>>2]>c>>>0){v[e>>2]=0;v[e+4>>2]=0}b=a;if(v[e+76>>2]){uc(e+76|0,c);b=v[e+104>>2]}d=v[e+88>>2];b=YC(d,b);h=v[(b?q:p)>>2];v[e+84>>2]=v[(b?s:r)>>2];v[e+80>>2]=h;b=d|v[f+8>>2];v[e+88>>2]=b;v[e+88>>2]=b&(v[f>>2]^-1);b=e+704|0;h=v[a+24>>2];a:{if(!v[e+704>>2]|!h){break a}if(Am(v[t>>2])){break a}d=v[(j?b:i)>>2];k=rka(v[(j?i:b)>>2],0,v[e+700>>2],0);l=k+(d>>>1|0)|0;m=kb;u=e,w=Bc(uka(l,k>>>0>l>>>0?m+1|0:m,d,0),kb),v[u+700>>2]=w}v[b>>2]=h}e=e+872|0;continue}break}v[a>>2]=c;v[a+20>>2]=g;sz(n);hb=f+16|0}function UC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-32|0;hb=c;v[23516]=0;e=Q(13,c+24|0,467192)|0;d=v[23516];v[23516]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!w[e|0]){break e}f=Jm(c+8|0,467192);d=v[v[116798]-12>>2]+467192|0;g=v[d+4>>2];v[23516]=0;h=T(14,d|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break d}f=v[f>>2];v[23516]=0;b=a+b|0;a=ka(15,f|0,a|0,((g&176)==32?b:a)|0,b|0,d|0,h|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break d}v[c+16>>2]=a;if(!Qu(c+16|0)){break e}a=v[v[116798]-12>>2];v[23516]=0;R(16,a+467192|0,5);a=v[23516];v[23516]=0;if((a|0)!=1){break e}break d}tk(e);break b}a=V(0)|0;O()|0;tk(e);break c}a=V(0)|0;O()|0}_(a|0)|0;a=v[v[116798]-12>>2];v[23516]=0;Y(17,a+467192|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$()}hb=c+32|0;return}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){V(0)|0;O()|0;Tb();L()}S(a|0);L()}function JB(a){var b=0,c=0,d=0,e=0,f=0,g=0;if((w[a|0]-16&255)>>>0>=241){e=a+1954|0;c=a+1698|0;a:{b:{while(1){if((c|0)==(e|0)){c=0;e=0;while(1){b=32;if((c|0)==32){break a}d=B(c,13)+a|0;if(w[d+14|0]){break b}b=(c<<4)+a|0;if(w[b+418|0]|w[b+419|0]<<8|(w[b+420|0]<<16|w[b+421|0]<<24)){break b}f=w[b+422|0]|w[b+423|0]<<8|(w[b+424|0]<<16|w[b+425|0]<<24);if(w[d+942|0]|f>>>0>1048575){break b}d=B(c,11)+a|0;g=d+1346|0;if(w[g|0]>15|w[d+1351|0]>3|w[d+1356|0]>3){break b}c:{d:{if(f){d=w[b+430|0]|w[b+431|0]<<8|(w[b+432|0]<<16|w[b+433|0]<<24);if(d>>>0<=1048574&(d>>>0<(w[b+426|0]|w[b+427|0]<<8|(w[b+428|0]<<16|w[b+429|0]<<24))>>>0|d>>>0>f>>>0)){break b}b=1;if(e){break c}break d}b=1;if(e){break c}if(Qb(g,26429,11)){break d}b=0;break c}b=1}e=b;c=c+1|0;continue}}b=t[c|0];c=c+1|0;if((b|0)>=-1){continue}break}return 0}b=c}a=b>>>0>31&e}else{a=0}return a}function kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;e=Kb(d+16|0);a:{b:{c:{if(c>>>0<64){break c}v[23516]=0;c=T(187,b|0)|0;f=v[23516];v[23516]=0;d:{if((f|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[23516]=0;Q(53,a|0,21751)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break b}}break a}v[23516]=0;c=T(200,b|0)|0;f=v[23516];v[23516]=0;if((f|0)!=1){g=d,h=Di(c),v[g+8>>2]=h;c=v[od(d+12|0,d+8|0)>>2];v[23516]=0;R(44,e|0,c|0);c=v[23516];v[23516]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{v[23516]=0;c=T(204,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break f}if(!c){break e}v[23516]=0;W(867,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[23516];v[23516]=0;if((c|0)!=1){continue}}break}break a}v[23516]=0;Q(186,b|0,4)|0;b=v[23516];v[23516]=0;if((b|0)==1){break a}Xc(a,e)}wb(e);hb=d+32|0;return}a=P()|0;O()|0;wb(e);S(a|0);L()}function Hp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;f=rka(b,d,5e4,0);e=kb;b=v[Vc(c+8|0,c)>>2];b=Dc(ska(f,e,b,b>>31),kb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=rka(v[a+1074420>>2],0,rka(v[a+1074408>>2],0,v[a+1074416>>2],0),kb),v[g>>2]=h;v[c+4>>2]=kb;b=rka(b,0,6e5,0);d=c+8|0;e=b;f=kb;b=av(v[d>>2],v[d+4>>2],v[c>>2],v[c+4>>2])?c:d;b=uka(e,f,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];f=rka(b,d,1e4,0);e=kb;b=v[Vc(c+8|0,c)>>2];b=Dc(ska(f,e,b,b>>31),kb);v[a+1074404>>2]=b}e=a+1074404|0;a=v[a+480244>>2];b=rka(a,a>>31,b,b>>31)+32768|0;a=kb;a=Dc(ska(b,b>>>0<32768?a+1|0:a,65536,0),kb);v[e>>2]=a?a:1;hb=c+16|0}function tK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0;o(+a);b=j(1)|0;c=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){e=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|c)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(e>>>0>2146435071){break a}b=1072693248;k=-1023;if((e|0)!=1072693248){b=e;break b}if(c){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;c=j(0)|0;k=-1077}l(0,c|0);c=b+614242|0;l(1,(c&1048575)+1072079006|0);d=+n()+-1;f=d*(d*.5);g=d/(d+2);h=g*g;a=h*h;o(+(d-f));b=j(1)|0;j(0)|0;l(0,0);l(1,b|0);i=+n();m=i*1.4426950407214463;p=+((c>>>20|0)+k|0);q=m+p;a=g*(f+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+h*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(d-i-f);a=q+(m+(p-q)+((a+i)*1.6751713164886512e-10+a*1.4426950407214463))}return a}function kK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=C(0);d=a+4208|0;j=C(C(z[Bb(d,2)>>2]*C(2999.9990234375))+C(.0010000000474974513));l=C(z[Bb(d,3)>>2]*C(.9980000257492065));f=-3e3/+C(j*C(y[v[a+16>>2]+24620>>2]));h=a+4272|0;c=$j(10,f*+y[Bb(h,4)>>2]);d=a+4232|0;o=Bb(d,0),p=C(c),z[o>>2]=p;c=$j(10,f*+y[Bb(h,5)>>2]);o=Bb(d,1),p=C(c),z[o>>2]=p;m=f*(1/+C(l+C(.0010000000474974513))+-1);c=0;while(1){if((e|0)==4){e=a+4208|0;f=$j(10,+iK(z[Bb(e,0)>>2])*.05);b=4/K(c)*f;c=$j(10,+iK(z[Bb(e,1)>>2])*.1);z[a+4228>>2]=b*K(c);z[a+4224>>2]=f*K(1-c)}else{g=Bb(h,e);k=e>>>1|0;n=v[Bb(h,k+4|0)>>2];g=v[g>>2];i=$j(10,m*+(n+g>>>0));b=$j(10,f*+(g>>>0));j=z[Bb(d,k)>>2];g=e<<1;i=(1-i)*.5;o=Bb(d,g+2|0),p=C(b*(1-i)),z[o>>2]=p;o=Bb(d,g+3|0),p=C(b*i),z[o>>2]=p;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;e=e+1|0;continue}break}}function dn(a,b,c,d){var e=0,f=0;f=hb-16|0;hb=f;v[23516]=0;Y(966,a|0);e=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=v[a+24>>2];v[23516]=0;R(d|0,f|0,e|0);d=v[23516];v[23516]=0;if((d|0)==1){break i}d=v[f>>2];e=ud(d,v[f+4>>2]);if(e>>>0<2147483647){break h}d=ba(8)|0;v[23516]=0;b=Q(1021,d|0,7389)|0;e=v[23516];v[23516]=0;if((e|0)==1){break g}v[23516]=0;U(117,b|0,93012,166);b=v[23516];v[23516]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=fg(21751);break j}b=fg(Ic(Jd(d,b)))}Me(f);break d}b=V(0)|0;O()|0;ca(d|0)}Me(f)}_(b|0)|0;b=0;v[23516]=0;X(953,c|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break c}$()}hb=f+16|0;return b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Tb()}L()}S(a|0);L()}function b6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[23516]=0;Y(967,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break g}v[23516]=0;Y(967,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break g}f=v[a+24>>2];v[23516]=0;d=Q(53,e+16|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break g}v[23516]=0;c=Q(53,e|0,c|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break f}v[23516]=0;X(982,f|0,d|0,c|0,1);b=v[23516];v[23516]=0;if((b|0)==1){break e}wb(c);wb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;wb(c)}wb(d)}_(b|0)|0;b=0;v[23516]=0;X(953,6412,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$()}hb=e+32|0;return b|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function YH(a,b,c,d){var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=hb-96|0;hb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=z[g+4>>2];f=z[g+8>>2];z[i+4>>2]=h+f;k=d<<1;z[(8-k<<2)+e>>2]=h-f;h=z[g+16>>2];f=z[g+12>>2];z[(7-k<<2)+e>>2]=h-f;z[i+8>>2]=-C(h+f);d=d+1|0;continue}break}XH(e+48|0);XH(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=z[i>>2];f=z[d+(e+48|0)>>2];l=z[d+71424>>2];m=z[d+71460>>2];n=z[d+e>>2];z[i>>2]=C(f*l)-C(m*n);i=a+d|0;d=c+d|0;f=C(C(f*m)+C(n*l));z[i>>2]=C(h*z[d>>2])-C(z[d+36>>2]*f);z[(17-g<<2)+a>>2]=C(h*z[d+36>>2])+C(f*z[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}hb=e+96|0}function RT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!w[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=w[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?(w[d-1|0]==13&(i|0)==10)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&w[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}_f(a);kt(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=t[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}Wp(a,e);c=c+1|0;continue}break}}function BV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;jd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Jq(a+4|0,a);d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=d;c=Jq(a+8|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=f;c=(w[a+15|0]|w[a+16|0]<<8)<<1;v[b+24>>2]=c;c=w[a+15|0]|w[a+16|0]<<8?c:16726;v[b+24>>2]=c;g=b,h=(B(Ku(t[a+17|0],w[a+14|0]<<28>>24),c)>>>0)/8363|0,v[g+24>>2]=h;t[e+15|0]=w[a+18|0];t[e+14|0]=127;g=b,h=(((w[Vb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[g+30>>1]=h;c=w[a+14|0];if(c>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=c&240}c=w[a+19|0];if(c&4){u[b+34>>1]=x[b+34>>1]|1;c=w[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=x[b+34>>1];d=f|2;u[b+34>>1]=d;c=w[a+19|0];if(c&16){d=f|6;u[b+34>>1]=d;c=w[a+19|0]}if(!(c&64)){break a}u[b+34>>1]=d|128}hb=e+16|0}function N3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb+-64|0;hb=e;a:{b:{if((b|0)>=0){d=v[a+24>>2];if(qj(Sb(v[d+484360>>2],w[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=v[a+24>>2];g=v[f+484344>>2];i=v[f+484348>>2];h=x[$b(v[Sb(v[f+484360>>2],w[f+484376|0])>>2],b)>>1];if(!Hm(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<v[Xb(g,h)+12>>2]){break c}}a=a+16|0;break a}u[f+1074448>>1]=b;c=f;f=b&65535;lM(c,f);c=v[a+24>>2];v[c+1074392>>2]=-2;v[c+1074428>>2]=d;g=w[a+64|0];b=e+24|0;u[b+4>>1]=0;t[b+6|0]=255;v[b+16>>2]=2;v[b>>2]=0;v[b+8>>2]=d;u[b+12>>1]=f;d=v[b+20>>2];v[e+16>>2]=v[b+16>>2];v[e+20>>2]=d;d=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=d;d=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=d;b=e+48|0;Jt(b,c,g?7:1,e);j=a,k=A[eM(v[e+52>>2])>>3],A[j+16>>3]=k;Ci(b);a=a+16|0}hb=e- -64|0;return+A[a>>3]}function OL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=hb-16|0;hb=k;t[k+15|0]=c;t[k+14|0]=12;Mg(b,w[Vb(k+15|0,k+14|0)|0]);c=0;l=v[b>>2];m=v[b+4>>2];p=Qd(l,m);while(1){if((c|0)==(p|0)){c=0;t[b+12|0]=0;a:{if(!(d&1)){break a}if(nc(l,m)){break a}c=1;t[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;t[b+12|0]=c}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=c|2}t[b+14|0]=g;t[b+13|0]=f}hb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=Bb(l,c);i=(c<<2)+a|0;u[j>>1]=w[i+96|0]|w[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=Bb(l,c);i=(c<<2)+a|0;u[j>>1]=w[i+144|0]|w[i+145|0]<<8;i=i+146|0}t[j+2|0]=w[i|0]}e:{if(!c){break e}i=Bb(l,c);j=x[i>>1];n=Bb(l,c-1|0);o=x[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;u[i>>1]=j;if(j>>>0>=x[n>>1]){break e}u[i>>1]=j+256}c=c+1|0;continue}break}}function kN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;h=-1;a:{if(!ey(a,b,2)){break a}f=v[b+656>>2];g=a+1074312|0;Ab(e+8|0,g,31);b:{if(zb(v[v[e+8>>2]>>2],v[e+12>>2])){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}Ab(e+8|0,g,31);g=d-zb(v[v[e+8>>2]>>2],v[e+12>>2])|0;i=v[a+480180>>2];d=(i|0)==4096;j=f+88|0;f=d?64:(i|0)==16384?192:512;d=Xp(j,g,f,d?255:64)-(f>>>1|0)|0;if(w[b+746|0]&16){h=Rp(a,b,!(v[b+88>>2]&32768),d);break a}if(uj(v[b+656>>2])){if((d|0)==u[b+772>>1]){break a}k=b,l=$c(d),u[k+772>>1]=l;t[b+851|0]=w[b+851|0]|64;break a}a=jj(a);v[e+8>>2]=d;c:{if((d|0)<0){v[e+8>>2]=0-d;bi(e+8|0,255);a=(v[e+8>>2]<<2)+(a?38336:37312)|0;break c}bi(e+8|0,255);a=(v[e+8>>2]<<2)+(a?37312:38336)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];k=c,l=Dc(ska(rka(b,d,a,a>>31),kb,65536,0),kb),v[k>>2]=l}hb=e+16|0;return h}function Tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=hb-16|0;hb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){f=v[b+8>>2];n=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;o=u[e+39894>>1];p=u[e+39892>>1];q=u[e+39890>>1];r=u[e+39888>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;v[(e<<2)+b>>2]=(((B(u[f>>1],q)+B(u[f-4>>1],r)|0)+B(u[f+4>>1],p)|0)+B(u[f+8>>1],o)|0)/16384;e=e+1|0;continue}break}h=h+k|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=g+j|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;hb=b+16|0}function U9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;jd(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;v[c>>2]=w[a+40|0]|w[a+41|0]<<8|(w[a+42|0]<<16|w[a+43|0]<<24);v[c+4>>2]=w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24);v[c+8>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[c+24>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);d=w[b+151|0];if(d>>>0<=4){t[c+38|0]=w[d+42890|0]}d=w[b+152|0]|w[b+153|0]<<8;t[c+39|0]=d;e=(w[b+156|0]|w[b+157|0]<<8)>>>4|0;t[c+41|0]=e;b=(w[b+154|0]|w[b+155|0]<<8)>>>2|0;t[c+40|0]=b;if((b|e)&255){t[c+39|0]=d^-1}b=w[a+38|0]|w[a+39|0]<<8;if(b&4){u[c+34>>1]=x[c+34>>1]|1;b=w[a+38|0]|w[a+39|0]<<8}if(b&8){u[c+34>>1]=x[c+34>>1]|2;b=w[a+38|0]|w[a+39|0]<<8}if(b&16){u[c+34>>1]=x[c+34>>1]|4;b=w[a+38|0]|w[a+39|0]<<8}if(b&32){u[c+34>>1]=x[c+34>>1]|32}}function Gaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-880|0;hb=b;c=Rb(a,0,76);v[c+84>>2]=0;v[c+88>>2]=0;v[c+80>>2]=256;u[c+76>>1]=65535;v[c+92>>2]=0;v[c+96>>2]=0;t[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=UP(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Lb(d);g=Dy(c+223860|0);f=b+8|0;Rb(f,0,108);Ez(b+120|0,48e3);Rb(b+664|0,0,72);t[b+754|0]=0;u[b+752>>1]=65535;t[b+746|0]=0;u[b+744>>1]=65535;t[b+738|0]=0;u[b+736>>1]=65535;v[b+748>>2]=0;v[b+740>>2]=0;Rb(b+756|0,0,103);v[b+868>>2]=0;v[b+872>>2]=0;t[b+875|0]=0;t[b+876|0]=0;t[b+877|0]=0;t[b+878|0]=0;v[b+860>>2]=0;v[b+864>>2]=0;t[b+859|0]=w[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=Mp(e,f)+872|0;continue}break}v[23516]=0;R(547,d|0,32);a=v[23516];v[23516]=0;if((a|0)!=1){hb=b+880|0;return c|0}a=P()|0;O()|0;Op(g);dc(d);S(a|0);L()}function zy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=x[a+480188>>1];h=d>>>0>256?d:256;f=v[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=B(c,872)+a|0;if(!v[e+1075068>>2]){if(!lj(v[e+1075648>>2])|w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!vd(f)){break a}if(!TM(f,c&65535)){break a}}c=c+1|0;continue}break}e=0;f=65535;g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){c=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}while(1){if((d|0)==(h|0)){c=f;break a}b=B(d,872)+a|0;if(!(v[b+1075688>>2]?0:v[b+1075068>>2])){c=(v[b+1075680>>2]|v[b+1075672>>2]<<9)>>>(v[b+1075080>>2]>>>1&1)|0;b:{c:{if(c>>>0<g>>>0){b=v[(B(d,872)+a|0)+1075716>>2];break c}if((c|0)!=(g|0)){break b}b=v[(B(d,872)+a|0)+1075716>>2];if(e>>>0>=b>>>0){break b}}g=c;f=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function b7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=ui(a,b,c,d);v[c+4260>>2]=0;v[c>>2]=46924;b=c+4960|0;d=c+4504|0;a=d;while(1){a=Lb(a)+24|0;if((b|0)!=(a|0)){continue}break}t[c+5046|0]=1;u[c+5044>>1]=0;a=c+4208|0;e=Bb(a,0),f=1063675494,v[e>>2]=f;e=Bb(a,1),f=1065185444,v[e>>2]=f;e=Bb(a,2),f=0,v[e>>2]=f;e=Bb(a,3),f=1032805417,v[e>>2]=f;e=Bb(a,4),f=1053079357,v[e>>2]=f;e=Bb(a,5),f=1059859440,v[e>>2]=f;e=Bb(a,6),f=1047457519,v[e>>2]=f;e=Bb(a,7),f=1062836634,v[e>>2]=f;e=Bb(a,8),f=1038174126,v[e>>2]=f;e=Bb(a,9),f=1065353216,v[e>>2]=f;e=Bb(a,10),f=1065353216,v[e>>2]=f;e=Bb(a,11),f=1048525618,v[e>>2]=f;e=Bb(a,12),f=1059760811,v[e>>2]=f;v[23516]=0;R(917,c+44|0,2);a=v[23516];v[23516]=0;if((a|0)==1){a=P()|0;O()|0;while(1){b=lc(b-24|0);if((d|0)!=(b|0)){continue}break}Ff(c);S(a|0);L()}ti(c);return c|0}function UH(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=v[a+32>>2];a:{b:{b=v[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=v[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=w[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(y[a+40>>2]<c>>>0){bc(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=v[a+40>>2];if(e>>>0<=c+26>>>0){bc(a,1);break a}if(Qb(c,93576,4)){bc(a,21);break a}if(w[c+4|0]){bc(a,21);break a}d:{if(d){if(!v[a+992>>2]|!(t[c+5|0]&1)){break d}bc(a,21);break a}if(t[c+5|0]&1){break d}bc(a,21);break a}b=0;f=c+27|0;d=w[c+26|0];c=f+d|0;if(e>>>0<c>>>0){bc(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=w[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}bc(a,1)}return 0}function Hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;c=nf(a,c);ke(f,v[a+36>>2]);a:{if(!c){b:{Pc(f,a+32|0,5);if(!zb(v[v[f>>2]>>2],v[f+4>>2])){break b}break a}}d=hb-32|0;hb=d;g=v[a+36>>2];Wf(g,d+30|0);c:{d:{e:{f:{e=x[d+30>>1];if(e>>>0>=4001){i=v[b+12>>2];e=hb-16|0;hb=e;h=vc(e,16028);Xc(d,h);xb(h);hb=e+16|0;v[23516]=0;U(487,d+16|0,d|0,d+30|0);e=v[23516];v[23516]=0;if((e|0)==1){break f}e=v[i+1298464>>2];v[23516]=0;U(384,e|0,2,d+16|0);e=v[23516];v[23516]=0;if((e|0)==1){break e}xb(d+16|0);ac(d);e=4e3}tg(wj(v[b>>2],0),e);b=wj(v[b>>2],0);j=d,k=Cb(v[b>>2]),v[j+16>>2]=k;b=Cb(v[b+4>>2]);break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;xb(d+16|0)}ac(d);S(a|0);L()}while(1){e=v[d+16>>2];if(Nb(e,b)){Wf(g,d);u[e>>1]=x[d>>1];Qe(d+16|0);continue}break}hb=d+32|0;d=c}Ve(a,d);hb=f+16|0}function _E(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-48|0;hb=d;v[23516]=0;Y(966,a|0);e=v[23516];v[23516]=0;a:{b:{c:{if((e|0)!=1){e=Kb(d+32|0);v[23516]=0;Y(c|0,d+16|0);c=v[23516];v[23516]=0;d:{e:{if((c|0)!=1){h=d,i=Cb(v[d+16>>2]),v[h+8>>2]=i;f=1;while(1){g=Cb(v[d+20>>2]);c=v[d+8>>2];if(!Nb(c,g)){c=fg(Ic(e));Me(d+16|0);wb(e);break b}if(!f){v[23516]=0;Q(955,e|0,14707)|0;c=v[23516];v[23516]=0;if((c|0)==1){break e}c=v[d+8>>2]}v[23516]=0;Q(820,e|0,c|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break e}gq(d+8|0);f=0;continue}}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Me(d+16|0)}wb(e);break c}c=V(0)|0;O()|0}_(c|0)|0;c=0;v[23516]=0;X(953,b|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$()}hb=d+48|0;return c}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){V(0)|0;O()|0;Tb();L()}S(a|0);L()}function gG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=hb-32|0;hb=h;a:{b:{c:{if((b|0)!=(c|0)){j=v[115992];v[115992]=0;g=hb-16|0;hb=g;Dd();e=hb-16|0;hb=e;f=hb-16|0;hb=f;uw(f,b,h+28|0,2);k=v[f>>2];i=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=i;hb=f+16|0;i=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=i;v[g+4>>2]=f;hb=e+16|0;f=v[g>>2];e=v[g+4>>2];b=v[g+12>>2];v[h+16>>2]=v[g+8>>2];v[h+20>>2]=b;v[h+8>>2]=f;v[h+12>>2]=e;hb=g+16|0;i=v[h+16>>2];f=v[h+20>>2];g=v[h+8>>2];e=v[h+12>>2];b=v[115992];if(!b){break c}if(v[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[115992]=j;if(v[h+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;i=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=i;v[a+12>>2]=f;hb=h+32|0}function tt(a,b){var c=0,d=0,e=0,f=0;e=hb-48|0;hb=e;d=e+24|0;XP(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);XP(e,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=v[d>>2];b=Eb(w[b|0]|w[b+1|0]<<8);a=v[e>>2];a=Eb(w[a|0]|w[a+1|0]<<8);c=1;a:{if(b>>>0<a>>>0){break a}c=0;if(a>>>0<b>>>0){break a}b=v[d+4>>2];b=Eb(w[b|0]|w[b+1|0]<<8);a=v[e+4>>2];a=Eb(w[a|0]|w[a+1|0]<<8);c=1;b:{if(b>>>0<a>>>0){break b}c=0;if(a>>>0<b>>>0){break b}b=v[d+8>>2];b=Eb(w[b|0]|w[b+1|0]<<8);a=v[e+8>>2];a=Eb(w[a|0]|w[a+1|0]<<8);c=1;c:{if(b>>>0<a>>>0){break c}c=0;if(a>>>0<b>>>0){break c}b=v[d+16>>2];a=v[e+12>>2];f=v[e+16>>2];d=v[d+12>>2];d=ne((w[d|0]|w[d+1|0]<<8)<<16>>16);a=ne((w[a|0]|w[a+1|0]<<8)<<16>>16);c=1;d:{if((d|0)<(a|0)){break d}c=0;if((a|0)<(d|0)){break d}c=Eb(w[b|0]|w[b+1|0]<<8)>>>0<Eb(w[f|0]|w[f+1|0]<<8)>>>0}}}}a=c;hb=e+48|0;return a}function s9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-16|0;hb=f;j=nf(a,c);ke(f,v[a+36>>2]);k=a;a:{if(!j){Pc(f,a+32|0,5);c=0;if(zb(v[v[f>>2]>>2],v[f+4>>2])){break a}}e=hb-48|0;hb=e;h=v[a+36>>2];Ck(h,e+40|0);c=v[e+44>>2];if(!c&y[e+40>>2]>=257|c){v[e+40>>2]=256;v[e+44>>2]=0}l=v[e+40>>2];m=v[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=l>>>0){break b}Wf(h,e+38|0);g=Kb(e+24|0);v[23516]=0;Q(494,h|0,g|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){v[23516]=0;U(11,e+8|0,d|0,g|0);a=v[23516];v[23516]=0;if((a|0)==1){break e}v[23516]=0;a=Q(908,b|0,e+38|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break d}i=a;a=e+8|0;Gb(i,a);xb(a);wb(g);c=c+1|0;continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;xb(e+8|0)}wb(g);S(c|0);L()}hb=e+48|0;c=j}Ve(k,c);hb=f+16|0}function Uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=hb-16|0;hb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){f=v[b+8>>2];n=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;o=u[e+39894>>1];p=u[e+39892>>1];q=u[e+39890>>1];r=u[e+39888>>1];e=0;while(1){if((e|0)!=2){f=e+n|0;v[(e<<2)+b>>2]=(((B(t[f|0],q)+B(t[f-2|0],r)|0)+B(t[f+2|0],p)|0)+B(t[f+4|0],o)<<8)/16384;e=e+1|0;continue}break}h=h+k|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=g+j|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;hb=b+16|0}function dv(a,b,c,d){var e=0,f=0,g=0,h=0;g=hb-16|0;hb=g;a:{if(!c){break a}if(d){b=fc(g+8|0,a,b);a=hb-16|0;hb=a;v[a+12>>2]=c;d=v[b+4>>2];b:{if(!d){d=v[b>>2];break b}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];h=e;e=v[Hb(a+8|0,a+12|0)>>2];v[c>>2]=-1<<d&-1>>>h-e|v[c>>2];f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Rb(e,255,d);e=c&31;v[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+v[b>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]|-1>>>32-e}hb=a+16|0;break a}b=fc(g,a,b);a=hb-16|0;hb=a;v[a+12>>2]=c;d=v[b+4>>2];c:{if(!d){d=v[b>>2];break c}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];f=v[c>>2];h=e;e=v[Hb(a+8|0,a+12|0)>>2];v[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Rb(e,0,d);e=c&31;v[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+v[b>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-e^-1)}hb=a+16|0}hb=g+16|0}function Yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=hb-432|0;hb=d;xc(b);qA(b,d+376|0,d+296|0,d+8|0);k=d,l=rg((m=w[d+427|0]+1|0,n=1,o=_b(v[d+408>>2]),o?m:n)),t[k+4|0]=l;i=w[Vb(26976,d+4|0)|0];t[d+7|0]=i;u[d+4>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Eb(x[d+8>>1])<<16>>16;if(!((e|0)<0|w[d+291|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=_b(v[d+296>>2]);if(e>>>0<g>>>0){if(Zc(b,g)){break c}}t[d+7|0]=h+1;break b}}else{d:{if(!Zc(b,_b(v[d+392>>2])+(f<<2)|0)){break d}if(!Zc(b,uo(b))){break d}e:{if(!c){j=Je(b);break e}j=Ej(b)}u[d+2>>1]=j;k=d,l=x[ie(d+4|0,d+2|0)>>1],u[k+4>>1]=l}f=f+1|0;continue}break}g=_b(v[d+296>>2]);qA(b,d+376|0,d+296|0,d+8|0);h=h+1|0;continue}break}fv(a);break a}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}hb=d+432|0}
function eka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-48|0;hb=g;h=a+8|0;c=v[a+8>>2];j=zc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;e=v[a+4>>2];d=v[a>>2];if(e>>>0>d>>>0){a=e;d=((a-d>>1)+1|0)/-2<<1;e=a+d|0;while(1){if((a|0)!=(c|0)){e=cV(e,a)+2|0;a=a+2|0;continue}break}c=e;v[h>>2]=c;v[i>>2]=d+v[i>>2];break a}v[g+24>>2]=c-d;v[g+44>>2]=1;e=g+24|0;c=v[Vc(e,g+44|0)>>2];c=Jj(e,c,c>>>2|0,v[a+16>>2]);d=cc(g+16|0,v[a+4>>2]);f=v[cc(g+8|0,v[a+8>>2])>>2];e=hb-32|0;hb=e;d=v[d>>2];v[e+24>>2]=d;d=Io(e+8|0,c+8|0,xB(d,f));f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){k=f;f=v[e+24>>2];qo(k,w[f|0]|w[f+1|0]<<8);f=v[d>>2]+2|0;v[d>>2]=f;Qe(e+24|0);continue}break}Kd(d);hb=e+32|0;oc(a,c);oc(i,c+4|0);oc(h,c+8|0);oc(j,zc(c));Li(c);c=v[a+8>>2]}qo(c,w[b|0]|w[b+1|0]<<8);v[h>>2]=v[h>>2]+2;hb=g+48|0}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){b=(v[f+12>>2]<<1)+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(u[b+4>>1],u[e+10>>1])+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/2|0)+((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)/2|0)|0)/16384|0;h=h+l|0;v[c>>2]=v[c>>2]+B(b,h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Pb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;hb=f+16|0}function Dd(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(w[468004]){return v[117e3]}c=hb-32|0;hb=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=BG(a,d?14381:21751)}else{d=v[a<<2>>2]}v[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!AG(0)){b=89728;if(!Qb(c+8|0,89728,24)){break a}b=89752;if(!Qb(c+8|0,89752,24)){break a}a=0;if(!w[467776]){while(1){f=(a<<2)+467728|0,g=BG(a,21751),v[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}t[467776]=1;v[116938]=v[116932]}b=467728;if(!Qb(c+8|0,467728,24)){break a}b=467752;if(!Qb(c+8|0,467752,24)){break a}b=Md(24);if(!b){break b}}a=v[c+12>>2];v[b>>2]=v[c+8>>2];v[b+4>>2]=a;a=v[c+28>>2];v[b+16>>2]=v[c+24>>2];v[b+20>>2]=a;a=v[c+20>>2];v[b+8>>2]=v[c+16>>2];v[b+12>>2]=a;break a}b=0}hb=c+32|0;t[468004]=1;v[117e3]=b;return b}function oq(a,b){var c=0;c=hb-16|0;hb=c;a=Zq(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:ny(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Lf(a,107);break a;case 3:ny(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Lf(a,4);break a;case 2:break b;case 0:break c}}Mb(a,88,1);break a}ny(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}hb=c+16|0}function bK(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=hb-48|0;hb=j;k=v[a+4>>2];l=v[a>>2];a=v[a+8>>2];v[j+32>>2]=b;v[j+44>>2]=a;v[j+36>>2]=l;v[j+40>>2]=k;v[23516]=0;a=Q(946,(d?d:947)|0,e|0)|0;b=v[23516];v[23516]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+16>>2]=a;a=v[dg(j+24|0,j+16|0)>>2];b=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=b;v[23516]=0;b=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=b;c=+Aa(948,j|0,+c,a|0);a=v[23516];v[23516]=0;if((a|0)==1){break d}ze(j+16|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;ze(j+16|0)}_(a|0)|0;v[23516]=0;ja(949,15156,d|0,e|0,f|0,g|0,h|0,i|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();c=0}hb=j+48|0;return+c}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function b9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((Mj(v[a>>2],v[a+4>>2])|0)==2){if((Mj(v[a+12>>2],v[a+16>>2])|0)==(b|0)){break b}}v[23516]=0;R(919,a|0,2);c=v[23516];v[23516]=0;c:{if((c|0)==1){break c}v[23516]=0;R(919,a+12|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break c}v[23516]=0;R(920,a+24|0,2);c=v[23516];v[23516]=0;if((c|0)==1){break c}v[23516]=0;R(920,a+36|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=Wq(v[c+12>>2],a);f=Bb(v[c+36>>2],a),g=d,v[f>>2]=g;a=a+1|0;continue}}else{e=Wq(v[a>>2],d);f=Bb(v[a+24>>2],d),g=e,v[f>>2]=g;d=d+1|0;continue}}b=V(92664)|0;if((O()|0)!=(ea(92664)|0)){break a}_(b|0)|0;Gc(a);iL(a);b=a+12|0;Gc(b);iL(b);b=a+24|0;Gc(b);hL(b);a=a+36|0;Gc(a);hL(a);$()}return}S(b|0);L()}function t8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=hb-4112|0;hb=c;h=lb[v[v[a>>2]+120>>2]](a)|0;if(!h){lb[v[v[a>>2]+124>>2]](a)}v[c+12>>2]=0;f=hb-16|0;hb=f;while(1){d=v[a+44>>2];if(Mj(d,v[a+48>>2])>>>0<=e>>>0){hb=f+16|0}else{v[f+12>>2]=0;d=Wq(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){z[d>>2]=z[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){v[c+8>>2]=b;uc(c+8|0,512);e=c+16|0;ry(e);d=v[c+8>>2];lb[v[v[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[g>>2]);i=c,j=z[Ax(c+12|0,c+4|0)>>2],z[i+12>>2]=j;z[c+4>>2]=D(z[g+2048>>2]);i=c,j=z[Ax(c+12|0,c+4|0)>>2],z[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){lb[v[v[a>>2]+128>>2]](a)}hb=c+4112|0;return C(z[c+12>>2])}function nV(a,b,c){var d=0,e=0;e=hb-16|0;hb=e;t[e+15|0]=c;a:{if(b>>>0>35){break a}b:{c:{d:{e:{f:{d=w[b+26464|0];switch(d-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break f}}g:{if(d-6>>>0<2){break g}if((d|0)==31){break b}if((d|0)==11){break g}if((d|0)!=1){break a}d=(c|0)!=0;break a}b=c&240;if(!b|(b|0)==240|(c&15)==15){break a}t[e+15|0]=b;break a}if(c>>>0<=64){t[e+15|0]=c<<1;d=23;break a}t[e+15|0]=128;d=23;break a}d=19;h:{switch((c&240)-48>>>4|0){case 0:t[e+15|0]=159;d=20;break a;case 1:t[e+15|0]=192;d=20;break a;case 2:if(c&14){break a}t[e+15|0]=((c|0)!=80)<<6;d=21;break a;case 4:break h;default:break a}}t[e+15|0]=c&15|160;d=20;break a}d=c>>>0<32?16:17;break a}t[e+15|0]=(b<<5|c<<24>>>27)^128;d=31}ae(a,d,e+15|0);hb=e+16|0}function kL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;a:{if(sc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!Mh(v[v[b>>2]-12>>2]+b|0)){break a}d=hb-16|0;hb=d;f=tc(64);v[23516]=0;g=T(855,f|0)|0;h=v[23516];v[23516]=0;b:{c:{if((h|0)!=1){f=If(d,g);g=v[f>>2];v[23516]=0;g=W(914,g|0,b|0,c|0)|0;h=v[23516];v[23516]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}yf(d+8|0);break d}a=P()|0;O()|0;qg(f);break c}dg(d+8|0,f)}qg(f);hb=d+16|0;d=v[d+8>>2];break b}a=P()|0;O()|0;Jb(f)}S(a|0);L()}v[e+8>>2]=d;f:{g:{if(!vd(d)){v[23516]=0;b=Q(913,b|0,c|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break g}v[e>>2]=b;$S(e+8|0,_d(e));qg(e);d=v[e+8>>2]}if(!vd(d)){break f}v[23516]=0;R(496,a|0,e+8|0);a=v[23516];v[23516]=0;i=d;if((a|0)!=1){break f}}a=P()|0;O()|0;qg(e+8|0);S(a|0);L()}qg(e+8|0)}hb=e+16|0;return i}function k3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-32|0;hb=d;j=d,k=zJ(),v[j+24>>2]=k;g=a+24|0;c=d+24|0;xJ(g,_d(c));fj(c);u[a+28>>1]=0;GP();f=hb-16|0;hb=f;e=tc(144);v[23516]=0;h=Q(1081,e|0,4)|0;i=v[23516];v[23516]=0;a:{if((i|0)!=1){e=v[If(f+8|0,h)>>2];hb=f+16|0;break a}a=P()|0;O()|0;Jb(e);S(a|0);L()}v[d+24>>2]=e;wJ(a+32|0,_d(c));os(c);j=d,k=yJ(v[a>>2]),v[j+24>>2]=k;vJ(a+4|0,_d(c));ej(c);xn(v[g>>2],v[a+4>>2]);t[a+64|0]=1;v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;j=d,k=Ei(v[b>>2]),v[j+24>>2]=k;e=tf(b);b:{while(1){b=v[d+24>>2];if(!Fg(b,e)){break b}c=sd(b);b=yh(d+8|0,c);v[23516]=0;X(982,a|0,b|0,c+12|0,0);c=v[23516];v[23516]=0;if((c|0)!=1){wb(b);Ig(d+24|0);continue}break}a=P()|0;O()|0;wb(b);S(a|0);L()}hb=d+32|0}function pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){b=v[f+12>>2]+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(t[b+2|0],u[e+10>>1])+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/2|0)+((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])<<8)/2|0)|0)/16384|0;h=h+l|0;v[c>>2]=v[c>>2]+B(b,h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Pb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;hb=f+16|0}function md(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=v[a+112>>2];d=v[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=v[a+4>>2];e=v[a+44>>2];b=f-e|0;h=b;g=b+v[a+120>>2]|0;b=v[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=Bw(a);if((h|0)>=0){break a}f=v[a+4>>2];e=v[a+44>>2]}v[a+112>>2]=-1;v[a+116>>2]=-1;v[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=v[a+4>>2];e=v[a+8>>2];c=v[a+112>>2];g=v[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}v[a+104>>2]=e;c=v[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){t[f-1|0]=h}return h}function Kn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b+88>>2];d=c|2048;v[b+88>>2]=d;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){d=c|6144;v[b+88>>2]=d}a:{if(!v[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=v[b+104>>2];if(!c){break b}e=x[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;v[b+88>>2]=d;e=v[c>>2];v[b+76>>2]=e;g=v[c+4>>2];v[b+80>>2]=g;c=v[c+8>>2];v[b+84>>2]=c;if(c>>>0<e>>>0){v[b+76>>2]=c;h=c}else{h=e}e=v[b+4>>2];if(h>>>0>=e>>>0){break b}v[b>>2]=0;v[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;v[b+88>>2]=d;v[b+76>>2]=v[c>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=d|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}i=b,j=$c(Xp(f+48|0,v[b+724>>2],256,64)),u[i+728>>1]=j;i=b,j=x[Bb(v[f+48>>2],w[f+65|0])>>1],v[i+724>>2]=j}}function EW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=hb-16|0;hb=g;Zc(b,w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24));h=Lb(a);a=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);v[23516]=0;R(182,h|0,a|0);a=v[23516];v[23516]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))>>>0<=a>>>0){break b}e=v[b+8>>2];f=v[b>>2];v[23516]=0;e=W(154,f|0,e|0,4)|0;f=v[23516];v[23516]=0;if((f|0)==1){break a}if(!e){break b}e=w[c+4|0]|w[c+5|0]<<8;v[23516]=0;e=Q(183,b|0,e|0)|0;f=v[23516];v[23516]=0;c:{if((f|0)!=1){v[g+12>>2]=e;if(ud(v[d>>2],v[d+4>>2])>>>0<=e>>>0){break c}v[23516]=0;R(184,h|0,g+12|0);e=v[23516];v[23516]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}hb=g+16|0;return}}a=P()|0;O()|0;lc(h);S(a|0);L()}function E7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=0,s=0;h=hb-16|0;hb=h;if(ai(a+44|0)){g=v[a+44>>2];r=h,s=Ec(g,0),v[r+8>>2]=s;r=h,s=Ec(g,1),v[r+12>>2]=s;g=v[a+56>>2];l=Ec(g,0);v[h>>2]=l;m=Ec(g,1);v[h+4>>2]=m;p=w[a+4273|0];q=w[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=v[i>>2];v[i>>2]=e+4;f=C(z[e>>2]*z[a+4240>>2]);e=a+j|0;i=e+4228|0;f=C(f+C(z[i>>2]*z[a+4236>>2]));z[i>>2]=f;f=BK(C(f*C(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=z[e>>2];o=z[a+4264>>2];f=C(C(C(f*z[a+4260>>2])-C(z[a+4268>>2]*z[i>>2]))-C(n*o));z[e>>2]=f;z[i>>2]=n+C(f*o);e=h+j|0;j=v[e>>2];v[e>>2]=j+4;z[j>>2]=f*C(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{si(a,b,c,l,m,d)}break}}hb=h+16|0}function vp(a){var b=C(0),c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=gi(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=C(-gi(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=hi(f+1.5707963267948966);break a}b=hi(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=gi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=hi(-4.71238898038469-+a);break a}b=hi(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(Uw(a,c+8|0)&3){case 0:b=gi(A[c+8>>3]);break a;case 1:b=hi(-A[c+8>>3]);break a;case 2:b=C(-gi(A[c+8>>3]));break a;default:break b}}b=hi(A[c+8>>3])}a=b;hb=c+16|0;return a}function b1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;v[c+28>>2]=0;if(Sd(w[Zl(c+24|0,a,0)|0])){d=c+16|0;bd(d,v[v[a>>2]-12>>2]+a|0);v[23516]=0;d=T(1120,d|0)|0;e=v[23516];v[23516]=0;a:{b:{if((e|0)!=1){e=Jm(c+8|0,a);f=wh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[23516]=0;la(1123,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[23516];v[23516]=0;if((d|0)!=1){break b}}b=V(0)|0;O()|0;Zb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;Wl(v[v[a>>2]-12>>2]+a|0,b);c:{d:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23516]=0;Z(103);a=v[23516];v[23516]=0;if((a|0)!=1){break c}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break d}S(a|0);L()}$();break a}V(0)|0;O()|0;Tb()}L()}Zb(c+16|0);v[b>>2]=v[c+20>>2]}Ii(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}hb=c+32|0;return a|0}function XK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;e=v[b+4220>>2];f=v[b+4224>>2];g=v[b+4228>>2];h=v[b+4232>>2];i=v[b+4240>>2];j=v[b+4236>>2];l=w[b+4244|0];k=b+4208|0;Oi(k,33);d=v[k>>2];t[d+32|0]=l;t[d+24|0]=j;t[d+25|0]=j>>>8;t[d+26|0]=j>>>16;t[d+27|0]=j>>>24;t[d+28|0]=i;t[d+29|0]=i>>>8;t[d+30|0]=i>>>16;t[d+31|0]=i>>>24;t[d+16|0]=g;t[d+17|0]=g>>>8;t[d+18|0]=g>>>16;t[d+19|0]=g>>>24;t[d+20|0]=h;t[d+21|0]=h>>>8;t[d+22|0]=h>>>16;t[d+23|0]=h>>>24;t[d+8|0]=e;t[d+9|0]=e>>>8;t[d+10|0]=e>>>16;t[d+11|0]=e>>>24;t[d+12|0]=f;t[d+13|0]=f>>>8;t[d+14|0]=f>>>16;t[d+15|0]=f>>>24;t[d|0]=76;t[d+1|0]=70;t[d+2|0]=79;t[d+3|0]=32;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;oe(c+8|0,v[k>>2],v[b+4212>>2]);fc(a,v[c+8>>2],v[c+12>>2]);hb=c+16|0}function EK(a){var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=hi(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=C(-gi(d+1.5707963267948966));break a}a=gi(d+-1.5707963267948966);break a}a=hi(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=gi(d+4.71238898038469);break a}a=C(-gi(d+-4.71238898038469));break a}a=hi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(Uw(a,b+8|0)&3){case 0:a=hi(A[b+8>>3]);break a;case 1:a=gi(A[b+8>>3]);break a;case 2:a=hi(-A[b+8>>3]);break a;default:break b}}a=C(-gi(A[b+8>>3]))}hb=b+16|0;return a}function XH(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);f=z[a>>2];i=z[a+24>>2];c=C(f-i);d=z[a+16>>2];b=z[a+32>>2];g=z[a+8>>2];e=C(d+C(b-g));z[a+16>>2]=c+e;j=C(c-C(e*C(.5)));c=z[a+4>>2];e=z[a+20>>2];h=z[a+28>>2];k=C(C(C(c-e)-h)*C(.8660253882408142));z[a+4>>2]=j+k;l=C(C(d-b)*C(.1736481785774231));f=C(f+C(i*C(.5)));i=C(C(g+b)*C(.7660444378852844));m=C(l+C(f-i));n=C(C(c+e)*C(.9848077297210693));b=C(z[a+12>>2]*C(.8660253882408142));c=C(C(c+h)*C(.6427876353263855));o=C(C(n-b)-c);z[a+12>>2]=m+o;z[a+20>>2]=m-o;z[a+28>>2]=j-k;d=C(C(g+d)*C(.9396926164627075));g=C(C(f+d)-l);e=C(C(e-h)*C(.3420201539993286));h=C(C(e-b)-n);z[a+32>>2]=g+h;d=C(C(f-d)+i);b=C(C(b+e)-c);z[a+24>>2]=d+b;z[a+8>>2]=d-b;z[a>>2]=g-h}function qN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{f=hb-16|0;hb=f;e=Kb(a);d=Pj(b);v[f+8>>2]=d;g=ov(b);a=0;b:{while(1){c:{if(!Nb(d,g)){if(!a){break c}v[23516]=0;R(47,e|0,65533);a=v[23516];v[23516]=0;if((a|0)!=1){break c}break b}b=w[d|0];d:{e:{if(!a){if(!(b&128)){a=0;v[23516]=0;R(47,e|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break d}break b}if((b&224)==192){c=b&31;a=1;break d}if((b&240)==224){c=b&15;a=2;break d}c=65533;if((b&248)!=240){break e}c=b&7;a=3;break d}if((b&192)!=128){c=0;v[23516]=0;R(47,e|0,65533);d=v[23516];v[23516]=0;a=0;if((d|0)==1){break b}}c=b&63|c<<6;a=a-1|0;if(a){break d}}a=0;v[23516]=0;R(47,e|0,c|0);b=v[23516];v[23516]=0;c=0;if((b|0)==1){break b}}d=v[He(f+8|0)>>2];continue}break}hb=f+16|0;break a}a=P()|0;O()|0;Yc(e);S(a|0);L()}}function y_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=OF(c);b:{if(b){Jk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ik(k,a);break b}Ar(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ph(k,a)}Ri(i,k);Yc(k);l=e,m=Xi(a),v[l>>2]=m;l=f,m=Yi(a),v[l>>2]=m;Wg(k,a);yc(g,k);wb(k);Qh(k,a);Ri(h,k);Yc(k);a=Hk(a);break a}a=NF(c);c:{if(b){Jk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ik(k,a);break c}Ar(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ph(k,a)}Ri(i,k);Yc(k);l=e,m=Xi(a),v[l>>2]=m;l=f,m=Yi(a),v[l>>2]=m;Wg(k,a);yc(g,k);wb(k);Qh(k,a);Ri(h,k);Yc(k);a=Hk(a)}v[j>>2]=a;hb=k+16|0}function HX(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-192|0;hb=c;b=c+16|0;pi(b,a);v[23516]=0;R(86,c+32|0,b|0);a=v[23516];v[23516]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23516]=0;a=Q(87,c+48|0,c+32|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break e}wb(c+32|0);wb(c+16|0);b=v[v[a>>2]-12>>2];v[23516]=0;d=ha(60)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}v[23516]=0;U(61,c+8|0,a+b|0,d|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}Zb(c+8|0);b=a+v[v[a>>2]-12>>2]|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;v[23516]=0;b=Q(93,a|0,c+32|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}a=Tk(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=v[c+32>>2];pf(b);hb=c+192|0;a=a?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;wb(c+32|0)}wb(c+16|0);break b}b=P()|0;O()|0;pf(a)}S(b|0);L()}return a|0}function C_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=RF(c);b:{if(b){Jk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ik(k,a);break b}Ar(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ph(k,a)}yc(i,k);wb(k);l=e,m=Xi(a),t[l|0]=m;l=f,m=Yi(a),t[l|0]=m;Wg(k,a);yc(g,k);wb(k);Qh(k,a);yc(h,k);wb(k);a=Hk(a);break a}a=QF(c);c:{if(b){Jk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ik(k,a);break c}Ar(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ph(k,a)}yc(i,k);wb(k);l=e,m=Xi(a),t[l|0]=m;l=f,m=Yi(a),t[l|0]=m;Wg(k,a);yc(g,k);wb(k);Qh(k,a);yc(h,k);wb(k);a=Hk(a)}v[j>>2]=a;hb=k+16|0}function Zo(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;v[d+28>>2]=0;a:{b:{c:{if(Sd(w[Zl(d+24|0,a,0)|0])){f=d+16|0;bd(f,v[v[a>>2]-12>>2]+a|0);v[23516]=0;f=T(1120,f|0)|0;e=v[23516];v[23516]=0;d:{e:{if((e|0)==1){break e}e=Jm(d+8|0,a);g=wh(d);h=v[v[a>>2]-12>>2];g=v[g>>2];e=v[e>>2];v[23516]=0;la(c|0,f|0,e|0,g|0,a+h|0,d+28|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break e}Zb(d+16|0);break d}b=V(0)|0;O()|0;Zb(d+16|0);_(b|0)|0;b=v[d+28>>2]|1;v[d+28>>2]=b;Wl(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23516]=0;Z(103);a=v[23516];v[23516]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ii(v[v[a>>2]-12>>2]+a|0,v[d+28>>2])}hb=d+32|0;break a}V(0)|0;O()|0;Tb()}L()}return a}function IR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=t[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=B(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=t[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=w[e+45|0];if(w[e+44|0]|c>>>0>64){break a}b=Eb(w[e+42|0]|w[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=w[a+470|0];if(d>>>0>128){break a}b=w[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=Yz(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=Dr(w[a|0],w[c|0])?c:a;continue}}a=w[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function Aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;t[e+15|0]=0;u[e+12>>1]=0;j=8;n=B(c,d)<<1;while(1){if((d|0)!=(k|0)){g=(k<<1)+b|0;o=n+g|0;while(1){if(g>>>0<o>>>0){u[e+10>>1]=0;$R(a,e+15|0,e+12|0,j,e+10|0);h=x[e+10>>1];c=j;while(1){a:{if(!(c&255)){break a}f=x[e+12>>1]<<1;i=f&254;u[e+12>>1]=i;if(i){f=(f&65534)>>>0>255}else{if(!hf(a,e+9|0)){break a}f=w[e+9|0];u[e+12>>1]=f<<1&254|1;f=f>>>7|0}c=c-1|0;h=f|h<<1;continue}break}c=1;i=h&65535;b:{if(i>>>0<4){break b}f=15;while(1){c=f;m=f&255;if(i>>>m&1){break b}f=c-1|0;if(m>>>0>1){continue}break}}f=h&1;t[e+15|0]=f;l=(f-1^(h&65534)>>>1)+l|0;u[e+10>>1]=l;u[g>>1]=l;g=(d<<1)+g|0;j=(c+j&254)>>>1|0;continue}break}k=k+1|0;continue}break}hb=e+16|0}function wy(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}f=v[a+480180>>2];d=f&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=v[a+480208>>2]&4096;if(!d){break h}if(!a){break b}a=0-(d>>>2|0)|0;break d}a=v[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!(f&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}Ab(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])){break d}a=(a|0)/4<<24>>24}c=a;if(!c){break b}}a=v[b+692>>2];u[b+784>>1]=0;g=b,h=Wb(a+c|0,0,256),v[g+692>>2]=h}hb=e+16|0}function Xp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;f=v[a>>2];e=v[a+4>>2];i=Qd(f,e)-1|0;while(1){a:{b:{if(Qd(f,e)-1>>>0<=g>>>0){g=i;break b}if(x[Lc(f,e,g)>>1]<(b|0)){break a}e=v[a+4>>2];f=v[a>>2]}i=x[Lc(f,e,g)>>1];f=0;v[h+12>>2]=0;c:{if((b|0)>=(i|0)){j=h,k=(w[Lc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break c}e=0;if(g){e=g-1|0;f=(w[Lc(v[a>>2],v[a+4>>2],e)+2|0]<<16)/(d|0)|0;v[h+12>>2]=f;e=x[Lc(v[a>>2],v[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=i>>>0){break c}a=((w[Lc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0)-f|0;d=a;g=a>>31;a=b-e|0;b=rka(d,g,a,a>>31);a=i-e|0;j=h,k=Dc(ska(b,kb,a,a>>31),kb)+f|0,v[j+12>>2]=k}me(h+12|0,0,65536);hb=h+16|0;return(B(v[h+12>>2],c)+32768|0)/65536|0}g=g+1|0;e=v[a+4>>2];f=v[a>>2];continue}}function uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-48|0;hb=e;g=Ic(b);d=Fb(b);i=Ic(c);h=Fb(c);d=d+g|0;f=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(Ap(i,h,w[d|0])){continue}break}f=d-g|0}b:{c:{if((f|0)!=-1){k=e,l=ge(b),v[k+16>>2]=l;k=e,l=Bp(e+16|0,f),v[k+24>>2]=l;k=e,l=Bp(e+24|0,1),v[k+32>>2]=l;c=hj(e+40|0,e+32|0);k=e,l=uh(b),v[k>>2]=l;d=hj(e+8|0,e);JL(b,v[c>>2],v[d>>2]);break c}if(!Fb(b)){break c}g=Ic(b);d=Fb(b);i=Ic(c);h=Fb(c);if(!d|!h){c=-1}else{c=g;f=d+c|0;h=h+i|0;while(1){d:{d=i;e:{if((c|0)!=(f|0)){while(1){if((d|0)==(h|0)){break e}j=t[d|0];d=d+1|0;if(!nc(t[c|0],j)){continue}break}}else{c=f}break d}c=c+1|0;continue}break}c=(c|0)==(f|0)?-1:c-g|0}if(c){break c}Kb(a);break b}Xc(a,b)}hb=e+48|0}function xp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;g=-1077}b=b+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function oC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=v[b>>2];d=Oc(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=hb-32|0;hb=i;d=c-d|0;f=v[Db(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=hb-16|0;hb=f;e=$h(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){ic(e);hb=f+16|0}else{zo(d);d=d+2|0;v[e+4>>2]=d;continue}break}break b}f=Db(b);e=Jj(i+8|0,Kj(b,Oc(v[b>>2],e)+d|0),Oc(v[b>>2],v[b+4>>2]),f);h=hb-16|0;hb=h;d=Io(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){zo(f);f=v[d>>2]+2|0;v[d>>2]=f;continue}break}Kd(d);hb=h+16|0;Cd(b,e);Li(e)}hb=i+32|0;break a}if(c>>>0<d>>>0){Ld(b,e+(c<<1)|0)}}c=Ob(v[a>>2],v[a+8>>2],c<<1);if(c){d=v[b>>2];ec(g+8|0,d,Oc(d,v[b+4>>2])<<1);pd(g,a,v[g+8>>2],v[g+12>>2])}hb=g+16|0;return c|0}function Yk(a,b,c){var d=0,e=0,f=0,g=0;e=hb-48|0;hb=e;d=v[a+24>>2];g=v[d+24620>>2];a:{if(!((g|0)==(b|0)&v[d+24624>>2]==(c|0))){f=e+8|0;pc(f,d+24604|0,40);v[e+28>>2]=c;v[e+24>>2]=b;c=v[e+44>>2];ps(f,v[e+40>>2]);Tn(f,c);jy(d,f);if((b|0)==(g|0)){break a}c=v[a+24>>2]+906300|0;d=ck(c);while(1){if((c|0)!=(d|0)){b=v[c>>2];b:{if(!b){break b}if(!(lb[v[v[b>>2]+120>>2]](b)|0)){break b}lb[v[v[b>>2]+112>>2]](b,0);lb[v[v[b>>2]+100>>2]](b);lb[v[v[b>>2]+128>>2]](b)}c=c+160|0;continue}break}c=v[a+24>>2]+906300|0;d=ck(c);while(1){if((c|0)!=(d|0)){b=v[c>>2];c:{if(!b){break c}if(lb[v[v[b>>2]+120>>2]](b)|0){break c}lb[v[v[b>>2]+112>>2]](b,1);lb[v[v[b>>2]+124>>2]](b)}c=c+160|0;continue}break}break a}if(w[a+29|0]){break a}cM(d,1)}t[a+29|0]=1;hb=e+48|0}function zga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;t[e+15|0]=0;u[e+12>>1]=0;n=B(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){t[e+11|0]=0;_R(a,e+15|0,e+12|0,e+11|0);i=w[e+11|0];f=x[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!hf(a,e+10|0)){break c}f=w[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}u[e+12>>1]=f;break b}k=k+1|0;continue a}u[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;t[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;t[e+11|0]=l;t[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}hb=e+16|0}function e3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-80|0;hb=d;a=v[a+4>>2];Lv(d+16|0,b);v[23516]=0;b=Q(1,d|0,17866)|0;e=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[23516]=0;U(2,d+32|0,d+16|0,b|0);e=v[23516];v[23516]=0;if((e|0)==1){break h}v[23516]=0;U(486,d+48|0,d+32|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break g}v[23516]=0;R(1029,d- -64|0,d+48|0);c=v[23516];v[23516]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[23516]=0;R(c|0,a|0,d- -64|0);a=v[23516];v[23516]=0;if((a|0)==1){break e}wb(d- -64|0);xb(d+48|0);xb(d+32|0);xb(b);xb(d+16|0);hb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;wb(d- -64|0)}xb(d+48|0)}xb(d+32|0)}xb(b)}xb(d+16|0);S(a|0);L()}function Pba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-48|0;hb=g;h=a+8|0;c=v[a+8>>2];j=zc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;d=v[a+4>>2];e=v[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Mi(d,c,a+d|0);v[h>>2]=c;v[i>>2]=a+v[i>>2];break a}v[g+24>>2]=c-e>>1;v[g+44>>2]=1;d=g+24|0;c=v[Vc(d,g+44|0)>>2];c=Tf(d,c,c>>>2|0,v[a+16>>2]);e=cc(g+16|0,v[a+4>>2]);f=v[cc(g+8|0,v[a+8>>2])>>2];d=hb-32|0;hb=d;e=v[e>>2];v[d+24>>2]=e;e=Dl(d+8|0,c+8|0,Nt(f,e));f=v[e>>2];while(1){if(v[e+4>>2]!=(f|0)){k=f;f=v[d+24>>2];xm(k,x[f>>1]|x[f+2>>1]<<16);f=v[e>>2]+4|0;v[e>>2]=f;Ie(d+24|0);continue}break}Kd(e);hb=d+32|0;oc(a,c);oc(i,c+4|0);oc(h,c+8|0);oc(j,zc(c));Sf(c);c=v[a+8>>2]}xm(c,x[b>>1]|x[b+2>>1]<<16);v[h>>2]=v[h>>2]+4;hb=g+48|0}function pE(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-32|0;hb=h;f=kf(h+16|0,1,0);a:{b:{while(1){j=h+8|0;e=wc(f);g=e;i=Fb(f)+e|0;e=w[b|0];c:{if((c|0)==10){MJ(j,g,i,e);break c}k=c>>>0>e>>>0?1:B(c,c)>>>0>e>>>0?2:3;if((k|0)>(i-g|0)){v[j+4>>2]=61;v[j>>2]=i;break c}i=g+k|0;g=i;while(1){k=e&255;e=(k|0)/(c|0)|0;g=g-1|0;t[g|0]=w[(k-B(c,e)|0)+4898|0];if(e&255){continue}break}v[j+4>>2]=0;v[j>>2]=i}if(!v[h+12>>2]){break b}e=Yg(Fb(f));v[23516]=0;R(57,f|0,e|0);e=v[23516];v[23516]=0;if((e|0)!=1){continue}break}break a}b=v[h+8>>2];c=wc(f);v[23516]=0;R(58,f|0,b-c|0);b=v[23516];v[23516]=0;d:{if((b|0)!=1){v[23516]=0;R(d|0,a|0,f|0);a=v[23516];v[23516]=0;if((a|0)!=1){break d}break a}break a}wb(f);hb=h+32|0;return}a=P()|0;O()|0;wb(f);S(a|0);L()}function tM(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:Ep(a,C(1));bk(a,C(3.725290298461914e-9));Dp(a,C(268435456));Cp(a,0);break b;case 1:Ep(a,C(32));bk(a,C(4.656612873077393e-10));Dp(a,C(2147483648));Cp(a,0);break b;case 2:Ep(a,C(2));bk(a,C(7.450580596923828e-9));Dp(a,C(134217728));Cp(a,1);break b;default:Ep(a,C(1));bk(a,C(7.450580596923828e-9));Dp(a,C(134217728));Cp(a,1);by(a,0);ay(a,1);$x(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}Ep(a,C(.75));bk(a,C(7.450580596923828e-9));Dp(a,C(134217728));Cp(a,1);by(a,0);b=(b|0)==4;ay(a,b?2:3);$x(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}by(a,1);ay(a,0);$x(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function vH(a,b,c,d){a:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 6:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 8:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 9:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 16:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 17:lb[d|0](a,c);default:return;case 1:case 4:case 14:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function PR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=v[b>>2];while(1){if((i|0)==128){tg(b,c);c=v[a+8>>2];d=c+d|0;i=x[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(nh(v[a>>2])&-2)){break c}Zc(a,c+(f<<10)|0);if(!bA(a,16,1)){break b}u[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((nh(v[a>>2])|0)!=(d+B(f,i)|0)){break a}}Zc(a,c+B(f,x[e>>1])|0);h=bA(a,64,1)?h:k}Zc(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(B(c,x[e>>1])<<8)|0)==(nh(v[a>>2])|0)){break d}}if(c>>>0>=255){aA(b,254,65534);aA(b,255,65535)}l=h}a=l&65535}else{j=x[$b(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function Ln(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;g=hb-16|0;hb=g;if(e){v[e>>2]=0}a:{h=v[a+484344>>2];if(!te(h,v[a+484348>>2],b)){break a}i=Xb(h,b);k=v[i+48>>2];b=ed(v[i>>2],v[k+12>>2],c,d);f=w[b+5|0];b:{c:{d:{e:{j=w[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}v[g+12>>2]=1;h=0;if((j|0)!=17){break b}h=v[a+480180>>2]==4;break b}v[g+12>>2]=2;h=0}v[g+8>>2]=v[i+12>>2]+(c^-1);d=0;c=v[Hb(g+8|0,g+12|0)>>2];a=c;while(1){f:{if(a){b=B(Lg(v[k+12>>2]),6)+b|0;if(w[b+3|0]==34){break f}c=d}f=(j-37&255)>>>0<254?f:c?f:f<<8;if(!e){break a}v[e>>2]=c;break a}i=f<<8;f=w[b+5|0]|(h?f>>>0<256?i+-8192|0:i:i);d=d+1|0;a=a-1|0;continue}}hb=g+16|0;return f}function $da(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb+-64|0;hb=c;a:{d=v[a+4>>2];b:{if(d>>>0<b>>>0){f=ce(c+56|0);e=b-d|0;g=nt(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){tm(c+40|0,v[a>>2],d);fc(f,v[c+40>>2],v[c+44>>2]);v[a+4>>2]=v[a+4>>2]+e;break c}d=Xn(c+40|0);v[23516]=0;b=Q(746,a|0,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break a}v[23516]=0;R(747,d|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}v[d+4>>2]=v[a+4>>2]+e;ml(c+24|0,v[a>>2]);tm(c+16|0,v[a>>2],v[a+4>>2]);ml(c+8|0,v[d>>2]);_Q(c+32|0,v[c+24>>2],v[c+28>>2],v[c+16>>2],v[c+20>>2],v[c+8>>2],v[c+12>>2]);fc(f,v[c+32>>2],v[c+36>>2]);xt(a,d);Ue(d)}a=fc(c,v[f>>2],v[f+4>>2]);dv(v[a>>2],v[a+4>>2],e,0);break b}v[a+4>>2]=b}hb=c- -64|0;return}a=P()|0;O()|0;Ue(d);S(a|0);L()}function mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=v[b>>2];d=Uf(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=hb-32|0;hb=i;d=c-d|0;f=v[Db(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=hb-16|0;hb=f;e=Az(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){ic(e);hb=f+16|0}else{NP(d);d=d+32|0;v[e+4>>2]=d;continue}break}break b}f=Db(b);e=pt(i+8|0,_p(b,Uf(v[b>>2],e)+d|0),Uf(v[b>>2],v[b+4>>2]),f);h=hb-16|0;hb=h;d=OP(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){NP(f);f=v[d>>2]+32|0;v[d>>2]=f;continue}break}Kd(d);hb=h+16|0;Cd(b,e);PP(e)}hb=i+32|0;break a}if(c>>>0<d>>>0){Ld(b,e+(c<<5)|0)}}if(Ob(v[a>>2],v[a+8>>2],c<<5)){c=v[b>>2];ec(g+8|0,c,Uf(c,v[b+4>>2])<<5);pd(g,a,v[g+8>>2],v[g+12>>2])}hb=g+16|0}function l6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=hb-48|0;hb=f;v[f+40>>2]=d;a=dg(a,f+40|0);d=yf(a+4|0);g=yf(a+24|0);h=yf(a+32|0);i=Lb(a+36|0);v[a+56>>2]=3;j=Lb(a+68|0);v[23516]=0;R(961,a|0,e|0);k=v[23516];v[23516]=0;a:{b:{c:{d:{if((k|0)!=1){ec(f+8|0,b,c);b=ce(f);c=v[b+4>>2];b=v[b>>2];v[23516]=0;da(965,f+16|0,v[f+8>>2],v[f+12>>2],b|0,c|0);b=v[23516];v[23516]=0;if((b|0)==1){break d}v[23516]=0;U(962,a|0,f+16|0,e|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}yb(f+16|0);v[23516]=0;Y(963,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){break a}}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;yb(f+16|0)}Me(j);Vf(i);os(h);fj(g);ej(d);ze(a);ze(f+40|0);S(e|0);L()}ze(f+40|0);hb=f+48|0;return a|0}function WK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=hb-80|0;hb=c;d=v[b>>2];e=v[b+4>>2];b=ce(c+48|0);b=fr(c+56|0,d,e,v[b>>2],v[b+4>>2]);v[23516]=0;d=T(200,b|0)|0;e=v[23516];v[23516]=0;a:{if((e|0)==1){break a}v[23516]=0;d=W(925,b|0,c+8|0,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break a}b:{if(!d){break b}if(Qb(c+8|0,17720,4)|v[c+12>>2]){break b}f=a,g=Td(z[c+16>>2],C(0)),z[f+4220>>2]=g;f=a,g=Td(z[c+20>>2],C(0)),z[f+4224>>2]=g;f=a,g=Td(z[c+24>>2],C(0)),z[f+4228>>2]=g;d=v[c+28>>2];if(d>>>0<=5){v[a+4232>>2]=d}v[a+4236>>2]=v[c+32>>2];t[a+4240|0]=w[c+36|0]!=0;t[a+4241|0]=w[c+37|0]!=0;t[a+4242|0]=w[c+38|0]!=0;t[a+4243|0]=w[c+39|0]!=0;t[a+4244|0]=w[c+40|0]!=0;Es(a)}yb(b);hb=c+80|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function s6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=hb-48|0;hb=b;c=Kb(b+32|0);v[23516]=0;Y(954,b+16|0);a=v[23516];v[23516]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=Cb(v[b+16>>2]),v[f+8>>2]=g;d=1;while(1){e=Cb(v[b+20>>2]);a=v[b+8>>2];if(!Nb(a,e)){a=fg(Ic(c));Me(b+16|0);wb(c);break b}if(!d){v[23516]=0;Q(955,c|0,14707)|0;a=v[23516];v[23516]=0;if((a|0)==1){break d}a=v[b+8>>2]}v[23516]=0;Q(820,c|0,a|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break d}gq(b+8|0);d=0;continue}}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Me(b+16|0)}wb(c);_(a|0)|0;a=0;v[23516]=0;X(953,6988,0,0,0);c=v[23516];v[23516]=0;if((c|0)==1){break a}$()}hb=b+48|0;return a|0}b=P()|0;O()|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)==1){V(0)|0;O()|0;Tb();L()}S(b|0);L()}function GX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=hb-16|0;hb=h;f=qd(b);d=wd(v[b+4>>2],w[b+11|0]);i=qd(c);g=wd(v[c+4>>2],w[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(cu(i,g,w[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=cc(h+8|0,Pf(Pf(Pj(b),e),1));d=cc(h,ov(b));gD(b,v[c>>2],v[d>>2]);break c}if(!zk(v[b+4>>2],w[b+11|0])){break c}f=qd(b);d=wd(v[b+4>>2],w[b+11|0]);i=qd(c);g=wd(v[c+4>>2],w[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=w[d|0];d=d+1|0;if(!nc(w[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Kb(a);break b}Xc(a,b)}hb=h+16|0}function HG(a,b,c,d,e,f){var g=0;g=hb-80|0;hb=g;a:{if((f|0)>=16384){Fd(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Fd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Fd(g- -64|0,b,c,d,e,0,0,0,7471104);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Fd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)>-48920?f:-48920)+32538|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Fd(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;hb=g+80|0}function L9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;c=Lg(v[v[a+48>>2]+12>>2]);a:{if(!b){break a}c=B(b,c);b:{if(v[a+12>>2]!=(b|0)){break b}if((lk(v[a>>2],v[a+4>>2])|0)!=(c|0)){break b}b=hb-16|0;hb=b;d=Cb(v[a>>2]);a=Cb(v[a+4>>2]);Cj(b+8|0);e=Ks(a,d);c=hb-16|0;hb=c;v[c+8>>2]=d;while(1){if((e|0)>0){a=v[c+8>>2];d=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8;t[a+4|0]=d;t[a+5|0]=d>>>8;e=e-1|0;vk(c+8|0);continue}break}hb=c+16|0;hb=b+16|0;break a}e=f+8|0;Cj(e);c=jT(f+16|0,c,e);EL(a);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];e=Db(c);g=Db(a),h=v[e>>2],v[g>>2]=h;v[e>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Ah(c);v[a+12>>2]=b}hb=f+32|0}function hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){e=v[b+8>>2];o=e>>>18|0;p=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){h=(e<<1)+p|0;i=u[h>>1];v[(e<<2)+b>>2]=i+((B(u[h+4>>1]-i|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;hb=b+16|0}function Uw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;g=(p(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;A[b>>3]=d;g=d<-.7853981852531433;if(D(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,i-(c<<23)|0),q());c=AH(e+8|0,e,c,1,0);d=A[e>>3];if((g|0)<0){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}hb=e+16|0;return c}function A0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=v[b+44>>2];i=v[b+24>>2];if(h>>>0<i>>>0){v[b+44>>2]=i;h=i}l=-1;m=-1;n=f&24;a:{if(!n|(e|0)==1&(n|0)==24){break a}if(h){g=h-wc(b+32|0)|0;o=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=i-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=o;k=g}d=d+k|0;c=c+j|0;d=j>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>o>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!i){break a}}if(d){d=v[b+8>>2];qn(b,d,d+e|0,h)}if(f&16){Fw(b,v[b+20>>2],v[b+28>>2]);Rr(b,e)}l=e;m=c}Sg(a,l,m)}function nJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;v[d+12>>2]=c;a:{b:{if(!b){a=a+120|0;wn(a);b=v[d+12>>2];a=Lb(a);c:{if(b){v[23516]=0;R(1088,a|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}iJ(a,b)}break c}t[a+20|0]=0;break b}e=hb-16|0;hb=e;v[e+12>>2]=c;d:{if((b|0)==1){b=a+120|0;wn(b);g=nx(b,a,v[e+12>>2]),h=1,t[g+20|0]=h;break d}f=hb-16|0;hb=f;v[f+12>>2]=c;e:{if((b|0)==2){a=a+120|0;wn(a);b=v[f+12>>2];a=Lb(a);f:{if(b){v[23516]=0;R(1087,a|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}iJ(a,b)}break f}ce(a+12|0);t[a+20|0]=2;break e}b=hb-16|0;hb=b;v[b+12>>2]=c;c=a+120|0;wn(c);g=nx(c,a,v[b+12>>2]),h=3,t[g+20|0]=h;hb=b+16|0}hb=f+16|0}hb=e+16|0}hb=d+16|0;return}b=P()|0;O()|0;dc(a);S(b|0);L()}function QE(a,b,c,d,e,f){var g=0,h=0,i=C(0),j=0;g=hb-80|0;hb=g;iy(v[a+24>>2]);t[v[a+24>>2]+1298420|0]=v[a+52>>2]!=0;v[g+40>>2]=b;v[g+36>>2]=c;v[g+32>>2]=d;i=z[a+48>>2];j=v[a+32>>2];v[g+8>>2]=b;c=v[g+36>>2];v[g>>2]=v[g+32>>2];v[g+4>>2]=c;d=hb-16|0;hb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;c=$I(g+48|0);v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=f;f=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=f;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=i;v[c>>2]=e;hb=d+16|0;while(1){if(b){d=v[a+24>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;d=bJ(d,v[Qq(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|h)){a=v[a+24>>2];v[a+480208>>2]=v[a+480208>>2]&-513}hb=g+80|0;return h}function FR(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],1024)){v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;a=64;while(1){if(a){d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}_z(c+8|0,b);pd(c+16|0,a,v[c+8>>2],v[c+12>>2])}hb=c+32|0}function Hba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;c=nf(a,c);ke(g,v[a+36>>2]);a:{if(!c){b:{Pc(g,a+32|0,5);if(!zb(v[v[g>>2]>>2],v[g+4>>2])){break b}break a}}h=v[a+36>>2];d=hb-16|0;hb=d;v[d+12>>2]=0;MG(h,d+12|0,1);e=v[d+12>>2];f=e>>>2&3;t[d+11|0]=f;if(f){t[d+4|0]=3;f=w[Vb(d+4|0,d+11|0)|0];t[d+4|0]=0;t[d|0]=0;t[d+10|0]=0;c:{if(!f){break c}ki(h,d+4|0);if((f|0)==1){break c}ki(h,d);if(f>>>0<3){break c}ki(h,d+10|0);i=w[d+10|0]<<24}e=e&255|w[d+4|0]<<8|w[d|0]<<16|i;v[d+12>>2]=e}f=e>>>4|0;v[d+4>>2]=f;v[d>>2]=1e6;Ex(b,v[Hb(d+4|0,d)>>2]);e=0;while(1){i=Fb(b);if(i>>>0<=e>>>0){if((f|0)!=(i|0)){Ul(h,f-i|0)}hb=d+16|0}else{Mk(h,Jc(b,e),1);e=e+1|0;continue}break}d=c}Ve(a,d);hb=g+16|0}function qI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;a:{b:{c:{d:{e:{if((b|0)>=0){g=a;a=v[a+32>>2];if((Lg(a)|0)>(b|0)){break e}}a=ba(8)|0;v[23516]=0;b=Q(53,f|0,10725)|0;c=v[23516];v[23516]=0;if((c|0)==1){break d}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break b}c=P()|0;O()|0;wb(b);break c}d=(a+(b<<5)|0)+480280|0;c=c?134218752:0;v[d>>2]=c|v[d>>2]&-134218753;d=(a+B(b,872)|0)+1075080|0;v[d>>2]=c|v[d>>2]&-134218753;a=x[a+480188>>1];d=a>>>0>256?a:256;b=b+1|0;g=v[g+32>>2];while(1){if((a|0)==(d|0)){break a}e=g+B(a,872)|0;if((b|0)==x[e+1075778>>1]){e=e+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;continue}}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}hb=f+16|0}function on(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0,n=0;l=hb-16|0;hb=l;t[l+15|0]=a;a:{b:{c:{k=v[d>>2];if((k|0)!=(c|0)){break c}m=43;n=a&255;if((n|0)!=w[j+24|0]){m=45;if(w[j+25|0]!=(n|0)){break c}}v[d>>2]=c+1;t[c|0]=m;break b}if(!(!Fb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=yi(j,j+26|0,l+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[f+84e3|0];break a}v[d>>2]=k+1;t[k|0]=w[f+84e3|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}hb=l+16|0;return a}function jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){e=v[b+8>>2];o=e>>>10&4194048;p=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){h=e+p|0;i=t[h|0];v[(e<<2)+b>>2]=((B(t[h+2|0]-i|0,o)|0)/16384|0)+(i<<8);e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;hb=b+16|0}function sh(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=0;f=nK(a);h=a+4208|0;c=C(C(z[Bb(h,4)>>2]*C(1.899999976158142))+C(.10000000149011612));g=z[a+4268>>2];d=qe(C(10),C(C(C(C(C(v[((b<<2)+a|0)+4292>>2])/g)*C(-60))/C(C(z[Bb(h,3)>>2]*C(19.899999618530273))+C(.10000000149011612)))/C(20)));c=C(C(qe(d,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-vp(c>C(1)?C(3.1415927410125732):C(f*C(C(6.2831854820251465)/g)))));a:{if(c==C(0)){break a}if(!fm(c)){break a}g=C(c+c);f=C(C(-2)-g);c=C(C(f*f)+C(C(c*c)*C(-4)));if(c>C(0)){e=C(K(c))}c=C(C(e-f)/g);if(C(D(c))>C(1)){c=C(C(C(-f)-e)/g)}e=Gf(c)}b=(b<<3)+a|0;z[b+4404>>2]=e;z[b+4400>>2]=d;c=z[a+4272>>2];c=C(c*c);e=C(C(1)-c);d=C(d*d);return C(C(C(e*C(d/C(C(1)-C(c*d))))*e)+c)}function Xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;m=u[e+39894>>1];n=u[e+39892>>1];o=u[e+39890>>1];p=u[e+39888>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+l|0;v[(e<<2)+b>>2]=(((B(u[f>>1],o)+B(u[f-4>>1],p)|0)+B(u[f+4>>1],n)|0)+B(u[f+8>>1],m)|0)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;hb=b+16|0}function ifa(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-192|0;hb=c;b=c+16|0;pi(b,a);v[23516]=0;R(86,c+32|0,b|0);a=v[23516];v[23516]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23516]=0;a=Q(87,c+48|0,c+32|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break e}wb(c+32|0);wb(c+16|0);b=v[v[a>>2]-12>>2];v[23516]=0;d=ha(60)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}v[23516]=0;U(61,c+8|0,a+b|0,d|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}Zb(c+8|0);v[23516]=0;b=Q(88,a|0,c+32|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}a=Tk(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=x[c+32>>1];pf(b);hb=c+192|0;a=(a?0:d)&65535;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;wb(c+32|0)}wb(c+16|0);break b}b=P()|0;O()|0;pf(a)}S(b|0);L()}return a|0}function ui(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=44488;b=a+24|0;v[b>>2]=0;v[b+4>>2]=0;v[b+16>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;c=Lb(a+44|0);d=Lb(c+12|0);e=Lb(c+24|0);f=Lb(c+36|0);v[23516]=0;R(917,c|0,0);g=v[23516];v[23516]=0;if((g|0)==1){a=P()|0;O()|0;lc(f);lc(e);Bx(d);Bx(c);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;u[a+4204>>1]=0;d=v[a+16>>2];v[d+946300>>2]=v[d+946300>>2]+1;v[23516]=0;d=T(918,a+92|0)|0;e=v[23516];v[23516]=0;a:{if((e|0)!=1){c=a+4200|0;v[b>>2]=d;d=v[a+16>>2]+906300|0;b=w[a+4200|0];e=v[a+20>>2];while(1){if((Id(d,b)|0)==(e|0)|b>>>0>248){break a}b=b+1|0;t[c|0]=b;continue}}a=P()|0;O()|0;TK(c);S(a|0);L()}return a}function hA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;d=w[a|0];if(d&1){t[b+12|0]=w[b+12|0]|1;d=w[a|0]}if(d&2){t[b+12|0]=w[b+12|0]|4;d=w[a|0]}if(d&4){t[b+12|0]=w[b+12|0]|2;d=w[a|0]}if(d&16){t[b+12|0]=w[b+12|0]|16;d=w[a|0]}if(d&32){t[b+12|0]=w[b+12|0]|8}t[e+15|0]=w[a+1|0];t[e+14|0]=25;Mg(b,w[Vb(e+15|0,e+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];g=v[b>>2];i=Qd(g,v[b+4>>2]);b=0;while(1){if((b|0)!=(i|0)){h=Bb(g,b);f=(b<<2)+a|0;d=w[f+6|0]|w[f+7|0]<<8;u[h>>1]=d;a:{if(!b){break a}j=d;d=x[Bb(g,b-1|0)>>1];if(j>>>0>=d>>>0){break a}u[h>>1]=d+1}k=h,l=Wb((w[f+8|0]|w[f+9|0]<<8)<<16>>16>>c,0,64),t[k+2|0]=l;b=b+1|0;continue}break}hb=e+16|0}
function afa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;jd(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;e=d+16|0;i=c,j=w[Vb(e,d)|0]<<2,u[i+30>>1]=j;v[c+24>>2]=(w[b+14|0]|w[b+15|0]<<8)<<1;ok(d,2,b+1|0);Cc(e,d);xe(c+43|0,e);wb(e);e=Uc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}g=w[b+22|0]|w[b+23|0]<<8|(w[b+24|0]<<16|w[b+25|0]<<24);v[c>>2]=g;f=w[b+26|0]|w[b+27|0]<<8|(w[b+28|0]<<16|w[b+29|0]<<24);v[c+4>>2]=f;a=w[b+30|0]|w[b+31|0]<<8|(w[b+32|0]<<16|w[b+33|0]<<24);h=a-(a>>>0>f>>>0)|0;v[c+8>>2]=h;a=w[b|0];if(a&4){u[c+34>>1]=x[c+34>>1]|2;a=w[b|0]}if(a&8){u[c+34>>1]=x[c+34>>1]|4;a=w[b|0]}if(!(a&16)){break a}nd(e,16);cg(e,9);v[c+8>>2]=h>>>1;v[c+4>>2]=f>>>1;v[c>>2]=g>>>1}hb=d+32|0}function BG(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=ww(13947);if(w[b|0]?b:0){break a}b=ww(B(a,12)+79840|0);if(w[b|0]?b:0){break a}b=ww(14231);if(w[b|0]?b:0){break a}b=14840}b:{while(1){d=w[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14840;c:{d:{c=w[b|0];e:{f:{if(!(w[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!w[e+1|0]){break e}}if(!xi(e,14840)){break e}if(xi(e,13557)){break d}}if(!a){c=79912;if(w[e+1|0]==46){break c}}return 0}c=v[116931];if(c){while(1){if(!xi(e,c+8|0)){break c}c=v[c+32>>2];if(c){continue}break}}c=Md(36);if(c){v[c+4>>2]=20;v[c>>2]=79808;b=c+8|0;pc(b,e,d);t[b+d|0]=0;v[c+32>>2]=v[116931];v[116931]=c}c=a|c?c:79912}return c}function ega(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=hb-528|0;hb=b;e=-1;a:{if(!eg(a,1468)){break a}ol(a,1464);c=b+524|0;XR(a,c);if(!le(c,27065)){e=0;if(!le(b+524|0,15629)){break a}}ol(a,20);c=1;while(1){if((c&65535)>>>0<=31){if(UR(a,b)){c=c+1|0;d=eA(b)+d|0;continue}else{e=-1;break a}}break}e=0;if(d>>>0>40){break a}d=b+520|0;c=hb-16|0;hb=c;b:{if(!eg(a,2)){t[c|0]=0;gC(d,c);break b}Nm(c+8|0,d);dA(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0;if(w[b+520|0]>128){break a}d=Kc(b+520|0);c=hb-16|0;hb=c;c:{if(!eg(a,512)){ER(b);break c}yu(c+8|0,b);dA(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0;c=0;e=1;a=w[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=w[d|0]){continue}break}e=0}hb=b+528|0;return e|0}function Uj(a,b){var c=0,d=0,e=0,f=0;c=hb+-64|0;hb=c;d=v[v[a>>2]-12>>2]+a|0;e=v[d+16>>2]&-3;Kl(d,e);a:{b:{if(Sd(w[Zl(c+56|0,a,1)|0])){d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23516]=0;f=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=f;f=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=f;U(106,c+40|0,d|0,c+8|0);b=v[23516];v[23516]=0;c:{if((b|0)!=1){b=aE(c+40|0,Sg(c+24|0,-1,-1))?e|4:e;break c}b=V(0)|0;O()|0;_(b|0)|0;b=e|1;Wl(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23516]=0;Z(103);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break b}S(a|0);L()}$()}Ii(v[v[a>>2]-12>>2]+a|0,b)}hb=c- -64|0;return a}V(0)|0;O()|0;Tb()}L()}function yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=hb-16|0;hb=b;i=v[a+16>>2];h=Rf(1,2);e=kb;j=e;Pb(a,h,e);f=v[a+40>>2];g=v[a+36>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){d=d-1|0;o=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+i|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+o>>1];e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;lg(a,h,j);hb=b+16|0}function DX(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-192|0;hb=c;b=c+16|0;pi(b,a);v[23516]=0;R(86,c+32|0,b|0);a=v[23516];v[23516]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23516]=0;a=Q(87,c+48|0,c+32|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break e}wb(c+32|0);wb(c+16|0);b=v[v[a>>2]-12>>2];v[23516]=0;d=ha(60)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}v[23516]=0;U(61,c+8|0,a+b|0,d|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}Zb(c+8|0);v[23516]=0;b=Q(91,a|0,c+32|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}a=Tk(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=v[c+32>>2];pf(b);hb=c+192|0;a=a?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;wb(c+32|0)}wb(c+16|0);break b}b=P()|0;O()|0;pf(a)}S(b|0);L()}return a|0}function MV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;jd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Jq(a+4|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=f;c=Jq(a+8|0,a);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=c;t[e+15|0]=127;t[e+14|0]=w[a+15|0];g=b,h=(((w[Vb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[g+30>>1]=h;d=w[a+12|0];if(d>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=d&240}d=(w[a+13|0]|w[a+14|0]<<8)<<1;v[b+24>>2]=d;d=w[a+13|0]|w[a+14|0]<<8?d:16726;v[b+24>>2]=d;g=b,h=(B(Ku(0,w[a+12|0]<<28>>24),d)>>>0)/8363|0,v[g+24>>2]=h;if(c>>>0>f>>>0){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}hb=e+16|0}function A4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-32|0;hb=d;e=Lb(a);a=0;c=v[b+24>>2];c=ft(v[c+484344>>2],v[c+484348>>2]);v[23516]=0;R(179,e|0,c|0);c=v[23516];v[23516]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=v[b+24>>2];f=v[c+484344>>2];if(ft(f,v[c+484348>>2])>>>0<=a>>>0){break b}v[23516]=0;R(1036,d|0,Xb(f,a)|0);c=v[23516];v[23516]=0;if((c|0)!=1){c=v[b+24>>2];v[23516]=0;U(1023,d+16|0,c|0,d|0);c=v[23516];v[23516]=0;if((c|0)==1){break e}v[23516]=0;R(181,e|0,d+16|0);c=v[23516];v[23516]=0;if((c|0)==1){break d}a=a+1|0;wb(d+16|0);wb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;wb(d+16|0)}wb(d);break a}hb=d+32|0;return}a=P()|0;O()|0}Me(e);S(a|0);L()}function B2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-80|0;hb=e;v[e+76>>2]=d;v[e+72>>2]=c;v[23516]=0;c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;c=T(1100,e+8|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){a:{b:{if(c){v[23516]=0;R(1101,e+48|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){d=e+56|0;sv(d,v[e+48>>2],v[e+52>>2]);b=Bg(e- -64|0,d);c=Bg(e+40|0,e+72|0);break b}break a}v[23516]=0;R(1102,e+48|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}d=e+56|0;sv(d,v[e+48>>2],v[e+52>>2]);b=Bg(e+32|0,d);c=Bg(e+24|0,e+72|0)}yD(a,v[b>>2],v[b+4>>2],v[c>>2],v[c+4>>2]);je(d);je(e+48|0);je(e+72|0);hb=e+80|0;return}}a=P()|0;O()|0;je(e+72|0);S(a|0);L()}function Cy(a,b,c){var d=0,e=0,f=0,g=0;d=hb+-64|0;hb=d;e=v[a>>2];f=v[e-4>>2];g=v[e-8>>2];v[d+28>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+40>>2]=0;v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+56>>2]=0;e=0;t[d+59|0]=0;t[d+60|0]=0;t[d+61|0]=0;t[d+62|0]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;a=a+g|0;a:{if(Tg(f,c,0)){v[d+56>>2]=1;lb[v[v[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=v[d+32>>2]==1?a:0;break a}lb[v[v[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:e=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}e=v[d+24>>2]}hb=d- -64|0;return e}function kh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb+-64|0;hb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=v[a>>2];e=v[a+4>>2];if(te(d,e,b)){break b}c:{d:{if(sk(d,e)>>>0<=b>>>0){d=Sx(f+8|0,a);v[23516]=0;U(199,a|0,b+1|0,d|0);e=v[23516];v[23516]=0;if((e|0)==1){break d}$k(d);d=v[a>>2]}v[23516]=0;R(209,ag(d,b)|0,c|0);c=v[23516];v[23516]=0;e:{if((c|0)!=1){c=ag(v[a>>2],b);v[c+16>>2]=0;v[c+20>>2]=0;c=v[a>>2];v[23516]=0;Y(210,ag(c,b)|0);c=v[23516];v[23516]=0;if((c|0)!=1){break e}}b=V(92664)|0;a=O()|0;break c}a=ag(v[a>>2],b);g=Nb(v[a>>2],v[a+4>>2]);break b}b=V(92664)|0;a=O()|0;$k(d)}if((ea(92664)|0)!=(a|0)){break a}_(b|0)|0;$()}hb=f- -64|0;return g|0}S(b|0);L()}function Bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb+-64|0;hb=c;i=c,j=$e(a)>>>5|0,u[i+32>>1]=j;u[c+16>>1]=3999;h=b+480190|0;d=x[Rc(c+32|0,c+16|0)>>1];u[h>>1]=d;g=1;while(1){f=g&65535;if(f>>>0<=d>>>0){d=Fi(b,f);e=c+32|0;Ht(a,e);jd(d,0);Aj(c,2,e);e=c+16|0;Cc(e,c);Ac(((f<<5)+b|0)+946304|0,e);wb(e);v[d+24>>2]=8287;i=c,j=Eb(x[c+60>>1]),u[i+16>>1]=j;u[c>>1]=64;i=d,j=x[Rc(e,c)>>1]<<2,u[i+30>>1]=j;i=d,j=_b(v[c+52>>2])&-2,v[i>>2]=j;e=Eb(x[c+62>>1]);i=Bb(d+68|0,0),j=e,v[i>>2]=j;e=Eb(x[c+56>>1]);f=Eb(x[c+58>>1]);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>y[d>>2]){break a}v[d+16>>2]=f;v[d+12>>2]=e<<1;u[d+34>>1]=x[d+34>>1]|8}g=g+1|0;d=x[h>>1];continue}break}hb=c- -64|0}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;m=u[e+39894>>1];n=u[e+39892>>1];o=u[e+39890>>1];p=u[e+39888>>1];e=0;while(1){if((e|0)!=2){f=e+l|0;v[(e<<2)+b>>2]=(((B(t[f|0],o)+B(t[f-2|0],p)|0)+B(t[f+2|0],n)|0)+B(t[f+4|0],m)<<8)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;hb=b+16|0}function f1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Vw(fb(v[a+60>>2],b|0,i|0,d+12|0)|0)){g=v[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}h=v[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;v[e>>2]=h+v[e>>2];b=(j?12:4)+b|0;v[b>>2]=v[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((i|0)==2){break a}a=c-v[b+4>>2]|0}hb=d+32|0;return a|0}function cF(a,b,c,d){var e=0,f=0,g=0;f=hb-32|0;hb=f;v[23516]=0;Y(966,a|0);e=v[23516];v[23516]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}v[23516]=0;Y(967,b|0);e=v[23516];v[23516]=0;if((e|0)==1){break f}g=v[a+24>>2];v[23516]=0;e=Q(53,f|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break e}v[23516]=0;U(d|0,f+16|0,g|0,e|0);b=v[23516];v[23516]=0;if((b|0)==1){break d}a=f+16|0;b=fg(Ic(a));wb(a);wb(e);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;wb(e)}_(b|0)|0;b=0;v[23516]=0;X(953,c|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$()}hb=f+32|0;return b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Mda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=hb-16|0;hb=g;jd(b,4);u[b+30>>1]=w[a+12|0]<<2;Bf(b+30|0,256);e=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=e;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=f;c=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);v[b+4>>2]=c;d=(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+c|0;v[b+8>>2]=d;e=w[a+14|0];if(e&16){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;f=f>>>1|0;v[b>>2]=f;e=w[a+14|0]}if(e&32){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;v[b>>2]=f>>>1;e=w[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){u[b+34>>1]=34;u[b+34>>1]=w[a+14|0]&2?38:34}a=Fc(g,21751);xe(b+43|0,a);wb(a);hb=g+16|0}function Z5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;a:{b:{c:{if((d|0)==1){break c}v[23516]=0;Y(967,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}v[23516]=0;Y(967,c|0);f=v[23516];v[23516]=0;d=1;if((f|0)==1){break c}f=v[a+24>>2];b=qc(e+8|0,b);c=qc(e,c);g=v[c+4>>2];c=v[c>>2];h=v[b+4>>2];b=v[b>>2];v[23516]=0;la(988,f|0,b|0,h|0,c|0,g|0,1);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,5510,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}hb=e+16|0;return d|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function uL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=C(0),k=0,l=C(0);g=hb-16|0;hb=g;e=u[d>>1];f=u[d+2>>1];if(!(!x[b>>1]|(e|0)>(f|0)|(!(z[c>>2]>C(0))|(f-e|0)>32766))){u[a>>1]=3;f=a+4|0;Gc(f);u[a+28>>1]=65472;v[g+12>>2]=1065353216;wL(f,g+12|0);v[a+32>>2]=0;u[a+30>>1]=0;Gc(a+16|0);h=u[d>>1];u[a+28>>1]=h;e=hb-16|0;hb=e;u[e+14>>1]=x[b>>1];u[e+12>>1]=32767;b=u[Rc(e+14|0,e+12|0)>>1];hb=e+16|0;u[a+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=qe(i,C(C(1)/C(b|0)));ak(f,(u[d+2>>1]-h|0)+1|0);b=v[a+4>>2];c=u[a+28>>1];e=u[d+2>>1];d=u[d>>1];while(1){if((d|0)>(e|0)){zp(a)}else{j=qe(i,C(d|0));k=Bb(b,d-c|0),l=j,z[k>>2]=l;d=d+1|0;continue}break}h=1}hb=g+16|0;return h|0}function gX(){var a=0,b=0,c=0,d=0;a=RC(v[v[116798]-12>>2]+467192|0,10);c=hb-16|0;hb=c;v[23516]=0;b=Q(13,c+8|0,467192)|0;d=v[23516];v[23516]=0;a:{b:{c:{d:{if((d|0)!=1){e:{if(!w[b|0]){break e}d=Jm(c,467192);v[23516]=0;a=Q(21,d|0,a|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){if(!Qu(a)){break e}a=v[v[116798]-12>>2];v[23516]=0;R(16,a+467192|0,1);a=v[23516];v[23516]=0;if((a|0)!=1){break e}}a=V(0)|0;O()|0;tk(b);break d}tk(b);break c}a=V(0)|0;O()|0}_(a|0)|0;b=v[v[116798]-12>>2];v[23516]=0;Y(17,b+467192|0);b=v[23516];v[23516]=0;if((b|0)==1){break b}$()}hb=c+16|0;break a}c=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(c|0);L()}V(0)|0;O()|0;Tb();L()}ev(467192)}function zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=hb-16|0;hb=b;i=v[a+16>>2];h=Rf(1,2);e=kb;j=e;Pb(a,h,e);f=v[a+40>>2];g=v[a+36>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){d=d-1|0;o=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+i|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+o|0]<<8;e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;lg(a,h,j);hb=b+16|0}function On(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}e=v[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(e&69206029){break b}g=d&240;f=d&15;if((f|0)==15){if(g){Nn(a,b,(d&240)>>>4|0,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((g|0)!=240){break b}if(f){Mn(a,b,f,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(!(t[b+851|0]&1)|w[a+480208|0]&2)&(v[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&255;d=d&15;d:{if(d){if(a&240?e&16777248:0){break c}c=c-(d<<2)|0;break d}c=(a>>>2&60)+c|0}if((e|0)!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}h=b,i=Wb(c,0,256),v[h+688>>2]=i}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){b=(v[f+12>>2]<<1)+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(u[b+4>>1],u[e+10>>1])+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/2|0)+((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(b,h);v[c+4>>2]=v[c+4>>2]+B(b,g);Pb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;hb=f+16|0}function rH(a){var b=0,c=0,d=0,e=0,f=0;c=hb-192|0;hb=c;b=c+16|0;pi(b,a);v[23516]=0;R(86,c+32|0,b|0);a=v[23516];v[23516]=0;a:{b:{c:{d:{if((a|0)!=1){v[23516]=0;a=Q(87,c+48|0,c+32|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break d}wb(c+32|0);wb(c+16|0);b=v[v[a>>2]-12>>2];v[23516]=0;d=ha(60)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}v[23516]=0;U(61,c+8|0,a+b|0,d|0);b=v[23516];v[23516]=0;if((b|0)==1){break b}Zb(c+8|0);v[23516]=0;b=Q(92,a|0,c+32|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}a=Tk(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);f=A[c+32>>3];pf(b);hb=c+192|0;return a?0:f}b=P()|0;O()|0;break c}b=P()|0;O()|0;wb(c+32|0)}wb(c+16|0);break a}b=P()|0;O()|0;pf(a)}S(b|0);L()}function tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=xj(b),v[i>>2]=j;d=hb-16|0;hb=d;g=a;c=Pd(a);a:{if(c){f=gc(g);while(1){a=c;c=a+13|0;if(ut(b,c)){f=a;c=v[a>>2];if(c){continue}break a}if(!ut(c,b)){break a}f=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=gc(g);f=a}v[d+12>>2]=a;b=v[f>>2];if(!b){c=hb-16|0;hb=c;a=gc(g);h=gh(d,tc(20),hh(c+8|0,a));b=v[h>>2];a=v[e>>2];a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+17|0]=0;t[b+13|0]=a;t[b+14|0]=a>>>8;t[b+15|0]=a>>>16;t[b+16|0]=a>>>24;i=gc(h),j=1,t[i+4|0]=j;hb=c+16|0;Hg(g,v[d+12>>2],f,v[d>>2]);b=_d(d);mk(d);h=1}Gg(e+8|0,v[cc(d,b)>>2],h);hb=d+16|0;hb=e+16|0;return v[e+8>>2]+17|0}function ev(a){var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[23516]=0;c=Q(13,d+8|0,a|0)|0;b=v[23516];v[23516]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23516]=0;b=T(22,b|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[23516]=0;R(16,a+b|0,1);b=v[23516];v[23516]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;tk(c);break c}tk(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[23516]=0;Y(17,a+c|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$()}hb=d+16|0;return}a=P()|0;O()|0;v[23516]=0;Z(18);c=v[23516];v[23516]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function qz(a,b,c){var d=0,e=0,f=0,g=0;d=Kb(a);a=Fb(b);v[23516]=0;R(44,d|0,a|0);a=v[23516];v[23516]=0;if((a|0)!=1){a:{while(1){if(Fb(b)>>>0>e>>>0){f=v[oj(b,e)>>2];g=f&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}else{v[23516]=0;R(45,d|0,a<<24>>24);a=v[23516];v[23516]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[23516]=0;R(45,d|0,a<<24>>24);a=v[23516];v[23516]=0;if((a|0)!=1){break b}break a}v[23516]=0;R(45,d|0,63);a=v[23516];v[23516]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;wb(d);S(a|0);L()}function EN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-112|0;hb=f;v[f+108>>2]=0;d=Ln(a,e&65535,d,c,f+108|0);c=w[b+790|0];if(!v[f+108>>2]){e=(c|0)==15;h=e&!w[b+792|0];d=d<<8;a:{if(d){v[b+664>>2]=d;break a}d=0;if(e){break a}d=v[b+664>>2]}h=h?0:w[b+836|0]<<16}if((c|0)==15){c=w[b+792|0];b:{if(!c){c=v[b+76>>2];v[f>>2]=1;e=v[Vc(f,f+108|0)>>2]<<3;g=rka(c,0,d,0);d=(256<<e>>>1|0)+g|0;c=kb;c=d>>>0<g>>>0?c+1|0:c;g=d;e=e+8|0;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}d=Bc(c,e);break b}VA(f);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}d=v[Bb(c+68|0,w[b+792|0]-1|0)>>2]+d|0}v[b+664>>2]=d}Pn(a,b,d+h|0);hb=f+112|0}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;v[d+28>>2]=0;kk(a,d+28|0);a:{b:{i=v[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Kb(d+16|0);v[23516]=0;u[d+14>>1]=0;e=W(492,a|0,g|0,255)|0;h=v[23516];v[23516]=0;if((h|0)==1){break b}if(!e){break d}v[23516]=0;R(481,a|0,d+14|0);e=v[23516];v[23516]=0;if((e|0)==1){break b}v[23516]=0;U(11,d|0,c|0,g|0);e=v[23516];v[23516]=0;if((e|0)!=1){v[23516]=0;e=Q(493,b|0,d+14|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break e}Gb(e,d);xb(d);wb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;xb(d);break a}wb(g)}hb=d+32|0;return}f=P()|0;O()|0}wb(g);S(f|0);L()}function jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-32|0;hb=e;v[e+24>>2]=b;j=e,k=ge(a),v[j+8>>2]=k;f=En(e+24|0,e+8|0);a:{b:{h=vh(c,d);if(!h){break b}if(!Ms(a,c)){b=Fb(a);g=_c(a);c:{if(g-b>>>0>=h>>>0){g=wc(a);if((b|0)==(f|0)){break c}i=f+g|0;Xh(i+h|0,i,b-f|0);break c}im(a,g,(b+h|0)-g|0,b,f,0,h);g=v[a>>2]}b=b+h|0;th(a,b);t[e+8|0]=0;$d(b+g|0,e+8|0);b=f+g|0;while(1){if((c|0)==(d|0)){break b}$d(b,c);c=c+1|0;b=b+1|0;continue}}d=Th(e+8|0,c,d);c=Ic(d);f=Fb(d);v[23516]=0;c=fa(363,a|0,b|0,c|0,c+f|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){wb(d);break a}a=P()|0;O()|0;wb(d);S(a|0);L()}j=e,k=ge(a),v[j+8>>2]=k;c=Bp(e+8|0,f)}hb=e+32|0;return c|0}function nL(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=hb-48|0;hb=e;d=Kb(e+32|0);v[23516]=0;R(909,b|0,e+24|0);f=v[23516];v[23516]=0;if((f|0)!=1){b:{g=v[e+28>>2];f=v[e+24>>2];_f(d);v[23516]=0;f=!g&f>>>0<255?f:255;R(58,d|0,f|0);g=v[23516];v[23516]=0;if((g|0)==1){break b}c:{while(1){if((f|0)==(h|0)){b=eV(Ic(d),Fb(d));if((b|0)==-1){break c}v[23516]=0;R(58,d|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break c}break b}g=Jc(d,h);v[23516]=0;Q(910,b|0,g|0)|0;g=v[23516];v[23516]=0;if((g|0)!=1){h=h+1|0;continue}break}break b}v[23516]=0;U(11,e+8|0,a|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}a=e+8|0;Gb(c,a);xb(a);wb(d);hb=e+48|0;break a}}a=P()|0;O()|0;wb(d);S(a|0);L()}}function Bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;u[d+30>>1]=0;Wf(a,d+30|0);a:{b:{i=x[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Kb(d+16|0);v[23516]=0;u[d+14>>1]=0;e=Q(494,a|0,g|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break b}if(!e){break d}v[23516]=0;R(481,a|0,d+14|0);e=v[23516];v[23516]=0;if((e|0)==1){break b}v[23516]=0;U(11,d|0,c|0,g|0);e=v[23516];v[23516]=0;if((e|0)!=1){v[23516]=0;e=Q(493,b|0,d+14|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break e}Gb(e,d);xb(d);wb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;xb(d);break a}wb(g)}hb=d+32|0;return}f=P()|0;O()|0}wb(g);S(f|0);L()}function my(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;b=v[a>>2];if(!nc(b,v[a+4>>2])){b=Cb(b);v[e+8>>2]=b;c=Cb(v[a+4>>2]);while(1){if(Nb(b,c)){Ko(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=d;b=f>>>0<g>>>0?b+1|0:b;d=b;b=v[Ie(e+8|0)>>2];continue}else{c=v[a>>2];b=sc(c,v[a+4>>2]);l=e,m=Cb(c),v[l>>2]=m;d=uka(f,d,b,0);h=d;g=((kb&1)<<31|d>>>1)&2147483647;f=b<<24;d=0;i=Cb(v[a+4>>2]);while(1){b=v[e>>2];if(Nb(b,i)){j=b;c=v[b>>2];b=c>>>8|0;c=g+(c<<24)|0;b=b+k|0;b=Bc(uka(c,c>>>0<g>>>0?b+1|0:b,h,k),kb);v[j>>2]=b;c=f;f=c-b|0;d=d-(b>>>0>c>>>0)|0;Ie(e);continue}else{d=v[a>>2];if(!sc(d,v[a+4>>2])){Vu();L()}v[d>>2]=f+v[d>>2]}break}}break}}hb=e+16|0}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){b=v[f+12>>2]+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(t[b+2|0],u[e+10>>1])+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/2|0)+((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(b,h);v[c+4>>2]=v[c+4>>2]+B(b,g);Pb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;hb=f+16|0}function sI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Lg(a)|0)>(b|0)){break d}}a=ba(8)|0;v[23516]=0;d=Q(53,d|0,10725)|0;b=v[23516];v[23516]=0;if((b|0)==1){break c}a=rc(a,d);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}b=P()|0;O()|0;wb(d);break b}if(c<0|c>1){a=ba(8)|0;v[23516]=0;d=Q(53,d|0,11788)|0;b=v[23516];v[23516]=0;if((b|0)!=1){a=rc(a,d);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}b=P()|0;O()|0;wb(d);break b}b=P()|0;O()|0;ca(a|0);break b}e=(a+B(b,872)|0)+1075740|0,f=pl(c*64),v[e>>2]=f;hb=d+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function xv(a,b,c,d){var e=0,f=0,g=0;e=hb-48|0;hb=e;v[e+44>>2]=d;a:{f=v[b>>2];b:{if(!(lb[v[v[f>>2]+36>>2]](f,c,d)|0)){Ih(a);break b}Gl(e+24|0,v[b>>2],v[b+4>>2]);b=v[b>>2];d=v[v[b>>2]+24>>2];v[23516]=0;b=T(d|0,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}v[e+20>>2]=b-c;d=v[e+24>>2];f=v[e+28>>2];g=v[Hb(e+44|0,e+20|0)>>2];b=hb-16|0;hb=b;v[b+12>>2]=f;v[b+8>>2]=d;d=Gl(b,d,f);f=v[d+4>>2];d=v[d>>2];v[23516]=0;da(170,e+32|0,d|0,f|0,c|0,g|0);c=v[23516];v[23516]=0;c:{if((c|0)!=1){je(b+8|0);hb=b+16|0;break c}a=P()|0;O()|0;je(b+8|0);S(a|0);L()}b=ce(e+8|0);yD(a,v[e+32>>2],v[e+36>>2],v[b>>2],v[b+4>>2])}hb=e+48|0;return}a=P()|0;O()|0;je(e+24|0);S(a|0);L()}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[h+39890>>1])+B(u[e-2>>1],u[h+39888>>1])|0)+B(u[e+2>>1],u[h+39892>>1])|0)+B(u[e+4>>1],u[h+39894>>1])|0)/16384|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;hb=b+16|0}function lN(a,b,c,d,e){var f=0,g=0,h=0,i=0;a:{b:{c:{if(t[b+851|0]&1){f=w[b+848|0];g=c&240;if(g){f=f&15|g;t[b+848|0]=f}c=c&15;if(c){f=c|f&-16;t[b+848|0]=f}t[b+849|0]=(f&240)>>>4;if(v[a+480180>>2]!=32768){break a}break c}if(v[a+480180>>2]==32768){break c}c=w[b+849|0]-1|0;t[b+849|0]=c;if(c&255){break a}f=w[b+848|0];break b}f=w[b+848|0];if((f&240)==16){break b}if(!(w[a+480209|0]&16)){break a}}t[b+849|0]=(f&240)>>>4;c=f&15;c=d?c:0-c|0;d=v[b+656>>2];d:{if(uj(d)){v[b+852>>2]=v[b+852>>2]+B(c,v[v[d+44>>2]+36>>2]);break d}h=b,i=_g(a,Us(a,v[b+700>>2],u[b+772>>1],v[b+704>>2])+c|0,u[b+772>>1],v[b+704>>2]),v[h+700>>2]=i}if(!e){break a}v[b>>2]=0;v[b+4>>2]=0}}function fia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=hb-48|0;hb=c;d=a;a:{if(Tt(v[d>>2],v[d+8>>2])){v[g>>2]=0;break a}OS(c+16|0,c+32|0);jc(c+24|0,v[d>>2],v[d+8>>2],v[c+16>>2],v[c+20>>2]);h=v[c+28>>2];i=w[c+32|0];f=i&127;v[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(B(h,7)+a|0)+B(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=w[(c+32|0)+e|0];f=i&127|f<<7;v[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}Yb(d,h);OS(c+8|0,c+32|0);jc(c+24|0,v[d>>2],v[d+8>>2],v[c+8>>2],v[c+12>>2]);h=v[c+28>>2];f=v[g>>2];e=0;a=b;continue}break}Yb(d,e);if(a>>>0<33){break a}v[g>>2]=-1}hb=c+48|0}function mn(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;a:{b:{k=v[d>>2];if((k|0)!=(c|0)){break b}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break b}}v[d>>2]=c+1;t[c|0]=l;break a}c:{if(!(!Fb(g)|(a|0)!=(f|0))){g=0;a=v[i>>2];if((a-h|0)>159){break c}b=v[e>>2];v[i>>2]=a+4;v[a>>2]=b;break a}g=-1;f=nw(j,j+104|0,a)-j|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break c}v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[a+84e3|0];return 0}v[d>>2]=k+1;t[k|0]=w[a+84e3|0];v[e>>2]=v[e>>2]+1;g=0}return g}v[e>>2]=0;return 0}function Q4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-32|0;hb=e;f=Lb(a);a=x[v[b+24>>2]+480192>>1];v[23516]=0;R(179,f|0,a|0);c=v[23516];v[23516]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=a&65535;c=v[b+24>>2];if(d>>>0>x[c+480192>>1]){break b}c=iM(c,d);v[23516]=0;c=Q(53,e|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){d=v[b+24>>2];v[23516]=0;U(1023,e+16|0,d|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break e}v[23516]=0;R(181,f|0,e+16|0);d=v[23516];v[23516]=0;if((d|0)==1){break d}wb(e+16|0);wb(c);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;wb(e+16|0)}wb(c);break a}hb=e+32|0;return}a=P()|0;O()|0}Me(f);S(a|0);L()}function lm(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;f=a+1074312|0;Ab(e+8|0,f,84);a:{if(zb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){Ab(e+8|0,f,10);if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;Ab(e+8|0,f,10);if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}t[b+831|0]=0;u[b+778>>1]=0}hb=e+16|0}function hz(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;i=gl(a,b);a:{if((i|0)==255){break a}if(gk(v[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=rka(1<<20-f,0,c,0)+24858e3|0;h=kb;c=Bc(uka(c,c>>>0<24858e3?h+1|0:h,49716e3,0),kb)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Rc(g+14|0,g+12|0)>>1]}h=jt(i);e=Ib(a+8|0,i);t[e|0]=(f<<10|c)>>>8|(d?0:32);ah(v[a>>2],v[a+4>>2],b,h|160,c&255);ah(v[a>>2],v[a+4>>2],b,h|176,w[e|0]);t[a+534|0]=1}hb=g+16|0}function bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-80|0;hb=d;e=uf(d+48|0);v[23516]=0;g=Q(817,b|0,e|0)|0;f=v[23516];v[23516]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23516]=0;T(818,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break b}}break a}g=v[e+4>>2];v[23516]=0;U(188,d|0,b|0,g|0);f=v[23516];v[23516]=0;if((f|0)==1){break a}f=hc(d+24|0,d);cd(e+8|0,f);yb(f);yb(d);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}v[23516]=0;Q(186,b|0,2-c|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break d}break a}qk(a,e)}yd(e);hb=d+80|0;return}a=P()|0;O()|0;yd(e);S(a|0);L()}function C0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-16|0;hb=g;a:{b:{if(!nc(b,-1)){i=v[a+8>>2];j=v[a+12>>2];d=v[a+24>>2];if((d|0)==v[a+28>>2]){e=-1;if(!(w[a+48|0]&16)){break a}h=v[a+20>>2];k=v[a+44>>2];v[23516]=0;c=a+32|0;R(45,c|0,0);f=v[23516];v[23516]=0;if((f|0)==1){break b}f=_c(c);v[23516]=0;R(58,c|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break b}e=wc(c);Fw(a,e,Fb(c)+e|0);Rr(a,d-h|0);v[a+44>>2]=v[a+20>>2]+(k-h|0);d=v[a+24>>2]}v[g+12>>2]=d+1;d=v[Vc(g+12|0,a+44|0)>>2];v[a+44>>2]=d;if(w[a+48|0]&8){c=wc(a+32|0);qn(a,c,c+(j-i|0)|0,d)}e=eH(a,kp(b));break a}e=Ew(b);break a}a=V(0)|0;O()|0;_(a|0)|0;$()}hb=g+16|0;return e|0}function s4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-32|0;hb=e;f=Lb(a);a=x[v[b+24>>2]+480190>>1];v[23516]=0;R(179,f|0,a|0);d=v[23516];v[23516]=0;a=1;a:{if((d|0)!=1){b:{c:{d:{e:{while(1){c=a&65535;d=v[b+24>>2];if(c>>>0>x[d+480190>>1]){break b}v[23516]=0;d=Q(53,e|0,jM(d,c)|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){c=v[b+24>>2];v[23516]=0;U(1023,e+16|0,c|0,d|0);c=v[23516];v[23516]=0;if((c|0)==1){break e}v[23516]=0;R(181,f|0,e+16|0);c=v[23516];v[23516]=0;if((c|0)==1){break d}wb(e+16|0);wb(d);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;wb(e+16|0)}wb(d);break a}hb=e+32|0;return}a=P()|0;O()|0}Me(f);S(a|0);L()}function _0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;if(HH(1,e+16|0)){Yr(v[115992],12747);L()}c=Xr(e+8|0,v[e+16>>2]);g=Xr(e,v[e+20>>2]);d=hb-32|0;hb=d;b=hb-16|0;hb=b;a=hb-16|0;hb=a;h=a,i=rka(v[c>>2],v[c+4>>2],1e9,0),v[h>>2]=i;v[a+4>>2]=kb;c=ot(a+8|0,a);f=v[c+4>>2];c=v[c>>2];hb=a+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=a;hb=b+16|0;f=v[d+8>>2];c=v[d+12>>2];a=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=a;a=d;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=ot(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];hb=d+32|0;a=Xl(e+24|0,a,b);b=v[a+4>>2];a=v[a>>2];hb=e+32|0;kb=b;return a|0}function il(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=Fb(b);v[23516]=0;R(44,d|0,a|0);a=v[23516];v[23516]=0;if((a|0)!=1){a:{while(1){if(Fb(b)>>>0>e>>>0){f=v[oj(b,e)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if(v[(a<<2)+c>>2]==(f|0)){v[23516]=0;R(45,d|0,a<<24>>24);a=v[23516];v[23516]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[23516]=0;R(45,d|0,a<<24>>24);a=v[23516];v[23516]=0;if((a|0)!=1){break b}break a}v[23516]=0;R(45,d|0,63);a=v[23516];v[23516]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;wb(d);S(a|0);L()}function c2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-32|0;hb=e;h=Kb(a);f=Kb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=v[b+24>>2];if(d>>>0>x[c+480192>>1]){if(!(i&1)){break c}v[23516]=0;R(249,h|0,f|0);a=v[23516];v[23516]=0;if((a|0)!=1){break c}a=P()|0;O()|0;break a}c=iM(c,d);v[23516]=0;c=Q(53,e|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}d=Pe(c);v[23516]=0;g=Q(820,f|0,c|0)|0;j=v[23516];v[23516]=0;d:{if((j|0)==1){break d}v[23516]=0;Q(955,g|0,21721)|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}i=d^1|i;wb(c);a=a+1|0;continue}break}a=P()|0;O()|0;wb(c);break a}wb(f);hb=e+32|0;return}a=P()|0;O()|0}wb(f);wb(h);S(a|0);L()}function Wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[h+39890>>1])+B(t[e-1|0],u[h+39888>>1])|0)+B(t[e+1|0],u[h+39892>>1])|0)+B(t[e+2|0],u[h+39894>>1])<<8)/16384|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;hb=b+16|0}function CX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{b:{c:{d:{if(h=oh(v[b+4>>2],w[b+11|0]),i=1,j=v[b+12>>2],j?h:i){Kb(a);break d}e=Kb(c+16|0);d=wd(v[b+4>>2],w[b+11|0]);f=er(14402);g=qd(b);v[23516]=0;X(100,e|0,g|0,d|0,d+f|0);d=v[23516];v[23516]=0;e:{if((d|0)!=1){v[23516]=0;W(101,e|0,14402,f|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;xb(e);S(a|0);L()}v[23516]=0;R(130,c|0,b+12|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}v[23516]=0;U(2,a|0,c+16|0,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}xb(c);xb(c+16|0)}hb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;xb(c)}xb(c+16|0);S(b|0);L()}function a2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-32|0;hb=e;h=Kb(a);f=Kb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=v[b+24>>2];if(d>>>0>x[c+480190>>1]){if(!(i&1)){break c}v[23516]=0;R(249,h|0,f|0);a=v[23516];v[23516]=0;if((a|0)!=1){break c}a=P()|0;O()|0;break a}v[23516]=0;c=Q(53,e|0,jM(c,d)|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}d=Pe(c);v[23516]=0;g=Q(820,f|0,c|0)|0;j=v[23516];v[23516]=0;d:{if((j|0)==1){break d}v[23516]=0;Q(955,g|0,21721)|0;g=v[23516];v[23516]=0;if((g|0)==1){break d}i=d^1|i;wb(c);a=a+1|0;continue}break}a=P()|0;O()|0;wb(c);break a}wb(f);hb=e+32|0;return}a=P()|0;O()|0}wb(f);wb(h);S(a|0);L()}function Lr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=hb-16|0;hb=h;f=d?d:467716;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}if(!v[v[116018]>>2]){v[i>>2]=d&57343;e=1;break a}a=a-194|0;if(a>>>0>50){break c}d=v[(a<<2)+83792>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[115992]=25;e=-1;break a}v[f>>2]=d}hb=h+16|0;return e}function dba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-80|0;hb=d;e=uf(d+48|0);v[23516]=0;c=Q(813,b|0,e|0)|0;f=v[23516];v[23516]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23516]=0;T(814,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break b}}break a}c=v[e+4>>2];v[23516]=0;c=_b(c);c=c?c:-1;U(188,d|0,b|0,c|0);f=v[23516];v[23516]=0;if((f|0)==1){break a}f=hc(d+24|0,d);cd(e+8|0,f);yb(f);yb(d);d:{c=c&1;if(!c){break d}v[23516]=0;Q(186,b|0,2-c|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break d}break a}qk(a,e)}yd(e);hb=d+80|0;return}a=P()|0;O()|0;yd(e);S(a|0);L()}function _aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-48|0;hb=d;f=Ic(b);e=Fb(b);h=Ic(c);i=Fb(c);g=-1;a:{if(!e){break a}j=e+f|0;e=f;while(1){if((e|0)==(j|0)){break a}if(Ap(h,i,w[e|0])){e=e+1|0;continue}break}g=e-f|0}b:{c:{if((g|0)!=-1){k=d,l=ge(b),v[k+32>>2]=l;f=hj(d+40|0,d+32|0);k=d,l=ge(b),v[k+8>>2]=l;k=d,l=Bp(d+8|0,g),v[k+16>>2]=l;c=hj(d+24|0,d+16|0);JL(b,v[f>>2],v[c>>2]);break c}i=Fb(b);if(!i){break c}h=Ic(b);j=Fb(b);e=Ic(c);g=-1;f=Fb(c);if(f){c=h+j|0;d:{while(1){if((c|0)==(h|0)){break d}c=c-1|0;if(!Ap(e,f,w[c|0])){continue}break}g=c-h|0}}if((i-1|0)!=(g|0)){break c}Kb(a);break b}Xc(a,b)}hb=d+48|0}function uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=hb-16|0;hb=c;a:{b:{d=v[b+8>>2];if((d|0)==v[a+8>>2]){e=v[b+4>>2];if((e|0)!=v[a+4>>2]){break b}v[c+12>>2]=d;v[c+8>>2]=d;d=v[Hb(c+12|0,c+8|0)>>2];v[c+12>>2]=e;v[c+8>>2]=e;h=v[Hb(c+12|0,c+8|0)>>2];i=v[a>>2];j=v[b>>2];a=0;c:while(1){if((a|0)==(d|0)){break a}k=B(a,e);b=0;while(1)if((b|0)==(h|0)){a=a+1|0;continue c}else{l=(b+k<<1)+i|0;f=Wh(C(Td(z[v[(b<<2)+j>>2]+(a<<2)>>2],C(-1))*C(32768)));d:{if(C(D(f))<C(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=$c(g),u[m>>1]=n;b=b+1|0;continue}}}aa(17433,9012,27,9539);L()}aa(17383,9012,28,9539);L()}hb=c+16|0}function oX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;e=qd(b);d=wd(v[b+4>>2],w[b+11|0]);i=qd(c);j=wd(v[c+4>>2],w[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(cu(i,j,w[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=cc(g+8|0,Pj(b));d=cc(g,Pf(Pj(b),f));gD(b,v[c>>2],v[d>>2]);break c}f=zk(v[b+4>>2],w[b+11|0]);if(!f){break c}e=qd(b);i=wd(v[b+4>>2],w[b+11|0]);j=qd(c);d=-1;h=wd(v[c+4>>2],w[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!cu(j,h,w[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Kb(a);break b}Xc(a,b)}hb=g+16|0}function kia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=v[a>>2];d=xq(c,v[a+4>>2]);if(d>>>0<b>>>0){f=hb-32|0;hb=f;c=b-d|0;b=v[Db(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=(b-e|0)/48>>>0){d=hb-16|0;hb=d;b=HU(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);hb=d+16|0}else{JS(a);a=a+48|0;v[b+4>>2]=a;continue}break}break a}b=Db(a);d=EU(f+8|0,FU(a,xq(v[a>>2],e)+c|0),xq(v[a>>2],v[a+4>>2]),b);b=hb-16|0;hb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=B(c,48)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){JS(c);c=v[b>>2]+48|0;v[b>>2]=c;continue}break}Kd(b);hb=b+16|0;DU(a,d);CU(d)}hb=f+32|0;return}if(b>>>0<d>>>0){Ld(a,c+B(b,48)|0)}}function CN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;v[d+12>>2]=b;if(b>>>0<4294967280){a:{if(rl(a)>>>0>=b>>>0){break a}i=d,j=wd(v[a+4>>2],w[a+11|0]),v[i+8>>2]=j;e=ih(v[Vc(d+12|0,d+8|0)>>2]);if((e|0)==(rl(a)|0)){break a}f=wd(v[a+4>>2],w[a+11|0]);b:{c:{if((e|0)==10){g=v[a>>2];h=1;b=a;c=f;break c}b=e+1|0;d:{if(rl(a)>>>0<e>>>0){b=tc(b);break d}v[23516]=0;b=T(50,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}c=w[a+11|0];h=zf(c);g=qd(a);c=wd(v[a+4>>2],c)}b=Ce(b,g,c+1|0);if(h){Jb(g)}if((e|0)!=10){bf(a,e+1|0);xd(a,f);td(a,b);break b}Xd(a,f)}}hb=d+16|0;return}df();L()}function tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=hb-16|0;hb=c;a:{b:{d=v[b+8>>2];if((d|0)==v[a+8>>2]){e=v[b+4>>2];if((e|0)!=v[a+4>>2]){break b}v[c+12>>2]=d;v[c+8>>2]=d;d=v[Hb(c+12|0,c+8|0)>>2];v[c+12>>2]=e;v[c+8>>2]=e;h=v[Hb(c+12|0,c+8|0)>>2];i=v[a>>2];j=v[b>>2];a=0;c:while(1){if((a|0)==(d|0)){break a}k=B(a,e);b=0;while(1)if((b|0)==(h|0)){a=a+1|0;continue c}else{l=(b+k|0)+i|0;f=Wh(C(Td(z[v[(b<<2)+j>>2]+(a<<2)>>2],C(-1))*C(128)));d:{if(C(D(f))<C(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=ZR(g),t[m|0]=n;b=b+1|0;continue}}}aa(17433,9012,27,9539);L()}aa(17383,9012,28,9539);L()}hb=c+16|0}function o6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=xj(b),v[i>>2]=j;c=hb-16|0;hb=c;g=a;d=Pd(a);a:{if(d){f=gc(g);while(1){a=d;d=a+16|0;if(at(b,d)){f=a;d=v[a>>2];if(d){continue}break a}if(!at(d,b)){break a}f=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=gc(g);f=a}v[c+12>>2]=a;b=v[f>>2];if(!b){a=hb-16|0;hb=a;b=gc(g);b=gh(c,tc(40),hh(a+8|0,b));Kb(Xc(v[b>>2]+16|0,v[e>>2])+12|0);i=gc(b),j=1,t[i+4|0]=j;hb=a+16|0;Hg(g,v[c+12>>2],f,v[c>>2]);b=_d(c);a=v[c>>2];v[c>>2]=0;if(a){if(w[gc(c)+4|0]){nm(a+16|0)}if(a){Jb(a)}}h=1}Gg(e+8|0,v[cc(c,b)>>2],h);hb=c+16|0;a=sd(v[e+8>>2]);hb=e+16|0;return a+12|0}function gv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;t[f+15|0]=d;t[b+12|0]=w[a|0]&15|w[b+12|0]&240;i=a+1|0;e=f+15|0;Mg(b,w[Vb(i,e)|0]);g=w[Vb(a+2|0,e)|0];t[b+13|0]=g;k=b,l=Bd(w[a+3|0],g,d),t[k+14|0]=l;e=w[Vb(a+4|0,e)|0];t[b+15|0]=e;k=b,l=Bd(w[a+5|0],e,d),t[k+16|0]=l;g=v[b>>2];b=0;while(1){t[f+14|0]=25;if(b>>>0<w[Vb(f+14|0,i)|0]){e=B(b,3)+a|0;h=Wb(w[e+6|0]+c<<24>>24,0,64);d=Bb(g,b);t[d+2|0]=h;e=w[e+7|0]|w[e+8|0]<<8;u[d>>1]=e;a:{if(!b){break a}h=Bb(g,b-1|0);j=x[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;u[d>>1]=e;if(x[h>>1]<=(e&65535)>>>0){break a}u[d>>1]=e+256}b=b+1|0;continue}break}hb=f+16|0}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-80|0;hb=d;e=uf(d+48|0);v[23516]=0;g=Q(888,b|0,e|0)|0;f=v[23516];v[23516]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23516]=0;T(889,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break b}}break a}g=v[e+4>>2];v[23516]=0;U(188,d|0,b|0,g|0);f=v[23516];v[23516]=0;if((f|0)==1){break a}f=hc(d+24|0,d);cd(e+8|0,f);yb(f);yb(d);d:{if(!(g&1)|c>>>0<2){break d}v[23516]=0;Q(186,b|0,1)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break d}break a}qk(a,e)}yd(e);hb=d+80|0;return}a=P()|0;O()|0;yd(e);S(a|0);L()}function fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-80|0;hb=d;e=uf(d+48|0);v[23516]=0;c=Q(809,b|0,e|0)|0;f=v[23516];v[23516]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23516]=0;T(810,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break b}}break a}c=v[e+4>>2];v[23516]=0;c=_b(c);U(188,d|0,b|0,c|0);f=v[23516];v[23516]=0;if((f|0)==1){break a}f=hc(d+24|0,d);cd(e+8|0,f);yb(f);yb(d);d:{c=c&1;if(!c){break d}v[23516]=0;Q(186,b|0,2-c|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break d}break a}qk(a,e)}yd(e);hb=d+80|0;return}a=P()|0;O()|0;yd(e);S(a|0);L()}function fD(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Qb(a,3878,4)){break a}b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);if(b>>>0<36){break a}c=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);if(c>>>0<36){break a}d=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);if(d>>>0<36){break a}e=w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24);if(B(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function MU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{if(!d){break a}i=w[e|0];if(!i){break a}g=d-6|0;j=(g&255)>>>0<6&35>>>g;l=d-2|0;m=0-c|0;while(1){if(!b){break a}k=(l&255)>>>0>2;h=B(m,6);c=a;a=h+c|0;f=w[a+3|0];b:{if(!(k|(f-2&255)>>>0>2)){g=1;if(w[(c+h|0)+5|0]<224){break b}break a}g=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}g=1}c:{if(k){break c}f=c+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=c+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}b=b-1|0;if(!g){continue}c=w[(c+h|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}t[e|0]=0}}function nY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(Tg(a,v[b+8>>2],f)){dw(b,c,d,e);return}g=w[b+53|0];i=v[a+12>>2];t[b+53|0]=0;h=w[b+52|0];t[b+52|0]=0;m=a+16|0;$v(v[m>>2],v[a+20>>2],b,c,d,e,f);j=w[b+53|0];l=g|j;k=w[b+52|0];h=h|k;g=a+24|0;i=(i<<3)+m|0;a:{if(g>>>0>=i>>>0){break a}while(1){if(w[b+54|0]){break a}b:{if(k){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!j){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;$v(v[g>>2],v[g+4>>2],b,c,d,e,f);j=w[b+53|0];l=j|l;k=w[b+52|0];h=k|h;g=g+8|0;if(i>>>0>g>>>0){continue}break}}t[b+53|0]=(l&255)!=0;t[b+52|0]=(h&255)!=0}function tS(a){var b=0,c=0,d=0,e=0,f=0;b=hb-32|0;hb=b;e=b,f=_b(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[e>>2]=f;v[b+4>>2]=0;e=b,f=_b(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[e+8>>2]=f;v[b+12>>2]=0;c=_b(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24));v[b+16>>2]=c?c:52;v[b+20>>2]=0;e=b,f=_b(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+80|0,v[e+24>>2]=f;v[b+28>>2]=0;a=b;d=_e(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=av(v[a>>2],v[a+4>>2],v[c>>2],v[c+4>>2])?c:a;continue}}hb=b+32|0;c=v[a>>2];b=c-52|0;kb=v[a+4>>2]-(c>>>0<52)|0;return b}function PZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=sc(d,v[a+4>>2]);if(c>>>0<b>>>0){g=hb-32|0;hb=g;d=b-c|0;b=v[Db(a)>>2];e=v[a+4>>2];a:{if(d>>>0<=b-e>>2>>>0){GF(a,d);break a}c=iw(a);e=pg(a,sc(v[a>>2],e)+d|0);f=sc(v[a>>2],v[a+4>>2]);b=g+8|0;og(b+12|0,c);if(e){c=CF(v[b+16>>2],e)}else{c=0}v[b>>2]=c;f=c+(f<<2)|0;v[b+8>>2]=f;v[b+4>>2]=f;h=zc(b),i=c+(e<<2)|0,v[h>>2]=i;e=hb-16|0;hb=e;c=Dl(e,b+8|0,d);d=v[c>>2];while(1){if(v[c+4>>2]!=(d|0)){DF(d);d=v[c>>2]+4|0;v[c>>2]=d;continue}break}Kd(c);hb=e+16|0;Cd(a,b);gQ(b);a=v[b>>2];if(a){FF(v[b+16>>2],a,Jz(b))}}hb=g+32|0;return}if(b>>>0<c>>>0){Ld(a,d+(b<<2)|0)}}function yH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=hb-208|0;hb=f;v[f+204>>2]=c;c=f+160|0;Rb(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((xH(0,b,f+200|0,f+80|0,c,d,e)|0)<0){b=-1;break a}i=v[a+76>>2]>=0;g=v[a>>2];if(v[a+72>>2]<=0){v[a>>2]=g&-33}b:{c:{d:{if(!v[a+48>>2]){v[a+48>>2]=80;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;h=v[a+44>>2];v[a+44>>2]=f;break d}if(v[a+16>>2]){break c}}c=-1;if(DC(a)){break b}}c=xH(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){lb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=h;v[a+28>>2]=0;b=v[a+20>>2];v[a+16>>2]=0;v[a+20>>2]=0;c=b?c:-1}b=a;a=v[a>>2];v[b>>2]=a|g&32;b=a&32?-1:c;if(!i){break a}}hb=f+208|0;return b}function naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;f=c;e=hb-16|0;hb=e;g=b;d=Pd(b);a:{if(d){c=gc(g);while(1){b=d;d=b+16|0;if(UL(f,d)){c=b;d=v[b>>2];if(d){continue}break a}if(!UL(d,f)){break a}c=b+4|0;d=v[b+4>>2];if(d){continue}break}break a}b=gc(g);c=b}v[e+12>>2]=b;b=v[c>>2];if(!b){b=hb-16|0;hb=b;d=gc(g);d=gh(e,tc(28),hh(b+8|0,d));i=v[d>>2];v[23516]=0;R(866,i+16|0,f|0);f=v[23516];v[23516]=0;b:{if((f|0)!=1){j=gc(d),k=1,t[j+4|0]=k;hb=b+16|0;break b}a=P()|0;O()|0;TL(d);S(a|0);L()}Hg(g,v[e+12>>2],c,v[e>>2]);b=_d(e);TL(e);i=1}c=h+8|0;Gg(c,v[cc(e,b)>>2],i);hb=e+16|0;bP(a,c);hb=h+16|0}function eP(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function x$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-48|0;hb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=lb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;bd(a,c);v[23516]=0;a=T(1136,a|0)|0;b=v[23516];v[23516]=0;b:{if((b|0)!=1){Zb(f+24|0);c:{if(e){Qh(f+24|0,a);break c}Ph(f+24|0,a)}g=f,h=ge(f+24|0),v[g+16>>2]=h;while(1){g=f,h=uh(f+24|0),v[g+8>>2]=h;if(!mj(f+16|0,f+8|0)){c=v[f+40>>2];wb(f+24|0);break a}a=t[v[f+16>>2]];v[23516]=0;Q(21,f+40|0,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){He(f+16|0);continue}break}c=P()|0;O()|0;wb(f+24|0);break b}c=P()|0;O()|0;Zb(f+24|0)}S(c|0);L()}hb=f+48|0;return c|0}function OA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Mg(b,Bd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;f=((c|0)!=0)<<1;h=v[b>>2];j=Qd(h,v[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){NA(b,32);hb=e+16|0}else{a=k+(d<<2)|0;u[e+12>>1]=w[a+160|0]|w[a+161|0]<<8;g=ie(e+14|0,e+12|0);i=Bb(h,d);g=x[g>>1];u[i>>1]=g;u[e+14>>1]=g+1;t[e+11|0]=(c^w[a+162|0])>>>f;t[e+10|0]=64;l=i,m=w[Vb(e+11|0,e+10|0)|0],t[l+2|0]=m;d=d+1|0;continue}break}}function DV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-208|0;hb=d;OB(c,a);NB(c,d+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=hb-16|0;hb=c;v[c+12>>2]=64;v[c+8>>2]=255;e=w[Hb(c+12|0,c+8|0)|0];hb=c+16|0;t[d+12|0]=e;Mg(b,w[Vb(a+4|0,d+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;e=v[b>>2];f=Qd(e,v[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=w[d+18|0];c=Bb(e,0);break b}g=x[Bb(e,a-1|0)>>1];v[d+12>>2]=1;b=(d+16|0)+B(a,3)|0;v[d+8>>2]=(t[b+1|0]&1)<<8|w[b|0];h=Ne(d+12|0,d+8|0);c=Bb(e,a);u[c>>1]=x[h>>1]+g;b=w[b+2|0]}t[c+2|0]=b;a=a+1|0;continue}}hb=d+208|0}function j3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb+-64|0;hb=d;f=d+16|0;h=hb-16|0;hb=h;i=qP(h+8|0);while(1){if((j|0)==12){hb=h+16|0}else{g=hb+-64|0;hb=g;c=v[i+4>>2];e=v[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=cJ(dJ(g+8|0,32));break a}e=E(c);e=dJ(g+8|0,(c<<e+1?32:31)-e|0);while(1){k=cJ(e);if(c>>>0<=k>>>0){continue}break}c=v[i>>2]+k|0}hb=g- -64|0;l=Bb(f,j),m=c,v[l>>2]=m;j=j+1|0;continue}break}f=zP(d,f,CP(f));xP(a,f);wm(f);hb=d- -64|0;d=nx(a+120|0,a,b);t[d+20|0]=1;v[23516]=0;R(1089,a|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){a=P()|0;O()|0;wn(d);S(a|0);L()}return a|0}function KL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=hb-16|0;hb=h;t[h+15|0]=b;t[h+14|0]=10;Mg(g,w[Vb(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;j=v[g>>2];k=Qd(j,v[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=w[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=Bb(j,b);l=B(b,3)+f|0;i=(w[l|0]|w[l+1|0]<<8)>>>4|0;u[m>>1]=i;c:{if(b){n=x[Bb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=Bb(j,b),p=i,u[o>>1]=p}o=m,p=Bd(w[l+2|0],0,64),t[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}t[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;hb=h+16|0}function Eaa(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){Rs(a+484344|0);_f(a+1298308|0);fA(a+1298320|0);_f(a+1298332|0);Gc(a+1298408|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){b=a+906300|0;c=ck(b);while(1){if((b|0)==(c|0)){break a}kV(b);b=b+160|0;continue}}d=v[b>>2];if(d){Jb(Ot(d))}v[b>>2]=0;b=b+4|0;continue}}}else{um(c);c=c+104|0;continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0}else{v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+872|0;continue}break}}function wD(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];d=Qg(c,v[a+4>>2]);if(d>>>0<b>>>0){f=hb-32|0;hb=f;c=b-d|0;b=v[Db(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=hb-16|0;hb=d;b=ar(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);hb=d+16|0}else{Qj(a);a=a+8|0;v[b+4>>2]=a;continue}break}break a}b=Db(a);d=cr(f+8|0,dr(a,Qg(v[a>>2],e)+c|0),Qg(v[a>>2],v[a+4>>2]),b);b=hb-16|0;hb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=(c<<3)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){Qj(c);c=v[b>>2]+8|0;v[b>>2]=c;continue}break}Kd(b);hb=b+16|0;Cd(a,d);br(d)}hb=f+32|0;return}if(b>>>0<d>>>0){Ld(a,c+(b<<3)|0)}}function kU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=kf(f+16|0,1,0);b:{c:{d:{while(1){d=wc(c);Cx(f+8|0,d,Fb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=Yg(Fb(c));v[23516]=0;R(57,c|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=wc(c);v[23516]=0;R(58,c|0,b-d|0);b=v[23516];v[23516]=0;e:{if((b|0)!=1){v[23516]=0;R(70,e|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break e}break c}break c}wb(c);hb=f+32|0;break b}a=P()|0;O()|0;wb(c);S(a|0);L()}v[23516]=0;R(69,a|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(e);hb=e+16|0;break a}a=P()|0;O()|0;xb(e);S(a|0);L()}}function Uo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=kf(f+16|0,1,0);b:{c:{d:{while(1){d=wc(c);Jx(f+8|0,d,Fb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=Yg(Fb(c));v[23516]=0;R(57,c|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=wc(c);v[23516]=0;R(58,c|0,b-d|0);b=v[23516];v[23516]=0;e:{if((b|0)!=1){v[23516]=0;R(70,e|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break e}break c}break c}wb(c);hb=f+32|0;break b}a=P()|0;O()|0;wb(c);S(a|0);L()}v[23516]=0;R(69,a|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(e);hb=e+16|0;break a}a=P()|0;O()|0;xb(e);S(a|0);L()}}function eY(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-32|0;hb=k;m=v[c>>2];l=v[c+8>>2];c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=l;v[k+24>>2]=c;v[k+28>>2]=l;v[k+20>>2]=m;v[k+16>>2]=d;v[23516]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Na(1063,a|0,b|0,k|0)|0;b=v[23516];v[23516]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23516]=0;ja(949,10434,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}$();a=-255}hb=k+32|0;break a}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}return a|0}function wp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=kf(f+16|0,1,0);a:{b:{c:{while(1){d=wc(c);Jx(f+8|0,d,Fb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break c}d=Yg(Fb(c));v[23516]=0;R(57,c|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=wc(c);v[23516]=0;R(58,c|0,b-d|0);b=v[23516];v[23516]=0;d:{if((b|0)!=1){v[23516]=0;R(59,e|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break d}break b}break b}wb(c);hb=f+32|0;break a}a=P()|0;O()|0;wb(c);S(a|0);L()}v[23516]=0;R(56,a|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){wb(e);hb=e+16|0;return}a=P()|0;O()|0;wb(e);S(a|0);L()}function i9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=kf(f+16|0,1,0);a:{b:{c:{while(1){d=wc(c);Jx(f+8|0,d,Fb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break c}d=Yg(Fb(c));v[23516]=0;R(57,c|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=wc(c);v[23516]=0;R(58,c|0,b-d|0);b=v[23516];v[23516]=0;d:{if((b|0)!=1){v[23516]=0;R(59,e|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break d}break b}break b}wb(c);hb=f+32|0;break a}a=P()|0;O()|0;wb(c);S(a|0);L()}v[23516]=0;R(56,a|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){wb(e);hb=e+16|0;return}a=P()|0;O()|0;wb(e);S(a|0);L()}function b2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;a:{if(!(c&1024)){break a}i=g,j=Pj(b),v[i+8>>2]=j;c=zk(v[b+4>>2],w[b+11|0]);b:{if(!c){break b}if(w[qd(b)|0]!=43){if(w[qd(b)|0]!=45){break b}}d=d+1|0;AJ(g+8|0)}if(c>>>0>=d>>>0){break a}e=v[cc(g,v[g+8>>2])>>2];c=d-zk(v[b+4>>2],w[b+11|0])|0;c:{e=jo(e,Pj(b));d=wd(v[b+4>>2],w[b+11|0]);if(e>>>0<=d>>>0){if(c){f=rl(b);d:{if(c>>>0<=f-d>>>0){f=qd(b);if((d|0)==(e|0)){break d}h=e+f|0;Xh(c+h|0,h,d-e|0);break d}Py(b,f,(c+d|0)-f|0,d,e,c);f=v[b>>2]}fI(e+f|0,c,48);c=c+d|0;io(b,c);nd(c+f|0,0)}break c}pk();L()}Pj(b)}Xc(a,b);hb=g+16|0}function gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(v[a+4>>2]!=v[Db(a)>>2]){c=hb-16|0;hb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;TN(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;ic(c);hb=c+16|0;return}f=hb-32|0;hb=f;h=Db(a);i=f+8|0;c=a;g=Yy(v[a>>2],v[a+4>>2])+1|0;e=hb-16|0;hb=e;v[e+12>>2]=g;d=hb-16|0;hb=d;v[d+12>>2]=613566756;v[d+8>>2]=2147483647;a=v[Hb(d+12|0,d+8|0)>>2];hb=d+16|0;a:{if(a>>>0>=g>>>0){d=Xy(c);if(d>>>0<a>>>1>>>0){v[e+8>>2]=d<<1;a=v[Vc(e+8|0,e+12|0)>>2]}hb=e+16|0;break a}rd();L()}a=XN(i,a,Yy(v[c>>2],v[c+4>>2]),h);TN(v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+7;WN(c,a);VN(a);hb=f+32|0}function efa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;jd(b,0);_h(d,1,a);c=d+16|0;Cc(c,d);xe(b+43|0,c);wb(c);v[b>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[b+4>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[b+8>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);v[b+24>>2]=w[a+62|0]|w[a+63|0]<<8;sl(b,+((w[a+60|0]^8)-120|0)/192);t[d+16|0]=w[a+61|0];t[d|0]=64;f=b,g=w[Vb(c,d)|0]<<2,u[f+30>>1]=g;u[b+34>>1]=0;c=w[a+47|0];if(c&4){u[b+34>>1]=1;v[b>>2]=v[b>>2]>>>1;e=1;c=w[a+47|0]}if(c&32){e=e|4;u[b+34>>1]=e;c=w[a+47|0]}if(c<<24>>24<0){u[b+34>>1]=e|2}hb=d+32|0}function I_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=OF(b);Jk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Ik(k,a);Ri(i,k);Yc(k);Ph(k,a);Ri(h,k);Yc(k);l=d,m=Xi(a),v[l>>2]=m;l=e,m=Yi(a),v[l>>2]=m;Wg(k,a);yc(f,k);wb(k);Qh(k,a);Ri(g,k);Yc(k);a=Hk(a);break a}a=NF(b);Jk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Ik(k,a);Ri(i,k);Yc(k);Ph(k,a);Ri(h,k);Yc(k);l=d,m=Xi(a),v[l>>2]=m;l=e,m=Yi(a),v[l>>2]=m;Wg(k,a);yc(f,k);wb(k);Qh(k,a);Ri(g,k);Yc(k);a=Hk(a)}v[j>>2]=a;hb=k+16|0}function yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-80|0;hb=d;e=uf(d+48|0);v[23516]=0;c=Q(408,b|0,e|0)|0;f=v[23516];v[23516]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23516]=0;T(409,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break a}}break c}c=hb-16|0;hb=c;g=c,h=_b(v[e+4>>2]),v[g+12>>2]=h;v[c+8>>2]=8;f=v[Vc(c+12|0,c+8|0)>>2];hb=c+16|0;v[23516]=0;U(188,d|0,b|0,f-8|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;yd(e);S(a|0);L()}b=hc(d+24|0,d);cd(e+8|0,b);yb(b);yb(d);qk(a,e)}yd(e);hb=d+80|0}function SK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;Jh(f+8|0,b);g=hb-16|0;hb=g;Vg(g+8|0,v[f+8>>2],v[f+12>>2]);j=v[g+8>>2];e=v[g+12>>2];h=hb-16|0;hb=h;k=h,l=Cb(a),v[k+8>>2]=l;b=hb-16|0;hb=b;i=v[h+8>>2];d=i;a=v[d+12>>2];d=v[d+8>>2];a:{if((a|0)<0){break a}c=v[i+4>>2];if(!a&c>>>0<d>>>0|a){break a}v[b+8>>2]=c-d;v[b+12>>2]=0-(a+(d>>>0>c>>>0)|0);a=e;v[b>>2]=a;v[b+4>>2]=0;c=MB(b+8|0,b);if((Vy(v[c>>2],v[c+4>>2])|0)!=(a|0)){break a}Mi(j,e+j|0,d+v[i>>2]|0);e=v[h+8>>2];c=e;d=a+v[c+8>>2]|0;e=v[c+12>>2];v[c+8>>2]=d;v[c+12>>2]=a>>>0>d>>>0?e+1|0:e}hb=b+16|0;hb=h+16|0;hb=g+16|0;hb=f+16|0}function KJ(a,b){var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=kf(f+16|0,1,0);b:{c:{d:{while(1){d=wc(c);tx(f+8|0,d,Fb(c)+d|0,x[b>>1]);if(!v[f+12>>2]){break d}d=Yg(Fb(c));v[23516]=0;R(57,c|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=wc(c);v[23516]=0;R(58,c|0,b-d|0);b=v[23516];v[23516]=0;e:{if((b|0)!=1){v[23516]=0;R(70,e|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break e}break c}break c}wb(c);hb=f+32|0;break b}a=P()|0;O()|0;wb(c);S(a|0);L()}v[23516]=0;R(69,a|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(e);hb=e+16|0;break a}a=P()|0;O()|0;xb(e);S(a|0);L()}}function es(a,b,c){var d=0,e=0;d=a,e=cj(C(C(z[c+1792>>2]*C(75038))+C(C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489))+C(C(C(z[c+1280>>2]+z[c+2304>>2])*C(6574))+C(C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153))+C(C(C(z[c+768>>2]+z[c+2816>>2])*C(2037))+C(C(C(z[c+3072>>2]-z[c+512>>2])*C(459))+C(C(C(z[c+256>>2]+z[c+3328>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))))))))),u[d>>1]=e;d=(b<<5)+a|0,e=cj(C(C(z[c+8>>2]*C(-5))+C(C(z[c+520>>2]*C(146))+C(C(z[c+1032>>2]*C(-45))+C(C(z[c+1544>>2]*C(-9975))+C(C(z[c+2056>>2]*C(64019))+C(C(z[c+2568>>2]*C(9727))+C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))))))))),u[d>>1]=e}function P_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=RF(b);Jk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Ik(k,a);yc(i,k);wb(k);Ph(k,a);yc(h,k);wb(k);l=d,m=Xi(a),t[l|0]=m;l=e,m=Yi(a),t[l|0]=m;Wg(k,a);yc(f,k);wb(k);Qh(k,a);yc(g,k);wb(k);a=Hk(a);break a}a=QF(b);Jk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Ik(k,a);yc(i,k);wb(k);Ph(k,a);yc(h,k);wb(k);l=d,m=Xi(a),t[l|0]=m;l=e,m=Yi(a),t[l|0]=m;Wg(k,a);yc(f,k);wb(k);Qh(k,a);yc(g,k);wb(k);a=Hk(a)}v[j>>2]=a;hb=k+16|0}function OJ(a,b){var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=kf(f+16|0,1,0);b:{c:{d:{while(1){d=wc(c);MJ(f+8|0,d,Fb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break d}d=Yg(Fb(c));v[23516]=0;R(57,c|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=wc(c);v[23516]=0;R(58,c|0,b-d|0);b=v[23516];v[23516]=0;e:{if((b|0)!=1){v[23516]=0;R(70,e|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break e}break c}break c}wb(c);hb=f+32|0;break b}a=P()|0;O()|0;wb(c);S(a|0);L()}v[23516]=0;R(69,a|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(e);hb=e+16|0;break a}a=P()|0;O()|0;xb(e);S(a|0);L()}}function q3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;a=qt(c,a,1);px(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;ic(a);hb=c+16|0;return}e=hb-32|0;hb=e;c=Db(a);c=RP(e+8|0,SP(a,ik(v[a>>2],v[a+4>>2])+1|0),ik(v[a>>2],v[a+4>>2]),c);px(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-16|0;px(v[b>>2]-16|0,d);v[b>>2]=v[b>>2]-16;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Db(a),zc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-16|0;v[c+8>>2]=b;qs(b);continue}break}a=v[c>>2];if(a){Vo(c);Jb(a)}hb=e+32|0}function ke(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a=Sg(a,-1,-1);a:{b:{if(Sd(w[Zl(c+24|0,b,1)|0])){d=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23516]=0;dF(c+8|0,d,0);d=v[23516];v[23516]=0;c:{if((d|0)!=1){d=v[c+12>>2];v[a>>2]=v[c+8>>2];v[a+4>>2]=d;d=v[c+20>>2];v[a+8>>2]=v[c+16>>2];v[a+12>>2]=d;break c}a=V(0)|0;O()|0;_(a|0)|0;e=1;Wl(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[23516]=0;Z(103);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break b}S(a|0);L()}$()}Ii(v[v[b>>2]-12>>2]+b|0,e)}hb=c+32|0;return}V(0)|0;O()|0;Tb()}L()}function sN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}d=c+8|0;f=a+1074312|0;Ab(d,f,21);e=a;a=w[b+821|0];a=gy(e,w[b+828|0],zb(v[v[c+8>>2]>>2],v[c+12>>2])?a:a+16>>>2|0);Ab(d,f,45);b:{if(!(!zb(v[v[c+8>>2]>>2],v[c+12>>2])|w[b+828|0]!=3)){d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];e=d+1|0;break c}t[b+832|0]=a;e=1}t[b+821|0]=e;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}Ab(c+8|0,f,47);if(!zb(v[v[c+8>>2]>>2],v[c+12>>2])){break a}t[b+831|0]=a}if(a){g=b,h=Wb(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}hb=c+16|0}function Rga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=xj(b),v[i>>2]=j;f=x[b>>1];d=hb-16|0;hb=d;g=a;c=Pd(a);a:{if(c){b=gc(g);while(1){a=c;c=x[a+14>>1];if(bo(f,c)){b=a;c=v[a>>2];if(c){continue}break a}if(!bo(c,f)){break a}b=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=gc(g);b=a}v[d+12>>2]=a;a=v[b>>2];if(!a){a=hb-16|0;hb=a;c=gc(g);f=gh(d,tc(20),hh(a+8|0,c));c=v[f>>2];h=x[v[e>>2]>>1];u[c+16>>1]=0;u[c+14>>1]=h;i=gc(f),j=1,t[i+4|0]=j;hb=a+16|0;Hg(g,v[d+12>>2],b,v[d>>2]);a=_d(d);mk(d);h=1}Gg(e+8|0,v[cc(d,a)>>2],h);hb=d+16|0;a=go(v[e+8>>2]);hb=e+16|0;return a+2|0}function RX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=hb+-64|0;hb=g;bn(g+16|0,c);v[23516]=0;c=g+28|0;R(111,c|0,d|0);d=v[23516];v[23516]=0;b:{c:{d:{if((d|0)==1){break d}v[23516]=0;c=g+40|0;R(111,c|0,e|0);d=v[23516];v[23516]=0;if((d|0)==1){break d}v[23516]=0;c=g+52|0;R(111,c|0,f|0);d=v[23516];v[23516]=0;if((d|0)==1){break d}Kv(g+8|0,g+16|0);v[23516]=0;X(112,a|0,b|0,v[g+8>>2],v[g+12>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}_D(g+16|0);hb=g- -64|0;break a}a=P()|0;O()|0;while(1){c=xb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=P()|0;O()|0;_D(g+16|0)}S(a|0);L()}}function GT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=xj(b),v[i>>2]=j;f=v[b>>2];d=hb-16|0;hb=d;g=a;c=Pd(a);a:{if(c){b=gc(g);while(1){a=c;c=v[a+16>>2];if(CT(f,c)){b=a;c=v[a>>2];if(c){continue}break a}if(!CT(c,f)){break a}b=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=gc(g);b=a}v[d+12>>2]=a;a=v[b>>2];if(!a){a=hb-16|0;hb=a;c=gc(g);f=gh(d,tc(24),hh(a+8|0,c));c=v[f>>2];h=v[v[e>>2]>>2];v[c+20>>2]=0;v[c+16>>2]=h;i=gc(f),j=1,t[i+4|0]=j;hb=a+16|0;Hg(g,v[d+12>>2],b,v[d>>2]);a=_d(d);mk(d);h=1}Gg(e+8|0,v[cc(d,a)>>2],h);hb=d+16|0;a=sd(v[e+8>>2]);hb=e+16|0;return a+4|0}function Ak(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;f=a+36|0;c=v[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=v[a+20>>2];if(d>>>0>=y[a+24>>2]){ln(e,f,CD(f));pd(e+8|0,a,v[e>>2],v[e+4>>2]);c=v[e+12>>2];v[a+24>>2]=c;v[a+20>>2]=0;if(!c){break c}d=0;c=v[a+32>>2]}v[a+20>>2]=d+1;g=w[(a+d|0)+36|0];d=c+8|0;v[a+32>>2]=d;v[a+28>>2]=v[a+28>>2]|g<<c;c=d;continue}break}a=ba(8)|0;v[23516]=0;b=T(165,a|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}v[a+32>>2]=c-b;d=a;a=v[a+28>>2];v[d+28>>2]=a>>>b;hb=e+16|0;return a&(-1<<b^-1)}ia(b|0,30656,166);L()}function mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=hb-16|0;hb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>18|0;n=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;g=u[f>>1];v[(e<<2)+b>>2]=g+((B(u[f+4>>1]-g|0,m)|0)/16384|0);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;hb=b+16|0}function E6(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=hb-80|0;hb=d;v[d+72>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=f;v[d+32>>2]=c;v[d+36>>2]=e;a=ce(d+24|0);c=v[a+4>>2];a=v[a>>2];e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;v[23516]=0;e=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=e;X(950,d+48|0,d|0,a|0,c|0);a=v[23516];v[23516]=0;a:{b:{if((a|0)!=1){a=v[dg(d+16|0,d+72|0)>>2];v[23516]=0;b=+Aa(951,d+48|0,+b,a|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}yb(d+48|0);ze(d+72|0);hb=d+80|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+48|0)}ze(d+72|0);S(a|0);L()}function NZ(a){a=a|0;if(w[468128]){return v[117031]}if(!w[469232]){a=468944;while(1){a=Kb(a)+12|0;if((a|0)!=469232){continue}break}t[469232]=1}ld(468944,89e3);ld(468956,89032);ld(468968,89068);ld(468980,89092);ld(468992,89116);ld(469004,89132);ld(469016,89152);ld(469028,89172);ld(469040,89200);ld(469052,89240);ld(469064,89272);ld(469076,89308);ld(469088,89344);ld(469100,89360);ld(469112,89376);ld(469124,89392);ld(469136,89116);ld(469148,89408);ld(469160,89424);ld(469172,89440);ld(469184,89456);ld(469196,89472);ld(469208,89488);ld(469220,89504);t[468128]=1;v[117031]=468944;return 468944}function e9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;a=yz(c,a);Lx(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;ic(a);hb=c+16|0;return}e=hb-32|0;hb=e;c=Db(a);c=Tf(e+8|0,pg(a,sc(v[a>>2],v[a+4>>2])+1|0),sc(v[a>>2],v[a+4>>2]),c);Lx(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-4|0;Lx(v[b>>2]-4|0,d);v[b>>2]=v[b>>2]-4;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Db(a),zc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;v[c+8>>2]=b;qg(b);continue}break}a=v[c>>2];if(a){Jz(c);Jb(a)}hb=e+32|0}function d6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;a:{b:{c:{if((d|0)==1){break c}v[23516]=0;Y(967,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(c+8|0,b);e=v[b+4>>2];b=v[b>>2];v[23516]=0;da(979,c+16|0,d|0,b|0,e|0,1);b=v[23516];v[23516]=0;if((b|0)==1){break c}a=c+16|0;b=fg(Ic(a));wb(a);break b}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23516]=0;X(953,5538,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$()}hb=c+32|0;return b|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Hg(a,b,c,d){var e=0,f=0;v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=v[v[a>>2]>>2];if(b){v[a>>2]=b;d=v[c>>2]}f=v[gc(a)>>2];t[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=v[d+8>>2];if(w[c+12|0]){break a}b:{if(zh(c)){b=v[c+8>>2];e=v[b+4>>2];if(!(!e|w[e+12|0])){break b}if(!zh(d)){lq(c);c=v[c+8>>2]}t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;kq(b);break a}b=v[c+8>>2];e=v[b>>2];if(!(!e|w[e+12|0])){break b}if(zh(d)){kq(c);c=v[c+8>>2]}t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;lq(b);break a}t[c+12|0]=1;d=b;t[d+12|0]=(d|0)==(f|0);t[e+12|0]=1;continue}break}a=Db(a);v[a>>2]=v[a>>2]+1}function $0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;if(HH(0,d+16|0)){Yr(v[115992],12710);L()}b=Xr(d+8|0,v[d+16>>2]);e=Xr(d,v[d+20>>2]/1e3|0);c=hb-32|0;hb=c;a=hb-16|0;hb=a;f=hb-16|0;hb=f;b=Xl(f+8|0,rka(v[b>>2],v[b+4>>2],1e6,0),kb);g=v[b+4>>2];b=v[b>>2];hb=f+16|0;v[a+8>>2]=b;v[a+12>>2]=g;b=v[a+12>>2];v[c+16>>2]=v[a+8>>2];v[c+20>>2]=b;hb=a+16|0;a=v[c+16>>2];f=v[c+20>>2];b=v[e+4>>2];v[c+8>>2]=v[e>>2];v[c+12>>2]=b;e=v[c+8>>2];b=a+e|0;a=v[c+12>>2]+f|0;a=Xl(c+24|0,b,b>>>0<e>>>0?a+1|0:a);b=v[a+4>>2];a=v[a>>2];hb=c+32|0;c=Xl(d+24|0,a,b);a=v[c+4>>2];c=v[c>>2];hb=d+32|0;kb=a;return c|0}function zm(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function cY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=hb-16|0;hb=f;v[23516]=0;Y(966,a|0);e=v[23516];v[23516]=0;a:{b:{c:{d:{if((e|0)==1){break d}v[23516]=0;Y(967,b|0);e=v[23516];v[23516]=0;if((e|0)==1){break d}e=v[a+24>>2];b=qc(f+8|0,b);g=v[b+4>>2];b=v[b>>2];v[23516]=0;Pa(987,e|0,b|0,g|0,c|0,d|0,1);c=v[23516];v[23516]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,8671,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break b}$();b=0}hb=f+16|0;break a}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}return b|0}function Zl(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;t[a|0]=0;a:{d=v[v[b>>2]-12>>2]+b|0;b:{if(Mh(d)){d=v[d+72>>2];if(d){ev(d)}c:{if(c){break c}c=v[v[b>>2]-12>>2]+b|0;if(!(v[c+4>>2]&4096)){break c}d=e+24|0;bd(d,c);v[23516]=0;f=T(19,d|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}Zb(e+24|0);c=Jm(e+16|0,b);d=wh(e+8|0);while(1){d:{if(!jp(c,d)){break d}g=Rk(v[c>>2]);if(!qh(v[f+8>>2],8192,g)){break d}Yl(c);continue}break}if(!Yj(c,d)){break c}Ii(v[v[b>>2]-12>>2]+b|0,6)}h=a,i=Mh(v[v[b>>2]-12>>2]+b|0),t[h|0]=i;break b}Ii(d,4)}hb=e+32|0;return a}a=P()|0;O()|0;Zb(e+24|0);S(a|0);L()}function TH(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(Ye(a)){bc(a,31);return 0}g=a,h=Ye(a),t[g+1375|0]=h;d=bj(a);b=bj(a);bj(a);g=a,h=bj(a),v[g+1112>>2]=h;bj(a);c=Ye(a);v[a+1116>>2]=c;if(!$w(a,a+1120|0,c)){bc(a,10);return 0}v[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=v[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){b=0;e=v[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}v[a- -64>>2]=d;v[a+60>>2]=(v[a+56>>2]+(c+e|0)|0)+27}v[a+1380>>2]=0;return 1}function nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=hb-16|0;hb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>10&4194048;n=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){f=e+n|0;g=t[f|0];v[(e<<2)+b>>2]=((B(t[f+2|0]-g|0,m)|0)/16384|0)+(g<<8);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;hb=b+16|0}function mw(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;g=f+8|0;bd(g,b);v[23516]=0;b=T(1153,g|0)|0;g=v[23516];v[23516]=0;a:{if((g|0)==1){break a}v[23516]=0;X(1165,b|0,84e3,84032,c|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}v[23516]=0;b=T(1154,f+8|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;c=T(1166,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break a}v[d>>2]=c;v[23516]=0;c=T(1163,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}v[e>>2]=c;v[23516]=0;R(1164,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}Zb(f+8|0);hb=f+16|0;return}a=P()|0;O()|0;Zb(f+8|0);S(a|0);L()}function n$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-32|0;hb=f;v[f+24>>2]=b;a:{if(!(v[c+4>>2]&1)){c=lb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+8|0;bd(a,c);v[23516]=0;a=T(1154,a|0)|0;b=v[23516];v[23516]=0;b:{if((b|0)!=1){Zb(f+8|0);c:{if(e){Qh(f+8|0,a);break c}Ph(f+8|0,a)}g=f,h=ge(f+8|0),v[g>>2]=h;while(1){a=Lk(f+8|0);b=v[f>>2];if(!Nb(b,a)){c=v[f+24>>2];Yc(f+8|0);break a}a=v[b>>2];v[23516]=0;Q(1169,f+24|0,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){Ie(f);continue}break}c=P()|0;O()|0;Yc(f+8|0);break b}c=P()|0;O()|0;Zb(f+8|0)}S(c|0);L()}hb=f+32|0;return c|0}function lha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-48|0;hb=e;d=v[a+8>>2];c=v[a>>2];v[23516]=0;d=W(154,c|0,d|0,1)|0;c=v[23516];v[23516]=0;a:{if((c|0)==1){break a}b:{if(!d){break b}v[23516]=0;Y(511,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break a}v[23516]=0;d=T(204,a|0)|0;c=v[23516];v[23516]=0;c:{if((c|0)!=1){while(1){if(!(d&255)){break b}v[23516]=0;c=Q(512,a|0,e+8|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break c}d:{if(!c){break d}c=w[e+8|0];if(c>>>0>63){break d}pc(DS(v[b>>2],c),e+8|0,33)}d=d-1|0;continue}}break a}break a}yb(a);hb=e+48|0;return}b=P()|0;O()|0;yb(a);S(b|0);L()}function qw(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;g=f+8|0;bd(g,b);v[23516]=0;b=T(19,g|0)|0;g=v[23516];v[23516]=0;a:{if((g|0)==1){break a}v[23516]=0;X(1151,b|0,84e3,84032,c|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}v[23516]=0;b=T(1136,f+8|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;c=T(1152,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break a}t[d|0]=c;v[23516]=0;c=T(1149,b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}t[e|0]=c;v[23516]=0;R(1150,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}Zb(f+8|0);hb=f+16|0;return}a=P()|0;O()|0;Zb(f+8|0);S(a|0);L()}function NK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=ui(a,b,c,d);t[a+4260|0]=e;v[a>>2]=46460;c=Lb(a+4264|0);d=Lb(a+4276|0);v[a+4328>>2]=0;b=a+4320|0;v[b>>2]=0;v[b+4>>2]=0;v[a+4312>>2]=0;v[a+4316>>2]=0;b=a+4208|0;f=Bb(b,0),g=1056964608,v[f>>2]=g;f=Bb(b,1),g=1036831949,v[f>>2]=g;f=Bb(b,2),g=1038174126,v[f>>2]=g;f=Bb(b,3),g=1065353216,v[f>>2]=g;f=Bb(b,4),g=1061158912,v[f>>2]=g;f=Bb(b,5),g=1059082943,v[f>>2]=g;f=Bb(b,6),g=1061997773,v[f>>2]=g;v[23516]=0;R(917,a+44|0,2);b=v[23516];v[23516]=0;if((b|0)!=1){ti(a);return a|0}b=P()|0;O()|0;lc(d);lc(c);Ff(a);S(b|0);L()}function Mg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=sc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=v[Db(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=hb-16|0;hb=c;b=eh(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){ic(b);hb=c+16|0}else{fv(a);a=a+4|0;v[b+4>>2]=a;continue}break}break a}c=Db(a);c=Tf(e+8|0,pg(a,sc(v[a>>2],d)+b|0),sc(v[a>>2],v[a+4>>2]),c);f=hb-16|0;hb=f;b=Dl(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){fv(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Kd(b);hb=f+16|0;Cd(a,c);Sf(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Ld(a,d+(b<<2)|0)}}function eD(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;v[b+4>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+8>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);v[b+12>>2]=(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+((w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24))<<2);a=b+4|0;d=Bb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=ho(v[a>>2],v[c>>2])?c:a;continue}}hb=b+16|0;return v[a>>2]-36|0}function GZ(a){a=a|0;if(w[468120]){return v[117029]}if(!w[468928]){a=468640;while(1){a=Kb(a)+12|0;if((a|0)!=468928){continue}break}t[468928]=1}kd(468640,5037);kd(468652,5028);kd(468664,10844);kd(468676,10609);kd(468688,5264);kd(468700,11688);kd(468712,5121);kd(468724,5612);kd(468736,8915);kd(468748,8898);kd(468760,8906);kd(468772,8925);kd(468784,10092);kd(468796,13291);kd(468808,8988);kd(468820,7674);kd(468832,5264);kd(468844,9781);kd(468856,10497);kd(468868,10856);kd(468880,9278);kd(468892,6466);kd(468904,5495);kd(468916,13200);t[468120]=1;v[117029]=468640;return 468640}function vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Lb(a);a:{if(b){v[23516]=0;R(725,d|0,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}c=hb-16|0;hb=c;v[c>>2]=d;a=v[d+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,36);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){ic(c);hb=c+16|0}else{a=Rb(b,0,36);v[a>>2]=0;v[a+4>>2]=0;u[a+22>>1]=0;u[a+24>>1]=0;u[a+26>>1]=0;u[a+28>>1]=0;t[a+21|0]=64;t[a+19|0]=64;t[a+20|0]=100;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;v[a+8>>2]=0;v[a+12>>2]=0;u[a+30>>1]=0;u[a+32>>1]=0;b=b+36|0;v[c+4>>2]=b;continue}break}}return d|0}a=P()|0;O()|0;Hz(d);S(a|0);L()}function g0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{b:{c:{if(nc(b,-1)){break c}i=c,j=kp(b),t[i+23|0]=j;if(w[a+44|0]){d=-1;if((rk(c+23|0,1,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Pr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((rk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((rk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=Ew(b);break a}d=-1}hb=c+32|0;return d|0}function dY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;v[23516]=0;Y(966,a|0);c=v[23516];v[23516]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23516]=0;Y(967,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break d}e=v[a+24>>2];b=qc(d+8|0,b);c=v[b+4>>2];b=v[b>>2];v[23516]=0;b=gF(e,b,c,1);e=v[23516];v[23516]=0;c=kb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,8702,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break b}$();b=0;c=0}hb=d+16|0;a=c;break a}b=P()|0;O()|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Tb();L()}ra(a|0);return b|0}function $5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;a:{b:{c:{if((d|0)==1){break c}v[23516]=0;Y(967,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(e+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23516]=0;da(984,d|0,b|0,f|0,(c|0)!=0|0,1);c=v[23516];v[23516]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,10024,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=0}hb=e+16|0;return b|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function RM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if(v[a+480180>>2]!=1){break a}c=w[b+846|0];if(!c){break a}d=v[b+104>>2];if(!d){break a}if(!Vd(v[d>>2],v[d+20>>2])){break a}f=x[d+34>>1];if(!(f&10)){break a}c=w[b+847|0]+w[(c&15)+33408|0]|0;t[b+847|0]=c;if(c<<24>>24>=0){break a}t[b+847|0]=0;h=f&2;c=v[(h?4:12)+d>>2];g=b;b=v[b+760>>2]+1|0;b=b>>>0<v[(h?8:16)+d>>2]-c>>>0?b:0;v[g+760>>2]=b;g=v[d+20>>2];c=b+c|0;b=yk(f);ec(e+8|0,g+B(c,b)|0,b);b=v[e+8>>2];f=Ib(b,v[e+12>>2]);while(1){if((b|0)==(f|0)){rj(d,a)}else{t[b|0]=w[b|0]^-1;b=b+1|0;continue}break}}hb=e+16|0}function lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){h=v[b+12>>2]+i|0;e=t[h|0];e=((B(t[h+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;hb=b+16|0}function Cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;g=v[a+16>>2];f=Rf(1,2);e=kb;h=e;Pb(a,f,e);i=v[a+24>>2];j=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){d=d-1|0;m=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+g|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+m>>1];e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],i);Pb(b+8|0,k,l);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,h);hb=b+16|0}function _$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;d=w[a+52|0];a:{if(nc(b,-1)){if(d){break a}b=v[a+48>>2];e=a,f=nc(b,-1)^1,t[e+52|0]=f;break a}b:{if(!d){break b}e=c,f=kp(v[a+48>>2]),t[e+19|0]=f;c:{d:{e:{d=c+20|0;switch(Pr(v[a+36>>2],v[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Nr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}hb=c+32|0;return b|0}function zO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=ht(b);a=Lb(a);v[23516]=0;R(783,a|0,2048);c=v[23516];v[23516]=0;a:{if((c|0)!=1){g=hb-16|0;hb=g;f=ar(g,a,2048);c=v[f+4>>2];i=v[f+8>>2];while(1){if((c|0)==(i|0)){ic(f);hb=g+16|0}else{v[c>>2]=0;v[c+4>>2]=0;c=c+8|0;v[f+4>>2]=c;continue}break}break a}c=P()|0;O()|0;be(a);S(c|0);L()}while(1){b:{d=1;if((e|0)!=1024){if((e|0)==2048){break b}d=+(e-1024|0);j=ht(K(d*d*-9.5367431640625e-7+1)*b);d=d*.0372006759294457;d=j*Bi(d)/(h*d)}k=_e(v[a>>2],e),l=d*.011841342921061943,A[k>>3]=l;e=e+1|0;continue}break}}function y6(a){a=a|0;var b=0;b=8045;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=21751;break a}b=8078;break a}b=17651;break a;case 0:b=5014;break a;case 9:b=8101;break a;case 10:b=8115;break a;case 11:b=5391;break a;case 12:b=5411;break a;case 19:b=8127;break a;case 20:b=8059;break a;case 21:b=12866;break a;case 22:b=12189;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=6022;break a}b=8012}return fg(b)|0}function kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){h=(v[b+12>>2]<<1)+i|0;e=u[h>>1];e=e+((B(u[h+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;hb=b+16|0}function Ht(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;uR(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;t[b+31|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;f=hb-32|0;hb=f;a:{c=v[a+12>>2];b:{if((c|0)==(b|0)){break b}d=b>>>0>c>>>0;c=B(Lg(v[v[a+48>>2]+12>>2]),d?b-c|0:c-b|0);e=Cb(v[a+4>>2]);c:{if(d){e=cc(f+24|0,e);d=f+16|0;Cj(d);e=v[e>>2];v[23516]=0;X(650,a|0,e|0,c|0,d|0);c=v[23516];v[23516]=0;if((c|0)!=1){break c}a=V(92664)|0;if((O()|0)!=(ea(92664)|0)){break a}_(a|0)|0;$();break b}c=cc(f+8|0,ZA(e,c));e=v[cc(f,Cb(v[a+4>>2]))>>2];d=v[c>>2];c=v[a>>2];c=B(Ks(d,Cb(c)),6)+c|0;if(Nb(d,e)){Ld(a,FL(c+B(Ks(e,d),6)|0,v[a+4>>2],c))}Cb(c)}v[a+12>>2]=b}hb=f+32|0;return}S(a|0);L()}function to(a,b,c,d,e,f){var g=0;g=hb-16|0;hb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;f=0;a:{b:{while(1){c=f&255;if(c>>>0>3){break b}d=w[g+15|0];Gq(g+8|0,d,w[g+14|0],c>>>0>1);if(!(w[g+8|0]|!d)){f=f+1|0;Bh(g+15|0,g+13|0);Bh(g+14|0,g+12|0);continue}break}c=x[g+8>>1];t[b+2|0]=c;t[b+4|0]=c>>>8;c=w[g+13|0];t[b+5|0]=w[g+12|0];t[b+3|0]=c;t[g+7|0]=0;ae(a,0,g+7|0);break a}f=w[g+15|0];c=Hi(f);e=w[g+13|0];if(c>>>0>Hi(e)>>>0){Bh(g+15|0,g+13|0);Bh(g+14|0,g+12|0);f=w[g+15|0];e=w[g+13|0]}t[b+4|0]=0;t[b+2|0]=0;t[b+5|0]=w[g+12|0];t[b+3|0]=e;ae(a,f,g+14|0)}hb=g+16|0}function _5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=hb-16|0;hb=e;v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;a:{b:{c:{if((d|0)==1){break c}v[23516]=0;Y(967,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(e+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23516]=0;Ya(986,d|0,b|0,f|0,+c,1);d=v[23516];v[23516]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,5929,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=0}hb=e+16|0;return b|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Z7(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=v[v[a+16>>2]+24620>>2];b=Dc(ska(rka(b,b>>31,3840,0),kb,1e3,0),kb);v[a+4316>>2]=b;v[23516]=0;v[c+12>>2]=0;U(923,a+4264|0,b|0,c+12|0);b=v[23516];v[23516]=0;a:{b:{c:{if((b|0)!=1){d:{if(!w[a+4260|0]){break d}b=v[a+4316>>2];v[23516]=0;v[c+12>>2]=0;U(923,a+4276|0,b|0,c+12|0);b=v[23516];v[23516]=0;if((b|0)!=1){break d}b=V(92664)|0;break c}v[c+12>>2]=0;b=c+12|0;JK(a+4288|0,b);v[c+12>>2]=0;JK(a+4300|0,b);break b}b=V(92664)|0}if((O()|0)!=(ea(92664)|0)){break a}_(b|0)|0;v[a+4316>>2]=0;$()}hb=c+16|0;return}S(b|0);L()}function Mk(a,b,c){var d=0,e=0;e=hb-16|0;hb=e;v[a+4>>2]=0;d=4;a:{b:{c:{if(!Sd(w[Zl(e+8|0,a,1)|0])){break c}d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23516]=0;b=W(104,d|0,b|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;_(b|0)|0;d=1;Wl(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23516]=0;Z(103);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)==1){break b}S(a|0);L()}$()}Ii(v[v[a>>2]-12>>2]+a|0,d);hb=e+16|0;return a}V(0)|0;O()|0;Tb()}L()}function cP(a,b){var c=0,d=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;uz(a+48|0);uz(a+68|0);uz(a+88|0);lt(a+492|0);lt(a+524|0);Ij(a,0,0);Hj(a,0,0);v[a+40>>2]=0;v[a+44>>2]=0;Pt(a,b);b=a+108|0;d=Yz(b);c=1;while(1){if((b|0)!=(d|0)){t[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function kr(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;a=Kb(a);a:{b:{c:{switch(b|0){case 0:v[23516]=0;b=Q(1,d|0,15958)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}Gb(a,b);xb(b);break b;case 1:v[23516]=0;b=Q(1,d|0,15983)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Gb(a,b);xb(b);break b}break a;case 2:v[23516]=0;b=Q(1,d|0,15931)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Gb(a,b);xb(b);break b}break a;case 3:break c;default:break b}}v[23516]=0;b=Q(1,d|0,15905)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}Gb(a,b);xb(b)}hb=d+16|0;return}b=P()|0;O()|0;xb(a);S(b|0);L()}function j0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;a:{b:{c:{if(sn(b)){break c}v[c+20>>2]=b;if(w[a+44|0]){d=-1;if((rk(c+20|0,4,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Pr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((rk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((rk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=sn(b)?0:b;break a}d=-1}hb=c+32|0;return d|0}function i6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;v[23516]=0;Y(966,a|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)==1){break c}v[23516]=0;Y(967,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break c}c=v[a+24>>2];b=qc(d+8|0,b);e=v[b+4>>2];b=v[b>>2];v[23516]=0;b=fa(973,c|0,b|0,e|0,1)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,10055,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=0}hb=d+16|0;return b|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function g6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;v[23516]=0;Y(966,a|0);c=v[23516];v[23516]=0;a:{b:{c:{if((c|0)==1){break c}v[23516]=0;Y(967,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break c}c=v[a+24>>2];b=qc(d+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23516]=0;e=+za(977,c|0,b|0,f|0,1);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,5966,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();e=0}hb=d+16|0;return+e}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function as(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=hb-240|0;hb=h;v[h+236>>2]=d;v[h+232>>2]=c;v[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-v[(e<<2)+g>>2]|0;if((lb[b|0](i,a)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=v[((e<<2)+g|0)-8>>2];l=j-4|0;if((lb[b|0](l,i)|0)>=0){break e}if((lb[b|0](l-f|0,i)|0)>=0){break e}}v[(k<<2)+h>>2]=i;c=FH(c,d);bs(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=v[h+236>>2];c=v[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}EH(h,k);Xw(i,b,e,g)}hb=h+240|0}function Dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;g=v[a+16>>2];f=Rf(1,2);e=kb;h=e;Pb(a,f,e);i=v[a+24>>2];j=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){d=d-1|0;m=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+g|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+m|0]<<8;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],i);Pb(b+8|0,k,l);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,h);hb=b+16|0}function HH(a,b){var c=0,d=0,e=0;if(!w[463972]){d=Ga()|0;t[463972]=1;t[463973]=d}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!w[463973]){break c}e=+Fa();break a}v[115992]=28;return-1}e=+Ma()}c=e/1e3;e:{if(D(c)<0x8000000000000000){d=D(c)>=1?~~(c>0?F(H(c*2.3283064365386963e-10),4294967295):I((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;a=~~c>>>0;break e}d=-2147483648;a=0}v[b>>2]=a;c=(e-(+(rka(a,d,1e3,0)>>>0)+ +(kb|0)*4294967296))*1e3*1e3;f:{if(D(c)<2147483648){a=~~c;break f}a=-2147483648}v[b+4>>2]=a;return 0}function rR(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break a}c=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(w[c|0]|w[c+1|0]<<8){break a}b=a+1096|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-5>>>0<4294967292){break a}if(!Ft(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|w[a+32|0]>15|w[a+33|0]>64){break a}b=Ft(a);a=a+34|0;if(b){continue}break}}return d}function c0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;d=w[a+52|0];a:{if(sn(b)){if(d){break a}b=v[a+48>>2];e=a,f=sn(b)^1,t[e+52|0]=f;break a}b:{if(!d){break b}v[c+16>>2]=v[a+48>>2];c:{d:{e:{d=c+20|0;switch(Pr(v[a+36>>2],v[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Nr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}hb=c+32|0;return b|0}function IA(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=w[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!w[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=w[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=B(c>>>3|0,b);b=((d|0)==10)<<4}c=b+B(iq(w[a+1|0]),c)|0}return c}function Caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-208|0;hb=e;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;EM(a+946304|0);f=a+906300|0;g=ck(f);d=e+48|0;Rb(d,0,160);d=GM(d);v[23516]=0;U(840,f|0,g|0,d|0);f=v[23516];v[23516]=0;a:{if((f|0)!=1){qy(d);d=he(e+24|0,b);v[23516]=0;f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;v[e+16>>2]=v[d+16>>2];f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;a=W(841,a|0,e|0,c|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){a=P()|0;O()|0;break a}yb(b);hb=e+208|0;return a|0}a=P()|0;O()|0;qy(d)}yb(b);S(a|0);L()}function Ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=hb-16|0;hb=b;j=v[a+16>>2];h=Rf(1,2);e=kb;k=e;Pb(a,h,e);e=v[a+40>>2];f=v[a+36>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){i=u[(v[b+12>>2]<<1)+j>>1];f=f+l|0;v[c>>2]=v[c>>2]+B(i,f>>12);e=e+g|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,i);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+36>>2]=f;v[a+24>>2]=e>>12;lg(a,h,k);hb=b+16|0}function Nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;h=x[c>>1];i=c;e=hb-16|0;hb=e;f=b;d=Pd(b);a:{if(d){c=gc(f);while(1){b=d;d=x[b+14>>1];if(xk(h,d)){c=b;d=v[b>>2];if(d){continue}break a}if(!xk(d,h)){break a}c=b+4|0;d=v[b+4>>2];if(d){continue}break}break a}b=gc(f);c=b}v[e+12>>2]=b;b=v[c>>2];if(!b){b=hb-16|0;hb=b;d=gc(f);d=gh(e,tc(16),hh(b+8|0,d));Ki(v[d>>2]+14|0,x[i>>1]);k=gc(d),l=1,t[k+4|0]=l;hb=b+16|0;Hg(f,v[e+12>>2],c,v[e>>2]);b=_d(e);mk(e);j=1}c=g+8|0;Gg(c,v[cc(e,b)>>2],j);hb=e+16|0;bP(a,c);hb=g+16|0}function dja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;g=x[yl(v[a>>2],v[a+4>>2],b)>>1];a:{b:{if(!zq(a,b)){break b}c=v[a+24>>2];d=Cb(v[c+484360>>2]);v[f+8>>2]=d;h=Cb(v[c+484364>>2]);while(1){if(!Nb(d,h)){break b}e=0;i=ul(v[d>>2],v[d+4>>2]);c:{while(1){if((e|0)!=(i|0)){if(!(!((a|0)!=(d|0)|(b|0)!=(e|0))|x[$b(v[d>>2],e)>>1]!=(g|0))){c=xR(v[a+24>>2]+484344|0,g);if((c|0)!=65535){break c}}e=e+1|0;continue}break}d=v[pz(f+8|0)>>2];continue}break}j=yl(v[a>>2],v[a+4>>2],b),k=c,u[j>>1]=k;break a}c=g}hb=f+16|0;return c&65535}function CC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;v[f+8>>2]=e;v[f+12>>2]=d;_f(a);kt(a,c);e=0;d=0;a:while(1){if(c>>>0>e>>>0){i=c-e|0;v[f+4>>2]=i;g=v[Hb(f+12|0,f+4|0)>>2];h=g+d|0;l=d>>>0>h>>>0?d:h;j=uu(zr(a,b+e|0,g),1,13);while(1)if((d|0)==(l|0)){v[f+4>>2]=i-g;d=h+1|0;e=v[Hb(f+8|0,f+4|0)>>2]+(e+g|0)|0;continue a}else{b:{c:{d:{k=t[Jc(j,d)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=Jc(j,d),n=32,t[m|0]=n}d=d+1|0;continue}}break}hb=f+16|0}function Bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=hb-16|0;hb=b;j=v[a+16>>2];h=Rf(1,2);e=kb;k=e;Pb(a,h,e);e=v[a+40>>2];f=v[a+36>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){i=t[v[b+12>>2]+j|0]<<8;f=f+l|0;v[c>>2]=v[c>>2]+B(i,f>>12);e=e+g|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,i);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+36>>2]=f;v[a+24>>2]=e>>12;lg(a,h,k);hb=b+16|0}function Z4(a){a=a|0;var b=0,c=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){a=v[a+24>>2];b=v[a+24>>2];c=x[b+1074448>>1];a:{if(c>>>0>=qj(Sb(v[b+484360>>2],w[b+484376|0]))>>>0){a=x[v[a+24>>2]+1074446>>1];break a}a=v[a+24>>2];b=x[$b(v[Sb(v[a+484360>>2],w[a+484376|0])>>2],c)>>1];a=Hm(v[a+484344>>2],v[a+484348>>2],b)?b:-1}return a|0}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,9785,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Fn(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}Ab(e+8|0,a+1074312|0,3);if(zb(v[v[e+8>>2]>>2],v[e+12>>2])){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){Ab(e+8|0,a+1074312|0,3);if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=B(b,872)+a|0;d=v[f+1075648>>2];a=Kp(a,v[f+1075080>>2],d);if(!a){break a}lb[v[v[a>>2]+84>>2]](a,c,(d?w[d+33|0]:13)<<24>>24,b)}hb=e+16|0}function oI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;a:{b:{c:{a=v[a+32>>2];e=ts(a);d:{if(!e){if(ss(a)>>>0<=b>>>0){break d}a=Fi(a,b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ba(8)|0;v[23516]=0;b=Q(53,d|0,6003)|0;c=v[23516];v[23516]=0;e:{if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}c=P()|0;O()|0;wb(b);break e}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}a=v[(a+(b<<2)|0)+900384>>2];if(!a){break b}t[a+15|0]=w[a+15|0]&253|(c?2:0)}hb=d+16|0;return}L()}function cx(a,b,c){var d=0,e=0,f=C(0),g=C(0),h=C(0),i=C(0),j=0,k=C(0),l=C(0),m=C(0);e=hb-32|0;hb=e;g=z[a+24>>2];f=z[a+12>>2];h=z[a+48>>2];i=z[a+36>>2];WH(C(-z[a>>2]),C(g+f),C(h+i),e+20|0);WH(z[a+60>>2],C(h-i),C(g-f),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=z[j>>2];f=z[d+(e+20|0)>>2];h=z[d+71504>>2];i=z[d+71516>>2];k=z[d+(e+8|0)>>2];z[j>>2]=C(f*h)-C(i*k);j=b+d|0;l=z[(0-a<<2)+71512>>2];d=5-a<<2;m=z[d+71504>>2];f=C(C(f*i)+C(k*h));z[j>>2]=C(g*l)-C(m*f);z[b+d>>2]=C(g*m)+C(f*l);a=a+1|0;continue}break}hb=e+32|0}function Zd(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;v[b+4>>2]=1147;v[b>>2]=a;v[b+8>>2]=0;d=hb-16|0;hb=d;if(v[a>>2]!=-1){a:{c=cc(d,If(d+8|0,b));while(1){if(v[a>>2]==1){continue}break}b:{if(!v[a>>2]){td(a,1);c=v[v[c>>2]>>2];v[23516]=0;Y(1148,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}v[a>>2]=-1}break a}b=V(0)|0;O()|0;_(b|0)|0;td(a,0);v[23516]=0;Z(103);a=v[23516];v[23516]=0;c:{if((a|0)==1){a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){break c}V(0)|0;O()|0;Tb()}L()}S(a|0);L()}}hb=d+16|0;hb=b+16|0;return v[a+4>>2]-1|0}function Zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[f+39890>>1])+B(u[e-2>>1],u[f+39888>>1])|0)+B(u[e+2>>1],u[f+39892>>1])|0)+B(u[e+4>>1],u[f+39894>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;hb=b+16|0}function Un(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0;d=x[a+24>>1];b=c+(d<<2)|0;v[a+40>>2]=((b&3)<<4)+28e3;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+32>>1]=f;u[a+36>>1]=b?1:1<<e-12;u[a+34>>1]=-1<<f^-1;if((d|0)==15){u[a+36>>1]=4095}b=c+(x[a+26>>1]<<2)|0;v[a+52>>2]=((b&3)<<4)+28e3;d=b>>>2|0;b=b>>>0<48;e=b?12-d|0:0;u[a+44>>1]=e;c=c+(x[a+30>>1]<<2)|0;v[a+64>>2]=((c&3)<<4)+28e3;f=c>>>2|0;c=c>>>0<48;g=c?12-f|0:0;u[a+56>>1]=g;u[a+48>>1]=b?1:1<<d-12;u[a+60>>1]=c?1:1<<f-12;u[a+46>>1]=-1<<e^-1;u[a+58>>1]=-1<<g^-1}function D9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=Lb(a);b:{c:{c=lk(v[b>>2],v[b+4>>2]);if(c){v[23516]=0;R(457,a|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break c}Tx(a,v[b>>2],v[b+4>>2],c)}break b}b=P()|0;O()|0;Ah(a);S(b|0);L()}v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[23516]=0;c=Q(898,a+24|0,b+24|0)|0;d=v[23516];v[23516]=0;d:{e:{if((d|0)!=1){v[23516]=0;Q(52,a+36|0,b+36|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break e}v[a+48>>2]=v[b+48>>2];break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;lc(c)}Ah(a);S(b|0);L()}}function faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-48|0;hb=d;c=d+24|0;zj(c,b,1819307379);cd(a+40|0,c);yb(c);zj(c,b,1953721961);cd(a+60|0,c);yb(c);zj(c,b,543520099);cd(a+120|0,c);yb(c);zj(c,b,1414744396);v[23516]=0;c=Q(410,c|0,13851)|0;e=v[23516];v[23516]=0;a:{if((e|0)!=1){b:{if(c){v[23516]=0;U(790,d|0,d+24|0,2);c=v[23516];v[23516]=0;if((c|0)==1){break b}Dt(a+140|0,d);Ud(d)}v[23516]=0;U(791,d|0,b|0,1634890872);b=v[23516];v[23516]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;yb(d+24|0);S(a|0);L()}cd(a+80|0,d);yb(d);yb(d+24|0);hb=d+48|0}function _9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=hb-32|0;hb=f;a=Lb(a);b:{c:{d:{e:{while(1){e=v[b+8>>2];g=v[b>>2];v[23516]=0;e=W(154,g|0,e|0,8)|0;g=v[23516];v[23516]=0;if((g|0)==1){break c}if(e){v[23516]=0;U(886,f|0,b|0,c|0);e=v[23516];v[23516]=0;if((e|0)==1){break e}v[23516]=0;R(887,a|0,f|0);e=v[23516];v[23516]=0;if((e|0)==1){break d}yd(f);e=QA(v[a+4>>2]);Zh(f,v[e>>2],v[e+4>>2]);if(v[f>>2]!=(d|0)){continue}}break}hb=f+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;yd(f);break b}b=P()|0;O()|0}Ud(a);S(b|0);L()}}function YK(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;Fx(a);c=Td(c,C(0));a:{switch(b|0){case 0:z[a+4220>>2]=c;return;case 1:z[a+4224>>2]=c;return;case 2:z[a+4228>>2]=c;Es(a);return;case 3:t[a+4240|0]=c>=C(.5);Es(a);return;case 4:b=hb-16|0;hb=b;e=b,f=Sh(C(c*C(32))),v[e+12>>2]=f;v[b+8>>2]=0;v[b+4>>2]=5;d=v[Gj(b+12|0,b+8|0,b+4|0)>>2];hb=b+16|0;v[a+4232>>2]=d;return;case 5:t[a+4241|0]=c>=C(.5);return;case 6:t[a+4242|0]=c>=C(.5);return;case 7:t[a+4244|0]=c>=C(.5);return;case 8:if(c==C(0)){Dx(a)}A[a+4256>>3]=c;break;default:break a}}}function S_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-416|0;hb=h;d=h+416|0;v[h+12>>2]=d;c=hb-144|0;hb=c;v[c+28>>2]=c+132;i=c+32|0;VF(v[a+8>>2],i,c+28|0,e,f,g);v[c+16>>2]=0;v[c+20>>2]=0;v[c+12>>2]=i;e=h+16|0;g=sc(e,v[h+12>>2]);f=hb-16|0;hb=f;i=ji(f+8|0,v[a+8>>2]);a=wG(e,c+12|0,g,c+16|0);ii(i);hb=f+16|0;if((a|0)==-1){Mr(12629);L()}v[h+12>>2]=(a<<2)+e;hb=c+144|0;c=v[h+12>>2];a=hb-16|0;hb=a;v[a+8>>2]=b;while(1){if((c|0)!=(e|0)){YG(a+8|0,v[e>>2]);e=e+4|0;continue}break}hb=a+16|0;hb=d;return v[a+8>>2]}function S4(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=hb-32|0;hb=b;a:{c=a+36|0;b:{if(Nb(v[c>>2],v[a+40>>2])){yf(b+24|0);break b}d=b+8|0;yn(d,a);v[23516]=0;d=T(1026,d|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break a}v[b+24>>2]=d;Vf(b+8|0)}c=(g=c,h=v[b+24>>2],i=Nb(v[a+36>>2],v[a+40>>2]),i?g:h);a=v[a+8>>2];c:{if((a|0)==-1){g=b,h=Cb(v[c>>2]),v[g+8>>2]=h;a=Cb(v[c+4>>2]);while(1){c=v[b+8>>2];if(!Nb(c,a)){break c}e=e+A[c>>3];Mx(b+8|0);continue}}e=A[ff(v[c>>2],a)>>3]}Vk(b+24|0);hb=b+32|0;return+e}a=P()|0;O()|0;Vf(b+8|0);S(a|0);L()}function vW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=16384;d=v[Hb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=17;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=Ak(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Vq(c+4|0,Ak(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}Vq(c+4|0,d-e|0);break b}VC(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}VC(a,e,0,b)}d=v[a+1072>>2];continue}break}hb=c+16|0}function xy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;g=Ys(a,a+1074376|0,b,c);a:{if(!g){break a}h=a+1074312|0;Ab(d+8|0,h,117);if(zb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}e=B(b,872)+a|0;i=e+1075648|0;c=v[i>>2];if(!c|!w[c+33|0]){break a}f=a;a=e+1074992|0;e=Kp(f,v[a+88>>2],c);if(!e){break a}Ab(d+8|0,h,34);f=!zb(v[v[d+8>>2]>>2],v[d+12>>2]);c=rg(w[a+797|0]-u[a+770>>1]|0);b:{if(f|(c<<24)-16777216>>24<0){break b}a=v[a+656>>2];if(!a){break b}c=w[Ib(a+108|0,c-1|0)|0]}lb[v[v[e>>2]+88>>2]](e,g,c&255,t[v[i>>2]+33|0],b)}hb=d+16|0}function sM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;v[e+12>>2]=16777216;h=e+12|0;d=v[a>>2];c=sc(d,v[a+4>>2]);a:{if(c>>>0<b>>>0){f=hb-32|0;hb=f;b=b-c|0;c=v[Db(a)>>2];d=v[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){nC(a,b,h);break b}c=Db(a);c=Tf(f+8|0,pg(a,sc(v[a>>2],d)+b|0),sc(v[a>>2],v[a+4>>2]),c);g=hb-16|0;hb=g;b=Dl(g,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){dq(d,v[h>>2]);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Kd(b);hb=g+16|0;Cd(a,c);Sf(c)}hb=f+32|0;break a}if(b>>>0<c>>>0){Ld(a,d+(b<<2)|0)}}my(a);hb=e+16|0}function uW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=32768;d=v[Hb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=9;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=Ak(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Vq(c+4|0,Ak(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}Vq(c+4|0,d-e|0);break b}TC(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}TC(a,e,0,b)}d=v[a+1072>>2];continue}break}hb=c+16|0}function Sia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=hb-32|0;hb=d;a=Lb(a);b:{c:{d:{e:{while(1){c=v[b+8>>2];e=v[b>>2];v[23516]=0;c=W(154,e|0,c|0,8)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}if(c){v[23516]=0;R(406,d|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break e}v[23516]=0;R(407,a|0,d|0);c=v[23516];v[23516]=0;if((c|0)==1){break d}yd(d);c=QA(v[a+4>>2]);Zh(d,v[c>>2],v[c+4>>2]);if((_b(v[d>>2])|0)!=1162757187){continue}}break}hb=d+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;yd(d);break b}b=P()|0;O()|0}Ud(a);S(b|0);L()}}function w4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0);v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;a:{if((d|0)==1){break a}v[23516]=0;Y(1038,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break a}d=v[a+24>>2];e=z[d+48>>2];d=v[d+24>>2];v[23516]=0;b=Xa(1039,d|0,C(e),b|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,10372,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function i5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;e=Lb(a);a=0;a:{b:{c:{d:{e:{while(1){d=v[b+24>>2];if(x[d+480188>>1]<=a>>>0){break a}v[23516]=0;R(1022,c|0,(d+(a<<5)|0)+480289|0);d=v[23516];v[23516]=0;if((d|0)!=1){d=v[b+24>>2];v[23516]=0;U(1023,c+16|0,d|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break e}v[23516]=0;R(181,e|0,c+16|0);d=v[23516];v[23516]=0;if((d|0)==1){break d}a=a+1|0;wb(c+16|0);wb(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;wb(c+16|0)}wb(c)}Me(e);S(a|0);L()}hb=c+32|0}function _ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[f+39890>>1])+B(t[e-1|0],u[f+39888>>1])|0)+B(t[e+1|0],u[f+39892>>1])|0)+B(t[e+2|0],u[f+39894>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;hb=b+16|0}function Oja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;jd(b,0);g=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=g;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);v[b+12>>2]=e;f=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+16>>2]=f;c=w[a+12|0]|w[a+13|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;c=w[a+14|0];u[b+30>>1]=c?c+1|0:256;d=x[b+34>>1]&32767|!w[a+14|0]<<15;u[b+34>>1]=d;c=w[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;u[b+34>>1]=d;c=w[a+15|0]}if(c&2){v[b+16>>2]=f>>>1;v[b+12>>2]=e>>>1;v[b>>2]=g>>>1;u[b+34>>1]=d|1}}function Ffa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-80|0;hb=c;d=uf(c+48|0);v[23516]=0;e=Q(637,b|0,d|0)|0;f=v[23516];v[23516]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23516]=0;T(638,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break a}}break c}e=v[d+4>>2];v[23516]=0;U(188,c|0,b|0,(e>>>0<9?0:e-8|0)|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;yd(d);S(a|0);L()}b=hc(c+24|0,c);cd(d+8|0,b);yb(b);yb(c);qk(a,d)}yd(d);hb=c+80|0}function Wi(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?E(c):E(d)+32|0;Hf(f,d,e,0,0,c+49|0);i=v[f>>2];h=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=i;v[a+4>>2]=h;v[a+8>>2]=c;v[a+12>>2]=g&-2147483648|d;hb=f+16|0}function tba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;v[d+12>>2]=b;if(b>>>0<1073741808){h=d,i=Fb(a),v[h+8>>2]=i;e=Tl(v[Vc(d+12|0,d+8|0)>>2]);if((e|0)!=(ep(a)|0)){a:{f=1;c=ep(a);g=Fb(a);b:{if((e|0)==1){b=a;c=v[a>>2];break b}b=e+1|0;c:{if(c>>>0<e>>>0){b=Ai(b);break c}v[23516]=0;b=T(1228,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}f=Fe(a);c=wc(a)}mi(b,c,Fb(a)+1|0);if(f){Jb(c)}if((e|0)!=1){bf(a,e+1|0);xd(a,g);td(a,b);break a}Xd(a,g)}}hb=d+16|0;return}df();L()}function aha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-80|0;hb=c;d=uf(c+48|0);v[23516]=0;e=Q(516,b|0,d|0)|0;f=v[23516];v[23516]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23516]=0;T(517,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break a}}break c}e=x[d+2>>1]|x[d+4>>1]<<16;v[23516]=0;U(188,c|0,b|0,e|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;yd(d);S(a|0);L()}b=hc(c+24|0,c);cd(d+8|0,b);yb(b);yb(c);vS(a,d)}yd(d);hb=c+80|0}function Yaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=Kb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(ud(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Jd(d,0);break e}v[23516]=0;Q(820,f|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}d=Jd(v[b>>2],a)}v[23516]=0;R(821,e|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;Q(820,f|0,e|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break d}a=a+1|0;wb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;wb(e);break a}hb=e+16|0;return}a=P()|0;O()|0}wb(f);S(a|0);L()}function $V(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;jd(b,0);_h(d,1,a+33|0);e=d+16|0;Cc(e,d);xe(b+43|0,e);wb(e);f=w[a+50|0]|w[a+51|0]<<8|(w[a+52|0]<<16|w[a+53|0]<<24);v[b>>2]=f;v[b+24>>2]=w[a+54|0]|w[a+55|0]<<8;t[d+16|0]=w[a+56|0];t[d|0]=64;h=b,i=w[Vb(e,d)|0]<<2,u[h+30>>1]=i;e=w[a+57|0]|w[a+58|0]<<8|(w[a+59|0]<<16|w[a+60|0]<<24);v[b+4>>2]=e;g=w[a+61|0]|w[a+62|0]<<8|(w[a+63|0]<<16|w[a+64|0]<<24);c=c?e?f:g:g;v[b+8>>2]=c;if(!(!w[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0)){u[b+34>>1]=x[b+34>>1]|2}hb=d+32|0}function kt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-16|0;hb=c;v[c+12>>2]=b;if(b>>>0<4294967280){h=c,i=Fb(a),v[h+8>>2]=i;d=ih(v[Vc(c+12|0,c+8|0)>>2]);if((d|0)!=(_c(a)|0)){a:{f=Fb(a);b:{if((d|0)==10){g=1;b=a;e=v[a>>2];break b}b=d+1|0;c:{if(_c(a)>>>0<d>>>0){b=tc(b);break c}v[23516]=0;b=T(1227,b|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}g=Fe(a);e=wc(a)}b=Ce(b,e,Fb(a)+1|0);if(g){Jb(e)}if((d|0)!=10){bf(a,d+1|0);xd(a,f);td(a,b);break a}Xd(a,f)}}hb=c+16|0;return}df();L()}function gy(a,b,c){var d=0,e=0;e=hb-16|0;hb=e;Ab(e+8|0,a+1074312|0,21);a:{if(zb(v[v[e+8>>2]>>2],v[e+12>>2])){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+33616|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=ZL(Jn(a))+-64|0;break a}d=t[(c>>>1&31)+32304|0];if(x[a+480182>>1]&1032){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+33488|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+33552|0]}a=d;hb=e+16|0;return a}function AQ(a,b,c,d,e,f){b=w[(b&15)+27200|0];t[a+3|0]=b;a:{b:{switch(b-11|0){case 0:b=w[a+5|0];c=b&15;if(c){t[a+5|0]=c;return}t[a+5|0]=b&240;return;case 3:b=w[a+5|0];b=B(b&240,10)|b&15;t[a+5|0]=b;d=b&255;b=x[e>>1];if(!(d|(b|0)==65535)){t[a+5|0]=b;t[a+3|0]=12;u[e>>1]=65535}uc(f,c);return;case 1:u[e>>1]=w[a+5|0];v[f>>2]=63;t[a+3|0]=0;return;case 5:b=w[a+5|0];if(d>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|B(c,-10)+b;t[a+5|0]=b}if(b&255){break a}t[a+3|0]=0;return;case 7:break a;default:break b}}if(w[a+5|0]){break a}t[a+3|0]=0}}function v6(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;a:{b:{if(!a){a=fg(21751);break b}v[23516]=0;c=Q(53,b|0,a|0)|0;a=v[23516];v[23516]=0;c:{d:{if((a|0)!=1){v[23516]=0;R(952,b+16|0,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break d}d=b+16|0;a=fg(Ic(d));wb(d);wb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;wb(c)}_(a|0)|0;a=0;v[23516]=0;X(953,10984,0,0,0);c=v[23516];v[23516]=0;if((c|0)==1){break a}$()}hb=b+32|0;return a|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function sX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=Kb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(ud(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Jd(d,0);break e}v[23516]=0;Q(96,f|0,c|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break b}d=Jd(v[b>>2],a)}v[23516]=0;R(151,e|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;Q(96,f|0,e|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break d}a=a+1|0;xb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(e);break a}hb=e+16|0;return}a=P()|0;O()|0}xb(f);S(a|0);L()}function rfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=hb-32|0;hb=d;a=Lb(a);b:{c:{d:{e:{while(1){c=v[b+8>>2];e=v[b>>2];v[23516]=0;c=W(154,e|0,c|0,8)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}if(c){v[23516]=0;R(667,d|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break e}v[23516]=0;R(668,a|0,d|0);c=v[23516];v[23516]=0;if((c|0)==1){break d}yd(d);c=QA(v[a+4>>2]);Zh(d,v[c>>2],v[c+4>>2]);if(v[d>>2]!=1413891155){continue}}break}hb=d+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;yd(d);break b}b=P()|0;O()|0}Ud(a);S(b|0);L()}}function Zt(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;v[g+12>>2]=0;v[g+8>>2]=a;i=hb-16|0;hb=i;b=fc(i+8|0,v[g+8>>2],v[g+12>>2]);e=hb-16|0;hb=e;d=118;v[e+12>>2]=118;c=v[b+4>>2];a:{if(!c){c=v[b>>2];break a}f=32-c|0;v[e+8>>2]=f;d=v[b>>2];j=v[d>>2];h=f;f=v[Hb(e+8|0,e+12|0)>>2];v[d>>2]=(-1<<c&-1>>>h-f^-1)&j;j=v[e+12>>2];c=d+4|0;v[b>>2]=c;d=j-f|0}h=c;c=d>>>5<<2;Rb(h,0,c);f=d&31;v[e+12>>2]=f;if((d&-32)!=(d|0)){h=b;b=c+v[b>>2]|0;v[h>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-f^-1)}hb=e+16|0;hb=i+16|0;hb=g+16|0;return a}function F6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;t[a+4202|0]=1;c=tj(C(C(y[v[a+16>>2]+24620>>2])*C(.04500000178813934)));d=tj(C(C(c>>>0)*C(1.1892070770263672)));e=tj(C(C(d>>>0)*C(1.1892070770263672)));h=tj(C(C(e>>>0)*C(1.1892070770263672)));f=tj(C(C(c+e>>>0)*C(.11546666920185089)));g=tj(C(C(d+h>>>0)*C(.11546666920185089)));b=a+4272|0;i=Bb(b,0),j=c-f|0,v[i>>2]=j;i=Bb(b,1),j=e-f|0,v[i>>2]=j;i=Bb(b,2),j=d-g|0,v[i>>2]=j;i=Bb(b,3),j=h-g|0,v[i>>2]=j;i=Bb(b,4),j=f,v[i>>2]=j;i=Bb(b,5),j=g,v[i>>2]=j;kK(a);jK(a)}function oaa(a){a=a|0;var b=0,c=0;b=32400;a=Lb(a);a:{b:{while(1){c:{if((b|0)==32800){b=32800;break c}d:{c=v[a+4>>2];if(!nc(v[a>>2],c)){if(!xi(v[b+4>>2],v[yj(c)>>2])){break d}}v[23516]=0;R(864,a|0,b+4|0);c=v[23516];v[23516]=0;if((c|0)!=1){break d}break b}b=b+8|0;continue}break}while(1){if((b|0)==32848){break a}e:{c=v[a+4>>2];f:{if(!nc(v[a>>2],c)){if(!xi(v[b+8>>2],v[yj(c)>>2])){break f}}v[23516]=0;R(864,a|0,b+8|0);c=v[23516];v[23516]=0;if((c|0)==1){break e}}b=b+12|0;continue}break}}b=P()|0;O()|0;lc(a);S(b|0);L()}}function E9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;v[f+12>>2]=b;a:{if(Qs(a)>>>0>=b>>>0){e=v[a>>2];g=sk(e,v[a+4>>2]);v[f+8>>2]=g;d=v[Hb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=DL(e,c)+52|0;continue}break}if(b>>>0>g>>>0){Rx(a,b-g|0,c);break a}AL(a,v[a>>2]+B(b,52)|0);break a}if(v[a>>2]){Rs(a);d=v[a>>2];Qs(a);Jb(d);h=Db(a),i=0,v[h>>2]=i;v[a>>2]=0;v[a+4>>2]=0}d=zL(a,b);if(Kh(82595524)>>>0<d>>>0){rd();L()}e=yL(d);v[a>>2]=e;v[a+4>>2]=e;h=Db(a),i=e+B(d,52)|0,v[h>>2]=i;Rx(a,b,c)}hb=f+16|0}function xJ(a,b){var c=0,d=0;c=v[a>>2];v[a>>2]=b;if(c){v[23516]=0;Y(833,c|0);a=v[23516];v[23516]=0;a:{if((a|0)!=1){a=v[c+4>>2];if(a){if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(d|0)){b=b-4|0;qg(b);continue}break}v[a+4>>2]=d;b=v[a>>2];Vh(a);Jb(b)}Jb(a)}v[c+4>>2]=0;DM(c+1298408|0);uy(c+1298344|0);wb(c+1298332|0);xb(c+1298320|0);wb(c+1298308|0);ty(c+1298304|0);sy(c+1298300|0);_s(c+1298264|0);Fy(c+1074376|0);JM(c+906300|0);SO(c+484360|0);AM(c+484344|0);lc(c+480248|0);break a}V(0)|0;O()|0;Tb();L()}Jb(c)}}function xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[Db(a)>>2]){c=hb-16|0;hb=c;a=Iv(c,a);d=v[a+4>>2];v[23516]=0;R(497,d|0,b|0);b=v[23516];v[23516]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+12;ic(a);hb=c+16|0;break a}b=P()|0;O()|0;ic(a);S(b|0);L()}return}d=hb-32|0;hb=d;c=Db(a);c=Bk(d+8|0,$m(a,ud(v[a>>2],v[a+4>>2])+1|0),ud(v[a>>2],v[a+4>>2]),c);e=v[c+8>>2];v[23516]=0;R(497,e|0,b|0);b=v[23516];v[23516]=0;b:{if((b|0)!=1){v[c+8>>2]=v[c+8>>2]+12;or(a,c);Hv(c);hb=d+32|0;break b}a=P()|0;O()|0;Hv(c);S(a|0);L()}}function uY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Tg(a,v[b+8>>2],e)){cw(b,c,d);return}a:{if(Tg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];lb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];lb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function nI(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;a:{b:{c:{a=v[a+32>>2];c=ts(a);d:{if(!c){if(ss(a)>>>0<=b>>>0){break d}c=(w[Fi(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ba(8)|0;v[23516]=0;b=Q(53,d|0,6003)|0;c=v[23516];v[23516]=0;e:{if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}c=P()|0;O()|0;wb(b);break e}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}a=v[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(w[a+15|0]&2)>>>1|0}hb=d+16|0;return c|0}L()}function ZO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=w[a+16|0];k=c?-1:1;l=c?1:-1;e=v[a+8>>2]-1|0;m=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;f=v[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=v[a>>2]+B(f,62)|0;d=b?1:-1;p=B(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=B(c,f);q=v[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{u[(b<<1)+h>>1]=x[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function NM(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}e=v[a+480180>>2];b=e&1048580?(b&240?-16:15)&b:b;c=b&240;f=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=f>>>3&30;break d}g=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!g){break b}b=0-(b<<1)|0;break c}if(g){break b}if(c){if(b?e&59314208:0){break b}b=f>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;v[d+12>>2]=v[a>>2]+(b<<!(e&59314208));me(d+12|0,0,256);v[a>>2]=v[d+12>>2]}hb=d+16|0}function pG(a,b,c,d){var e=0,f=0,g=0;f=hb-16|0;hb=f;a:{b:{if((a|0)!=(b|0)){c:{g=v[115992];v[115992]=0;Dd();d=uG(a,f+12|0,d);e=kb;d:{a=v[115992];if(a){if(v[f+12>>2]!=(b|0)){break c}if((a|0)!=68){break d}v[c>>2]=4;a=2147483647;if(!!d&(e|0)>=0|(e|0)>0){break a}break b}v[115992]=g;if(v[f+12>>2]==(b|0)){break d}break c}if((e|0)<0&d>>>0<=2147483647|(e|0)<-1){v[c>>2]=4;break b}if((e|0)>=0&d>>>0>=2147483648|(e|0)>0){v[c>>2]=4;a=2147483647;break a}a=d;break a}}v[c>>2]=4;a=0;break a}a=-2147483648}hb=f+16|0;return a}function hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-80|0;hb=c;d=uf(c+48|0);v[23516]=0;e=Q(673,b|0,d|0)|0;f=v[23516];v[23516]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23516]=0;T(674,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break a}}break c}e=v[d+4>>2];v[23516]=0;U(188,c|0,b|0,e|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;yd(d);S(a|0);L()}b=hc(c+24|0,c);cd(d+8|0,b);yb(b);yb(c);qk(a,d)}yd(d);hb=c+80|0}function g5(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;e=Lb(a);Rd(c+24|0);a=0;b=v[c+28>>2];d=v[c+24>>2];v[23516]=0;R(179,e|0,FI(d,b)|0);b=v[23516];v[23516]=0;a:{if((b|0)!=1){b:{while(1){b=v[c+24>>2];if((FI(b,v[c+28>>2])|0)<=(a|0)){hb=c+32|0;return}b=v[b+(a<<3)>>2];v[23516]=0;b=Q(53,c+8|0,b|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;R(181,e|0,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break b}wb(b);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;wb(b);break a}a=P()|0;O()|0}Me(e);S(a|0);L()}function iI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=hb-32|0;hb=d;A[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23516]=0;d=Q(53,d+8|0,10725)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(b,d);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(d);break b}a=v[a+32>>2];v[d+8>>2]=0;v[d+12>>2]=-1074790400;v[d>>2]=0;v[d+4>>2]=1072693248;e=(a+B(b,872)|0)+1075684|0,f=pl(A[Eg(d+24|0,d+8|0,d)>>3]*128+128),v[e>>2]=f;hb=d+32|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function QC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=w[a+8|0];h=v[a>>2];e=v[a+4>>2];f=Ic(b);a=Fb(b);b=hb-16|0;hb=b;v[b+8>>2]=a;v[b+12>>2]=e;a=h;g=v[Hb(b+12|0,b+8|0)>>2];c=g;while(1){a:{if(!c){c=0;break a}i=w[f|0];t[a|0]=i;if(!i){break a}f=f+1|0;a=a+1|0;c=c-1|0;continue}break}b:{if((d-1&255)>>>0<=1){t[b+7|0]=0;gm(a,((a+e|0)-g|0)+c|0,b+7|0);break b}if((d-3&255)>>>0>1){break b}t[b+6|0]=32;gm(a,((a+e|0)-g|0)+c|0,b+6|0)}c:{switch(d-1|0){case 0:case 3:t[(v[b+12>>2]+h|0)-1|0]=0;break;default:break c}}hb=b+16|0}function r9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);e=hb-16|0;hb=e;c=nf(a,c);ke(e,v[a+36>>2]);a:{if(!c){b:{Pc(e,a+32|0,5);if(!zb(v[v[e>>2]>>2],v[e+4>>2])){break b}break a}}d=hb-32|0;hb=d;h=v[a+36>>2];Ck(h,d+24|0);i=d,j=Bc(v[d+24>>2],v[d+28>>2]),v[i+16>>2]=j;v[d+12>>2]=256;ak(b,v[Hb(d+16|0,d+12|0)>>2]);f=v[b>>2];while(1){if(sc(f,v[b+4>>2])>>>0<=g>>>0){hb=d+32|0}else{v[d+16>>2]=0;yp(h,d+16|0);f=v[b>>2];i=Bb(f,g),k=z[d+16>>2],z[i>>2]=k;g=g+1|0;continue}break}d=c}Ve(a,d);hb=e+16|0}function gga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=hb-608|0;hb=f;b=hb-16|0;hb=b;d=f+8|0;HR(b+8|0,d);c=v[b+12>>2];id(b,a,v[b+8>>2],c);e=v[b+4>>2];if((e|0)==(c|0)){dd(a,v[b+12>>2])}hb=b+16|0;c=(c|0)==(e|0);if(!c){GR(d)}b=-1;a:{if(!c){break a}b=0;if(!IR(f+8|0)){break a}b=-1;if(!eg(a,1024)){break a}b=0;d=hb-1024|0;hb=d;c=hb-16|0;hb=c;_z(c+8|0,d);e=v[c+12>>2];id(c,a,v[c+8>>2],e);g=v[c+4>>2];if((e|0)==(g|0)){dd(a,v[c+12>>2])}hb=c+16|0;if((e|0)==(g|0)){b=$z(d,0)>>>0<17}hb=d+1024|0}hb=f+608|0;return b|0}function F_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;h=hb-16|0;hb=h;d=Fb(a);e=ep(a);g=Qd(b,c);a:{if(!g){break a}b:{f=wc(a);if(f>>>0<=b>>>0){f=(Fb(a)<<2)+f>>>0>=b>>>0}else{f=0}if(!f){if(e-d>>>0<g>>>0){MF(a,e,(d+g|0)-e|0,d,d)}e=wc(a)+(d<<2)|0;while(1){if((b|0)==(c|0)){break b}td(e,v[b>>2]);b=b+4|0;e=e+4|0;continue}}b=tG(h,b,c);c=wc(b);d=Fb(b);v[23516]=0;W(1189,a|0,c|0,d|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){Yc(b);break a}a=P()|0;O()|0;Yc(b);S(a|0);L()}td(e,0);th(a,d+g|0)}hb=h+16|0;return a|0}function Eq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!Fe(a)){if(!Fe(b)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return}d=Ic(b);b=Fb(b);c=hb-16|0;hb=c;a:{if(b>>>0<=10){Xd(a,b);a=Ce(a,d,b);t[c+15|0]=0;$d(a+b|0,c+15|0);break a}f=a;a=w[a+11|0];cp(f,10,b-10|0,a,0,a,b,d)}hb=c+16|0;return}d=Ic(b);b=Fb(b);c=hb-16|0;hb=c;e=Al(a);b:{if(e>>>0>b>>>0){e=v[a>>2];xd(a,b);a=Ce(e,d,b);t[c+15|0]=0;$d(a+b|0,c+15|0);break b}f=a;a=v[a+4>>2];cp(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}hb=c+16|0}}function Hja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;jd(b,0);_h(c,1,a);d=c+16|0;Cc(d,c);xe(b+43|0,d);wb(d);v[b+24>>2]=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);u[b+34>>1]=x[b+34>>1]&65533|(w[a+13|0]|w[a+14|0]<<8)<<1&2;v[b>>2]=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b+4>>2]=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);v[b+8>>2]=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);t[c+16|0]=w[a+15|0];t[c|0]=64;e=b,f=w[Vb(d,c)|0]<<2,u[e+30>>1]=f;hb=c+32|0}function vm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function AE(a,b,c,d){var e=0,f=0,g=0;e=hb-80|0;hb=e;f=uf(e+48|0);v[23516]=0;d=Q(d|0,b|0,f|0)|0;g=v[23516];v[23516]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23516]=0;T(c|0,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break a}}break c}c=v[f+4>>2];v[23516]=0;U(188,e|0,b|0,_b(c)|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;yd(f);S(a|0);L()}b=hc(e+24|0,e);cd(f+8|0,b);yb(b);yb(e);qk(a,f)}yd(f);hb=e+80|0}function vl(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(w[a+35|0]&2)){break a}Fo(a)}d=x[a+34>>1]&-513|d;u[a+34>>1]=d;if(b){v[a>>2]=4;u[a+34>>1]=d&65470;Jg(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}}function e5(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0);v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;if((d|0)!=1){a=v[v[a+24>>2]+24>>2];if(!((b|0)<0|x[a+480188>>1]<=b>>>0)){a=a+B(b,872)|0;c=C(C(w[a+1075834|0])*C(.0078125));e=C(c*c);c=C(C(w[a+1075835|0])*C(.0078125));c=C(K(C(e+C(c*c))))}return C(c)}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,9406,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;ec(c+8|0,b,26);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function gea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=hb-48|0;hb=f;Bq(f+8|0,c);v[23516]=0;c=f+20|0;R(587,c|0,d|0);d=v[23516];v[23516]=0;b:{c:{d:{if((d|0)==1){break d}v[23516]=0;c=f+32|0;R(587,c|0,e|0);d=v[23516];v[23516]=0;if((d|0)==1){break d}Dv(f,f+8|0);v[23516]=0;X(299,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}ZP(f+8|0);hb=f+48|0;break a}a=P()|0;O()|0;while(1){c=wb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;ZP(f+8|0)}S(a|0);L()}}function e$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=hb-208|0;hb=a;u[a+204>>1]=w[84043]|w[84044]<<8;v[a+200>>2]=w[84039]|w[84040]<<8|(w[84041]<<16|w[84042]<<24);f=Dd();v[a>>2]=e;g=a+176|0;i=Ug(g,20,f,a+200|0,a);e=i+g|0;g=Vi(g,e,c);f=a+8|0;bd(f,c);v[23516]=0;f=T(1153,f|0)|0;h=v[23516];v[23516]=0;if((h|0)!=1){Zb(a+8|0);h=f;f=a+16|0;cG(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Er(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);hb=a+208|0;return b|0}b=P()|0;O()|0;Zb(a+8|0);S(b|0);L()}function $Q(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;v[a>>2]=0;v[a+4>>2]=0;vj(a+8|0,0);d=v[b+4>>2];if(d){Rq(a,d);ml(c+8|0,v[b>>2]);tm(c,v[b>>2],v[b+4>>2]);b=hb-16|0;hb=b;d=v[a+4>>2];h=v[c+8>>2];i=v[c+12>>2];j=v[c>>2];k=v[c+4>>2];e=ZQ(h,i,j,k)+d|0;v[a+4>>2]=e;a:{b:{if(!d){f=e-1|0;break b}f=e-1|0;if((f^d-1)>>>0>31){break b}g=v[a>>2];break a}g=v[a>>2];v[g+((e>>>0<33?0:f>>>5|0)<<2)>>2]=0}Go(b+8|0,g,d);_Q(b,h,i,j,k,v[b+8>>2],v[b+12>>2]);hb=b+16|0}hb=c+16|0;return a|0}function wX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=hb-48|0;hb=f;Uo(f+8|0,c);v[23516]=0;c=f+20|0;R(137,c|0,d|0);d=v[23516];v[23516]=0;b:{c:{d:{if((d|0)==1){break d}v[23516]=0;c=f+32|0;R(137,c|0,e|0);d=v[23516];v[23516]=0;if((d|0)==1){break d}Dv(f,f+8|0);v[23516]=0;X(112,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}lr(f+8|0);hb=f+48|0;break a}a=P()|0;O()|0;while(1){c=xb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;lr(f+8|0)}S(a|0);L()}}function lfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-32|0;hb=d;jd(b,0);_A(d,a+1|0);c=d+16|0;Cc(c,d);xe(b+43|0,c);wb(c);v[b+24>>2]=w[a+73|0]|w[a+74|0]<<8|(w[a+75|0]<<16|w[a+76|0]<<24);c=w[a+54|0]|w[a+55|0]<<8|(w[a+56|0]<<16|w[a+57|0]<<24);v[b>>2]=c;v[b+4>>2]=w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24);e=w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24);if(e){v[b+8>>2]=e+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;uc(b+8|0,c);uc(b+4|0,v[b+8>>2]);hb=d+32|0}function Oha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;e=c+8|0;f=Lb(e+8|0);v[23516]=0;d=T(200,b|0)|0;g=v[23516];v[23516]=0;a:{b:{if((g|0)==1){break b}v[23516]=0;U(246,e|0,b|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break b}d=v[e>>2];v[23516]=0;Q(186,b|0,d|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;dc(f);S(a|0);L()}Gu(c,e);v[23516]=0;U(472,a|0,v[c>>2],v[c+4>>2]);a=v[23516];v[23516]=0;if((a|0)!=1){Qc(c+8|0);hb=c+32|0;return}a=P()|0;O()|0;Qc(c+8|0);S(a|0);L()}function tk(a){var b=0,c=0;a:{b=v[a+4>>2];b=v[v[b>>2]-12>>2]+b|0;b:{if(!v[b+24>>2]){break b}if(!Mh(b)|!(v[b+4>>2]&8192)){break b}if((eb()|0)>0){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23516]=0;b=T(22,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[23516]=0;R(16,a+b|0,1);a=v[23516];v[23516]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Tb();L()}function gM(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;a:{f=b-4e3&65535;if(f>>>0<61537){break a}c=B(b,104)+a|0;e=c+484380|0;if(!Vd(v[e>>2],v[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){um(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[d+24>>2]=0;v[d+8>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d>>2]=0;v[d+4>>2]=0;vl(e,0,d);break a}if(v[c+104>>2]==(e|0)){v[c+76>>2]=0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0}c=c+872|0;continue}}hb=d+32|0;return f>>>0>61536}function cy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{if((c|0)<2){break a}k=c-2>>>1|0;f=d-a|0;if((k|0)<f>>1){break a}h=f+1|0;e=(h<<1)+a|0;g=x[e>>1];i=f+2|0;if((i|0)<(c|0)){j=x[e+2>>1];f=Fp(b,g&65535,j);e=f?e+2|0:e;h=f?i:h;g=f?j:g}i=x[d>>1];if(Fp(b,g&65535,i)){break a}while(1){b:{f=e;u[d>>1]=g;if((h|0)>(k|0)){break b}d=h<<1;h=d|1;e=(h<<1)+a|0;g=x[e>>1];j=d+2|0;if((j|0)<(c|0)){l=x[e+2>>1];d=Fp(b,g&65535,l);e=d?e+2|0:e;h=d?j:h;g=d?l:g}d=f;if(!Fp(b,g&65535,i)){continue}}break}u[f>>1]=i}}function _O(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=v[a+8>>2]-1|0;e=v[a+12>>2];f=v[a>>2]+B(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=B(e,g);i=v[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!w[a+16|0]){d=1;c=0;break c}d=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=w[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{t[b+f|0]=w[v[a+4>>2]+(B(c,e)+b|0)|0];b=b+1|0;e=v[a+12>>2];continue}}break}}function wba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-48|0;hb=d;f=xO(a,1<<b-1);v[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=v[10509];c=d+16|0;v[c+8>>2]=v[10508];v[c+12>>2]=e;e=v[10507];v[c>>2]=v[10506];v[c+4>>2]=e;cz(c,h*+(b>>>0));sO(d+32|0,c);c=Gd(v[f>>2],a);e=v[d+44>>2];v[c+8>>2]=v[d+40>>2];v[c+12>>2]=e;e=v[d+36>>2];v[c>>2]=v[d+32>>2];v[c+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=pm(d,1,0);Xx(f,0,g,A[a>>3],A[a+8>>3]);hb=d+48|0;return f|0}function Er(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((Gm(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=aG(i,b,f);h=wc(f);v[23516]=0;h=W(1172,a|0,h|0,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break a}Yc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((Gm(a,c,b)|0)!=(b|0)){break b}}wo(e);j=a}hb=i+16|0;return j|0}a=P()|0;O()|0;Yc(f);S(a|0);L()}function C4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23516]=0;Y(966,a|0);c=v[23516];v[23516]=0;if((c|0)!=1){a=v[a+24>>2];c=-1;a:{if((b|0)<0){break a}d=v[a+24>>2];if(qj(Sb(v[d+484360>>2],w[d+484376|0]))>>>0<=b>>>0){break a}a=v[a+24>>2];c=x[$b(v[Sb(v[a+484360>>2],w[a+484376|0])>>2],b)>>1]}return c|0}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,9820,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function vz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;f=a+14|0;c=v[a>>2];e=v[a+4>>2];if(nc(c,e)){b=c}else{u[c>>1]=0;sf(c+2|0,b);g=d,h=qm(Cb(v[a>>2]),1),v[g+8>>2]=h;while(1){e=Cb(v[a+4>>2]);c=v[d+8>>2];if(Nb(c,e)){g=c,h=x[ie(c,qm(c,-1))>>1],u[g>>1]=h;sf(c+2|0,b);iQ(d+8|0);continue}else{e=v[a+4>>2];b=v[a>>2]}break}}sf(f,Qd(b,e)-1&255);sf(a+13|0,w[a+14|0]);sf(a+16|0,Qd(v[a>>2],v[a+4>>2])-1&255);sf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){sf(a+17|0,Qd(v[a>>2],v[a+4>>2])-1&255)}hb=d+16|0}function Bv(a){var b=0,c=0,d=0;if(y[a+4>>2]<y[Db(a)>>2]){b=hb-16|0;hb=b;a=pD(b,a);c=v[a+4>>2];v[23516]=0;Y(168,c|0);c=v[23516];v[23516]=0;a:{if((c|0)!=1){v[a+4>>2]=v[a+4>>2]+36;ic(a);hb=b+16|0;break a}b=P()|0;O()|0;ic(a);S(b|0);L()}return}c=hb-32|0;hb=c;b=Db(a);b=nD(c+8|0,oD(a,$q(v[a>>2],v[a+4>>2])+1|0),$q(v[a>>2],v[a+4>>2]),b);d=v[b+8>>2];v[23516]=0;Y(168,d|0);d=v[23516];v[23516]=0;b:{if((d|0)!=1){v[b+8>>2]=v[b+8>>2]+36;mD(a,b);rv(b);hb=c+32|0;break b}a=P()|0;O()|0;rv(b);S(a|0);L()}}function cJ(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=v[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(y[a+12>>2]<=d>>>0)){while(1){e=py(v[a>>2]);c=kb;f=v[a+36>>2];if((c|0)==(f|0)&y[a+32>>2]<=e>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(e&v[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){d=py(v[a>>2]);c=kb;f=v[a+28>>2];if((c|0)==(f|0)&y[a+24>>2]<=d>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(d&v[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function o$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=hb-96|0;hb=a;u[a+92>>1]=w[84043]|w[84044]<<8;v[a+88>>2]=w[84039]|w[84040]<<8|(w[84041]<<16|w[84042]<<24);f=Dd();v[a>>2]=e;g=a- -64|0;i=Ug(g,20,f,a+88|0,a);e=i+g|0;g=Vi(g,e,c);f=a+8|0;bd(f,c);v[23516]=0;f=T(19,f|0)|0;h=v[23516];v[23516]=0;if((h|0)!=1){Zb(a+8|0);h=f;f=a+16|0;iG(h,a- -64|0,e,f);h=b;b=f+i|0;b=Lq(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);hb=a+96|0;return b|0}b=P()|0;O()|0;Zb(a+8|0);S(b|0);L()}function $ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;a=bV(c,a);uA(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;ic(a);hb=c+16|0;return}e=hb-32|0;hb=e;c=Db(a);c=$U(e+8|0,aV(a,Cq(v[a>>2],v[a+4>>2])+1|0),Cq(v[a>>2],v[a+4>>2]),c);uA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;uA(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Db(a),zc(c));v[c>>2]=v[c+4>>2];_U(c);hb=e+32|0}function Bj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;a=bV(c,a);wB(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;ic(a);hb=c+16|0;return}e=hb-32|0;hb=e;c=Db(a);c=$U(e+8|0,aV(a,Cq(v[a>>2],v[a+4>>2])+1|0),Cq(v[a>>2],v[a+4>>2]),c);wB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;wB(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Db(a),zc(c));v[c>>2]=v[c+4>>2];_U(c);hb=e+32|0}function eJ(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==10){Cx(a,b,c,d);return}g=d;i=B(e,e);k=B(i,e);j=B(i,i);a:{while(1){h=f|1;if(e>>>0>g>>>0){break a}h=f|2;if(g>>>0<i>>>0){break a}h=f|3;if(g>>>0<k>>>0){break a}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){v[a+4>>2]=61;v[a>>2]=c;return}f=b+f|0;b=f;while(1){b=b-1|0;c=(d>>>0)/(e>>>0)|0;t[b|0]=w[(d-B(c,e)|0)+4898|0];g=d>>>0>=e>>>0;d=c;if(g){continue}break}v[a+4>>2]=0;v[a>>2]=f}function zQ(a){var b=0,c=0;a:{if(Qb(a+60|0,13906,4)){break a}b=w[a+28|0]|w[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=w[a+42|0];if(b>>>0>64&(b|0)!=88|(w[a+48|0]|w[a+49|0]<<8)>>>0>64|(w[a+50|0]|w[a+51|0]<<8)>>>0>96){break a}b=w[a+52|0]|w[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(w[a+30|0]|w[a+31|0]<<8)|(w[a+38|0]|w[a+39|0]<<8|(w[a+40|0]<<16|w[a+41|0]<<24)|(w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1)){break a}c=CQ(a+20|0)}return c}function aF(a,b,c,d,e,f,g,h){var i=0,j=0;i=hb-16|0;hb=i;v[23516]=0;Y(966,a|0);j=v[23516];v[23516]=0;a:{b:{if((j|0)!=1){c:{j=v[a+24>>2];v[23516]=0;ja(h|0,i|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}b=fg(Ic(i));wb(i);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23516]=0;X(953,g|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$()}hb=i+16|0;return b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Hf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function DL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)!=(b|0)){c=hb-16|0;hb=c;d=v[b>>2];f=v[b+4>>2];e=lk(d,f);a:{if(e>>>0<=nu(a)>>>0){g=f;h=v[a>>2];i=lk(h,v[a+4>>2]);j=i>>>0>=e>>>0;if(!j){v[c+12>>2]=d;v[c+12>>2]=v[c+12>>2]+B(i,6);g=v[c+12>>2]}d=FL(d,g,h);if(!j){Tx(a,g,f,e-lk(v[a>>2],v[a+4>>2])|0);break a}Ld(a,d);break a}EL(a);cT(a,BA(a,e));Tx(a,d,f,e)}hb=c+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];CL(a+24|0,b+24|0);Eq(a+36|0,b+36|0);return a}function gu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;h=Ib(b,0);f=(w[h|0]&15)<<8|w[Ib(b,1)|0];d=0;a:{if(!f){break a}d=0;if((f|0)==4095){break a}while(1){d=108;if((e|0)==84){break a}b:{d=x[(e<<1)+32848>>1];if(d>>>0<=f>>>0){if(!e|(f|0)==(d|0)|(x[(e<<1)+32846>>1]-f|0)>=(f-d|0)){break b}d=e+24|0;break a}e=e+1|0;continue}break}d=e+25|0}t[c|0]=d;e=Ib(b,2);d=w[e|0];f=w[h|0];t[c+3|0]=0;t[c+1|0]=f&16|d>>>4;c=w[e|0];i=g,j=w[Ib(b,3)|0],t[i+15|0]=j;ae(a,c&15,g+15|0);hb=g+16|0}function _3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;d=kf(e+16|0,1,0);a:{b:{while(1){f=wc(d);CJ(e+8|0,f,Fb(d)+f|0,w[b|0],c);if(!v[e+12>>2]){break b}f=Yg(Fb(d));v[23516]=0;R(57,d|0,f|0);f=v[23516];v[23516]=0;if((f|0)!=1){continue}break}break a}b=v[e+8>>2];c=wc(d);v[23516]=0;R(58,d|0,b-c|0);b=v[23516];v[23516]=0;c:{if((b|0)!=1){v[23516]=0;R(59,a|0,d|0);a=v[23516];v[23516]=0;if((a|0)!=1){break c}break a}break a}wb(d);hb=e+32|0;return}a=P()|0;O()|0;wb(d);S(a|0);L()}function Rja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Lb(a);a:{b:{if(b){v[23516]=0;R(321,a|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}d=hb-16|0;hb=d;c=yq(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){ic(c);hb=d+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4;b=b+6|0;v[c+4>>2]=b;continue}break}}break a}b=P()|0;O()|0;Ah(a);S(b|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function ZC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;g=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=g;a:{if(!g){break a}e=b+80|0;c=v[b+84>>2];if(c>>>0<=15){d=v[e>>2]}else{v[f+12>>2]=c-16;d=v[Vc(e,f+12|0)>>2]}v[a+8>>2]=d;c=v[b+88>>2];if(!(c&2)){break a}d=c;c=v[b+104>>2];b:{if(!(!YC(d,c)|v[e>>2]!=v[c+12>>2])){e=1;d=v[b+84>>2];if((d|0)==v[c+16>>2]){break b}}e=0;d=v[b+84>>2];if((d|0)!=v[c+8>>2]){break a}}h=a,i=B((v[c>>2]-d|0)+(e?112:48)|0,yk(x[c+34>>1]))+g|0,v[h+4>>2]=i}hb=f+16|0}function $E(a,b,c,d,e,f,g){var h=0,i=0;h=hb-16|0;hb=h;v[23516]=0;Y(966,a|0);i=v[23516];v[23516]=0;a:{b:{if((i|0)!=1){c:{i=v[v[a+24>>2]+24>>2];v[23516]=0;la(g|0,h|0,i|0,b|0,c|0,d|0,e|0);b=v[23516];v[23516]=0;if((b|0)==1){break c}b=fg(Ic(h));wb(h);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23516]=0;X(953,f|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$()}hb=h+16|0;return b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function xM(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;kb=v[e+4>>2];return v[e>>2]}function o2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=Oo(a);v[e>>2]=61468;c=zc(e);a=hb-16|0;hb=a;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=hb-16|0;hb=d;b=v[a+12>>2];v[d+8>>2]=v[a+8>>2];v[d+12>>2]=b;b=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=b;b=JI(d);c=Wm(c);t[c+8|0]=0;v[c+4>>2]=b;v[c>>2]=61868;Lb(c+12|0);v[c>>2]=61632;b=v[a+4>>2];v[c+24>>2]=v[a>>2];v[c+28>>2]=b;b=v[a+12>>2];v[c+32>>2]=v[a+8>>2];v[c+36>>2]=b;hb=d+16|0;hb=a+16|0;return e|0}function O8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ui(a,b,c,d);v[a>>2]=44252;b=Lb(a+4208|0);v[a+4236>>2]=-1;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Rb(a+4248|0,0,48);v[23516]=0;Z(830);c=v[23516];v[23516]=0;a:{if((c|0)==1){break a}e=a,f=FM(),v[e+4296>>2]=f;Es(a);Ds(a);v[23516]=0;R(917,a+44|0,2);c=v[23516];v[23516]=0;if((c|0)==1){break a}ti(a);return a|0}c=P()|0;O()|0;dc(b);Ff(a);S(c|0);L()}function h9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=hb-48|0;hb=f;d=v[a+36>>2];Kl(v[v[d>>2]-12>>2]+d|0,0);e=v[b>>2];d=v[e+12>>2];g=v[e+8>>2];if(d|g){h=v[a+36>>2];d=v[a+20>>2]+d|0;e=v[a+16>>2];g=g+e|0;e=Sg(f+32|0,g,e>>>0>g>>>0?d+1|0:d);d=v[e+12>>2];v[f+8>>2]=v[e+8>>2];v[f+12>>2]=d;d=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=d;Uj(h,f)}d=f+16|0;ke(d,v[a+36>>2]);lz(v[a+36>>2],c,v[v[b>>2]+16>>2]);c=v[b>>2];b=Fk(d,Ib(v[a+40>>2],v[c>>2]),x[c+20>>1]);Ve(a,c);Ub(b);hb=f+48|0}function _R(a,b,c,d){var e=0,f=0,g=0;f=hb-16|0;hb=f;while(1){a:{e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!hf(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){e=hf(a,f+14|0);if(e){g=w[f+14|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!e){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}hb=f+16|0}function Z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb-16|0;hb=c;a:{d=Sh(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}j=d>>31;k=v[b>>2];g=v[b+4>>2];l=v[b+8>>2];b:while(1){if((f|0)==(l|0)){break a}m=B(f,g);e=0;while(1)if((e|0)==(g|0)){f=f+1|0;continue b}else{h=(e+m<<2)+k|0;i=v[h>>2];n=h,o=Dc(ska(rka(i,i>>31,d,j),kb,65536,0),kb),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;_I(a,c);hb=c+16|0}function P2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb-16|0;hb=c;a:{d=Sh(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}j=d>>31;k=v[b>>2];g=v[b+4>>2];l=v[b+8>>2];b:while(1){if((f|0)==(l|0)){break a}m=B(f,g);e=0;while(1)if((e|0)==(g|0)){f=f+1|0;continue b}else{h=(e+m<<2)+k|0;i=v[h>>2];n=h,o=Dc(ska(rka(i,i>>31,d,j),kb,65536,0),kb),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;UI(a,c);hb=c+16|0}function z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;v[d+4>>2]=1;g=d,h=tc(56),v[g+8>>2]=h;c=Oo(v[d+8>>2]);v[c>>2]=61968;e=zc(c);c=hb-16|0;hb=c;f=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=f;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;b=Wm(e);v[b>>2]=62332;Lb(b+4|0);t[b+20|0]=0;v[b+16>>2]=0;v[b>>2]=62132;e=v[c+4>>2];v[b+24>>2]=v[c>>2];v[b+28>>2]=e;e=v[c+12>>2];v[b+32>>2]=v[c+8>>2];v[b+36>>2]=e;t[b+40|0]=0;hb=c+16|0;b=a;a=Qo(d);Po(b,zc(a),a);Xm(d);hb=d+16|0}function vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=xj(b),v[i>>2]=j;g=x[b>>1];c=hb-16|0;hb=c;f=a;d=Pd(a);a:{if(d){b=gc(f);while(1){a=d;d=x[a+16>>1];if(bo(g,d)){b=a;d=v[a>>2];if(d){continue}break a}if(!bo(d,g)){break a}b=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=gc(f);b=a}v[c+12>>2]=a;a=v[b>>2];if(!a){ZS(c,f,e);Hg(f,v[c+12>>2],b,v[c>>2]);a=_d(c);YS(c);h=1}Gg(e+8|0,v[cc(c,a)>>2],h);hb=c+16|0;a=sd(v[e+8>>2]);hb=e+16|0;return a+4|0}function tL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=xj(b),v[i>>2]=j;g=x[b>>1];c=hb-16|0;hb=c;f=a;d=Pd(a);a:{if(d){b=gc(f);while(1){a=d;d=x[a+16>>1];if(Is(g,d)){b=a;d=v[a>>2];if(d){continue}break a}if(!Is(d,g)){break a}b=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=gc(f);b=a}v[c+12>>2]=a;a=v[b>>2];if(!a){ZS(c,f,e);Hg(f,v[c+12>>2],b,v[c>>2]);a=_d(c);YS(c);h=1}Gg(e+8|0,v[cc(c,a)>>2],h);hb=c+16|0;a=sd(v[e+8>>2]);hb=e+16|0;return a+4|0}function bW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;jd(b,0);_h(d,1,a+33|0);c=d+16|0;Cc(c,d);xe(b+43|0,c);wb(c);e=w[a+50|0]|w[a+51|0]<<8;v[b>>2]=e;v[b+24>>2]=w[a+52|0]|w[a+53|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;g=b,h=w[Vb(c,d)|0]<<2,u[g+30>>1]=h;f=w[a+55|0]|w[a+56|0]<<8;v[b+4>>2]=f;c=w[a+57|0]|w[a+58|0]<<8;v[b+8>>2]=c;a:{if((c|0)==65535){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(!w[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0){break a}u[b+34>>1]=x[b+34>>1]|2}hb=d+32|0}function V9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;Gi(d,2,a+2|0);e=d+16|0;Cc(e,d);Ac(b+492|0,e);f=b+236|0;g=c+1|0;wb(e);c=0;while(1){if((c|0)==120){v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;KL(w[a|0]&15,w[a+1|0]&15,w[a+2|0]&15,w[a+3|0]&15,w[a+4|0]&15,a+5|0,b+48|0);KL(w[a|0]>>>4|0,w[a+1|0]>>>4|0,w[a+2|0]>>>4|0,w[a+3|0]>>>4|0,w[a+4|0]>>>4|0,a+35|0,b+68|0);hb=d+32|0}else{h=$b(f,c),i=w[(a+c|0)+31|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function rf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=rka(b,c,h,i);i=kb;j=h;h=rka(d,e,f,g);e=j+h|0;d=kb+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=rka(g,e,c,d);g=j+i|0;c=kb+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=rka(h,0,i,0);b=kb;c=0;d=rka(h,c,l,d);b=b+d|0;c=kb+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=rka(i,m,k,e)+b|0;e=kb;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;v[g+8>>2]=h;v[g+12>>2]=h>>>0<i>>>0?c+1|0:c;v[g>>2]=f;v[g+4>>2]=d}function nG(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115992];v[115992]=0;Dd();a=vw(a,e+12|0,d);d=kb;g=v[115992];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}v[115992]=h;if((b|0)!=v[e+12>>2]){break c}if(!d&a>>>0<65536){break b}}v[c>>2]=4;a=65535;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}hb=e+16|0;return a&65535}function To(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!zf(w[a+11|0])){c=w[b+11|0];if(!zf(c)){d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];return}d=qd(b);b=wd(v[b+4>>2],c);a:{if(b>>>0<=10){Xd(a,b);nd(Ce(a,d,b)+b|0,0);break a}e=a;a=Kf(w[a+11|0]);mq(e,10,b-10|0,a,0,a,b,d)}return}d=qd(b);b=wd(v[b+4>>2],w[b+11|0]);c=jB(v[a+8>>2]);b:{if(b>>>0<c>>>0){c=v[a>>2];xd(a,b);nd(Ce(c,d,b)+b|0,0);break b}e=a;a=v[a+4>>2];mq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function Lq(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>0){if((Gm(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=kf(i,b,f);g=wc(f);v[23516]=0;g=W(23,a|0,g|0,b|0)|0;h=v[23516];v[23516]=0;if((h|0)==1){break a}wb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((Gm(a,c,b)|0)!=(b|0)){break b}}wo(e);j=a}hb=i+16|0;return j|0}a=P()|0;O()|0;wb(f);S(a|0);L()}function Hy(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}dk(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}Ab(d+8|0,a+1074312|0,7);if(zb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}hb=d+16|0}function sE(a,b,c,d,e,f){var g=0;a:{g=hb-48|0;hb=g;bn(g+8|0,c);v[23516]=0;c=g+20|0;R(f|0,c|0,d|0);d=v[23516];v[23516]=0;b:{c:{d:{if((d|0)==1){break d}v[23516]=0;c=g+32|0;R(111,c|0,e|0);d=v[23516];v[23516]=0;if((d|0)==1){break d}Dv(g,g+8|0);v[23516]=0;X(112,a|0,b|0,v[g>>2],v[g+4>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}lr(g+8|0);hb=g+48|0;break a}a=P()|0;O()|0;while(1){c=xb(c-12|0);if((c|0)!=(g+8|0)){continue}break}break b}a=P()|0;O()|0;lr(g+8|0)}S(a|0);L()}}function j9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=hb-48|0;hb=g;e=v[a+36>>2];Kl(v[v[e>>2]-12>>2]+e|0,0);f=v[b>>2];e=v[f+12>>2];h=v[f+8>>2];if(e|h){i=v[a+36>>2];e=v[a+20>>2]+e|0;f=v[a+16>>2];h=h+f|0;f=Sg(g+32|0,h,f>>>0>h>>>0?e+1|0:e);e=v[f+12>>2];v[g+8>>2]=v[f+8>>2];v[g+12>>2]=e;e=v[f+4>>2];v[g>>2]=v[f>>2];v[g+4>>2]=e;Uj(i,g)}e=g+16|0;ke(e,v[a+36>>2]);nL(d,v[a+36>>2],c);c=v[b>>2];b=Fk(e,Ib(v[a+40>>2],v[c>>2]),x[c+20>>1]);Ve(a,c);Ub(b);hb=g+48|0}function g9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=hb-48|0;hb=g;e=v[a+36>>2];Kl(v[v[e>>2]-12>>2]+e|0,0);f=v[b>>2];e=v[f+12>>2];h=v[f+8>>2];if(e|h){i=v[a+36>>2];e=v[a+20>>2]+e|0;f=v[a+16>>2];h=h+f|0;f=Sg(g+32|0,h,f>>>0>h>>>0?e+1|0:e);e=v[f+12>>2];v[g+8>>2]=v[f+8>>2];v[g+12>>2]=e;e=v[f+4>>2];v[g>>2]=v[f>>2];v[g+4>>2]=e;Uj(i,g)}e=g+16|0;ke(e,v[a+36>>2]);kL(c,v[a+36>>2],d);c=v[b>>2];b=Fk(e,Ib(v[a+40>>2],v[c>>2]),x[c+20>>1]);Ve(a,c);Ub(b);hb=g+48|0}function nE(a,b,c,d){var e=0,f=0,g=0;f=hb-32|0;hb=f;e=kf(f+16|0,1,0);a:{b:{while(1){g=wc(e);CJ(f+8|0,g,Fb(e)+g|0,v[b>>2],c);if(!v[f+12>>2]){break b}g=Yg(Fb(e));v[23516]=0;R(57,e|0,g|0);g=v[23516];v[23516]=0;if((g|0)!=1){continue}break}break a}b=v[f+8>>2];c=wc(e);v[23516]=0;R(58,e|0,b-c|0);b=v[23516];v[23516]=0;c:{if((b|0)!=1){v[23516]=0;R(d|0,a|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){break c}break a}break a}wb(e);hb=f+32|0;return}a=P()|0;O()|0;wb(e);S(a|0);L()}function mE(a,b,c,d){var e=0,f=0,g=0;f=hb-32|0;hb=f;e=kf(f+16|0,1,0);a:{b:{while(1){g=wc(e);eJ(f+8|0,g,Fb(e)+g|0,v[b>>2],c);if(!v[f+12>>2]){break b}g=Yg(Fb(e));v[23516]=0;R(57,e|0,g|0);g=v[23516];v[23516]=0;if((g|0)!=1){continue}break}break a}b=v[f+8>>2];c=wc(e);v[23516]=0;R(58,e|0,b-c|0);b=v[23516];v[23516]=0;c:{if((b|0)!=1){v[23516]=0;R(d|0,a|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){break c}break a}break a}wb(e);hb=f+32|0;return}a=P()|0;O()|0;wb(e);S(a|0);L()}function Js(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{d:{if(!(a&3)|!c){break d}e=b&255;while(1){if((e|0)==w[a|0]){break c}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break d}if(c){continue}break}}if(!d){break a}if(w[a|0]==(b&255)|c>>>0<4){break c}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){if(w[a|0]==(b&255)){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Gy(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}dk(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}Ab(d+8|0,a+1074312|0,7);if(zb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}hb=d+16|0}function gY(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[23516]=0;m=a;a=b;b=0;a=Oa(1062,m|b,a|0,c|0,d|0,b|e,f|0)|0;b=v[23516];v[23516]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23516]=0;ja(949,8872,g|0,h|0,i|0,j|0,k|0,l|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}return a|0}function X1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;a:{g=v[c+12>>2];if(!g){break a}e=Jl(d,c+16|0);f=zk(v[b+4>>2],w[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){xb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(w[qd(b)|0]==43){break c}if(w[qd(b)|0]==45){break c}}v[23516]=0;W(82,b|0,f-c|0,e|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=P()|0;O()|0;xb(e);S(a|0);L()}Xc(a,b);hb=d+16|0}function KE(a,b,c,d,e){var f=0,g=0,h=0;f=hb-160|0;hb=f;u[f+156>>1]=w[84037]|w[84038]<<8;v[f+152>>2]=w[84033]|w[84034]<<8|(w[84035]<<16|w[84036]<<24);g=f+152|0;Gr(g|1,10773,e,v[b+4>>2]);e=Dd();v[f>>2]=d;d=f+139|0;e=Ug(d,13,e,g,f)+d|0;g=Vi(d,e,b);h=f+16|0;bd(h,b);v[23516]=0;ja(1170,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=v[23516];v[23516]=0;if((d|0)!=1){Zb(f+16|0);a=Er(a,f+32|0,v[f+28>>2],v[f+24>>2],b,c);hb=f+160|0;return a}a=P()|0;O()|0;Zb(f+16|0);S(a|0);L()}function K5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[23516]=0;Y(991,a|0);f=v[23516];v[23516]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[23516]=0;b=Ta(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11334,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function wL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=v[a>>2];c=sc(d,v[a+4>>2]);if(c>>>0<=127){f=hb-32|0;hb=f;c=128-c|0;e=v[Db(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){Qx(a,c,b);break a}e=Db(a);d=Tf(f+8|0,pg(a,sc(v[a>>2],d)+c|0),sc(v[a>>2],v[a+4>>2]),e);g=hb-16|0;hb=g;c=Dl(g,d+8|0,c);e=v[c>>2];while(1){if(v[c+4>>2]!=(e|0)){bk(e,z[b>>2]);e=v[c>>2]+4|0;v[c>>2]=e;continue}break}Kd(c);hb=g+16|0;Cd(a,d);Sf(d)}hb=f+32|0;return}if((c|0)!=128){Ld(a,d+512|0)}}function kG(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if((a|0)!=(b|0)){b:{c:{f=w[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=v[115992];v[115992]=0;Dd();a=vw(a,e+12|0,d);d=kb;d:{g=v[115992];if(g){if(v[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}v[c>>2]=4;b=-1;a=-1;break a}v[115992]=h;if(v[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}v[c>>2]=4;b=0;a=0}hb=e+16|0;kb=a;return b}function JL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-32|0;hb=e;v[e+16>>2]=c;v[e+24>>2]=b;i=e,j=ge(a),v[i+8>>2]=j;c=e+24|0;b=En(c,e+8|0);c=En(e+16|0,c);a:{if(Fb(a)>>>0>=b>>>0){if((c|0)==-1){BL(a,b);break a}f=a;d=hb-16|0;hb=d;v[d+12>>2]=c;if(c){g=Fb(f);h=wc(f);c=g-b|0;v[d+8>>2]=c;a=v[Hb(d+12|0,d+8|0)>>2];v[d+12>>2]=a;b:{if((a|0)==(c|0)){a=c;break b}b=b+h|0;Xh(b,a+b|0,c-a|0)}a=g-a|0;th(f,a);t[d+7|0]=0;$d(a+h|0,d+7|0)}hb=d+16|0;break a}pk();L()}hb=e+32|0}function L_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;d=Fb(a);e=_c(a);g=vh(b,c);a:{if(!g){break a}b:{if(!Ms(a,b)){if(e-d>>>0<g>>>0){im(a,e,(d+g|0)-e|0,d,d,0,0)}e=wc(a)+d|0;while(1){if((b|0)==(c|0)){break b}$d(e,b);b=b+1|0;e=e+1|0;continue}}b=Th(f,b,c);c=Ic(b);d=Fb(b);v[23516]=0;W(1083,a|0,c|0,d|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){wb(b);break a}a=P()|0;O()|0;wb(b);S(a|0);L()}t[f+15|0]=0;$d(e,f+15|0);th(a,d+g|0)}hb=f+16|0;return a|0}function ME(a,b,c,d,e){var f=0,g=0,h=0;f=hb-80|0;hb=f;u[f+76>>1]=w[84037]|w[84038]<<8;v[f+72>>2]=w[84033]|w[84034]<<8|(w[84035]<<16|w[84036]<<24);g=f+72|0;Gr(g|1,10773,e,v[b+4>>2]);e=Dd();v[f>>2]=d;d=f+59|0;e=Ug(d,13,e,g,f)+d|0;g=Vi(d,e,b);h=f+16|0;bd(h,b);v[23516]=0;ja(1167,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=v[23516];v[23516]=0;if((d|0)!=1){Zb(f+16|0);a=Lq(a,f+32|0,v[f+28>>2],v[f+24>>2],b,c);hb=f+80|0;return a}a=P()|0;O()|0;Zb(f+16|0);S(a|0);L()}function Eea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;sm(c+48|0,b);oe(c+16|0,v[c+48>>2],v[c+52>>2]);b=ce(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23516]=0;b=ga(164,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[23516];v[23516]=0;a:{if((d|0)!=1){d=Lb(a);a=v[c+52>>2];e=v[c+48>>2];v[23516]=0;U(718,b|0,d|0,ad(e,a)>>>5|0);a=v[23516];v[23516]=0;if((a|0)==1){a=P()|0;O()|0;Ci(d);yb(b);break a}yb(b);dc(c+48|0);hb=c- -64|0;return}a=P()|0;O()|0}dc(c+48|0);S(a|0);L()}
function zea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;sm(c+48|0,b);oe(c+16|0,v[c+48>>2],v[c+52>>2]);b=ce(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23516]=0;b=ga(164,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[23516];v[23516]=0;a:{if((d|0)!=1){d=Lb(a);a=v[c+52>>2];e=v[c+48>>2];v[23516]=0;U(721,b|0,d|0,ad(e,a)>>>4|0);a=v[23516];v[23516]=0;if((a|0)==1){a=P()|0;O()|0;kl(d);yb(b);break a}yb(b);dc(c+48|0);hb=c- -64|0;return}a=P()|0;O()|0}dc(c+48|0);S(a|0);L()}function Bea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;sm(c+48|0,b);oe(c+16|0,v[c+48>>2],v[c+52>>2]);b=ce(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23516]=0;b=ga(164,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[23516];v[23516]=0;a:{if((d|0)!=1){d=Lb(a);a=v[c+52>>2];e=v[c+48>>2];v[23516]=0;U(719,b|0,d|0,ad(e,a)>>>2|0);a=v[23516];v[23516]=0;if((a|0)==1){a=P()|0;O()|0;lc(d);yb(b);break a}yb(b);dc(c+48|0);hb=c- -64|0;return}a=P()|0;O()|0}dc(c+48|0);S(a|0);L()}function Aea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;sm(c+48|0,b);oe(c+16|0,v[c+48>>2],v[c+52>>2]);b=ce(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23516]=0;b=ga(164,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[23516];v[23516]=0;a:{if((d|0)!=1){d=Lb(a);a=v[c+52>>2];e=v[c+48>>2];v[23516]=0;U(720,b|0,d|0,ad(e,a)>>>8|0);a=v[23516];v[23516]=0;if((a|0)==1){a=P()|0;O()|0;yt(d);yb(b);break a}yb(b);dc(c+48|0);hb=c- -64|0;return}a=P()|0;O()|0}dc(c+48|0);S(a|0);L()}function nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Cb(v[b>>2]);h=Cb(v[b+4>>2]);g=hb-16|0;hb=g;v[g+8>>2]=d;while(1){a:{if(!Nb(d,h)){break a}e=hb-16|0;hb=e;f=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[e+8|0]=f;t[e+9|0]=f>>>8;t[e+10|0]=f>>>16;t[e+11|0]=f>>>24;f=w[d+4|0]|w[d+5|0]<<8;t[e+12|0]=f;t[e+13|0]=f>>>8;hb=e+16|0;if(x[e+8>>1]==(c|0)){break a}d=v[Em(g+8|0)>>2];continue}break}hb=g+16|0;if(nc(d,Cb(v[b+4>>2]))){Ih(a);return}so(a,d)}function JN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-16|0;hb=d;j=d,k=xj(b),v[j>>2]=k;c=hb-16|0;hb=c;g=Ay(a,c+12|0,w[b|0],v[b+4>>2]);b=v[g>>2];if(!b){e=hb-16|0;hb=e;b=gc(a);h=gh(c,tc(28),hh(e+8|0,b));b=v[h>>2];f=v[d>>2];i=v[f+4>>2];f=v[f>>2];v[b+24>>2]=0;v[b+16>>2]=f;v[b+20>>2]=i;j=gc(h),k=1,t[j+4|0]=k;hb=e+16|0;Hg(a,v[c+12>>2],g,v[c>>2]);b=_d(c);mk(c);e=1}Gg(d+8|0,v[cc(c,b)>>2],e);hb=c+16|0;a=sd(v[d+8>>2]);hb=d+16|0;return a+8|0}function pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+12>>2]+i|0;e=t[f|0];e=((B(t[f+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;hb=b+16|0}function nx(a,b,c){var d=0,e=0,f=0;e=Lb(a);a:{b:{if(c){v[23516]=0;R(1086,e|0,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}d=hb-16|0;hb=d;c=eh(d,e,c);a=v[c+4>>2];f=v[c+8>>2];while(1){if((a|0)==(f|0)){ic(c);hb=d+16|0}else{v[a>>2]=0;wh(a);a=a+4|0;v[c+4>>2]=a;continue}break}}break a}a=P()|0;O()|0;lc(e);S(a|0);L()}a=0;c=0;d=hb-16|0;hb=d;f=d+8|0;while(1){if(a>>>0<32){a=a+48|0;c=yM(b);continue}break}v[f>>2]=c;In(f);hb=d+16|0;v[e+12>>2]=v[f>>2];return e}function lE(a,b,c,d,e){var f=0,g=0,h=0;a:{f=hb-32|0;hb=f;h=Lb(a);b:{c:{d:{e:{while(1){a=v[b+8>>2];g=v[b>>2];v[23516]=0;a=W(154,g|0,a|0,8)|0;g=v[23516];v[23516]=0;if((g|0)==1){break c}if(!a){break d}v[23516]=0;U(e|0,f|0,b|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){v[23516]=0;R(d|0,h|0,f|0);a=v[23516];v[23516]=0;if((a|0)==1){break e}yd(f);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;yd(f);break b}hb=f+32|0;break a}a=P()|0;O()|0}Ud(h);S(a|0);L()}}function _C(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=hb-16|0;hb=d;b:{c:{if(!b){b=Ic(c);e=b;f=Fb(c)+b|0;c=vh(b,f);if(c>>>0<4294967280){d:{if(c>>>0<=10){Xd(a,c);break d}g=ih(c)+1|0;b=tc(g);td(a,b);bf(a,g);xd(a,c);a=b}while(1){if((e|0)!=(f|0)){nd(a,w[e|0]);a=a+1|0;e=e+1|0;continue}break}nd(a,0);break c}df();L()}jP(d,b,c);v[23516]=0;R(48,a|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}Yc(d)}hb=d+16|0;break a}a=P()|0;O()|0;Yc(d);S(a|0);L()}}function N5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23516]=0;Y(991,a|0);e=v[23516];v[23516]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[23516]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11479,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function vca(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:bh(a,0,c);return;case 1:bh(a,1,c);return;case 2:bh(a,2,c);return;case 3:bh(a,3,c);return;case 4:bh(a,4,c);return;case 5:bh(a,5,c);return;case 6:dP(a,23872,c);return;case 7:dP(a,24896,c);return;case 8:bh(a,6,c);return;case 9:bh(a,7,c);return;case 10:bh(a,8,c);return;case 11:bh(a,9,c);return;case 12:bh(a,10,c);return;case 13:bh(a,11,c);return;case 14:bh(a,12,c);return;default:break a}}Kb(a)}function M5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23516]=0;Y(991,a|0);e=v[23516];v[23516]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[23516]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11515,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function BX(a,b){a=a|0;b=b|0;var c=0;a=Kb(a);a:{if(w[b+16|0]){v[23516]=0;Q(131,a|0,4948)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[23516]=0;Q(131,a|0,12576)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}}if(oh(v[a+4>>2],w[a+11|0])){v[23516]=0;Q(131,a|0,10086)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[23516]=0;Q(131,a|0,11101)|0;b=v[23516];v[23516]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;xb(a);S(b|0);L()}function $o(a,b,c,d,e){var f=0,g=0,h=0;a:{f=hb-32|0;hb=f;h=Lb(a);b:{c:{d:{e:{while(1){a=v[b+8>>2];g=v[b>>2];v[23516]=0;a=W(154,g|0,a|0,e|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break c}if(!a){break d}v[23516]=0;R(d|0,f|0,b|0);a=v[23516];v[23516]=0;if((a|0)!=1){v[23516]=0;R(c|0,h|0,f|0);a=v[23516];v[23516]=0;if((a|0)==1){break e}yd(f);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;yd(f);break b}hb=f+32|0;break a}a=P()|0;O()|0}Ud(h);S(a|0);L()}}function taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=x[a+30>>1];if(d){b=Dn(b<<16>>16,d<<16>>16)}u[e+14>>1]=b;a=a+52|0;a:{if(!oh(v[c+4>>2],w[c+11|0])){To(tL(a,e+14|0),c);break a}b=Ox(a,e+14|0);if(!Fg(b,tf(a))){break a}c=hb-16|0;hb=c;b=v[cc(c,b)>>2];d=hb-16|0;hb=d;f=Ig(cc(d+8|0,b));if((b|0)==v[a>>2]){v[a>>2]=v[f>>2]}g=Db(a);v[g>>2]=v[g>>2]-1;sL(v[gc(a)>>2],b);a=v[f>>2];hb=d+16|0;Xt(sd(b));Jb(b);cc(c+8|0,a);hb=c+16|0}hb=e+16|0}function Z0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);g=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=g;a:{b:{if(Vw(db(v[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=v[d+12>>2];if((e|0)>0){break b}b=e?32:16}v[a>>2]=b|v[a>>2];break a}g=v[d+20>>2];if(g>>>0>=e>>>0){f=e;break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}f=c}hb=d+32|0;return f|0}function oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=(v[b+12>>2]<<1)+i|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;hb=b+16|0}function kfa(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-32|0;hb=d;jd(b,0);_A(d,a+1|0);c=d+16|0;Cc(c,d);xe(b+43|0,c);wb(c);v[b+24>>2]=w[a+78|0]|w[a+79|0]<<8;c=w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24);v[b>>2]=c;v[b+4>>2]=w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24);v[b+8>>2]=w[a+66|0]|w[a+67|0]<<8|(w[a+68|0]<<16|w[a+69|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;uc(b+8|0,c);uc(b+4|0,v[b+8>>2]);hb=d+32|0}function YE(a,b,c,d){var e=0,f=C(0);v[23516]=0;Y(966,a|0);e=v[23516];v[23516]=0;if((e|0)!=1){a=v[v[a+24>>2]+24>>2];a:{if((b|0)<0|x[a+480188>>1]<=b>>>0){break a}a=a+B(b,872)|0;if(!(t[a+1075081|0]&1)){break a}f=C(C(w[a+d|0])*C(.0078125))}return f}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,c|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return C(0)}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function I5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23516]=0;Y(991,a|0);d=v[23516];v[23516]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[23516]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,6663,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function G5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23516]=0;Y(991,a|0);d=v[23516];v[23516]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[23516]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,6717,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function z3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;a:{g=v[c+12>>2];if(!g){break a}e=yh(d,c+16|0);f=Fb(b);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){wb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(w[Jc(b,0)|0]==43){break c}if(w[Jc(b,0)|0]==45){break c}}v[23516]=0;W(75,b|0,f-c|0,e|0)|0;i=v[23516];v[23516]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=P()|0;O()|0;wb(e);S(a|0);L()}Xc(a,b);hb=d+16|0}function pC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=Oc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=v[Db(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){iC(a,b);break a}c=Db(a);c=Jj(e+8|0,Kj(a,Oc(v[a>>2],d)+b|0),Oc(v[a>>2],v[a+4>>2]),c);f=hb-16|0;hb=f;b=Io(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){hC(d);d=v[b>>2]+2|0;v[b>>2]=d;continue}break}Kd(b);hb=f+16|0;Cd(a,c);Li(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Ld(a,d+(b<<1)|0)}}function ak(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=sc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=v[Db(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){wP(a,b);break a}c=Db(a);c=Tf(e+8|0,pg(a,sc(v[a>>2],d)+b|0),sc(v[a>>2],v[a+4>>2]),c);f=hb-16|0;hb=f;b=Dl(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){uP(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Kd(b);hb=f+16|0;Cd(a,c);Sf(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Ld(a,d+(b<<2)|0)}}function qM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;d=_c(a);a:{b:{c:{f=vh(b,c);if(d>>>0<f>>>0){if(Ms(a,b)){break c}g=d;h=f-d|0;d=Fb(a);im(a,g,h,d,0,d,0)}d=wc(a);while(1){if((b|0)==(c|0)){break b}$d(d,b);d=d+1|0;b=b+1|0;continue}}b=Th(e,b,c);c=Ic(b);d=Fb(b);v[23516]=0;W(55,a|0,c|0,d|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){wb(b);break a}a=P()|0;O()|0;wb(b);S(a|0);L()}t[e+15|0]=0;$d(d,e+15|0);th(a,f)}hb=e+16|0;return a|0}function ZE(a,b,c,d){var e=0,f=C(0);v[23516]=0;Y(966,a|0);e=v[23516];v[23516]=0;if((e|0)!=1){a=v[v[a+24>>2]+24>>2];a:{if((b|0)<0|x[a+480188>>1]<=b>>>0){break a}a=a+B(b,872)|0;if(t[a+1075081|0]&1){break a}f=C(C(w[a+d|0])*C(.0078125))}return f}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,c|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return C(0)}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function xs(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(v[23510]){b=xs(v[23510])}if(!v[23434]){break a}c=b|c;a=v[23434];continue}break}d=v[a+76>>2]>=0;b:{c:{if(v[a+20>>2]==v[a+28>>2]){break c}lb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break c}b=-1;if(d){break b}break a}b=v[a+8>>2];e=v[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;lb[v[a+40>>2]](a,b,b>>31,1)|0}b=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;if(!d){break a}}}return b|c}function mc(a,b){var c=0,d=0,e=0;c=v[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return mc(a,24)+(mc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=ds(a);d=0;if((e|0)==-1){break a}d=v[a+1396>>2];c=d+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){aa(10096,13226,1632,6833);L()}d=v[a+1392>>2];v[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}v[a+1396>>2]=c}return d}function fg(a){var b=0,c=0,d=0;d=tp(Og(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=w[a|0];break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}t[c|0]=b;if(!(b&255)){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function Ck(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;v[b>>2]=0;v[b+4>>2]=0;t[e+15|0]=0;Oh(a,e+15|0);c=w[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){v[b>>2]=f;v[b+4>>2]=d;if(!g&(h|0)==(i|0)){hb=e+16|0}else{t[e+15|0]=0;Oh(a,e+15|0);c=v[b>>2];j=v[b+4>>2];f=w[e+15|0];d=g;g=h+1|0;d=g?d:d+1|0;h=g;g=d;k=c;d=(h<<3)-2|0;c=d&31;if((d&63)>>>0>=32){d=f<<c;c=0}else{d=(1<<c)-1&f>>>32-c;c=f<<c}f=k|c;d=d|j;continue}break}}function ut(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;e=d+16|0;YP(e,a,a+1|0,a+2|0,a+3|0);YP(d,b,b+1|0,b+2|0,b+3|0);hb=d+32|0;a=w[v[e>>2]];b=w[v[d>>2]];c=1;a:{if(a>>>0<b>>>0){break a}c=0;if(a>>>0>b>>>0){break a}a=t[v[e+4>>2]];b=t[v[d+4>>2]];c=1;b:{if((a|0)<(b|0)){break b}c=0;if((a|0)>(b|0)){break b}f=v[e+12>>2];g=v[d+12>>2];a=w[v[d+8>>2]];b=w[v[e+8>>2]];c=1;c:{if(a>>>0>b>>>0){break c}c=0;if(a>>>0<b>>>0){break c}c=w[f|0]<w[g|0]}}}return c}function gD(a,b,c){var d=0,e=0,f=0,g=0;a:{d=jo(b,Pj(a));c=jo(c,b);if(wd(v[a+4>>2],w[a+11|0])>>>0>=d>>>0){if((c|0)==-1){if(zf(w[a+11|0])){nd(d+v[a>>2]|0,0);xd(a,d);break a}nd(a+d|0,0);Xd(a,d);break a}b=a;e=hb-16|0;hb=e;v[e+12>>2]=c;if(c){f=wd(v[b+4>>2],w[b+11|0]);g=qd(b);c=f-d|0;v[e+8>>2]=c;a=v[Hb(e+12|0,e+8|0)>>2];v[e+12>>2]=a;b:{if((a|0)==(c|0)){a=c;break b}d=d+g|0;Xh(d,a+d|0,c-a|0)}a=f-a|0;io(b,a);nd(a+g|0,0)}hb=e+16|0;break a}pk();L()}}function Tw(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[116018]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[115992]=25;a=-1}else{a=1}return a}t[a|0]=b;return 1}function PL(a,b,c,d,e,f,g,h){var i=0,j=0;i=hb-16|0;hb=i;v[i+12>>2]=d;a:{if(!(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24))){break a}v[i+8>>2]=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);j=b;b=v[Hb(i+8|0,i+12|0)>>2];v[j>>2]=b;b=Bd(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),b,d);v[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=x[e>>1]|f;u[e>>1]=b;if((w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=1){break a}u[e>>1]=b|g}hb=i+16|0}function JV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a:{b:{if(!eg(a,7)){break b}c=0;if(!eC(a,17924)){break a}if(!eg(a,1)){break b}c=-1;if(!dd(a,Fq(a))){break a}c=hb-16|0;hb=c;f=d+8|0;yo(c+8|0,f);e=v[c+12>>2];id(c,a,v[c+8>>2],e);g=v[c+4>>2];if((g|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){Eu(f)}c=-1;if(!e){break a}c=0;if(!TB(w[d+8|0],w[d+9|0])){break a}c=we(a,b,SB(d+8|0),kb);break a}c=-1}hb=d+16|0;return c|0}function u5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23516]=0;Y(991,a|0);d=v[23516];v[23516]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+96>>2];v[23516]=0;ta(f|0,d|0,b|0,+c);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11652,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function s5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23516]=0;Y(991,a|0);d=v[23516];v[23516]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+88>>2];v[23516]=0;ta(f|0,d|0,b|0,+c);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11035,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function S5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;v[e+24>>2]=c;c=v[dg(e+16|0,e+24|0)>>2];v[23516]=0;f=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;fa(960,a+8|0,e|0,c|0,d|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){a=EI(a);b=DI(a+88|0);c=CI(a+92|0);d=BI(a+96|0);v[a>>2]=62696;v[b>>2]=62812;v[c>>2]=62892;v[d>>2]=62932;ze(e+24|0);hb=e+32|0;return a|0}a=P()|0;O()|0;ze(e+24|0);S(a|0);L()}function Jea(a,b){a=a|0;b=b|0;var c=0,d=0;c=Lb(a);a:{if(b){v[23516]=0;R(696,c|0,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}a=hb-16|0;hb=a;v[a>>2]=c;d=v[c+4>>2];v[a+4>>2]=d;v[a+8>>2]=d+B(b,9);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){ic(a);hb=a+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[a+4>>2]=b;continue}break}}return c|0}a=P()|0;O()|0;bq(c);S(a|0);L()}function E5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23516]=0;Y(991,a|0);d=v[23516];v[23516]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[23516]=0;ta(f|0,d|0,b|0,+c);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11714,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Cea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-4096|0;hb=c;sm(a,b);a:while(1){if(ad(v[a>>2],v[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){g=f|2048;b=0;while(1){if((b|0)!=2048){h=Ib(v[a>>2],b+g|0);i=Ib(c,b<<1);d=w[h|0]+d|0;t[i|0]=d;b=b+1|0;continue}break}lh(c,hQ(c),Pf(Cb(v[a>>2]),f));e=e+1|0;continue a}else{g=Ib(v[a>>2],b+f|0);h=Ib(c,b<<1|1);d=w[g|0]+d|0;t[h|0]=d;b=b+1|0;continue}}break}hb=c+4096|0}function Dba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=Uf(e,v[a+4>>2]);if(d>>>0<b>>>0){e=hb-32|0;hb=e;a:{b:{d=b-d|0;b=v[Db(a)>>2];f=v[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){oz(a,d,c);break c}b=Db(a);b=pt(e+8|0,_p(a,Uf(v[a>>2],f)+d|0),Uf(v[a>>2],v[a+4>>2]),b);v[23516]=0;U(775,b|0,d|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}MO(a,b);mz(b)}hb=e+32|0;break a}a=P()|0;O()|0;mz(b);S(a|0);L()}return}if(b>>>0<d>>>0){OO(a,e+(b<<5)|0)}}function Oi(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=ad(d,v[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=v[Db(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>>0){jE(a,b);break a}c=Db(a);c=Ql(e+8|0,Ol(a,ad(v[a>>2],d)+b|0),ad(v[a>>2],v[a+4>>2]),c);f=hb-16|0;hb=f;b=Mv(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){iE(d);d=v[b>>2]+1|0;v[b>>2]=d;continue}break}Kd(b);hb=f+16|0;Cd(a,c);Pl(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Ld(a,b+d|0)}}function Bia(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=hb-32|0;hb=g;a:{if(x[a+480192>>1]<b>>>0){break a}b=v[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+16|0;IT(h,b);i=g,j=Cb(v[g+16>>2]),v[i+8>>2]=j;h=Yf(h);while(1){b=v[g+8>>2];if(Nb(b,h)){b=x[go(b)>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}Ig(g+8|0);continue}else{bu(g+16|0)}break}}hb=g+32|0}function z4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23516]=0;Y(966,a|0);c=v[23516];v[23516]=0;if((c|0)!=1){a=v[v[a+24>>2]+24>>2];c=0;a:{if(!gs(b)){break a}d=v[a+484344>>2];if(!te(d,v[a+484348>>2],b&65535)){break a}c=v[Xb(d,b)+12>>2]}return c|0}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,6627,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function h4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=hb-16|0;hb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[23516]=0;b=Q(53,h|0,8229)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}e=P()|0;O()|0;wb(b);break b}Yk(a,b,4);c=lx(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);hb=h+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function aO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;j=e,k=xj(b),v[j>>2]=k;c=hb-16|0;hb=c;f=$y(a,c+12|0,x[b>>1],v[b+4>>2]);b=v[f>>2];if(!b){b=hb-16|0;hb=b;d=gc(a);g=gh(c,tc(36),hh(b+8|0,d));d=v[g>>2]+16|0;h=v[e>>2];i=v[h+4>>2];v[d>>2]=v[h>>2];v[d+4>>2]=i;Lb(d+8|0);j=gc(g),k=1,t[j+4|0]=k;hb=b+16|0;Hg(a,v[c+12>>2],f,v[c>>2]);b=_d(c);eO(c);d=1}Gg(e+8|0,v[cc(c,b)>>2],d);hb=c+16|0;a=sd(v[e+8>>2]);hb=e+16|0;return a+8|0}function U3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=hb-16|0;hb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[23516]=0;b=Q(53,h|0,8229)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}e=P()|0;O()|0;wb(b);break b}Yk(a,b,4);c=mx(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);hb=h+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function IS(a,b){var c=0,d=0,e=0,f=0;d=v[a>>2];c=sc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=v[Db(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){xA(a,b);break a}c=Db(a);c=Tf(e+8|0,pg(a,sc(v[a>>2],d)+b|0),sc(v[a>>2],v[a+4>>2]),c);f=hb-16|0;hb=f;b=Dl(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){Fm(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Kd(b);hb=f+16|0;Cd(a,c);Sf(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Ld(a,d+(b<<2)|0)}}function nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;d=Uc(c+8|0,16,1,1,0);v[c+4>>2]=0;jd(a,0);xc(b);a:{b:{if(Kq(b,13843)){Zc(b,12);if(!uo(b)){Eo(d,2)}Zc(b,24);break b}if(Fh(b,13715)){xc(b);v[c+4>>2]=4;e=1;break a}nd(d,8)}e=0}f=a,g=($e(b)>>>0)/(B(w[d|0],iq(w[d+1|0]))>>>3>>>0)|0,v[f>>2]=g;b=ug(d,a,b);if(!(!b|!e)){d=v[a+20>>2];f=c,g=Fj(v[a>>2],x[a+34>>1]),v[f>>2]=g;Rb(d,0,v[Hb(c+4|0,c)>>2])}hb=c+16|0;return(b|0)!=0|0}function lG(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115992];v[115992]=0;Dd();a=vw(a,e+12|0,d);d=kb;g=v[115992];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}v[115992]=h;if((b|0)!=v[e+12>>2]){break c}if(!d){break b}}v[c>>2]=4;a=-1;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}hb=e+16|0;return a}function jP(a,b,c){a:{switch(b|0){case 0:ch(a,0,c);return;case 1:ch(a,1,c);return;case 2:ch(a,2,c);return;case 3:ch(a,3,c);return;case 4:ch(a,4,c);return;case 5:ch(a,5,c);return;case 6:iP(a,23872,c);return;case 7:iP(a,24896,c);return;case 8:ch(a,6,c);return;case 9:ch(a,7,c);return;case 10:ch(a,8,c);return;case 11:ch(a,9,c);return;case 12:ch(a,10,c);return;case 13:ch(a,11,c);return;case 14:ch(a,12,c);return;default:break a}}Kb(a)}function zU(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(B(b,6)+a|0)+1072|0,g=Ak(a,7),t[f|0]=g;d=Ak(a,1);e=Ak(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;zU(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;continue}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=v[a>>2];c=wf(d,v[a+4>>2]);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;b=v[Db(a)>>2];e=v[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){mC(a,c);break c}b=Db(a);b=bB(d+8|0,cB(a,wf(v[a>>2],e)+c|0),wf(v[a>>2],v[a+4>>2]),b);v[23516]=0;R(515,b|0,c|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}aB(a,b);fu(b)}hb=d+32|0;break a}a=P()|0;O()|0;fu(b);S(a|0);L()}return}if(b>>>0<c>>>0){kC(a,d+B(b,20)|0)}}function XW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;v[e+4>>2]=1;k=e,l=tc(32),v[k+8>>2]=l;f=Oo(v[e+8>>2]);v[f>>2]=43144;i=zc(f);f=hb-16|0;hb=f;g=Gl(f+8|0,v[b>>2],v[b+4>>2]);h=v[g>>2];j=v[c>>2];d=v[d>>2];b=hb-16|0;hb=b;g=v[g+4>>2];v[b+12>>2]=g;v[b+8>>2]=h;c=Wm(i);v[c>>2]=43280;Gl(c+4|0,h,g);v[c+16>>2]=d;v[c+12>>2]=j;je(b+8|0);hb=b+16|0;hb=f+16|0;b=a;a=Qo(e);Po(b,zc(a),a);Xm(e);hb=e+16|0}function w5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[23516]=0;R(e|0,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,12815,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function r5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+84>>2];v[23516]=0;R(e|0,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,12298,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function q5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+80>>2];v[23516]=0;R(e|0,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11125,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function p5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+104>>2];v[23516]=0;oa(e|0,c|0,+b);c=v[23516];v[23516]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23516]=0;X(953,15236,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23516]=0;Z(18);d=v[23516];v[23516]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function L5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[23516]=0;R(e|0,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11344,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function x5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[23516]=0;R(e|0,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,9341,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function v5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+100>>2];v[23516]=0;d=+sa(e|0,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11670,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function oF(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=hb-16|0;hb=i;if(1073741806-b>>>0>=c>>>0){j=wc(a);k=1073741807;if(b>>>0<=536870886){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=Tl(v[Vc(i+12|0,i+8|0)>>2])+1|0}c=Ai(k);if(e){mi(c,j,e)}if(g){mi(c+(e<<2)|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){d=e<<2;mi((d+c|0)+(g<<2)|0,(d+j|0)+(f<<2)|0,h)}if((b|0)!=1){Jb(j)}td(a,c);bf(a,k);b=a;a=h+(e+g|0)|0;xd(b,a);td(c+(a<<2)|0,0);hb=i+16|0;return}df();L()}function X0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+16>>2];d=v[a+12>>2];b:{if(g>>>0>d>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=g-d;v[e+4>>2]=c-f;g=d;d=v[od(e+12|0,od(e+8|0,e+4|0))>>2];b=Ce(b,g,d);v[a+12>>2]=v[a+12>>2]+d;b=b+d|0;break b}d=lb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=kp(d),t[h|0]=i;d=1;b=b+1|0}f=d+f|0;continue}break}hb=e+16|0;return f|0}function C5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[23516]=0;oa(e|0,c|0,+b);c=v[23516];v[23516]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23516]=0;X(953,11752,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23516]=0;Z(18);d=v[23516];v[23516]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function y5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[23516]=0;oa(e|0,c|0,+b);c=v[23516];v[23516]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23516]=0;X(953,7685,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23516]=0;Z(18);d=v[23516];v[23516]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function t5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+92>>2];v[23516]=0;d=+sa(e|0,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11055,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function MX(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;b=vc(c,16868);v[23516]=0;U(118,c+16|0,a|0,b|0);a=v[23516];v[23516]=0;a:{if((a|0)!=1){xb(b);a=0;b=0;while(1){d=v[c+16>>2];if(!(b>>>0<=3&ud(d,v[c+20>>2])>>>0>b>>>0)){Il(c+16|0);hb=c+32|0;return a|0}v[23516]=0;d=T(119,Jd(d,b)|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=P()|0;O()|0;Il(c+16|0);break a}a=P()|0;O()|0;xb(b)}S(a|0);L()}function Kq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=fc(c+8|0,c+24|0,7);jc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Qb(c+24|0,b,7)){break b}Yb(a,7);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17562,9108,413,13190);L()}aa(17541,9108,411,13190);L()}return d|0}function F5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[23516]=0;d=+sa(e|0,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11733,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function A5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[23516]=0;oa(e|0,c|0,+b);c=v[23516];v[23516]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23516]=0;X(953,7737,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23516]=0;Z(18);d=v[23516];v[23516]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function yQ(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;v[b+4>>2]=((w[a+48|0]|w[a+49|0]<<8)<<1)+((w[a+32|0]|w[a+33|0]<<8)<<4);v[b+8>>2]=((w[a+50|0]|w[a+51|0]<<8)<<1)+((w[a+34|0]|w[a+35|0]<<8)<<4);v[b+12>>2]=(B(w[a+52|0]|w[a+53|0]<<8,5)+((w[a+36|0]|w[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=Bb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=fp(v[a>>2],v[c>>2])?c:a;continue}}hb=b+16|0;a=v[a>>2];kb=a>>31;return a}function ws(a,b){var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;c=Pd(a);d=gc(a);f=hb-16|0;hb=f;while(1){if(c){g=at(c+16|0,b);d=g?d:c;c=v[(g?c+4|0:c)>>2];continue}break}c=v[cc(f+8|0,d)>>2];hb=f+16|0;a:{if(Nb(c,Yf(a))){if(!at(b,sd(c))){break a}}c=Yf(a)}if(!nc(c,Yf(a))){b=v[cc(e+8|0,c)>>2];c=hb-16|0;hb=c;d=Ig(cc(c+8|0,b));if((b|0)==v[a>>2]){v[a>>2]=v[d>>2]}d=Db(a);v[d>>2]=v[d>>2]-1;sL(v[gc(a)>>2],b);hb=c+16|0;nm(sd(b));Jb(b)}hb=e+16|0}function Eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=hb-16|0;hb=b;i=v[a+16>>2];f=Rf(1,2);g=kb;Pb(a,f,g);j=v[a+24>>2];k=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=u[(v[b+12>>2]<<1)+i>>1];v[c>>2]=v[c>>2]+B(h,k);v[c+4>>2]=v[c+4>>2]+B(j,h);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,g);hb=b+16|0}function J5(a,b){a=a|0;b=b|0;var c=0,d=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[23516]=0;b=Q(d|0,c|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,6690,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function H5(a,b){a=a|0;b=b|0;var c=0,d=0;v[23516]=0;Y(991,a|0);c=v[23516];v[23516]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[23516]=0;b=Q(d|0,c|0,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,6741,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function uJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-16|0;hb=g;v[g+8>>2]=b;j=g,k=ge(a),v[j>>2]=k;b=En(g+8|0,g);h=hb-16|0;hb=h;a:{f=Fb(a);if(b>>>0<=f>>>0){if(c){e=_c(a);b:{if(e-f>>>0>=c>>>0){e=wc(a);if((b|0)==(f|0)){break b}i=b+e|0;Xh(i+c|0,i,f-b|0);break b}im(a,e,(c+f|0)-e|0,f,b,0,c);e=v[a>>2]}vB(b+e|0,c,d);b=c+f|0;th(a,b);t[h+15|0]=0;$d(b+e|0,h+15|0)}hb=h+16|0;break a}pk();L()}ge(a);hb=g+16|0}function UG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;v[e+44>>2]=c;v[e+40>>2]=b;b=Fc(e+8|0,d);v[23516]=0;U(1128,e+24|0,e+40|0,b|0);c=v[23516];v[23516]=0;a:{b:{if((c|0)!=1){v[23516]=0;a=Q(1129,a|0,e+24|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break b}wb(e+24|0);wb(b);v[a>>2]=91980;b=v[e+44>>2];v[a+8>>2]=v[e+40>>2];v[a+12>>2]=b;hb=e+48|0;return a|0}d=P()|0;O()|0;break a}d=P()|0;O()|0;wb(e+24|0)}wb(b);S(d|0);L()}function tg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Rc(43132,d+14|0)>>1];e=v[a>>2];c=Oc(e,v[a+4>>2]);a:{if(b>>>0>c>>>0){e=hb-32|0;hb=e;b=b-c|0;c=v[Db(a)>>2];g=v[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){Ao(a,b,f);break b}c=Db(a);c=Jj(e+8|0,Kj(a,Oc(v[a>>2],g)+b|0),Oc(v[a>>2],v[a+4>>2]),c);AC(c,b,f);Cd(a,c);Li(c)}hb=e+32|0;break a}if(b>>>0<c>>>0){Ld(a,e+(b<<1)|0)}}hb=d+16|0}function q6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;if(a){b=qc(d+8|0,a);f=v[b>>2];c=hb-16|0;hb=c;e=v[b+4>>2];a=0;a:{if(!e){break a}a=32400;while(1){if((a|0)==32800){b=32800;while(1){a=b;if((a|0)!=32848){b=a+12|0;if(!WL(f,e,v[qc(c,v[a+8>>2])>>2],v[c+4>>2])){continue}}break}a=(a|0)!=32848;break a}b=v[a+4>>2];a=a+8|0;if(!WL(f,e,v[qc(c+8|0,b)>>2],v[c+12>>2])){continue}break}a=1}hb=c+16|0}else{a=0}hb=d+16|0;return a|0}function iT(a,b,c,d,e){var f=0,g=0,h=0,i=0;h=-1;f=d&2147483647;i=f;g=(f|0)==2147418112;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=(f|0)==2147418112;if(g?0:g&0|f>>>0>2147418112){break a}if(!(a|c|(f|i|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function S7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ui(a,b,c,d);v[a>>2]=45332;c=Lb(a+4256|0);b=a+4208|0;e=Bb(b,0),f=1056964608,v[e>>2]=f;e=Bb(b,1),f=1017370378,v[e>>2]=f;e=Bb(b,2),f=1028670828,v[e>>2]=f;e=Bb(b,3),f=1059760811,v[e>>2]=f;e=Bb(b,4),f=1017370378,v[e>>2]=f;e=Bb(b,5),f=1065353216,v[e>>2]=f;v[23516]=0;R(917,a+44|0,2);b=v[23516];v[23516]=0;if((b|0)!=1){ti(a);return a|0}b=P()|0;O()|0;lc(c);Ff(a);S(b|0);L()}function Fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=hb-16|0;hb=b;i=v[a+16>>2];f=Rf(1,2);g=kb;Pb(a,f,g);j=v[a+24>>2];k=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=t[v[b+12>>2]+i|0]<<8;v[c>>2]=v[c>>2]+B(h,k);v[c+4>>2]=v[c+4>>2]+B(j,h);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,g);hb=b+16|0}function OZ(a){a=a|0;if(w[468112]){return v[117027]}if(!w[468632]){a=468464;while(1){a=Kb(a)+12|0;if((a|0)!=468632){continue}break}t[468632]=1}ld(468464,88660);ld(468476,88688);ld(468488,88716);ld(468500,88748);ld(468512,88788);ld(468524,88824);ld(468536,88852);ld(468548,88888);ld(468560,88904);ld(468572,88920);ld(468584,88936);ld(468596,88952);ld(468608,88968);ld(468620,88984);t[468112]=1;v[117027]=468464;return 468464}function pfa(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;t[b+15|0]=128;a=qu(a,127,b+15|0);v[23516]=0;t[b+14|0]=64;d=W(589,a+12|0,127,b+14|0)|0;c=v[23516];v[23516]=0;a:{b:{if((c|0)!=1){v[23516]=0;t[b+13|0]=0;Q(666,a+24|0,b+13|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;v[a+44>>2]=0;v[a+48>>2]=0;u[a+52>>1]=0;hb=b+16|0;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;dc(d)}dc(a);S(b|0);L()}function WE(a,b,c,d,e,f,g,h,i){var j=0;v[23516]=0;Y(966,a|0);j=v[23516];v[23516]=0;a:{b:{if((j|0)!=1){j=v[a+24>>2];v[23516]=0;b=ua(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,h|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function I3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=hb-32|0;hb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{e=a;a=fc(b+16|0,c,d);a=Os(e,v[a>>2],v[a+4>>2],b+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[23516]=0;b=Q(53,b|0,8086)|0;c=v[23516];v[23516]=0;b:{if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}d=P()|0;O()|0;wb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}hb=b+32|0;return a|0}L()}function PH(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;c=z[a>>2];i=a-16|0;d=z[i>>2];e=C(c+d);b=a-8|0;f=z[b>>2];j=a-24|0;g=z[j>>2];h=C(f+g);z[a>>2]=e+h;z[b>>2]=e-h;b=a-12|0;h=z[b>>2];k=a-28|0;l=z[k>>2];e=C(h+l);p=b;b=a-4|0;m=z[b>>2];a=a-20|0;n=z[a>>2];o=C(m+n);z[p>>2]=o-e;f=C(f-g);g=C(m-n);z[k>>2]=f+g;c=C(c-d);d=C(h-l);z[i>>2]=c+d;z[j>>2]=c-d;z[b>>2]=e+o;z[a>>2]=g-f}function sx(a,b,c,d,e){var f=0,g=0;a:{if(!gs(b)){break a}f=v[a+484344>>2];if(!te(f,v[a+484348>>2],b&65535)){break a}b=Xb(f,b);if(v[b+12>>2]<=(c|0)|e>>>0>5|x[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=ed(v[b>>2],v[v[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=w[b|0]}return g}function K3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23516]=0;U(1061,d|0,b|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,10340,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function we(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;g=nh(a);a:{b:{if(!b){i=e,j=nh(a),v[i+8>>2]=j;v[e+12>>2]=0;break b}f=v[b+4>>2];h=v[b>>2];v[e+8>>2]=h;v[e+12>>2]=f;a=v[a+12>>2];v[e>>2]=2048;v[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Qq(e+8|0,e);c=v[a>>2];a=v[a+4>>2];if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break b}break a}a=0;if((d|0)==(f|0)&b>>>0>h>>>0|d>>>0>f>>>0){break a}}a=1}hb=e+16|0;return a}function fY(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[23516]=0;a=La(1064,a|0,b|0,c|0,d|0)|0;b=v[23516];v[23516]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23516]=0;ja(949,11148,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}return a|0}function T0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;f=d;d=v[od(e+12|0,od(e+8|0,e+4|0))>>2];mi(b,f,d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=lb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}hb=e+16|0;return g|0}function lO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;v[a+4>>2]=0;a:{if(b){b:{if(nt(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}e=Xn(d+16|0);v[23516]=0;f=Q(746,a|0,b|0)|0;g=v[23516];v[23516]=0;if((g|0)==1){break a}v[23516]=0;R(747,e|0,f|0);f=v[23516];v[23516]=0;if((f|0)==1){break a}v[e+4>>2]=b;xt(a,e);Ue(e)}ml(d+8|0,v[a>>2]);dv(v[d+8>>2],v[d+12>>2],b,w[c|0])}hb=d+32|0;return}a=P()|0;O()|0;Ue(e);S(a|0);L()}function Xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=lk(e,v[a+4>>2]);if(d>>>0<b>>>0){e=hb-32|0;hb=e;d=b-d|0;b=v[Db(a)>>2];f=v[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){FA(a,d,c);break a}b=Db(a);b=US(e+8|0,BA(a,lk(v[a>>2],f)+d|0),lk(v[a>>2],v[a+4>>2]),b);TS(b,d,c);c=b+4|0;RS(v[a>>2],v[a+4>>2],c);oc(a,c);oc(a+4|0,b+8|0);oc(Db(a),zc(b));v[b>>2]=v[b+4>>2];SS(b)}hb=e+32|0;return}if(b>>>0<d>>>0){Ld(a,e+B(b,6)|0)}}function SV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;v[d+12>>2]=-1;if(xg(a,d+8|0)){v[d+4>>2]=w[d+8|0];f=v[Hb(d+4|0,d+12|0)>>2];c=hb+-64|0;hb=c;e=c+40|0;Mf(e,a,f);g=v[c+40>>2];a=c+8|0;bg(a,3,Ee(e),g);v[23516]=0;R(221,c+24|0,a|0);a=v[23516];v[23516]=0;a:{if((a|0)!=1){fc(c,b,11);a=c+24|0;Cl(c,a);wb(a);Qc(c+40|0);hb=c- -64|0;e=!f|(g|0)!=0;break a}a=P()|0;O()|0;Qc(c+40|0);S(a|0);L()}}hb=d+16|0;return e|0}function O3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23516]=0;e=+ya(1057,d|0,b|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,5353,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function D5(a){a=a|0;var b=0,c=0,d=0;v[23516]=0;Y(991,a|0);b=v[23516];v[23516]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[23516]=0;c=+ma(d|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,11770,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function z5(a){a=a|0;var b=0,c=0,d=0;v[23516]=0;Y(991,a|0);b=v[23516];v[23516]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[23516]=0;c=+ma(d|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,7702,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function OH(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){bc(a,21);return-1}if(v[a+1396>>2]<=9){Uk(a)}d=v[a+1392>>2];c=u[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=w[d+v[b+8>>2]|0];v[a+1392>>2]=e>>>c;c=v[a+1396>>2]-c|0;v[a+1396>>2]=(c|0)>0?c:0;c=(c|0)>=0?d:-1;break a}c=$l(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>=0)){bc(a,21)}return c}aa(7526,13226,1793,5753);L()}function B5(a){a=a|0;var b=0,c=0,d=0;v[23516]=0;Y(991,a|0);b=v[23516];v[23516]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[23516]=0;c=+ma(d|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,7754,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function f4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[23516]=0;b=Q(53,f|0,8229)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}e=P()|0;O()|0;wb(b);break b}Yk(a,b,2);c=lx(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function S3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[23516]=0;b=Q(53,f|0,8229)|0;c=v[23516];v[23516]=0;if((c|0)==1){break c}a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}e=P()|0;O()|0;wb(b);break b}Yk(a,b,2);c=mx(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function ax(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!cs(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}bc(a,32);return 0}aa(15853,13226,1564,6039);L()}function Jv(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=qd(a);a=wd(v[a+4>>2],w[a+11|0]);d=qd(b);b=wd(v[b+4>>2],w[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}c=c+e|0;a=a+e|0;b=b+d|0;b:{if((b|0)==(d|0)){break b}c:{b=b-d|0;if((b|0)>(a-c|0)){break c}g=1-b|0;h=w[d|0];while(1){f=a-c|0;if((f|0)<(b|0)){break c}c=cu(c,g+f|0,h);if(!c){break c}if(!Gv(c,d,b)){break b}c=c+1|0;continue}}c=a}c=(a|0)==(c|0)?-1:c-e|0}else{c=-1}}return c}function HZ(a){a=a|0;if(w[468104]){return v[117025]}if(!w[468456]){a=468288;while(1){a=Kb(a)+12|0;if((a|0)!=468456){continue}break}t[468456]=1}kd(468288,5243);kd(468300,5250);kd(468312,5216);kd(468324,5224);kd(468336,5207);kd(468348,5257);kd(468360,5234);kd(468372,9777);kd(468384,9983);kd(468396,11330);kd(468408,12898);kd(468420,5506);kd(468432,10787);kd(468444,6590);t[468104]=1;v[117025]=468288;return 468288}function pI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Lg(a)|0)>(b|0)){break d}}b=ba(8)|0;v[23516]=0;c=Q(53,c|0,10725)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(b,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(c);break b}hb=c+16|0;return(v[(a+B(b,872)|0)+1075080>>2]&134218752)!=0|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function VE(a,b,c,d,e,f,g){var h=0;v[23516]=0;Y(966,a|0);h=v[23516];v[23516]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[23516]=0;b=ga(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,f|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function I2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-16|0;hb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;QI(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=B(v[a+16>>2],e+g|0);j=v[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=(b+i<<2)+j|0;z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}hb=c+16|0}function C2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-32|0;hb=e;v[e+24>>2]=c;v[e+28>>2]=d;a:{a=fc(e+16|0,a,b);a=Os(3,v[a>>2],v[a+4>>2],e+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[23516]=0;c=Q(53,e|0,8086)|0;b=v[23516];v[23516]=0;b:{if((b|0)!=1){a=rc(a,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}b=P()|0;O()|0;wb(c);break b}b=P()|0;O()|0;ca(a|0)}S(b|0);L()}hb=e+32|0;return a|0}L()}function Zaa(a){a=a|0;var b=0;a=Kb(a);v[23516]=0;R(44,a|0,4);b=v[23516];v[23516]=0;a:{b:{if((b|0)==1){break b}v[23516]=0;R(45,a|0,32);b=v[23516];v[23516]=0;if((b|0)==1){break b}v[23516]=0;R(45,a|0,10);b=v[23516];v[23516]=0;if((b|0)==1){break b}v[23516]=0;R(45,a|0,13);b=v[23516];v[23516]=0;if((b|0)==1){break b}v[23516]=0;R(45,a|0,9);b=v[23516];v[23516]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;wb(a);S(b|0);L()}}function rX(a){a=a|0;var b=0;a=Kb(a);v[23516]=0;R(71,a|0,4);b=v[23516];v[23516]=0;a:{b:{if((b|0)==1){break b}v[23516]=0;R(49,a|0,32);b=v[23516];v[23516]=0;if((b|0)==1){break b}v[23516]=0;R(49,a|0,10);b=v[23516];v[23516]=0;if((b|0)==1){break b}v[23516]=0;R(49,a|0,13);b=v[23516];v[23516]=0;if((b|0)==1){break b}v[23516]=0;R(49,a|0,9);b=v[23516];v[23516]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;xb(a);S(b|0);L()}}function kV(a){a=a|0;var b=0,c=0,d=0;b=v[a>>2];if(b){lb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;Gc(a);b=hb-32|0;hb=b;a:{b:{d=dp(a);c=ad(v[a>>2],v[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}v[23516]=0;c=fa(926,b+8|0,c|0,c|0,Db(a)|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){Cd(a,c);Pl(c);break c}a=V(0)|0;O()|0;_(a|0)|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)==1){break b}}hb=b+32|0;break a}V(0)|0;O()|0;Tb();L()}}function R3(a,b){a=a|0;b=b|0;var c=0,d=0;v[23516]=0;Y(966,a|0);c=v[23516];v[23516]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23516]=0;R(1056,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,10869,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function T2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-16|0;hb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;WI(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=v[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=v[(b<<2)+j>>2]+(i<<2)|0;z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}hb=c+16|0}function JE(a,b,c,d,e,f){var g=0,h=0;g=hb-256|0;hb=g;v[g+248>>2]=37;v[g+252>>2]=0;h=g+248|0;Gr(h|1,10606,f,v[b+4>>2]);f=Dd();v[g>>2]=d;v[g+4>>2]=e;d=g+224|0;e=Ug(d,24,f,h,g)+d|0;f=Vi(d,e,b);h=g+16|0;bd(h,b);v[23516]=0;ja(1170,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=v[23516];v[23516]=0;if((d|0)!=1){Zb(g+16|0);a=Er(a,g+32|0,v[g+28>>2],v[g+24>>2],b,c);hb=g+256|0;return a}a=P()|0;O()|0;Zb(g+16|0);S(a|0);L()}function rI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Lg(a)|0)>(b|0)){break d}}b=ba(8)|0;v[23516]=0;c=Q(53,c|0,10725)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(b,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(c);break b}hb=c+16|0;return+(+v[(a+B(b,872)|0)+1075740>>2]*.015625)}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function cp(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=hb-16|0;hb=i;if(-18-b>>>0>=c>>>0){j=wc(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=ih(v[Vc(i+12|0,i+8|0)>>2])+1|0}c=tc(k);if(e){Ce(c,j,e)}if(g){Ce(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){Ce((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Jb(j)}td(a,c);bf(a,k);b=a;a=h+(e+g|0)|0;xd(b,a);t[i+7|0]=0;$d(a+c|0,i+7|0);hb=i+16|0;return}df();L()}function au(a,b){var c=0;c=hb-16|0;hb=c;v[c+12>>2]=b;a:{b:{switch(a|0){case 0:a=b;b=a>>31<<6|a>>>26;a=a<<6;a=Dc(ska(a- -8192|0,b-((a>>>0<4294959104)-1|0)|0,16384,0),kb);break a;case 1:a=b>>31;a=a<<6|b>>>26;b=(b<<6)+2048|0;a=b>>>0<2048?a+1|0:a;a=Dc(ska(b,a,4096,0),kb);break a;default:break b}}v[c+8>>2]=1;a=pl(tK(8192/+v[Ne(c+12|0,c+8|0)>>2])*24+8)}v[c+12>>2]=a;hb=c+16|0;a=(a|0)<64?a:64;return(a|0)>0?a:0}function LE(a,b,c,d,e,f){var g=0,h=0;g=hb-112|0;hb=g;v[g+104>>2]=37;v[g+108>>2]=0;h=g+104|0;Gr(h|1,10606,f,v[b+4>>2]);f=Dd();v[g>>2]=d;v[g+4>>2]=e;d=g+80|0;e=Ug(d,24,f,h,g)+d|0;f=Vi(d,e,b);h=g+16|0;bd(h,b);v[23516]=0;ja(1167,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=v[23516];v[23516]=0;if((d|0)!=1){Zb(g+16|0);a=Lq(a,g+32|0,v[g+28>>2],v[g+24>>2],b,c);hb=g+112|0;return a}a=P()|0;O()|0;Zb(g+16|0);S(a|0);L()}function cn(a,b,c,d,e,f){var g=0;v[23516]=0;Y(966,a|0);g=v[23516];v[23516]=0;a:{b:{if((g|0)!=1){g=v[a+24>>2];v[23516]=0;b=fa(f|0,g|0,b|0,c|0,d|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,e|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function P5(a){a=a|0;var b=0;v[23516]=0;Y(991,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){lb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Jb(b);v[a+20>>2]=0}Jb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,5054,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function k2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;a:{if(w[b+8|0]){f=v[b+12>>2];h=e,i=ad(f,v[b+16>>2])-c|0,v[h+28>>2]=i;v[e+24>>2]=v[d+4>>2];g=v[Hb(e+28|0,e+24|0)>>2];f=Pf(Cb(f),c);c=Pf(Pf(Cb(v[b+12>>2]),c),g);b=v[d>>2];lh(f,c,b);ec(a,b,g);break a}g=v[d+4>>2];d=v[d>>2];v[e+16>>2]=d;v[e+20>>2]=g;f=v[v[b>>2]+40>>2];v[e+8>>2]=d;v[e+12>>2]=g;lb[f|0](a,b,c,e+8|0)}hb=e+32|0}function U0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+28>>2];d=v[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=Kf(t[b|0]),h=v[v[a>>2]+52>>2],lb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{v[e+12>>2]=g-d;v[e+8>>2]=c-f;g=d;d=v[od(e+12|0,e+8|0)>>2];Ce(g,b,d);v[a+24>>2]=d+v[a+24>>2];f=f+d|0;b=b+d|0}continue}break}hb=e+16|0;return f|0}function Ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=v[b+4>>2];if(!c){break a}f=a+480190|0;u[d>>1]=x[f>>1];u[d+14>>1]=c-1;c=x[Rc(d,d+14|0)>>1];while(1){if(!c){break a}Ab(d,v[b>>2],c);b:{if(zb(v[v[d>>2]>>2],v[d+4>>2])){break b}if(gM(a,c&65535)){e=Fc(d,21751);Ac(((c<<5)+a|0)+946304|0,e);wb(e)}if(c>>>0<2){break b}e=x[f>>1];if((e|0)!=(c|0)){break b}u[f>>1]=e-1}c=c-1|0;continue}}hb=d+16|0}function Ze(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=ap(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(jF(a,b)&3){case 0:c=ap(A[b>>3],A[b+8>>3]);break a;case 1:c=-bp(A[b>>3],A[b+8>>3],1);break a;case 2:c=-ap(A[b>>3],A[b+8>>3]);break a;default:break b}}c=bp(A[b>>3],A[b+8>>3],1)}a=c;hb=b+16|0;return a}function S9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;Ke(d,2,a+6|0);e=d+16|0;Cc(e,d);Ac(b+492|0,e);f=b+236|0;g=c+1|0;wb(e);c=0;while(1){if((c|0)==128){v[b>>2]=(w[a+226|0]|w[a+227|0]<<8)<<5;Ux(a+180|0,b+48|0,0);Ux(a+228|0,b+88|0,2);Ux(a+276|0,b+68|0,1);if(!(w[a+324|0]|w[a+325|0]<<8)){Rb(f,0,256)}hb=d+32|0}else{h=$b(f,c),i=w[(a+c|0)+38|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function j4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[23516]=0;c=Q(53,e|0,8229)|0;b=v[23516];v[23516]=0;if((b|0)==1){break c}a=rc(a,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}b=P()|0;O()|0;wb(c);break b}Yk(a,b,1);c=lx(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);hb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function W3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[23516]=0;c=Q(53,e|0,8229)|0;b=v[23516];v[23516]=0;if((b|0)==1){break c}a=rc(a,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}b=P()|0;O()|0;wb(c);break b}Yk(a,b,1);c=mx(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);hb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function oy(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;tM(a+1074332|0,b);a=a+906300|0;f=ck(a);while(1){if((a|0)!=(f|0)){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;if(lb[v[v[b>>2]+140>>2]](b)|0){d=v[b+16>>2];e=d+1074332|0;c=C(C(c/z[e+8>>2])*C(C(y[d+480232>>2])/z[e+20>>2]))}z[b+4196>>2]=c}a=a+160|0;continue}break}}function M3(a,b){a=a|0;b=+b;var c=0;v[23516]=0;Y(966,a|0);c=v[23516];v[23516]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23516]=0;b=+Wa(1058,c|0,+b);c=v[23516];v[23516]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;_(c|0)|0;v[23516]=0;X(953,7566,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[23516]=0;Z(18);c=v[23516];v[23516]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;c=nf(a,c);ke(e,v[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);d=-1;if(!zb(v[v[e>>2]>>2],v[e+4>>2])){break b}break a}d=v[c+16>>2]}f=v[a+36>>2];c:{d:{switch(d+1|0){case 0:case 2:d=hb-32|0;hb=d;t[d+24|0]=0;_i(d+8|0,d+24|0);nn(d+16|0,f,v[d+8>>2],v[d+12>>2]);t[b|0]=w[d+24|0];hb=d+32|0;break c;default:break d}}XS(f,b,d)}f=c}Ve(a,f);hb=e+16|0}function Fs(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function it(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;v[b+40>>2]=0;v[b+44>>2]=0;f=b- -64|0;v[f>>2]=0;v[f+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=Cb(v[c>>2]);v[e+8>>2]=d;f=Cb(v[c+4>>2]);while(1){if(!Nb(d,f)){break a}g=d,h=pO(b,A[d>>3]),A[g>>3]=h;d=v[gt(e+8|0)>>2];continue}}}else{pO(b,A[_e(v[c>>2],0)>>3]);d=d+1|0;continue}break}nl(a,c);hb=e+16|0}function eC(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=fc(c+8|0,c+24|0,7);id(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Qb(c+24|0,b,7)){break b}dd(a,7);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17562,9108,413,13190);L()}aa(17541,9108,411,13190);L()}return d}function gI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23516]=0;d=Q(53,d|0,10725)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(b,d);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(d);break b}e=(v[a+32>>2]+B(b,872)|0)+1075766|0,f=Iz(c*32768),u[e>>1]=f;hb=d+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Efa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;b=-1;a:{if(!eg(a,8)){break a}b=hb-32|0;hb=b;v[b+24>>2]=0;v[b+28>>2]=0;d=fc(b+8|0,b+24|0,8);id(b+16|0,a,v[d>>2],v[d+4>>2]);d=0;b:{if(v[b+20>>2]!=8){break b}if(Qb(b+24|0,14222,8)){break b}dd(a,8);d=1}hb=b+32|0;b=0;if(!d){break a}b=-1;if(!Nj(a,c+8|0)){break a}b=0;if(!_b(v[c+12>>2])){break a}b=!(_b(v[c+8>>2])&-2139062144)}hb=c+16|0;return b|0}function nr(a){var b=0,c=0;_m(a,1,13647);v[23516]=0;b=ha(124)|0;c=v[23516];v[23516]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[23516]=0;b=ha(125)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}t[a+16|0]=b;v[23516]=0;b=ha(126)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[23516]=0;Y(127,a+20|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;xb(a);S(b|0);L()}function ko(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-16|0;hb=f;v[f+12>>2]=c;a:{if(!Ob(v[b>>2],v[b+8>>2],c)){break a}uc(f+12|0,65535);tg(a,x[f+12>>1]);c=Cb(v[a>>2]);v[f>>2]=c;h=Cb(v[a+4>>2]);while(1){if(!Nb(c,h)){break a}a=f+11|0;if(!xg(b,a)){Ch(a)}a=w[f+11|0];u[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}u[c>>1]=g}c=v[Qe(f)>>2];continue}}hb=f+16|0}function Nda(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;a=yz(c,a);vP(v[a+4>>2],w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));v[a+4>>2]=v[a+4>>2]+4;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=Tf(d+8|0,pg(a,sc(v[a>>2],v[a+4>>2])+1|0),sc(v[a>>2],v[a+4>>2]),c);vP(v[c+8>>2],w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));v[c+8>>2]=v[c+8>>2]+4;Cd(a,c);Sf(c);hb=d+32|0}function rE(a,b,c,d,e){var f=0,g=0;a:{f=hb-80|0;hb=f;fA(b);g=f+56|0;Mf(g,a,c);a=v[f+56>>2];c=f+8|0;bg(c,e,Ee(g),a);v[23516]=0;R(221,f+24|0,c|0);a=v[23516];v[23516]=0;b:{c:{if((a|0)!=1){v[23516]=0;U(11,f+40|0,d|0,f+24|0);a=v[23516];v[23516]=0;if((a|0)==1){break c}a=f+40|0;Gb(b,a);xb(a);wb(f+24|0);Qc(f+56|0);hb=f+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;wb(f+24|0)}Qc(f+56|0);S(a|0);L()}}function G4(a){a=a|0;var b=0,c=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23516]=0;b=T(1034,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,7238,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function CM(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];v[a>>2]=b;if(c){d=hb-16|0;hb=d;b=Cb(v[c>>2]);v[d+8>>2]=b;f=Cb(v[c+4>>2]);while(1){a:{b:{if(Nb(b,f)){while(1){a=v[b>>2];e=v[a>>2];if(!e){break b}a=v[v[e>>2]+8>>2];v[23516]=0;Y(a|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){continue}break}V(0)|0;O()|0;Tb();L()}a=lc(c);hb=d+16|0;break a}Ub(a+20|0);Ub(a+8|0);Jb(a);b=v[Ie(d+8|0)>>2];continue}break}Jb(a)}}function jfa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=Oz(a,b);v[23516]=0;c=Q(671,a+12|0,b+12|0)|0;d=v[23516];v[23516]=0;b:{c:{if((d|0)!=1){v[23516]=0;Q(672,a+24|0,b+24|0)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;dc(c)}dc(a);S(b|0);L()}}function uS(a){var b=0;a:{if(Qb(a,14363,3)|(w[a+3|0]-52&255)>>>0<252){break a}if(_b(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788>>>0<840){break a}if(_b(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))>>>0<52){break a}if(_b(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))-1>>>0<51){break a}b=_b(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))>>>0<4294967216}return b}function mR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!w[b+8|0]){while(1){if((d|0)==8){v[c+24>>2]=0;v[c+28>>2]=0;d=fc(c+8|0,c+24|0,8);jc(c+16|0,v[a>>2],v[a+8>>2],v[d>>2],v[d+4>>2]);d=0;b:{if(v[c+20>>2]!=8){break b}if(Qb(c+24|0,b,8)){break b}Yb(a,8);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17562,9108,413,13190);L()}aa(17541,9108,411,13190);L()}return d|0}function ld(a,b){var c=0,d=0,e=0,f=0,g=0;a:{e=yG(b);c=ep(a);if(e>>>0<=c>>>0){f=wc(a);d=f;c=e;if(c){b:{if((b|0)==(d|0)){break b}if(d-b>>>0>=c<<2>>>0){if(!c){break b}while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break b}if(!c){break b}while(1){c=c-1|0;g=c<<2;v[g+d>>2]=v[b+g>>2];if(c){continue}break}}}td((e<<2)+f|0,0);th(a,e);break a}d=a;a=Fb(a);oF(d,c,e-c|0,a,0,a,e,b)}}function Y2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;ZI(a,c);hb=c+16|0}function Vda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;u[b+12>>1]=0;u[b+14>>1]=1;Bf(b+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=hb-16|0;hb=d;c=x[b+14>>1];v[d+12>>2]=c;a:{if(Om(a)>>>0>=c>>>0){g=v[a>>2];f=Oc(g,v[a+4>>2]);v[d+8>>2]=f;Lt(g,v[Hb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){Ao(a,c-f|0,e);break a}Ld(a,v[a>>2]+(c<<1)|0);break a}XO(a);Tz(a,Kj(a,c));Ao(a,c,e)}hb=d+16|0;hb=b+16|0}function T4(a){a=a|0;var b=0,c=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23516]=0;c=+ma(1025,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,7638,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function S2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;VI(a,c);hb=c+16|0}function O2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;TI(a,c);hb=c+16|0}function H2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}i=v[b>>2];j=+f;g=v[b+4>>2];k=v[b+8>>2];b:while(1){if((e|0)==(k|0)){break a}l=B(e,g);d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{h=(d+l<<3)+i|0;A[h>>3]=A[h>>3]*j;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;PI(a,c);hb=c+16|0}function Bi(a){var b=0,c=0;b=hb-16|0;hb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=bp(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(jF(a,b)&3){case 0:a=bp(A[b>>3],A[b+8>>3],1);break a;case 1:a=ap(A[b>>3],A[b+8>>3]);break a;case 2:a=-bp(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-ap(A[b>>3],A[b+8>>3])}hb=b+16|0;return a}function KV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;v[a>>2]=0;v[a+4>>2]=0;if(!Ob(v[b>>2],v[b+8>>2],c)){c=$e(b)}v[a>>2]=c;c=v[b>>2];a:{if(lb[v[v[c>>2]+16>>2]](c)|0){c=a;a=v[b>>2];e=c,f=(lb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[e+4>>2]=f;break a}Oi(a+8|0,v[a>>2]);c=v[a+8>>2];a=v[a+12>>2];if(nc(c,a)){break a}oe(d+8|0,c,a);jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2])}hb=d+16|0}function B7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ui(a,b,c,d);v[a>>2]=45952;b=Lb(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=v[c+24620>>2];v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;d=a+4228|0;v[d>>2]=1048576e3;v[d+4>>2]=1048576e3;v[a+4236>>2]=0;v[a+4260>>2]=0;v[a+4256>>2]=c;v[23516]=0;R(917,a+44|0,2);c=v[23516];v[23516]=0;if((c|0)!=1){ti(a);return a|0}c=P()|0;O()|0;lc(b);Ff(a);S(c|0);L()}function mq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=hb-16|0;hb=i;if(-18-b>>>0>=c>>>0){j=qd(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=ih(v[Vc(i+12|0,i+8|0)>>2])+1|0}c=tc(k);if(e){Ce(c,j,e)}if(g){Ce(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){Ce((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Jb(j)}td(a,c);bf(a,k);b=a;a=h+(e+g|0)|0;xd(b,a);nd(a+c|0,0);hb=i+16|0;return}df();L()}function jG(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0);e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115992];v[115992]=0;Dd();d=hb-16|0;hb=d;uw(d,a,e+12|0,0);f=wF(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);hb=d+16|0;a=v[115992];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115992]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}hb=e+16|0;return f}function ix(a,b,c){var d=0,e=0;d=hb-32|0;hb=d;a:{if(w[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=LI(b,4096);KI(a,b-c|0);c=v[a+16>>2];b=fc(d+16|0,Ib(v[a+4>>2],c),b-c|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;lb[c|0](d+24|0,a,d+8|0);v[a+16>>2]=v[a+16>>2]+v[d+28>>2];if(!(lb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}hb=d+32|0}function Nu(a,b,c){var d=0,e=0,f=0;d=v[c+16>>2];a:{if(!d){if(DC(c)){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<b>>>0){return lb[v[c+36>>2]](c,a,b)|0}b:{if(v[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(w[e+a|0]!=10){continue}break}e=lb[v[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=v[c+20>>2]}pc(f,a,b);v[c+20>>2]=v[c+20>>2]+b;e=b+d|0}return e}function HA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Ob(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=3){d=hb-16|0;hb=d;if(Ob(v[a>>2],v[a+8>>2],b)){while(1){if((c|0)==4){c=v[d+12>>2]}else{t[d+11|0]=0;b:{if(b>>>0>c>>>0){xg(a,d+11|0);e=t[d+11|0];g=e>>>31|0;break b}e=0-g|0}t[(d+12|0)+c|0]=e;c=c+1|0;continue}break}}hb=d+16|0;break a}c=zg(a);Yb(a,b-4|0)}t[f|0]=c}function U1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=qd(c);c=wd(v[c+4>>2],w[c+11|0]);a:{d=wd(v[a+4>>2],w[a+11|0]);if(d>>>0>=b>>>0){e=rl(a);if(c>>>0<=e-d>>>0){if(!c){break a}e=qd(a);h=e+b|0;if((b|0)!=(d|0)){g=b+e|0;Xh(c+g|0,g,d-b|0);f=(f>>>0>=g>>>0?d+e>>>0>f>>>0?c:0:0)+f|0}Xh(h,f,c);b=c+d|0;io(a,b);nd(b+e|0,0);break a}mq(a,e,(c+d|0)-e|0,d,b,0,c,f);break a}pk();L()}return a|0}function SR(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function NP(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Ti(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(Yj(a,f+8|0)){break b}h=Rk(v[a>>2]);g=4;if(!qh(v[d+8>>2],2048,h)){break b}b=kn(d,h);while(1){c:{b=b-48|0;h=Yl(a);if(!jp(h,f+8|0)|(e|0)<2){break c}g=Rk(v[h>>2]);if(!qh(v[d+8>>2],2048,g)){break a}e=e-1|0;b=kn(d,g)+B(b,10)|0;continue}break}g=2;if(!Yj(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}hb=f+16|0;return b}function E3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=hb-32|0;hb=b;a:{e=a;a=fc(b+24|0,c,d);a=Os(e,v[a>>2],v[a+4>>2],0);if(a+1>>>0>=3){a=ba(8)|0;v[23516]=0;b=Q(53,b+8|0,8086)|0;c=v[23516];v[23516]=0;b:{if((c|0)!=1){a=rc(a,b);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}d=P()|0;O()|0;wb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}hb=b+32|0;return a|0}L()}function yI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[23516]=0;c=Q(53,c|0,7814)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}a=rc(a,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}d=P()|0;O()|0;wb(c);break b}a=v[a+32>>2];e=a,f=Oe(65536/b),v[e+480244>>2]=f;Hp(a);hb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function wI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[23516]=0;c=Q(53,c|0,7835)|0;d=v[23516];v[23516]=0;if((d|0)==1){break c}a=rc(a,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}d=P()|0;O()|0;wb(c);break b}a=v[a+32>>2];e=a,f=Oe(b*65536),v[e+480240>>2]=f;Hp(a);hb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function hG(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115992];v[115992]=0;Dd();d=hb-16|0;hb=d;uw(d,a,e+12|0,1);f=Mw(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);hb=d+16|0;a=v[115992];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115992]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}hb=e+16|0;return f}function UE(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!d){a=ba(8)|0;v[23516]=0;c=Q(53,f|0,8229)|0;b=v[23516];v[23516]=0;if((b|0)==1){break c}a=rc(a,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}b=P()|0;O()|0;wb(c);break b}Yk(a,b,e);c=QE(a,c,e,d,60640,61412);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function TE(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!d){a=ba(8)|0;v[23516]=0;c=Q(53,f|0,8229)|0;b=v[23516];v[23516]=0;if((b|0)==1){break c}a=rc(a,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}b=P()|0;O()|0;wb(c);break b}Yk(a,b,e);c=QE(a,c,e,d,59812,60584);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Z8(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[23516]=0;R(288,b+4|0,8);b=v[23516];v[23516]=0;if((b|0)!=1){b=v[a+4264>>2];c=v[v[a+20>>2]+4>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(92664)|0;if((O()|0)==(ea(92664)|0)){_(b|0)|0;Gc(v[a+20>>2]+4|0);$();return}S(b|0);L()}function lI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23516]=0;c=Q(53,c|0,10725)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(b,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;hb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Eja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{e=Je(a);b:{if(e>>>0>1){break b}c:{if(e){v[23516]=0;U(334,d|0,a|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){Bm(b,d);dc(d);break c}a=V(30656)|0;if((O()|0)!=(ea(30656)|0)){break a}_(a|0)|0;$();break b}if(!Ob(v[a>>2],v[a+8>>2],c)){break b}Lu(a,b,c)}f=ad(v[b>>2],v[b+4>>2])>>>0>=c>>>0}hb=d+16|0;return f|0}S(a|0);L()}function hI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23516]=0;c=Q(53,c|0,10725)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(b,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(c);break b}hb=c+16|0;return+(+(v[(v[a+32>>2]+B(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function d1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;Eq(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){b=wc(c)+Fb(c)|0;v[a+44>>2]=b;d=wc(c);qn(a,d,d,b);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Fb(c);e=a,f=b+wc(c)|0,v[e+44>>2]=f;Ex(c,_c(c));d=wc(c);Fw(a,d,Fb(c)+d|0);if(!(w[a+48|0]&3)){break a}while(1){if((b|0)<0){Rr(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}Rr(a,b)}}function Fh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=fc(c+8|0,c+28|0,4);jc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Qb(c+28|0,b,4)){break b}Yb(a,4);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17562,9108,413,13190);L()}aa(17541,9108,411,13190);L()}return d|0}function eI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23516]=0;c=Q(53,c|0,10725)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(b,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(c);break b}hb=c+16|0;return+(+u[(v[a+32>>2]+B(b,872)|0)+1075766>>1]*30517578125e-15)}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function bha(a){a=a|0;var b=0,c=0,d=0,e=0;e=hb-16|0;hb=e;b=tc(2500);c=hb-2496|0;hb=c;zR(a,c,c+2496|0);a=0;while(1){if((a|0)==624){v[b+2496>>2]=0;a:{if(v[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!v[b+d>>2]){continue}break a}break}v[b>>2]=-2147483648}hb=c+2496|0}else{d=a<<2;v[d+b>>2]=v[c+d>>2];a=a+1|0;continue}break}a=v[If(e+8|0,b)>>2];hb=e+16|0;return a|0}function Y5(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Jb(vs(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Jb(b);v[a+20>>2]=0}Jb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,5081,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function R0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+24>>2];e=v[a+28>>2];if(d>>>0>=e>>>0){if((lb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{v[f+12>>2]=e-d>>2;v[f+8>>2]=c-g;e=d;d=v[od(f+12|0,f+8|0)>>2];mi(e,b,d);e=d<<2;v[a+24>>2]=e+v[a+24>>2];g=g+d|0;b=b+e|0}continue}break}hb=f+16|0;return g|0}function OR(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!w[b+5|0]){while(1){if((d|0)==5){d=0;t[c+28|0]=0;v[c+24>>2]=0;e=fc(c+8|0,c+24|0,5);jc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=5){break b}if(Qb(c+24|0,b,5)){break b}Yb(a,5);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17562,9108,413,13190);L()}aa(17541,9108,411,13190);L()}return d}function pja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;ec(c+8|0,b,15);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function kha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;ec(c+8|0,b,14);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function f9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=tc(64);v[23516]=0;e=T(855,c|0)|0;f=v[23516];v[23516]=0;a:{if((f|0)!=1){c=If(d,e);e=v[c>>2];v[23516]=0;a=W(915,e|0,a|0,b|0)|0;b=v[23516];v[23516]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}yf(d+8|0);break b}a=P()|0;O()|0;qg(c);break a}dg(d+8|0,c)}qg(c);hb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Jb(c)}S(a|0);L()}function U5(a,b){a=a|0;b=b|0;var c=0;v[23516]=0;Y(966,a|0);c=v[23516];v[23516]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Jb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,5663,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function oP(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a=Kb(a);d=Fb(b);v[23516]=0;R(44,a|0,d|0);d=v[23516];v[23516]=0;a:{if((d|0)!=1){e=c,f=et(b),v[e+8>>2]=f;e=c,f=dt(b),v[e>>2]=f;while(1){if(!mj(c+8|0,c)){break a}b=w[v[c+8>>2]];v[23516]=0;R(45,a|0,((b|0)==13?10:b)<<24>>24);b=v[23516];v[23516]=0;if((b|0)!=1){He(c+8|0);continue}break}}b=P()|0;O()|0;wb(a);S(b|0);L()}hb=c+16|0}function K8(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function PT(a){var b=0,c=0;a:{if(Qb(a,15325,3)){break a}c=w[a+3|0];if(c>>>0>9){break a}if((Eb(w[a+202|0]|w[a+203|0]<<8)-1e4&65535)>>>0<57516){break a}b=1;b:{if(c>>>0>5){break b}if(!Eb(w[a+228|0]|w[a+229|0]<<8)){break a}if(!Eb(w[a+230|0]|w[a+231|0]<<8)){break a}b=0;if(Eb(w[a+232|0]|w[a+233|0]<<8)>>>0>4095){break b}b=Eb(w[a+234|0]|w[a+235|0]<<8)>>>0<100}return b}return 0}function J7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ui(a,b,c,d);v[a>>2]=45572;b=a+4208|0;e=Bb(b,0),f=1060320051,v[e>>2]=f;e=Bb(b,1),f=1041865114,v[e>>2]=f;e=Bb(b,2),f=1065353216,v[e>>2]=f;e=Bb(b,3),f=1049951732,v[e>>2]=f;e=Bb(b,4),f=1049951732,v[e>>2]=f;v[23516]=0;R(917,a+44|0,2);b=v[23516];v[23516]=0;if((b|0)!=1){ti(a);return a|0}b=P()|0;O()|0;Ff(a);S(b|0);L()}function yx(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(y[v[a+16>>2]+24620>>2]);c=C(C(C(lb[v[v[a>>2]+208>>2]](a))*b)/C(1e3));d=a,e=C(C(c*C(lb[v[v[a>>2]+200>>2]](a)))*C(2048)),z[d+4248>>2]=e;d=a,f=Sh(C(C(c+C(2))*C(4096))),v[d+4256>>2]=f;c=C(lb[v[v[a>>2]+212>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(lb[v[v[a>>2]+196>>2]](a)|0)){b=EK(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function Si(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(Ok(a,f+8|0)){break b}g=4;h=Qk(v[a>>2]);if(!Pk(d,2048,h)){break b}b=jn(d,h);while(1){c:{b=b-48|0;h=rn(a);if(!Tr(h,f+8|0)|(e|0)<2){break c}g=Qk(v[h>>2]);if(!Pk(d,2048,g)){break a}e=e-1|0;b=jn(d,g)+B(b,10)|0;continue}break}g=2;if(!Ok(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}hb=f+16|0;return b}function yy(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;jm(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=v[a+1298300>>2];if(!vd(a)){break a}nj(a,b,0)}}function F4(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-32|0;hb=b;a:{d=a+36|0;b:{if(Nb(v[d>>2],v[a+40>>2])){yf(b+24|0);break b}c=b+8|0;yn(c,a);v[23516]=0;e=T(1026,c|0)|0;c=v[23516];v[23516]=0;if((c|0)==1){break a}v[b+24>>2]=e;Vf(b+8|0)}c=v[a+36>>2];if(!Nb(c,v[a+40>>2])){d=v[b+24>>2];c=v[d>>2]}a=Ni(c,v[d+4>>2]);Vk(b+24|0);hb=b+32|0;return a|0}a=P()|0;O()|0;Vf(b+8|0);S(a|0);L()}function am(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return t[a+72944|0]}if(a>>>0<=511){return t[(a>>>5|0)+72944|0]+5|0}return t[(a>>>10|0)+72944|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return t[(a>>>15|0)+72944|0]+15|0}return t[(a>>>20|0)+72944|0]+20|0}if(a>>>0<=536870911){return t[(a>>>25|0)+72944|0]+25|0}a=t[(a>>>30|0)+72944|0]+30|0}else{a=0}return a}function zI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ba(8)|0;v[23516]=0;c=Q(53,c|0,9392)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(b,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);hb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function d3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;a:{b:{if((_j(w[a+140|0])|0)!=1){break b}if((oJ(a)|0)!=(b|0)){break b}d=a+120|0;ns(w[d+20|0]);b=hb-16|0;hb=b;v[b+8>>2]=c+8;a=hb-16|0;hb=a;e=v[14507];v[a+8>>2]=v[14506];v[a+12>>2]=e;e=v[14505];v[a>>2]=v[14504];v[a+4>>2]=e;lb[v[qp(a,_j(w[d+20|0]))>>2]](b+8|0,d);hb=a+16|0;hb=b+16|0;break a}nJ(a,1,b)}hb=c+16|0}function X5(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Jb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,8945,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function NE(a,b,c){var d=0;d=hb-16|0;hb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23516]=0;c=Q(53,d|0,10725)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(b,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(c);break b}a=(v[a+32>>2]+B(b,872)|0)+1075080|0;v[a>>2]=v[a>>2]|c;hb=d+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function EB(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){a=hb-16|0;hb=a;c=ba(16)|0;b=hb-16|0;hb=b;if(!w[464592]){t[464592]=1}fc(b+8|0,1,93744);d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;hb=b+16|0;b=v[a+12>>2];a=v[a+8>>2];v[23516]=0;a=fF(1130,c,8972,a,b);b=v[23516];v[23516]=0;if((b|0)!=1){ia(a|0,78628,1131);L()}a=P()|0;O()|0;ca(c|0);S(a|0);L()}}function Jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;c=nf(a,c);ke(f,v[a+36>>2]);a:{if(!c){Pc(f,a+32|0,5);e=0;if(zb(v[v[f>>2]>>2],v[f+4>>2])){break a}}h=v[a+36>>2];g=hb-16|0;hb=g;e=Kb(g);v[23516]=0;fa(466,b|0,h|0,e|0,d|0)|0;b=v[23516];v[23516]=0;b:{if((b|0)!=1){xb(e);hb=g+16|0;break b}a=P()|0;O()|0;xb(e);S(a|0);L()}e=c}Ve(a,e);hb=f+16|0}function HC(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if(Qb(a,11122,2)){if(Qb(a,13860,2)){break a}if(w[a+110|0]<=64){break b}break a}if(w[a+110|0]>64){break a}}if(t[a+112|0]<0|w[a+111|0]>128){break a}while(1){d=(b|0)==128;if(d){break a}c=a+b|0;e=t[c+113|0];if((e|0)<-2){break a}f=w[c+241|0];if(!f&(e|0)>=0|f>>>0>15){break a}b=b+1|0;if(w[c+369|0]<64){continue}break}}return d}function Fr(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}t[a|0]=b;return(d|0)!=260}function Wja(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;tu(c,a,b);Nf(b,w[d+8|0],w[Kc(c)|0]);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}t[b+3|0]=45;t[b+5|0]=a&15;break a}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;break a}t[b+3|0]=20;t[b+5|0]=a&15|160;break a}t[b+3|0]=0}hb=d+16|0}function V5(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return fg(a)|0}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,12211,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();return 0}return fg(21751)|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function cN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=(B(b,872)+a|0)+1429|0;e=v[a+16>>2];if(e){d=w[d|0]}else{t[d|0]=0;d=0}f=v[a+40>>2];b=B(b,872)+a|0;a=b+1467|0;t[a|0]=w[a|0]|64;a=b+1468|0;h=a;i=v[a>>2];g=(+(e>>>0)+1)*+(c|0)/+(f>>>0);a:{if(D(g)<2147483648){a=~~g;break a}a=-2147483648}v[h>>2]=i+(a+((c|0)<0?d:0-d|0)|0);c=(f|0)==(e+1|0)?c:a;a=c>>31;t[b+1429|0]=(a^c)-a}function aM(a,b){var c=0,d=0,e=0,f=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;d=w[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=t[c+1075785|0];d:{if((c|0)>=0){d=ue(a+901692|0,w[(B(b,872)+a|0)+1075836|0]);break d}d=ue(a+902204|0,c&127)}tN(a,e,b,f,d,c&255)}}function y4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[23516]=0;Y(966,a|0);f=v[23516];v[23516]=0;if((f|0)!=1){return sx(v[v[a+24>>2]+24>>2],b,c,d,e)|0}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,12454,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Uaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=b;c=hb-16|0;hb=c;d=tc(223888);v[23516]=0;b=Q(822,d|0,b+1074376|0)|0;e=v[23516];v[23516]=0;a:{if((e|0)!=1){b=v[If(c+8|0,b)>>2];hb=c+16|0;break a}a=P()|0;O()|0;Jb(d);S(a|0);L()}v[a+4>>2]=b;b=Lb(a+8|0);v[23516]=0;Y(597,a|0);c=v[23516];v[23516]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;be(b);hN(a+4|0);S(c|0);L()}function AI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ba(8)|0;v[23516]=0;c=Q(53,c|0,5851)|0;a=v[23516];v[23516]=0;if((a|0)==1){break c}a=rc(b,c);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(c);break b}v[v[a+32>>2]+1074416>>2]=b;hb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function lU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Lb(a);a=Cb(v[b>>2]);v[d+24>>2]=a;b=Cb(v[b+4>>2]);a:{while(1){if(Nb(a,b)){Zh(d,v[a>>2],v[a+4>>2]);if((_b(v[d>>2])|0)==(c|0)){so(d,a);v[23516]=0;R(359,e|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}yb(d)}a=v[Em(d+24|0)>>2];continue}break}hb=d+32|0;return}a=P()|0;O()|0;yb(d);Nc(e);S(a|0);L()}function PE(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=hb-16|0;hb=h;a:{b:{c:{if(b<g|b>f){a=ba(8)|0;v[23516]=0;d=Q(53,h|0,e|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}a=rc(a,d);v[23516]=0;U(117,a|0,62944,970);a=v[23516];v[23516]=0;if((a|0)!=1){break a}e=P()|0;O()|0;wb(d);break b}i=v[a+32>>2]+d|0,j=Oe(b*c),v[i>>2]=j;hb=h+16|0;return}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function Nn(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function oG(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{if((a|0)!=(b|0)){g=v[115992];v[115992]=0;Dd();d=uG(a,e+12|0,d);a=kb;f=v[115992];b:{if(f){if(v[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}v[c>>2]=4;a=!!d&(a|0)>=0|(a|0)>0;d=a?-1:0;a=a?2147483647:-2147483648;break a}v[115992]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0}hb=e+16|0;kb=a;return d}function UV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-32|0;hb=e;Ou(e+8|0,c);c=w[d|0];v[23516]=0;R(245,e+20|0,c|0);c=v[23516];v[23516]=0;b:{c:{if((c|0)!=1){Tj(e,e+8|0);v[23516]=0;X(112,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}Rg(e+8|0);hb=e+32|0;break a}a=P()|0;O()|0;xb(e+8|0);break b}a=P()|0;O()|0;Rg(e+8|0)}S(a|0);L()}}function WV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=-1;a:{if(!eg(a,7)){break a}c=0;if(!eC(a,11810)){break a}c=hb-16|0;hb=c;bC(c+8|0,d);e=v[c+12>>2];id(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){aC(d)}c=-1;if(!e){break a}c=0;if(!dC(w[d+1|0])){break a}c=we(a,b,cC(d),kb)}hb=d+16|0;return c|0}function J4(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){a=v[v[a+24>>2]+24>>2];return qj(Sb(v[a+484360>>2],w[a+484376|0]))|0}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,6888,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Q5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;v[f+8>>2]=d;d=v[dg(f,f+8|0)>>2];v[23516]=0;ga(964,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){a=EI(a);b=DI(a+88|0);c=CI(a+92|0);d=BI(a+96|0);v[a>>2]=62696;v[b>>2]=62812;v[c>>2]=62892;v[d>>2]=62932;ze(f+8|0);hb=f+16|0;return a|0}a=P()|0;O()|0;ze(f+8|0);S(a|0);L()}function vt(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;rka(b,0,a,0);a=kb?0:B(a,b)}else{a=0}a:{if(!a){break a}v[23516]=0;b=T(769,a|0)|0;c=v[23516];v[23516]=0;b:{c:{if((c|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;Z(18);c=v[23516];v[23516]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;O()|0;Tb();L()}if(!b){break a}d=Rb(b,0,a)- -64|0}return d}function Rz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Lb(a);a=Cb(v[b>>2]);v[d+24>>2]=a;b=Cb(v[b+4>>2]);a:{while(1){if(Nb(a,b)){Zh(d,v[a>>2],v[a+4>>2]);if(v[d>>2]==(c|0)){so(d,a);v[23516]=0;R(359,e|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}yb(d)}a=v[Em(d+24|0)>>2];continue}break}hb=d+32|0;return}a=P()|0;O()|0;yb(d);Nc(e);S(a|0);L()}function I4(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){a=v[v[a+24>>2]+24>>2];return ft(v[a+484344>>2],v[a+484348>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,6956,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function lJ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=Fb(a);if(e>>>0>=b>>>0){f=_c(a);a:{if(f-e>>>0>=d>>>0){if(!d){break a}f=wc(a);i=f+b|0;if((b|0)!=(e|0)){h=b+f|0;Xh(h+d|0,h,e-b|0);c=(c>>>0>=h>>>0?e+f>>>0>c>>>0?d:0:0)+c|0}Xh(i,c,d);b=d+e|0;th(a,b);t[g+15|0]=0;$d(b+f|0,g+15|0);break a}cp(a,f,(d+e|0)-f|0,e,b,0,d,c)}hb=g+16|0;return a}pk();L()}function gp(a,b,c){var d=0,e=0,f=0;e=hb-16|0;hb=e;d=e+8|0;bd(d,b);v[23516]=0;b=T(1154,d|0)|0;d=v[23516];v[23516]=0;a:{if((d|0)==1){break a}v[23516]=0;d=T(1163,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break a}v[c>>2]=d;v[23516]=0;R(1164,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}Zb(e+8|0);hb=e+16|0;return}a=P()|0;O()|0;Zb(e+8|0);S(a|0);L()}function Y$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=v[a+84>>2];f=v[e>>2];d=v[e+4>>2];h=v[a+28>>2];g=v[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){pc(f,h,g);f=g+v[e>>2]|0;v[e>>2]=f;d=v[e+4>>2]-g|0;v[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){pc(f,b,d);f=d+v[e>>2]|0;v[e>>2]=f;v[e+4>>2]=v[e+4>>2]-d}t[f|0]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;return c|0}function LQ(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=fc(c+8|0,c+28|0,4);id(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Qb(c+28|0,b,4)){break b}dd(a,4);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17562,9108,413,13190);L()}aa(17541,9108,411,13190);L()}return d}function t7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=NK(a,b,c,d,e^1);v[b>>2]=46184;a=b+4208|0;f=Bb(a,0),g=1056964608,v[f>>2]=g;f=Bb(a,1),g=1065353216,v[f>>2]=g;f=Bb(a,2),g=1020054733,v[f>>2]=g;f=Bb(a,3),g=1065353216,v[f>>2]=g;f=Bb(a,4),g=1056964608,v[f>>2]=g;f=Bb(a,5),g=1048406533,v[f>>2]=g;f=Bb(a,6),g=1056964608,v[f>>2]=g;return b|0}function saa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;u[a>>1]=0;c=Lb(a+4|0);d=Lb(a+16|0);v[a+36>>2]=0;e=Kb(a+40|0);f=Xf(a+52|0);Gc(c);u[a+28>>1]=65472;v[23516]=0;v[b+12>>2]=1065353216;R(859,c|0,b+12|0);g=v[23516];v[23516]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;Gc(d);hb=b+16|0;return a|0}a=P()|0;O()|0;_S(f);xb(e);lc(d);lc(c);S(a|0);L()}function mL(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0);c=hb-16|0;hb=c;d=0;a:{if(!Mh(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;kk(a,c+12|0);e=v[c+12>>2];d=0;if(e>>>0>65535){break a}ak(b,e);while(1){if((f|0)==(e|0)){d=Mh(v[v[a>>2]-12>>2]+a|0)}else{v[c+8>>2]=0;yp(a,c+8|0);g=Bb(v[b>>2],f),h=z[c+8>>2],z[g>>2]=h;f=f+1|0;continue}break}}a=d;hb=c+16|0;return a}function ip(a,b,c){var d=0,e=0,f=0;e=hb-16|0;hb=e;d=e+8|0;bd(d,b);v[23516]=0;b=T(1136,d|0)|0;d=v[23516];v[23516]=0;a:{if((d|0)==1){break a}v[23516]=0;d=T(1149,b|0)|0;f=v[23516];v[23516]=0;if((f|0)==1){break a}t[c|0]=d;v[23516]=0;R(1150,a|0,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}Zb(e+8|0);hb=e+16|0;return}a=P()|0;O()|0;Zb(e+8|0);S(a|0);L()}function uT(a){var b=0,c=0,d=0;a:{if(Qb(a+60|0,15639,4)|(w[a+32|0]|w[a+33|0]<<8)>>>0>256|(w[a+49|0]<32|(w[a+36|0]|w[a+37|0]<<8)>>>0>255)){break a}if(t[a+51|0]<4|w[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(w[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function r6(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-32|0;hb=b;a=Lb(a);v[23516]=0;Y(956,b+16|0);c=v[23516];v[23516]=0;a:{b:{if((c|0)!=1){c=Cb(v[b+16>>2]);d=Cb(v[b+20>>2]);e=v[cc(b+8|0,a)>>2];v[23516]=0;U(957,c|0,d|0,e|0);c=v[23516];v[23516]=0;if((c|0)==1){break b}lc(b+16|0);hb=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;lc(b+16|0)}Me(a);S(c|0);L()}function Taa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Db(a)>>2]){c=hb-16|0;hb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+32;UM(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;ic(c);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=pt(d+8|0,_p(a,Uf(v[a>>2],v[a+4>>2])+1|0),Uf(v[a>>2],v[a+4>>2]),c);UM(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;Cd(a,c);PP(c);hb=d+32|0}function Nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-32|0;hb=e;wT(e+8|0,c);v[23516]=0;R(111,e+20|0,d|0);c=v[23516];v[23516]=0;b:{c:{if((c|0)!=1){Tj(e,e+8|0);v[23516]=0;X(112,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}Rg(e+8|0);hb=e+32|0;break a}a=P()|0;O()|0;xb(e+8|0);break b}a=P()|0;O()|0;Rg(e+8|0)}S(a|0);L()}}function Jga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-32|0;hb=e;Bq(e+8|0,c);v[23516]=0;R(587,e+20|0,d|0);c=v[23516];v[23516]=0;b:{c:{if((c|0)!=1){Tj(e,e+8|0);v[23516]=0;X(299,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}YR(e+8|0);hb=e+32|0;break a}a=P()|0;O()|0;wb(e+8|0);break b}a=P()|0;O()|0;YR(e+8|0)}S(a|0);L()}}function VT(a){var b=0,c=0;a:{if(Qb(a,13964,3)|(w[a+3|0]-1&255)>>>0>3){break a}if(Eb(w[a+196|0]|w[a+197|0]<<8)>>>0>255){break a}if((Eb(w[a+198|0]|w[a+199|0]<<8)-1&65535)>>>0>255){break a}if((Eb(w[a+200|0]|w[a+201|0]<<8)-1&65535)>>>0>31){break a}b=Eb(w[a+202|0]|w[a+203|0]<<8);if(b>>>0>256){break a}c=Eb(w[a+204|0]|w[a+205|0]<<8)>>>0<b>>>0}return c}function SX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-32|0;hb=e;bn(e+8|0,c);v[23516]=0;R(111,e+20|0,d|0);c=v[23516];v[23516]=0;b:{c:{if((c|0)!=1){Tj(e,e+8|0);v[23516]=0;X(112,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}Rg(e+8|0);hb=e+32|0;break a}a=P()|0;O()|0;xb(e+8|0);break b}a=P()|0;O()|0;Rg(e+8|0)}S(a|0);L()}}function Q3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,13075,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Du(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-32|0;hb=e;LB(e+8|0,c);v[23516]=0;R(111,e+20|0,d|0);c=v[23516];v[23516]=0;b:{c:{if((c|0)!=1){Tj(e,e+8|0);v[23516]=0;X(112,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}Rg(e+8|0);hb=e+32|0;break a}a=P()|0;O()|0;xb(e+8|0);break b}a=P()|0;O()|0;Rg(e+8|0)}S(a|0);L()}}function m3(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;BJ(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;ic(c);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=fE(d+8|0,gE(a,Ni(v[a>>2],v[a+4>>2])+1|0),Ni(v[a>>2],v[a+4>>2]),c);BJ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;eE(a,c);dE(c);hb=d+32|0}function Us(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;a:{if(!b){break a}Ab(e+8|0,a+1074312|0,73);j=zb(v[v[e+8>>2]>>2],v[e+12>>2])?c- -64|0:c;c=120;h=jj(a);k=h^-1;f=1;while(1){if(!c){break a}l=c;c=c>>>1|0;i=f+c|0;g=_g(a,i,j,d);if(!(g>>>0>b>>>0&k)&(!(!g|h)|b>>>0<=g>>>0)){continue}f=i+1|0;c=(c^-1)+l|0;continue}}hb=e+16|0;return f}function Mn(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function dw(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if((d|0)!=1){break a}if(v[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function Hu(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if(!(w[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function JI(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=lb[a|0](b)|0;d=kb;if((d|0)<0){break b}if((lb[c|0](b,0,0,0)|0)<0){break a}if((lb[c|0](b,0,0,2)|0)<0){break a}f=lb[a|0](b)|0;a=kb;lb[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=Vy(f,a)}return g}lb[c|0](b,e,d,0)|0;return 0}function mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+11|0;dR(a,c);if(Qb(c,13615,4)){a=1}else{dR(a,d+11|0);t[b|0]=1;a=0}c=hb-16|0;hb=c;a:{b:{a=(d+11|0)+a|0;c:{if(!a){a=0;break c}b=Fc(c,a);v[23516]=0;a=T(669,b|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break b}wb(b)}hb=c+16|0;break a}a=P()|0;O()|0;wb(b);S(a|0);L()}hb=d+16|0;return a|0}function Kba(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=Lb(a);b:{c:{c=Oc(v[b>>2],v[b+4>>2]);if(c){v[23516]=0;R(630,a|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break b}NO(a,v[b>>2],v[b+4>>2],c)}break c}v[23516]=0;Q(3,a+12|0,b+12|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}}b=P()|0;O()|0;gd(a);S(b|0);L()}}function zia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(y[a+4>>2]<y[Db(a)>>2]){d=hb-16|0;hb=d;a=eh(d,a,1);AT(v[a+4>>2],x[b>>1],w[c|0]);v[a+4>>2]=v[a+4>>2]+4;ic(a);hb=d+16|0;return}e=hb-32|0;hb=e;d=Db(a);d=Tf(e+8|0,pg(a,sc(v[a>>2],v[a+4>>2])+1|0),sc(v[a>>2],v[a+4>>2]),d);AT(v[d+8>>2],x[b>>1],w[c|0]);v[d+8>>2]=v[d+8>>2]+4;Cd(a,d);Sf(d);hb=e+32|0}function Iba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=hb-32|0;hb=d;AA(d+8|0,c);v[23516]=0;R(471,d+20|0,43388);c=v[23516];v[23516]=0;b:{c:{if((c|0)!=1){Tj(d,d+8|0);v[23516]=0;X(112,a|0,b|0,v[d>>2],v[d+4>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}Rg(d+8|0);hb=d+32|0;break a}a=P()|0;O()|0;xb(d+8|0);break b}a=P()|0;O()|0;Rg(d+8|0)}S(a|0);L()}}function Dk(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;v[f+8>>2]=a;v[f+12>>2]=b;h=v[a+8>>2]+120|0;ns(w[h+20|0]);g=hb-16|0;hb=g;v[g+8>>2]=f+8;e=hb-16|0;hb=e;i=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=i;d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;lb[v[qp(e,_j(w[h+20|0]))>>2]](g+8|0,h);hb=e+16|0;hb=g+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];hb=f+16|0}function Cg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=Ic(a);d=Fb(a);c=Og(b);a=0;a:{if(!c){break a}a=e;d=d+a|0;c=b+c|0;b:{if((c|0)==(b|0)){break b}c:{c=c-b|0;if((c|0)>(d-a|0)){break c}g=1-c|0;h=w[b|0];while(1){f=d-a|0;if((c|0)>(f|0)){break c}a=Ap(a,g+f|0,h);if(!a){break c}if(!Ip(a,b,c)){break b}a=a+1|0;continue}}a=d}a=(a|0)==(d|0)?-1:a-e|0}return a}function Vj(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if(b>>>0<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.004168360008973e-292;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2.004168360008973e-292;b=((b|0)>-2960?b:-2960)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function m8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ui(a,b,c,d);v[a>>2]=45072;c=Lb(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[23516]=0;R(917,a+44|0,2);b=v[23516];v[23516]=0;if((b|0)!=1){ti(a);Cs(a);return a|0}b=P()|0;O()|0;lc(c);Ff(a);S(b|0);L()}function Yia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a=Lb(a);a:{if(b){v[23516]=0;R(373,a|0,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break a}e=hb-16|0;hb=e;d=$h(e,a,b);b=v[d+4>>2];f=v[d+8>>2];while(1){if((b|0)==(f|0)){ic(d);hb=e+16|0}else{qo(b,w[c|0]|w[c+1|0]<<8);b=b+2|0;v[d+4>>2]=b;continue}break}}return a|0}b=P()|0;O()|0;gd(a);S(b|0);L()}function yja(a){a=a|0;var b=0,c=0,d=0;c=Lb(a);v[23516]=0;Y(343,c|0);a=v[23516];v[23516]=0;if((a|0)==1){a=P()|0;O()|0;lc(c);S(a|0);L()}a=hb-16|0;hb=a;v[a>>2]=c;b=v[c+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+32768;b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){ic(a);hb=a+16|0}else{u[b>>1]=0;u[b+2>>1]=0;b=b+4|0;v[a+4>>2]=b;continue}break}return c|0}function wY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=hb+-64|0;hb=e;d=1;a:{if(Tg(a,b,0)){break a}d=0;if(!b){break a}b=Cy(b,92316,92364);d=0;if(!b){break a}d=e+8|0;Rb(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;lb[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}hb=e- -64|0;return d|0}function MN(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;i=v[d+20>>2];h=v[d+52>>2];g=!h|e;t[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}v[(B(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}v[d+24>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+48>>2]=h;u[d+72>>1]=x[d+74>>1];ae(a,i>>>0>1&e&(b|0)==1,f+15|0);hb=f+16|0}function J3(a,b){a=a|0;b=b|0;var c=0;v[23516]=0;Y(966,a|0);c=v[23516];v[23516]=0;if((c|0)!=1){v[v[v[a+24>>2]+24>>2]+480272>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,5787,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function ly(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;e=vh(b,c);a:{if(e>>>0<=dp(a)>>>0){f=c;g=v[a>>2];h=ad(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+h;f=v[d+12>>2]}b=Mi(b,f,g);if(!i){Wt(a,f,c,e-ad(v[a>>2],v[a+4>>2])|0);break a}Ld(a,b);break a}iB(a);El(a,Ol(a,e));Wt(a,b,c,e)}hb=d+16|0}function ez(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function fZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=hb-16|0;hb=g;k=ji(g+8|0,v[a+8>>2]);i=Lr(0,c,d-c|0,b?b:467836);ii(k);hb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function Wp(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;t[d+15|0]=b;a:{b:{c:{d:{if(Fe(a)){c=Al(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=w[a+11|0];if((b|0)!=10){break c}}im(a,c,1,c,c,0,0);b=c;if(Fe(a)){break b}}Xd(a,b+1|0);break a}c=v[a>>2];xd(a,b+1|0);a=c}a=a+b|0;$d(a,d+15|0);t[d+14|0]=0;$d(a+1|0,d+14|0);hb=d+16|0}function QW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;f=v[b+16>>2];a:{if(f>>>0<=c>>>0){ec(a,v[d>>2],0);break a}g=v[b+12>>2];b=v[b+4>>2];v[e+20>>2]=v[d+4>>2];v[e+16>>2]=f-c;ec(e+24|0,v[d>>2],v[Hb(e+20|0,e+16|0)>>2]);d=v[v[b>>2]+28>>2];f=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=f;lb[d|0](a,b,c+g|0,e+8|0)}hb=e+32|0}function P3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:947;return}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,13105,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function NG(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=lb[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if((rk(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=xs(v[a+32>>2])?-1:0}hb=b+16|0;return d|0}function v2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;g=v[d+4>>2];ix(b,c,g);f=v[b+16>>2];a:{if(f>>>0<=c>>>0){ec(a,v[d>>2],0);break a}v[e+12>>2]=f-c;v[e+8>>2]=g;d=v[d>>2];f=v[Hb(e+12|0,e+8|0)>>2];uq(e,d,g,0,f);h=v[e>>2];i=v[e+4>>2];lh(Pf(Cb(v[b+4>>2]),c),Pf(Pf(Cb(v[b+4>>2]),c),i),h);uq(a,d,g,0,f)}hb=e+16|0}function de(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;Um(b);f=If(e+8|0,b);a:{d=a+8|0;b=v[d>>2];if(sc(b,v[a+12>>2])>>>0<=c>>>0){v[23516]=0;R(1226,d|0,c+1|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}b=v[d>>2]}a=Bb(b,c);b=v[a>>2];if(b){Ym(b);a=Bb(v[d>>2],c)}g=a,h=_d(f),v[g>>2]=h;EF(f);hb=e+16|0;return}a=P()|0;O()|0;EF(f);S(a|0);L()}function U4(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){return+(+y[v[v[a+24>>2]+24>>2]+1074420>>2]/1e4)}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,15255,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb+-64|0;hb=c;b=-1;a:{if(!(lb[v[v[a>>2]+32>>2]](a,0,1084)|0)){break a}ol(a,1080);d=c+60|0;XR(a,d);e=d;d=WR(c+40|0);b=0;if(!VR(e,d)){break a}ol(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=y[d+4>>2]>=f>>>0}else{e=c+8|0;UR(a,e);b=b+1|0;f=eA(e)+f|0;continue}break}}hb=c- -64|0;return b|0}function iL(a){var b=0,c=0,d=0;c=hb-32|0;hb=c;a:{d=Kx(a);b=Mj(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[23516]=0;b=fa(921,c+8|0,b|0,b|0,Db(a)|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){Cd(a,b);fL(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)==1){break a}}hb=c+32|0;return}V(0)|0;O()|0;Tb();L()}function hL(a){var b=0,c=0,d=0;c=hb-32|0;hb=c;a:{d=Vh(a);b=sc(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[23516]=0;b=fa(922,c+8|0,b|0,b|0,Db(a)|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){Cd(a,b);Sf(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[23516]=0;Z(18);a=v[23516];v[23516]=0;if((a|0)==1){break a}}hb=c+32|0;return}V(0)|0;O()|0;Tb();L()}function cC(a){var b=0,c=0,d=0,e=0,f=0;d=w[a+9|0]|w[a+10|0]<<8;c=rka(w[a+3|0],0,18,0);d=d+c|0;b=kb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;c=w[a+6|0]|w[a+7|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=w[a+4|0]|w[a+5|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;kb=a;return b}function V4(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){return y[v[v[a+24>>2]+24>>2]+1074420>>2]/1e4|0}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,9359,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function hja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-112|0;hb=d;c=hb-16|0;hb=c;f=d+8|0;hU(c+8|0,f);e=v[c+12>>2];id(c,a,v[c+8>>2],e);g=v[c+4>>2];if((g|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){gU(f)}c=-1;a:{if(!e){break a}c=0;if(!jU(d+8|0)){break a}c=we(a,b,iU(w[d+55|0]|w[d+56|0]<<8),kb)}hb=d+112|0;return c|0}function dz(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=Fb(b);v[23516]=0;R(46,d|0,a|0);a=v[23516];v[23516]=0;if((a|0)!=1){a:{while(1){if(Fb(b)>>>0>e>>>0){a=65533;f=t[gg(b,e)|0];if((f|0)>=-96){a=v[((f&255)<<2)+c>>2]}v[23516]=0;R(47,d|0,a|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;Yc(d);S(a|0);L()}function daa(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;t[b+23|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;v[b+16>>2]=0;v[b+20>>2]=0;c=fc(b,b+16|0,15);jc(b+8|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);c=0;a:{if(v[b+12>>2]!=15){break a}if(Qb(b+16|0,8554,15)){break a}Yb(a,15);c=1}hb=b+32|0;return c|0}function vo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Cb(v[b>>2]);g=Cb(v[b+4>>2]);e=hb-16|0;hb=e;v[e+8>>2]=d;while(1){a:{if(!Nb(d,g)){break a}f=hb-16|0;hb=f;Zh(f+8|0,v[d>>2],v[d+4>>2]);h=_b(v[f+8>>2]);hb=f+16|0;if((c|0)==(h|0)){break a}d=v[Em(e+8|0)>>2];continue}break}hb=e+16|0;if(nc(d,Cb(v[b+4>>2]))){Ih(a);return}so(a,d)}function sR(a){var b=0,c=0,d=0,e=0,f=0;e=w[a+28|0]|w[a+29|0]<<8;b=rka(w[a+30|0],0,37,0);c=kb;d=b;b=rka(w[a+24|0]|w[a+25|0]<<8,0,192,0);d=d+b|0;c=kb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;a=w[a+26|0];c=a>>>26|0;e=d;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;kb=a;return b}function nW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-512|0;hb=d;c=hb-16|0;hb=c;f=d+8|0;FC(c+8|0,f);e=v[c+12>>2];id(c,a,v[c+8>>2],e);g=v[c+4>>2];if((g|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){EC(f)}c=-1;a:{if(!e){break a}c=0;if(!HC(d+8|0)){break a}c=we(a,b,GC(w[d+118|0],w[d+119|0]),kb)}hb=d+512|0;return c|0}function j2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=0;a:{if(!v[b+28>>2]){break a}e=0;if((lb[v[b+32>>2]](v[b+24>>2],c,0,0)|0)<0){break a}f=v[d+4>>2];c=v[d>>2];while(1){b:{if(!f){break b}e=lb[v[b+28>>2]](v[b+24>>2],c,f)|0;if(!e){break b}f=f-e|0;c=c+e|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}break}e=g}ec(a,v[d>>2],e)}function Aia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;v[c+12>>2]=1;a:{if(Vh(a)){d=v[a>>2];e=sc(d,v[a+4>>2]);v[c+8>>2]=e;f=v[Hb(c+12|0,c+8|0)>>2];while(1){if(f){u[d>>1]=x[b>>1];t[d+2|0]=w[b+2|0];f=f-1|0;d=d+4|0;continue}break}if(!e){ET(a,1-e|0,b);break a}Ld(a,v[a>>2]+4|0);break a}$t(a);Im(a,pg(a,1));ET(a,1,b)}hb=c+16|0}function zK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=v[v[a+16>>2]+24620>>2]/5|0;b=Dc(b,b>>31);v[a+4272>>2]=b;v[23516]=0;v[c+12>>2]=0;U(923,a+4256|0,b<<1,c+12|0);b=v[23516];v[23516]=0;a:{if((b|0)==1){b=V(92664)|0;if((O()|0)!=(ea(92664)|0)){break a}_(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;hb=c+16|0;return}S(b|0);L()}function Up(a){var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;d=Cb(v[a>>2]);e=a;f=Cb(v[a+4>>2]);a=hb-16|0;hb=a;v[a+8>>2]=d;while(1){if(Nb(d,f)){b=b+A[d>>3];d=v[gt(a+8|0)>>2];continue}break}hb=a+16|0;a=Cb(v[e>>2]);v[c+8>>2]=a;b=-b;e=Cb(v[e+4>>2]);while(1){if(Nb(a,e)){b=b+A[a>>3];A[a>>3]=b;a=v[gt(c+8|0)>>2];continue}else{hb=c+16|0}break}}function jd(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;um(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;d=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?d|32:d;b=Fc(c,21751);xe(a+43|0,b);wb(b);aQ(a);hb=c+16|0}function S6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ui(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=47216;b=a+4208|0;e=Bb(b,0),f=1056880300,v[e>>2]=f;e=Bb(b,1),f=1050733080,v[e>>2]=f;e=Bb(b,2),f=1056964608,v[e>>2]=f;v[23516]=0;R(917,a+44|0,2);b=v[23516];v[23516]=0;if((b|0)!=1){ti(a);return a|0}b=P()|0;O()|0;Ff(a);S(b|0);L()}function K6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ui(a,b,c,d);v[a>>2]=47452;b=a+4208|0;e=Bb(b,0),f=1065353216,v[e>>2]=f;e=Bb(b,1),f=1065353216,v[e>>2]=f;e=Bb(b,2),f=1051372203,v[e>>2]=f;e=Bb(b,3),f=0,v[e>>2]=f;v[23516]=0;R(917,a+44|0,2);b=v[23516];v[23516]=0;if((b|0)!=1){ti(a);return a|0}b=P()|0;O()|0;Ff(a);S(b|0);L()}function ZM(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{while(1){v[e+12>>2]=b;v[e+8>>2]=d;if(y[Hb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=Np(t[Ib(a,f)|0]);h=Np(t[Ib(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}hb=e+16|0;return a}function OI(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a>>2];a:{if(!b){break a}c=v[a+8>>2];if(!c){break a}d=v[a+12>>2];if(!d){break a}e=lb[d|0](b)|0;a=kb;f=a;if((a|0)<0){break a}a=0;b:{if((lb[c|0](b,0,0,0)|0)<0){break b}a=0;if((lb[c|0](b,0,0,2)|0)<0){break b}lb[d|0](b)|0;a=kb;a=(a|0)>0|(a|0)>=0}g=a;lb[c|0](b,e,f,0)|0}return g|0}function z9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+e;a=v[d>>2];a:{while(1){if(v[d+4>>2]==(a|0)){break a}v[23516]=0;R(897,a|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){a=v[d>>2]+52|0;v[d>>2]=a;continue}break}a=P()|0;O()|0;Kd(d);S(a|0);L()}Kd(d);hb=d+16|0}function im(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;i=-17;if(-17-b>>>0>=c>>>0){j=wc(a);if(b>>>0<=2147483622){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;i=ih(v[Vc(h+12|0,h+8|0)>>2])+1|0}c=tc(i);if(e){Ce(c,j,e)}k=e+f|0;if((k|0)!=(d|0)){Ce((c+e|0)+g|0,(e+j|0)+f|0,d-k|0)}if((b|0)!=10){Jb(j)}td(a,c);bf(a,i);hb=h+16|0;return}df();L()}function Xw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=hb-240|0;hb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((lb[b|0](a,f)|0)>=0){if((lb[b|0](a,e)|0)>=0){break a}}j=f;f=(lb[b|0](f,e)|0)>=0;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}EH(g,h);hb=g+240|0}function Fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;v[e+24>>2]=d;c=nf(a,c);ke(e+8|0,v[a+36>>2]);f=a;a:{if(!c){Pc(e+8|0,a+32|0,5);d=0;if(zb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}}d=v[a+36>>2];a=0;pC(b,v[e+24>>2]);while(1){if(y[e+24>>2]>a>>>0){LO(d,$b(v[b>>2],a));a=a+1|0;continue}break}d=c}Ve(f,d);hb=e+32|0}function zE(a,b,c,d,e){var f=0;a:{f=hb-32|0;hb=f;Uo(f+8|0,c);v[23516]=0;R(e|0,f+20|0,d|0);c=v[23516];v[23516]=0;b:{c:{if((c|0)!=1){Tj(f,f+8|0);v[23516]=0;X(112,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}Rg(f+8|0);hb=f+32|0;break a}a=P()|0;O()|0;xb(f+8|0);break b}a=P()|0;O()|0;Rg(f+8|0)}S(a|0);L()}}function vaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(!vd(v[a+1298300>>2])){d=v[a+24620>>2];e=hb-16|0;hb=e;b=tc(536);v[23516]=0;d=Q(854,b|0,d|0)|0;f=v[23516];v[23516]=0;a:{if((f|0)!=1){b=v[If(e+8|0,d)>>2];hb=e+16|0;break a}a=P()|0;O()|0;Jb(b);S(a|0);L()}v[c+8>>2]=b;b=a+1298300|0;a=c+8|0;BM(b,_d(a));sy(a)}hb=c+16|0}function vE(a,b,c,d,e){var f=0;a:{f=hb-32|0;hb=f;kU(f+8|0,c);v[23516]=0;R(e|0,f+20|0,d|0);c=v[23516];v[23516]=0;b:{c:{if((c|0)!=1){Tj(f,f+8|0);v[23516]=0;X(112,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23516];v[23516]=0;if((a|0)==1){break c}Rg(f+8|0);hb=f+32|0;break a}a=P()|0;O()|0;xb(f+8|0);break b}a=P()|0;O()|0;Rg(f+8|0)}S(a|0);L()}}function jS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;e=Qd(b,c);a:{if(e>>>0<=Vh(a)>>>0){f=c;g=v[a>>2];h=sc(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+(h<<2);f=v[d+12>>2]}b=Mi(b,f,g);if(!i){lA(a,f,c,e-sc(v[a>>2],v[a+4>>2])|0);break a}Ld(a,b);break a}$t(a);Im(a,pg(a,e));lA(a,b,c,e)}hb=d+16|0}function SF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;i=v[b>>2];h=v[a>>2];e=v[gc(a)>>2]==1175;f=v[c>>2]-h|0;g=f<<1;f=f>>>0<2147483647?g?g:4:-1;g=_r(e?0:h,f);if(g){if(!e){_d(a)}v[d+4>>2]=1140;e=pe(d+8|0,g,d+4|0);a=PF(a,e);Sc(e);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=v[a>>2]+(f&-4);hb=d+16|0;return}sw();L()}function Yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=ad(e,v[a+4>>2]);if(d>>>0<b>>>0){e=hb-32|0;hb=e;b=b-d|0;d=v[Db(a)>>2];f=v[a+4>>2];a:{if(b>>>0<=d-f>>>0){Ho(a,b,c);break a}d=Db(a);d=Ql(e+8|0,Ol(a,ad(v[a>>2],f)+b|0),ad(v[a>>2],v[a+4>>2]),d);PS(d,b,c);Cd(a,d);Pl(d)}hb=e+32|0;return}if(b>>>0<d>>>0){Ld(a,b+e|0)}}function UL(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;fc(d+8|0,qd(b),wd(v[b+4>>2],w[b+11|0]));b=v[d+8>>2];e=v[d+12>>2];c=hb-16|0;hb=c;f=wd(v[a+4>>2],w[a+11|0]);v[c+12>>2]=f;v[c+8>>2]=e;g=Hb(c+12|0,c+8|0);a=Gv(qd(a),b,v[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}hb=c+16|0;hb=d+16|0;return a>>>31|0}function IC(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(b>>>0<3){if(!b){break a}if(!Ob(v[a>>2],v[a+8>>2],b)){break a}while(1)if((d|0)==2){d=x[c+14>>1];break a}else{t[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){xg(a,c+13|0);e=w[c+13|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}aa(11259,9108,136,14288);L()}hb=c+16|0;return d&65535}function D0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=v[a+44>>2];c=v[a+24>>2];if(e>>>0<c>>>0){v[a+44>>2]=c;e=c}f=v[a+8>>2];c=v[a+12>>2];d=-1;a:{if(f>>>0>=c>>>0){break a}if(nc(b,-1)){qn(a,f,c-1|0,e);return Ew(b)|0}g=kp(b);if(!(v[a+48>>2]&16)){d=-1;if(!nc(g,t[c-1|0])){break a}}qn(a,f,c-1|0,e);t[v[a+12>>2]]=g;d=b}return d|0}function mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+12>>2]=c;a:{e=Ob(v[b>>2],v[b+8>>2],c<<2);if(!e){break a}uc(d+12|0,65535);tg(a,x[d+12>>1]);c=Cb(v[a>>2]);v[d>>2]=c;a=Cb(v[a+4>>2]);while(1){if(!Nb(c,a)){break a}f=d+8|0;if(!Mo(b,f)){Fm(f)}u[c>>1]=v[d+8>>2];c=v[Qe(d)>>2];continue}}hb=d+16|0;return e|0}function Th(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=a;f=hb-16|0;hb=f;a:{e=vh(b,c);if(e>>>0<4294967280){b:{if(e>>>0<=10){Xd(d,e);break b}g=ih(e)+1|0;h=tc(g);td(d,h);bf(d,g);xd(d,e);d=h}while(1){if((b|0)!=(c|0)){$d(d,b);d=d+1|0;b=b+1|0;continue}break}t[f+15|0]=0;$d(d,f+15|0);hb=f+16|0;break a}df();L()}return a|0}function YW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-32|0;hb=f;v[f+28>>2]=c;v[f+24>>2]=b;v[f+20>>2]=d;v[f+16>>2]=e;v[23516]=0;X(171,f|0,f+24|0,f+20|0,f+16|0);b=v[23516];v[23516]=0;if((b|0)!=1){b=f+8|0;sv(b,v[f>>2],v[f+4>>2]);Bg(a,b);je(b);je(f);je(f+24|0);hb=f+32|0;return}a=P()|0;O()|0;je(f+24|0);S(a|0);L()}function MF(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;g=1073741807;if(1073741807-b>>>0>=c>>>0){h=wc(a);if(b>>>0<=536870886){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;g=Tl(v[Vc(f+12|0,f+8|0)>>2])+1|0}c=Ai(g);if(e){mi(c,h,e)}if((d|0)!=(e|0)){i=e<<2;mi(c+i|0,h+i|0,d-e|0)}if((b|0)!=1){Jb(h)}td(a,c);bf(a,g);hb=f+16|0;return}df();L()}function $aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;b=yh(d,b);v[23516]=0;U(819,d+16|0,b|0,c|0);e=v[23516];v[23516]=0;a:{b:{if((e|0)!=1){v[23516]=0;U(54,a|0,d+16|0,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}wb(d+16|0);wb(b);hb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;wb(d+16|0)}wb(b);S(c|0);L()}function vK(a){var b=C(0),c=0,d=C(0);b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}v[a+4248>>2]=c;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function tV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;ec(c+8|0,b,10);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function n9(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Db(a)>>2]){c=hb-16|0;hb=c;a=eh(c,a,1);bk(v[a+4>>2],z[b>>2]);v[a+4>>2]=v[a+4>>2]+4;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=Tf(d+8|0,pg(a,sc(v[a>>2],v[a+4>>2])+1|0),sc(v[a>>2],v[a+4>>2]),c);bk(v[c+8>>2],z[b>>2]);v[c+8>>2]=v[c+8>>2]+4;Cd(a,c);Sf(c);hb=d+32|0}function j8(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;v[v[a+20>>2]+148>>2]=-1;yo(c+8|0,a+4228|0);d=v[a+20>>2];e=v[c+12>>2];b=v[c+8>>2];v[23516]=0;U(935,d+4|0,b|0,Ib(b,e)|0);b=v[23516];v[23516]=0;a:{if((b|0)==1){b=V(92664)|0;if((O()|0)!=(ea(92664)|0)){break a}_(b|0)|0;Gc(v[a+20>>2]+4|0);$()}hb=c+16|0;return}S(b|0);L()}function PB(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Db(a)>>2]){c=hb-16|0;hb=c;a=$h(c,a,1);Ki(v[a+4>>2],x[b>>1]);v[a+4>>2]=v[a+4>>2]+2;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=Jj(d+8|0,Kj(a,Oc(v[a>>2],v[a+4>>2])+1|0),Oc(v[a>>2],v[a+4>>2]),c);Ki(v[c+8>>2],x[b>>1]);v[c+8>>2]=v[c+8>>2]+2;Cd(a,c);Li(c);hb=d+32|0}function N_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;i=v[b>>2];h=v[a>>2];e=v[gc(a)>>2]==1175;f=v[c>>2]-h|0;g=f<<1;f=f>>>0<2147483647?g?g:1:-1;g=_r(e?0:h,f);if(g){if(!e){_d(a)}v[d+4>>2]=1140;e=pe(d+8|0,g,d+4|0);a=PF(a,e);Sc(e);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=f+v[a>>2];hb=d+16|0;return}sw();L()}function L4(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){return Lg(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,7081,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function K4(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){return ts(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,6790,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function H4(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){return ss(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,7440,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function w8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;v[d+28>>2]=c;v[d+8>>2]=33;e=v[a>>2];f=v[a+8>>2];c=v[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=$e(a)}e=d+8|0;vA(e,b);f=fc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);vA(e,b);Rb(v[d+8>>2]+c|0,0,33-c|0);Yb(a,v[d+28>>2]);hb=d+32|0;return c|0}function qj(a){var b=0,c=0,d=0,e=0,f=0;b=v[a+4>>2];if(nc(v[a>>2],b)){a=0}else{b=Ei(b);e=Ei(v[a>>2]);c=hb-16|0;hb=c;v[c+8>>2]=b;while(1){a:{if(!Fg(b,e)){break a}d=hb-16|0;hb=d;v[d+8>>2]=b;f=VO(d+8|0);hb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}b=v[VO(c+8|0)>>2];continue}break}hb=c+16|0;a=xB(Cb(v[a>>2]),b)}return a&65535}function pX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;b=Jl(d,b);v[23516]=0;U(152,d+16|0,b|0,c|0);e=v[23516];v[23516]=0;a:{b:{if((e|0)!=1){v[23516]=0;U(4,a|0,d+16|0,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}xb(d+16|0);xb(b);hb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;xb(d+16|0)}xb(b);S(c|0);L()}function Yv(a,b,c){var d=0;v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;if((d|0)!=1){return v[v[v[a+24>>2]+24>>2]+c>>2]}c=V(0)|0;O()|0;_(c|0)|0;v[23516]=0;X(953,b|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function XE(a,b,c){var d=0;v[23516]=0;Y(966,a|0);d=v[23516];v[23516]=0;if((d|0)!=1){return x[v[v[a+24>>2]+24>>2]+c>>1]}c=V(0)|0;O()|0;_(c|0)|0;v[23516]=0;X(953,b|0,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function $4(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){return+mM(v[v[a+24>>2]+24>>2])}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,10168,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function oY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Tg(a,v[b+8>>2],e)){cw(b,c,d);return}a:{if(!Tg(a,v[b>>2],e)){break a}if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function MI(a){var b=0,c=0,d=0,e=0;b=hb-32|0;hb=b;if(!w[a+20|0]){while(1){if(!(lb[v[v[a>>2]+40>>2]](a)|0)){KI(a,65536);c=fc(b+16|0,Ib(v[a+4>>2],v[a+16>>2]),65536);d=v[v[a>>2]+44>>2];e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;lb[d|0](b+24|0,a,b+8|0);v[a+16>>2]=v[a+16>>2]+v[b+28>>2];continue}break}t[a+20|0]=1}hb=b+32|0}function FO(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;if(w[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){t[a+534|0]=0}else{nj(a,d,1);c=c+1|0;continue}break}}t[b+15|0]=0;ci(a+8|0,18,b+15|0);Lt(a+26|0,18,29370);t[b+14|0]=255;ci(a+62|0,256,b+14|0);ah(v[a>>2],v[a+4>>2],65535,261,1);ah(v[a>>2],v[a+4>>2],65535,260,0);hb=b+16|0}function kW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-48|0;hb=e;c=hb-16|0;hb=c;f=e+8|0;xC(c+8|0,f);d=v[c+12>>2];id(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;d=(d|0)==(g|0);if(!d){wC(f)}c=-1;a:{if(!d){break a}c=0;if(!zC(e+8|0)){break a}c=we(a,b,yC(w[e+43|0]),kb)}hb=e+48|0;return c|0}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb+-64|0;hb=e;c=hb-16|0;hb=c;f=e+8|0;sS(c+8|0,f);d=v[c+12>>2];id(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;d=(d|0)==(g|0);if(!d){rS(f)}c=-1;a:{if(!d){break a}c=0;if(!uS(e+8|0)){break a}c=we(a,b,tS(e+8|0),kb)}hb=e- -64|0;return c|0}function JC(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(b>>>0<5){if(!b){break a}if(!Ob(v[a>>2],v[a+8>>2],b)){break a}while(1)if((d|0)==4){d=v[c+12>>2];break a}else{t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){xg(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}aa(11259,9108,136,14288);L()}hb=c+16|0;return d}function xia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-576|0;hb=d;c=hb-16|0;hb=c;rT(c+8|0,d);e=v[c+12>>2];id(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){qT(d)}c=-1;a:{if(!e){break a}c=0;if(!uT(d)){break a}c=we(a,b,sT(x[d+34>>1],x[d+36>>1]),kb)}hb=d+576|0;return c|0}function nN(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;f=-2147483648;f=!c|!(t[c+15|0]&1)?f:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){f=x[d+28>>1];break b}if((f|0)==-2147483648){break a}}Yp(b,f,a);Ab(e+8|0,a+1074312|0,10);if(!zb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}hb=e+16|0}function cha(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,20)+d;a=v[c>>2];a:{while(1){if(v[c+4>>2]==(a|0)){break a}v[23516]=0;Y(230,a|0);a=v[23516];v[23516]=0;if((a|0)!=1){a=v[c>>2]+20|0;v[c>>2]=a;continue}break}a=P()|0;O()|0;Kd(c);S(a|0);L()}Kd(c);hb=c+16|0}function x4(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){return+A[v[a+24>>2]+16>>3]}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,7602,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function r4(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){return v[v[a+24>>2]+8>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,10899,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Yx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=F(c,.999);h=c*3.141592653589793;i=ht(b);while(1){if((e|0)!=32768){f=((e<<12^-1)&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=Bi(g)*ht(K(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=Iz(c*d*32768),u[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function YQ(a){var b=0,c=0;a:{if(Qb(a,3868,4)|w[a+63|0]!=26){break a}b=w[a+65|0];if(w[a+66|0]|(b|0)!=16&(b|0)!=1|(w[a+64|0]&3|(w[a+78|0]|w[a+79|0]<<8)>>>0>127)){break a}if((w[a+80|0]|w[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=xk(w[a|0]|w[a+1|0]<<8,w[b|0]|w[b+1|0]<<8)?b:a;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function u_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a:{if(!Fe(f)){b=v[f+4>>2];v[a>>2]=v[f>>2];v[a+4>>2]=b;v[a+8>>2]=v[f+8>>2];break a}d=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(c>>>0<=1){Xd(a,c);break d}if(c>>>0>=1073741808){break c}e=Tl(c)+1|0;b=Ai(e);td(a,b);bf(a,e);xd(a,c);a=b}mi(a,d,c+1|0);break b}df();L()}}}function c5(a,b){a=a|0;b=b|0;var c=0,d=0;a=Kb(a);c=Fb(b);v[23516]=0;R(71,a|0,c|0);c=v[23516];v[23516]=0;if((c|0)!=1){a:{b:{while(1){if(Fb(b)>>>0<=d>>>0){break b}c=t[gg(b,d)|0];v[23516]=0;R(49,a|0,Kf(Kf(c))|0);c=v[23516];v[23516]=0;if((c|0)!=1){d=d+1|0;continue}break}break a}return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function VQ(a){var b=0;a:{if(Qb(a+44|0,14245,4)|w[a+28|0]!=26|(w[a+40|0]|w[a+41|0]<<8|w[a+30|0]>2)){break a}if(((w[a+38|0]|w[a+39|0]<<8)-33&65535)>>>0<65504|((w[a+32|0]|w[a+33|0]<<8)-257&65535)>>>0<65280|((w[a+34|0]|w[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((w[a+36|0]|w[a+37|0]<<8)-1&65535)>>>0<128}return b}function Lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;v[d+28>>2]=c;v[d+8>>2]=4896;e=v[a>>2];f=v[a+8>>2];c=v[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=$e(a)}e=d+8|0;yA(e,b);f=fc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);yA(e,b);Rb(v[d+8>>2]+c|0,0,4896-c|0);Yb(a,v[d+28>>2]);hb=d+32|0}function yV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-1968|0;hb=e;c=hb-16|0;hb=c;f=e+8|0;IB(c+8|0,f);d=v[c+12>>2];id(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;d=(d|0)==(g|0);if(!d){HB(f)}c=-1;a:{if(!d){break a}c=0;if(!JB(e+8|0)){break a}c=we(a,b,1024,0)}hb=e+1968|0;return c|0}function h2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-32|0;hb=f;v[f+28>>2]=e;v[f+24>>2]=d;Vg(f+16|0,b,c);b=Bg(f+8|0,f+24|0);c=v[b+4>>2];b=v[b>>2];v[23516]=0;ga(167,a|0,v[f+16>>2],v[f+20>>2],b|0,c|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){je(f+24|0);hb=f+32|0;return}a=P()|0;O()|0;je(f+24|0);S(a|0);L()}function Tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;v[d+28>>2]=c;v[d+8>>2]=263;e=v[a>>2];f=v[a+8>>2];c=v[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=$e(a)}e=d+8|0;sP(e,b);f=fc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);sP(e,b);Rb(v[d+8>>2]+c|0,0,263-c|0);Yb(a,v[d+28>>2]);hb=d+32|0}function Ox(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;h=x[b>>1];c=Pd(a);e=gc(a);f=hb-16|0;hb=f;while(1){if(c){g=Is(x[c+16>>1],h);e=g?e:c;c=v[(g?c+4|0:c)>>2];continue}break}c=v[cc(f+8|0,e)>>2];hb=f+16|0;a:{if(Nb(c,Yf(a))){if(!Is(x[b>>1],x[sd(c)>>1])){break a}}c=Yf(a)}a=v[cc(d+8|0,c)>>2];hb=d+16|0;return a}function Hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;v[d+28>>2]=c;v[d+8>>2]=102;e=v[a>>2];f=v[a+8>>2];c=v[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=$e(a)}e=d+8|0;FT(e,b);f=fc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);FT(e,b);Rb(v[d+8>>2]+c|0,0,102-c|0);Yb(a,v[d+28>>2]);hb=d+32|0}function Afa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Db(a)>>2]){c=hb-16|0;hb=c;a=Su(c,a,1);lR(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=bB(d+8|0,cB(a,wf(v[a>>2],v[a+4>>2])+1|0),wf(v[a>>2],v[a+4>>2]),c);lR(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;aB(a,c);fu(c);hb=d+32|0}function tB(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Db(a)>>2]){c=hb-16|0;hb=c;a=HU(c,a,1);GU(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+48;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=EU(d+8|0,FU(a,xq(v[a>>2],v[a+4>>2])+1|0),xq(v[a>>2],v[a+4>>2]),c);GU(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+48;DU(a,c);CU(c);hb=d+32|0}function kja(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;a=Su(c,a,1);dB(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=bB(d+8|0,cB(a,wf(v[a>>2],v[a+4>>2])+1|0),wf(v[a>>2],v[a+4>>2]),c);dB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;aB(a,c);fu(c);hb=d+32|0}function ey(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;f=v[b+656>>2];e=0;a:{if(!f){break a}f=Yu(f,c);e=a+1074312|0;Ab(d+8|0,e,31);a=0;if(!zb(v[v[d+8>>2]>>2],v[d+12>>2])){Ab(d,e,93);a=zb(v[v[d>>2]>>2],v[d+4>>2])^1}if(!(t[YL(b,c)+6|0]&1)){e=0;if(!(t[f+12|0]&1)|a){break a}}e=nc(v[f>>2],v[f+4>>2])^1}hb=d+16|0;return e}function Jba(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;a=Az(c,a,1);nz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+32;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=pt(d+8|0,_p(a,Uf(v[a>>2],v[a+4>>2])+1|0),Uf(v[a>>2],v[a+4>>2]),c);nz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;MO(a,c);mz(c);hb=d+32|0}function Z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=v[21059];v[g+24>>2]=v[21058];v[g+28>>2]=h;h=v[21057];v[g+16>>2]=v[21056];v[g+20>>2]=h;h=v[21055];v[g+8>>2]=v[21054];v[g+12>>2]=h;h=v[21053];v[g>>2]=v[21052];v[g+4>>2]=h;h=a;a=g+32|0;b=Wj(h,b,c,d,e,f,g,a);hb=a;return b|0}function Wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;v[d+28>>2]=c;v[d+8>>2]=22;e=v[a>>2];f=v[a+8>>2];c=v[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=$e(a)}e=d+8|0;iu(e,b);f=fc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);iu(e,b);Rb(v[d+8>>2]+c|0,0,22-c|0);Yb(a,v[d+28>>2]);hb=d+32|0}function Uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;v[d+28>>2]=c;v[d+8>>2]=40;e=v[a>>2];f=v[a+8>>2];c=v[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=$e(a)}e=d+8|0;mA(e,b);f=fc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);mA(e,b);Rb(v[d+8>>2]+c|0,0,40-c|0);Yb(a,v[d+28>>2]);hb=d+32|0}function RN(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;a=At(c,a,1);Wo(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=Bk(d+8|0,$m(a,ud(v[a>>2],v[a+4>>2])+1|0),ud(v[a>>2],v[a+4>>2]),c);Wo(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;or(a,c);QN(c);hb=d+32|0}function Kea(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Db(a)>>2]){c=hb-16|0;hb=c;a=Iv(c,a);Lz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=Bk(d+8|0,$m(a,ud(v[a>>2],v[a+4>>2])+1|0),ud(v[a>>2],v[a+4>>2]),c);Lz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;tQ(a,c);sQ(c);hb=d+32|0}function aW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;v[d+28>>2]=c;v[d+8>>2]=65;e=v[a>>2];f=v[a+8>>2];c=v[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=$e(a)}e=d+8|0;Ru(e,b);f=fc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);Ru(e,b);Rb(v[d+8>>2]+c|0,0,65-c|0);Yb(a,v[d+28>>2]);hb=d+32|0}function Cf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Fb(a)|(c-b|0)<5){break a}Ir(b,c);e=c-4|0;c=Ic(a);g=c+Fb(a)|0;b:{while(1){c:{a=t[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=v[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>v[e>>2]-1>>>0){break a}}v[d>>2]=4}}function Xia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;v[d+28>>2]=c;v[d+8>>2]=5;e=v[a>>2];f=v[a+8>>2];c=v[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=$e(a)}e=d+8|0;xo(e,b);f=fc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);xo(e,b);Rb(v[d+8>>2]+c|0,0,5-c|0);Yb(a,v[d+28>>2]);hb=d+32|0}function Rv(a,b,c,d,e){var f=0,g=0;g=c-b|0;a:{if((e|0)>=(g|0)){e=B(32-E(d|1)|0,1233)>>>12|0;f=61;if((g|0)<((e-(y[(e<<2)+25920>>2]>d>>>0)|0)+1|0)){break a}}b:{if(d>>>0<=99999999){c=Rw(b,d);break b}c=d;d=(d>>>0)/1e8|0;e=c+B(d,-1e8)|0;c=(e>>>0)/1e4|0;c=$i($i(sH(b,d),c),e+B(c,-1e4)|0)}f=0}v[a+4>>2]=f;v[a>>2]=c}function IX(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;a=Iv(c,a);Wo(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=Bk(d+8|0,$m(a,ud(v[a>>2],v[a+4>>2])+1|0),ud(v[a>>2],v[a+4>>2]),c);Wo(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;or(a,c);Hv(c);hb=d+32|0}function CW(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;a=pD(c,a);qv(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+36;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Db(a);c=nD(d+8|0,oD(a,$q(v[a>>2],v[a+4>>2])+1|0),$q(v[a>>2],v[a+4>>2]),c);qv(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+36;mD(a,c);rv(c);hb=d+32|0}function v0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Kb(a);d=wd(v[b+4>>2],w[b+11|0]);e=wd(v[c+4>>2],w[c+11|0]);b=qd(b);v[23516]=0;X(100,a|0,b|0,d|0,d+e|0);b=v[23516];v[23516]=0;a:{if((b|0)!=1){b=qd(c);v[23516]=0;W(101,a|0,b|0,e|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;xb(a);S(b|0);L()}}function q2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}if(!v[b+28>>2]){t[b+40|0]=1;break a}d=v[c+4>>2];f=v[c>>2];while(1){b:{if(d){e=lb[v[b+28>>2]](v[b+24>>2],f,d)|0;if(e){break b}t[b+40|0]=1}d=g;break a}d=d-e|0;f=e+f|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}}ec(a,v[c>>2],d)}function _K(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[23516]=0;v[c+12>>2]=0;U(923,a+4208|0,b<<1,c+12|0);b=v[23516];v[23516]=0;a:{if((b|0)==1){b=V(92664)|0;if((O()|0)!=(ea(92664)|0)){break a}_(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;hb=c+16|0;return}S(b|0);L()}function Py(a,b,c,d,e,f){var g=0,h=0,i=0;g=hb-16|0;hb=g;h=-17;if(-17-b>>>0>=c>>>0){i=qd(a);if(b>>>0<=2147483622){v[g+8>>2]=b<<1;v[g+12>>2]=b+c;h=ih(v[Vc(g+12|0,g+8|0)>>2])+1|0}c=tc(h);if(e){Ce(c,i,e)}if((d|0)!=(e|0)){Ce((c+e|0)+f|0,e+i|0,d-e|0)}if((b|0)!=10){Jb(i)}td(a,c);bf(a,h);hb=g+16|0;return}df();L()}function Gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-32|0;hb=e;c=hb-16|0;hb=c;f=e+8|0;VB(c+8|0,f);d=v[c+12>>2];id(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;d=(d|0)==(g|0);if(!d){Fu(f)}c=-1;a:{if(!d){break a}c=0;if(!tU(e+8|0)){break a}c=we(a,b,72,0)}hb=e+32|0;return c|0}function rB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-32|0;hb=f;v[f+8>>2]=c;g=f,h=$e(b),v[g+28>>2]=h;c=f+8|0;Mf(c,b,v[Hb(c,f+28|0)>>2]);b=Ee(c);v[23516]=0;da(238,a|0,b|0,v[f+8>>2],d|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){Qc(f+8|0);hb=f+32|0;return}a=P()|0;O()|0;Qc(f+8|0);S(a|0);L()}function oka(a){a=a|0;var b=0,c=0,d=0;c=hb-32|0;hb=c;b=255;a:{if(pj(v[a>>2],v[a+4>>2])>>>0<=49){b=rz(c,v[a+12>>2]);v[23516]=0;R(292,a|0,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break a}hl(b);Dj(a,pj(v[a>>2],v[a+4>>2])-1&255);b=pj(v[a>>2],v[a+4>>2])-1|0}hb=c+32|0;return b&255}a=P()|0;O()|0;hl(b);S(a|0);L()}function o5(a){a=a|0;var b=0;v[23516]=0;Y(991,a|0);b=v[23516];v[23516]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,12010,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function dfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-608|0;hb=d;c=hb-16|0;hb=c;TQ(c+8|0,d);e=v[c+12>>2];id(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){SQ(d)}c=-1;a:{if(!e){break a}c=0;if(!VQ(d)){break a}c=we(a,b,UQ(x[d+34>>1]),kb)}hb=d+608|0;return c|0}function W5(a){a=a|0;var b=0;v[23516]=0;Y(966,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[23516]=0;X(953,5693,a|0,0,0);a=v[23516];v[23516]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Fl(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=B(c,872)+b|0;f=YM(v[d+720>>2],v[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return XM(a,b,c,e);case 1:break b;default:break a}}f=XM(a,b,c,e);if((f+5&255)>>>0>5){break a}a=B(c,872)+b|0;f=YM(v[a+720>>2],v[a+1272>>2],e)}return f}function Es(a){var b=0,c=0,d=0;b=ni(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){if(b>45e-5){c=xp(b)/.6931471805599453;b=c-H(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=ni(d+c)*.5}else{b=0}A[a+4248>>3]=b}Ds(a)}function mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+12>>2]=c;a:{if(!Ob(v[b>>2],v[b+8>>2],c<<1)){break a}uc(d+12|0,65535);tg(a,x[d+12>>1]);c=Cb(v[a>>2]);v[d>>2]=c;a=Cb(v[a+4>>2]);while(1){if(!Nb(c,a)){break a}Ju(b,d+8|0);e=c,f=Eb(x[d+8>>1]),u[e>>1]=f;c=v[Qe(d)>>2];continue}}hb=d+16|0}function Uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-240|0;hb=d;c=hb-16|0;hb=c;NT(c+8|0,d);e=v[c+12>>2];id(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){MT(d)}c=-1;a:{if(!e){break a}c=0;if(!PT(d)){break a}c=we(a,b,OT(v[d+4>>2]),kb)}hb=d+240|0;return c|0}function Rx(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;v[d>>2]=a;a=v[a+4>>2];v[d+4>>2]=a;v[d+8>>2]=a+B(b,52);a=v[d+4>>2];b=v[d+8>>2];a:{while(1){if((a|0)==(b|0)){break a}v[23516]=0;R(897,a|0,c|0);e=v[23516];v[23516]=0;if((e|0)!=1){a=a+52|0;v[d+4>>2]=a;continue}break}a=P()|0;O()|0;ic(d);S(a|0);L()}ic(d);hb=d+16|0}function Rm(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(v[c>>2]|v[d>>2]){while(1){if((b|0)==(f|0)){break a}e=v[d>>2];g=v[c>>2];h=c,i=g-hd((hd(0-g|0,31)&255)+g|0,8)|0,v[h>>2]=i;h=d,i=v[d>>2]-hd(e+(hd(0-e|0,31)&255)|0,8)|0,v[h>>2]=i;e=(f<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];f=f+1|0;continue}}Rb(a,0,b<<3)}}function xO(a,b){var c=0,d=0,e=0;a=Lb(a);a:{if(b){v[23516]=0;R(784,a|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}d=hb-16|0;hb=d;c=qt(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){ic(c);hb=d+16|0}else{pm(b,0,0);b=b+16|0;v[c+4>>2]=b;continue}break}}return a}b=P()|0;O()|0;kl(a);S(b|0);L()}function sO(a,b){var c=0,d=0,e=0,f=0;c=A[b+8>>3];a:{d=A[b>>3];if(gf(d)){if(d<0){c=nO(c)?c:1;break a}if(c!=0){if(nO(c)){break a}}pm(a,d,gf(c)?M:c);return}if(!Uh(d)|c!=0){break a}e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;return}d=ux(d);f=Bi(c);pm(a,d*Ze(c),f*d)}function hZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;b=hb-16|0;hb=b;v[e>>2]=c;a=fw(b+12|0,0,v[a+8>>2]);c=2;a:{if(a+1>>>0<2){break a}a=a-1|0;c=1;if(a>>>0>d-v[e>>2]>>>0){break a}c=b+12|0;while(1){if(a){d=w[c|0];f=v[e>>2];v[e>>2]=f+1;t[f|0]=d;a=a-1|0;c=c+1|0;continue}break}c=0}hb=b+16|0;return c|0}function Zk(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;rp(c,b);v[23516]=0;R(1071,c+16|0,c|0);b=v[23516];v[23516]=0;a:{b:{if((b|0)!=1){v[23516]=0;U(1072,a|0,0,c+16|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}Yc(c+16|0);xb(c);hb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Yc(c+16|0)}xb(c);S(b|0);L()}function Gr(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}t[a|0]=b}function G7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;bd(a,b);v[23516]=0;U(64,d+8|0,b|0,c|0);e=v[23516];v[23516]=0;a:{if((e|0)==1){break a}Zb(d+8|0);b=v[b+24>>2];if(b){v[23516]=0;U(65,d|0,b|0,c|0);b=v[23516];v[23516]=0;if((b|0)==1){break a}Zb(d)}hb=d+16|0;return}b=P()|0;O()|0;Zb(a);S(b|0);L()}function hu(a){var b=0,c=0;b=v[a+76>>2];if(!((b|0)>=0&(!b|v[116e3]!=(b&-1073741825)))){b=v[a+4>>2];if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return Bw(a)}b=v[a+76>>2];v[a+76>>2]=b?b:1073741823;c=a+76|0;b=v[a+4>>2];a:{if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=Bw(a)}v[c>>2]=0;return a}function c9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ui(a,b,c,d);v[a>>2]=44012;b=Lb(a+4208|0);v[a+4228>>2]=0;v[a+4220>>2]=0;v[a+4224>>2]=0;v[a+4232>>2]=v[c+24620>>2];iV(a+4260|0,80,150,80,255);v[23516]=0;R(917,a+44|0,2);c=v[23516];v[23516]=0;if((c|0)!=1){ti(a);return a|0}c=P()|0;O()|0;lc(b);Ff(a);S(c|0);L()}function Naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=pc(a,b,614);e=c+616|0;a=0;while(1){d=B(a,872);Mp(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=Oz(c+223848|0,b+223848|0);v[23516]=0;Q(823,c+223860|0,b+223860|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){return c|0}b=P()|0;O()|0;dc(a);S(b|0);L()}function Eba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;c=nf(a,c);ke(d,v[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!zb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}e=v[c+16>>2]}f=v[a+36>>2];c:{d:{switch(e+1|0){case 0:case 2:ki(f,b);break c;default:break d}}XS(f,b,e)}f=c}Ve(a,f);hb=d+16|0}function IL(a){var b=0,c=0;a:{if(Qb(a,14279,4)){break a}b=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))}return c}function jq(a){var b=0,c=0;b=hb-32|0;hb=b;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;c=a+288|0;wz(c,c+512|0,b);v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;a=a+800|0;wz(a,hQ(a),b);hb=b+32|0}function Kfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-1120|0;hb=d;c=hb-16|0;hb=c;pR(c+8|0,d+8|0);e=v[c+12>>2];id(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!rR(d+8|0)){break a}c=we(a,b,qR(v[d+1112>>2]),kb)}hb=d+1120|0;return c|0}function H3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{if(!(c&1024)){break a}f=e,g=ge(b),v[f+8>>2]=g;b:{if(!Fb(b)){break b}if(w[Jc(b,0)|0]!=43){if(w[Jc(b,0)|0]!=45){break b}}d=d+1|0;AJ(e+8|0)}c=Fb(b);if(c>>>0>=d>>>0){break a}uJ(b,v[hj(e,e+8|0)>>2],d-c|0,48)}Xc(a,b);hb=e+16|0}function r7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=6){c=Td(c,C(0));a:{b:{switch(b-1|0){case 0:c=Wh(c);if(c==z[Bb(a+4208|0,1)>>2]){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 3:break b;default:break a}}c=C(Wh(C(c*C(4)))*C(.25))}d=Bb(a+4208|0,b),e=c,z[d>>2]=e;yx(a)}}function fja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-224|0;hb=d;c=hb-16|0;hb=c;$T(c+8|0,d);e=v[c+12>>2];id(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!bU(d)){break a}c=we(a,b,aU(w[d+216|0],w[d+217|0]),kb)}hb=d+224|0;return c|0}function b8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=6){c=Td(c,C(0));a:{b:{switch(b-3|0){case 0:c=Wh(c);if(c==z[Bb(a+4208|0,3)>>2]){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 1:break b;default:break a}}c=C(Wh(C(c*C(4)))*C(.25))}d=Bb(a+4208|0,b),e=c,z[d>>2]=e;yx(a)}}function Sea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb+-64|0;hb=d;c=hb-16|0;hb=c;su(c+8|0,d);e=v[c+12>>2];id(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){lu(d)}c=-1;a:{if(!e){break a}c=0;if(!zQ(d)){break a}c=we(a,b,yQ(d),kb)}hb=d- -64|0;return c|0}function Raa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=w[a+11|0];c:{d:{if(zf(c)){c=v[a+4>>2];d=jB(v[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break b}d=10;c=Kf(c);if((c|0)!=10){break c}}Py(a,d,1,d,d,0);c=d;if(zf(w[a+11|0])){break b}}Xd(a,c+1|0);break a}d=v[a>>2];xd(a,c+1|0);a=d}a=a+c|0;nd(a,b);nd(a+1|0,0)}function KN(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[Xb(v[a+484344>>2],x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;Ab(d+8|0,a+1074312|0,63);if(!zb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}hb=d+16|0}function Ff(a){a=a|0;var b=0,c=0;v[a>>2]=44488;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;TK(a+44|0);return a|0}function qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-192|0;hb=d;c=hb-16|0;hb=c;Dq(c+8|0,d);e=v[c+12>>2];id(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){lT(d)}c=-1;a:{if(!e){break a}c=0;if(!nT(d)){break a}c=we(a,b,mT(d),kb)}hb=d+192|0;return c|0}function qY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Tg(a,v[b+8>>2],0)){bw(b,c,d);return}e=v[a+12>>2];f=a+16|0;lF(v[f>>2],v[a+20>>2],b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){lF(v[a>>2],v[a+4>>2],b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function fl(a,b,c){var d=0,e=0;a=Kb(a);d=Fb(b);v[23516]=0;R(46,a|0,d|0);d=v[23516];v[23516]=0;if((d|0)!=1){a:{while(1){if(Fb(b)>>>0>e>>>0){d=v[(w[gg(b,e)|0]<<2)+c>>2];v[23516]=0;R(47,a|0,d|0);d=v[23516];v[23516]=0;if((d|0)==1){break a}e=e+1|0;continue}break}return}}b=P()|0;O()|0;Yc(a);S(b|0);L()}function UK(a){a=a|0;var b=0,c=0,d=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];a:{if(D(b)<0x8000000000000000){d=~~b>>>0;c=D(b)>=1?~~(b>0?F(H(b*2.3283064365386963e-10),4294967295):I((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}A[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function $ia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-208|0;hb=d;c=hb-16|0;hb=c;TT(c+8|0,d);e=v[c+12>>2];id(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){ST(d)}c=-1;a:{if(!e){break a}c=0;if(!VT(d)){break a}c=we(a,b,UT(d),kb)}hb=d+208|0;return c|0}function Xda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-80|0;hb=d;c=hb-16|0;hb=c;MS(c+8|0,d);e=v[c+12>>2];id(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){zA(d)}c=-1;a:{if(!e){break a}c=0;if(!BP(d)){break a}c=we(a,b,AP(d),kb)}hb=d+80|0;return c|0}function aja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;v[d+8>>2]=c;v[d+12>>2]=-1;if((c|0)!=-1){f=d,g=Fb(a),v[f>>2]=g;e=v[Hb(d+12|0,d)>>2];v[d+4>>2]=e;a=Ip(Ic(a),b,v[Hb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}hb=d+16|0;return a|0}pk();L()}function _fa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-128|0;hb=e;c=hb-16|0;hb=c;BR(c+8|0,e);d=v[c+12>>2];id(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;d=(d|0)==(f|0);if(!d){AR(e)}c=-1;a:{if(!d){break a}c=0;if(!CR(e)){break a}c=we(a,b,256,0)}hb=e+128|0;return c|0}function Xg(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=E(e);Hf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;hb=d+16|0}function zY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;a:{e=v[b>>2];if(vd(e)){if(!Pe(c)){ZJ(c,17866);e=v[b>>2]}b=v[b+4>>2];lb[v[v[b>>2]+24>>2]](d,b,e);v[23516]=0;Q(820,c|0,d|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break a}wb(d)}Xc(a,c);hb=d+16|0;return}a=P()|0;O()|0;wb(d);S(a|0);L()}function lB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;v[e+8>>2]=c;f=e,g=$e(b),v[f+28>>2]=g;c=e+8|0;Mf(c,b,v[Hb(c,e+28|0)>>2]);b=Ee(c);v[23516]=0;X(342,a|0,b|0,v[e+8>>2],d|0);a=v[23516];v[23516]=0;if((a|0)!=1){Qc(e+8|0);hb=e+32|0;return}a=P()|0;O()|0;Qc(e+8|0);S(a|0);L()}function NB(a,b,c){var d=0,e=0,f=0;d=hb-32|0;hb=d;v[d+28>>2]=c;v[d+8>>2]=192;e=v[a>>2];f=v[a+8>>2];c=v[Hb(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=$e(a)}e=d+8|0;Dq(e,b);f=fc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);Dq(e,b);Rb(v[d+8>>2]+c|0,0,192-c|0);Yb(a,v[d+28>>2]);hb=d+32|0}function Laa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(Sd(w[b+24|0])){a=Xf(a);c=Ei(v[b>>2]);d=tf(b);v[23516]=0;U(826,a|0,c|0,d|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}v[23516]=0;Q(825,a+12|0,b+12|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break a}t[a+24|0]=1}return}b=P()|0;O()|0;fN(a);S(b|0);L()}function lL(a,b){var c=0,d=0,e=0,f=0,g=C(0);c=hb-16|0;hb=c;if(Mh(v[v[a>>2]-12>>2]+a|0)){u[c+14>>1]=0;Wf(a,c+14|0);e=x[c+14>>1];ak(b,e);while(1){if((d|0)!=(e|0)){v[c+8>>2]=0;yp(a,c+8|0);f=Bb(v[b>>2],d),g=z[c+8>>2],z[f>>2]=g;d=d+1|0;continue}break}d=Mh(v[v[a>>2]-12>>2]+a|0)}hb=c+16|0;return d}function cQ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;v[e+12>>2]=6553600;i=e,j=_b(b),v[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=sq(f*+y[Hb(g,b)>>2]);v[e+8>>2]=6553600;i=e,j=_b(c),v[i+4>>2]=j;i=e,j=sq(f*+y[Hb(b,e+4|0)>>2]),v[i+12>>2]=j;v[e+8>>2]=d-h;Yn(a,h,Hb(b,g));hb=e+16|0}function Vp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{e=gl(a,b);if((e|0)==255){break a}g=v[a>>2];if(gk(g)){break a}f=Jd(a+318|0,e);e=EO(e);if(h=1,i=t[Ib(f,10)|0]&1,j=d,j?h:i){ah(g,v[a+4>>2],b,e- -64&65535,DO(c,w[Ib(f,2)|0]))}if(d){break a}ah(v[a>>2],v[a+4>>2],b,e+67&65535,DO(c,w[Ib(f,3)|0]))}}function IT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=Xf(a);a=b+236|0;b=rq(a);a:{while(1){if((a|0)!=(b|0)){d=x[a>>1];u[c+14>>1]=d;if(d){v[23516]=0;U(400,c|0,e|0,c+14|0);d=v[23516];v[23516]=0;if((d|0)==1){break a}}a=a+2|0;continue}break}hb=c+16|0;return}a=P()|0;O()|0;bu(e);S(a|0);L()}function DJ(a,b){var c=0;c=hb-32|0;hb=c;pi(c,b);v[23516]=0;U(1077,c+16|0,0,c|0);b=v[23516];v[23516]=0;a:{b:{if((b|0)!=1){v[23516]=0;R(1078,a|0,c+16|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}Yc(c+16|0);wb(c);hb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Yc(c+16|0)}wb(c);S(b|0);L()}function uw(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-160|0;hb=e;v[e+60>>2]=b;v[e+20>>2]=b;v[e+24>>2]=-1;f=e+16|0;li(f,0,0);GG(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+60>>2]|0)+b}v[a+8>>2]=d;v[a+12>>2]=f;v[a>>2]=g;v[a+4>>2]=h;hb=e+160|0}function mU(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Cv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function uK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[23516]=0;v[c+12>>2]=0;U(923,a+4208|0,b<<2,c+12|0);b=v[23516];v[23516]=0;a:{if((b|0)==1){b=V(92664)|0;if((O()|0)!=(ea(92664)|0)){break a}_(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;hb=c+16|0;return}S(b|0);L()}function u3(a,b){a=a|0;b=b|0;var c=0,d=0;a=Lb(a);a:{c=ik(v[b+4>>2],v[b+8>>2]);if(!c){break a}v[23516]=0;R(1073,a|0,c|0);d=v[23516];v[23516]=0;if((d|0)!=1){d=v[b+8>>2];b=v[b+4>>2];v[23516]=0;X(1074,a|0,b|0,d|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;rs(a);S(b|0);L()}}function Iy(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}dk(a,b,b+700|0,c<<2,0)}}function $C(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){v[a+96>>2]=e;v[a+92>>2]=d}else{f=(g<<3)+b|0;h=v[f>>2];d=d-hd((hd(0-d|0,31)&255)+d|0,8)|0;v[f>>2]=h+d;h=v[f+4>>2];e=e-hd((hd(0-e|0,31)&255)+e|0,8)|0;v[f+4>>2]=h+e;g=g+1|0;continue}break}}}function wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;_f(b);v[d+12>>2]=0;a:{if(!kk(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}t[d+11|0]=0;if(Oh(a,d+11|0)){Wp(b,t[d+11|0]);e=e+1|0;continue}break}e=0}hb=d+16|0;return e|0}function hp(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;bd(d,a);v[23516]=0;a=T(1153,d|0)|0;d=v[23516];v[23516]=0;a:{b:{if((d|0)==1){break b}v[23516]=0;X(1165,a|0,84e3,84026,b|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}Zb(c+8|0);hb=c+16|0;break a}a=P()|0;O()|0;Zb(c+8|0);S(a|0);L()}return b}function T_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=hb-128|0;hb=c;v[c+12>>2]=c+116;d=v[a+8>>2];a=c+16|0;VF(d,a,c+12|0,e,f,g);e=v[c+12>>2];d=hb-16|0;hb=d;v[d+8>>2]=b;while(1){if((a|0)!=(e|0)){ZG(d+8|0,t[a|0]);a=a+1|0;continue}break}hb=d+16|0;hb=c+128|0;return v[d+8>>2]}function Ry(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;g=v[b+480180>>2];a:{if(g&64671904){b=w[(d&15)+43920|0];t[a+2|0]=0;u[a>>1]=b;break a}Ab(f+8|0,b+1074312|0,66);h=a;a=(c&255)==4&(g|0)==4;b=(d&255)<<a<<4;ql(h,(i=zb(v[v[f+8>>2]>>2],v[f+12>>2])?0:b,j=b,k=e,k?i:j),a)}hb=f+16|0}function Jy(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}dk(a,b,b+700|0,c,0)}}function eaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;_f(b);e=d+40|0;Mf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,1,Ee(e),a);v[23516]=0;R(221,d+24|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){a=d+24|0;yc(b,a);wb(a);Qc(d+40|0);hb=d- -64|0;break a}a=P()|0;O()|0;Qc(d+40|0);S(a|0);L()}}function Mz(a,b,c,d,e){var f=0;a:{f=v[a>>2];if(!Vd(f,v[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}um(b);b=_n(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Jg(b)){break a}if(v[a>>2]!=(d|0)){Yq(b+68|0)}pc(v[b+20>>2],v[a+20>>2]+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function qL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+12>>2]=b;a:{if(Vh(a)>>>0>=b>>>0){f=v[a>>2];e=sc(f,v[a+4>>2]);v[d+8>>2]=e;pL(f,v[Hb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Qx(a,b-e|0,c);break a}Ld(a,v[a>>2]+(b<<2)|0);break a}$t(a);Im(a,pg(a,b));Qx(a,b,c)}hb=d+16|0}function l1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=As(c);v[a>>2]=78376;v[d>>2]=78396;v[a+60>>2]=78436;v[a>>2]=78416;v[a+4>>2]=0;e=c;c=a+8|0;zn(e,c);v[a>>2]=78376;v[d>>2]=78396;v[23516]=0;Q(89,c|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Sk(d);S(a|0);L()}function VC(a,b,c,d){var e=0,f=0,g=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;e=d;d=v[a+1068>>2];u[e+(d<<1)>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;f=a,g=Hd(x[v[a+1060>>2]+34>>1])+d|0,v[f+1068>>2]=g;v[a+1072>>2]=v[a+1072>>2]-1}function SG(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a=us(a);v[a+32>>2]=b;v[a>>2]=79116;b=d+8|0;Qr(b,a);v[23516]=0;b=T(1132,b|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){Zb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;f=a,g=pn(b),t[f+44|0]=g;hb=d+16|0;return}b=P()|0;O()|0;Zb(d+8|0);Bn(a);S(b|0);L()}function RG(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a=kH(a);v[a+32>>2]=b;v[a>>2]=79284;b=d+8|0;Qr(b,a);v[23516]=0;b=T(1133,b|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){Zb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;f=a,g=pn(b),t[f+44|0]=g;hb=d+16|0;return}b=P()|0;O()|0;Zb(d+8|0);Vr(a);S(b|0);L()}function eT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=hb+-64|0;hb=c;d=c+40|0;Mf(d,a,32);a=v[c+40>>2];e=c+8|0;bg(e,2,Ee(d),a);v[23516]=0;R(221,c+24|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){Mm(c,b);a=c+24|0;Cl(c,a);wb(a);Qc(c+40|0);hb=c- -64|0;break a}a=P()|0;O()|0;Qc(c+40|0);S(a|0);L()}}function QV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;v[d+12>>2]=c;a:{if(!Ob(v[b>>2],v[b+8>>2],c<<1)){break a}uc(d+12|0,65535);tg(a,x[d+12>>1]);c=Cb(v[a>>2]);v[d>>2]=c;a=Cb(v[a+4>>2]);while(1){if(!Nb(c,a)){break a}Ju(b,d+8|0);u[c>>1]=x[d+8>>1];c=v[Qe(d)>>2];continue}}hb=d+16|0}function oJ(a){var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=a+120|0;ns(w[b+20|0]);c=hb-16|0;hb=c;v[c+8>>2]=d+8;a=hb-16|0;hb=a;e=v[14503];v[a+8>>2]=v[14502];v[a+12>>2]=e;e=v[14501];v[a>>2]=v[14500];v[a+4>>2]=e;b=lb[v[qp(a,_j(w[b+20|0]))>>2]](c+8|0,b)|0;hb=a+16|0;hb=c+16|0;hb=d+16|0;return b}function jm(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!sj(w[f+31|0])){break a}e=w[f+34|0]-1|0;if((e&255)>>>0>249){break a}e=v[Id(a+906300|0,e)>>2];if(!e){break a}lb[v[v[e>>2]+96>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function Og(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function Kr(a,b,c,d){var e=0,f=0;e=hb-160|0;hb=e;f=-1;v[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;v[e+144>>2]=a;e=Rb(e,0,144);v[e+76>>2]=-1;v[e+36>>2]=1135;v[e+80>>2]=-1;v[e+44>>2]=e+159;v[e+84>>2]=e+144;a:{if((b|0)<0){v[115992]=61;break a}t[a|0]=0;f=yH(e,c,d,1115,1116)}hb=e+160|0;return f}function hK(a,b,c){t[a+12|0]=0;v[c>>2]=0;v[b>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;u[a+24>>1]=0;v[a+36>>2]=0;v[a+40>>2]=0;v[a+44>>2]=0;v[a+48>>2]=0;gK(a+60|0);gK(a+52|0);Jp(a+49956|0);Jp(a+58148|0);Jp(a+66340|0);Jp(a+74532|0);Rb(a+228|0,0,32768);Rb(a+32996|0,0,512);Rb(a+33508|0,0,16384)}function vv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;v[f+12>>2]=e;v[f+8>>2]=d;Vg(f,b,c);v[23516]=0;U(169,a|0,v[f>>2],v[f+4>>2]);b=v[23516];v[23516]=0;if((b|0)!=1){v[a+8>>2]=0;b=f+8|0;Bg(a+12|0,b);je(b);hb=f+16|0;return a|0}a=P()|0;O()|0;je(f+8|0);S(a|0);L()}function uba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=Lb(a);a:{d=Qg(v[b>>2],v[b+4>>2]);if(d){v[23516]=0;R(783,a|0,d|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}c=hb-16|0;hb=c;e=v[b>>2];f=v[b+4>>2];b=ar(c,a,d);Vt(e,f,b+4|0);ic(b);hb=c+16|0}return a|0}b=P()|0;O()|0;be(a);S(b|0);L()}function nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+12>>2]=b;a:{if(dp(a)>>>0>=b>>>0){f=v[a>>2];e=ad(f,v[a+4>>2]);v[d+8>>2]=e;ci(f,v[Hb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Ho(a,b-e|0,c);break a}Ld(a,v[a>>2]+b|0);break a}iB(a);El(a,Ol(a,b));Ho(a,b,c)}hb=d+16|0}function Ui(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;v[e+12>>2]=d;g=ji(e+8|0,b);b=hb-16|0;hb=b;d=v[e+12>>2];v[b+12>>2]=d;v[b+8>>2]=d;f=-1;d=Kr(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Md(d);v[h>>2]=a;if(!a){break a}f=Kr(a,d,c,v[b+12>>2])}hb=b+16|0;ii(g);hb=e+16|0;return f}function UB(a,b,c){var d=0,e=0,f=0;d=hb+-64|0;hb=d;_f(b);e=d+40|0;Mf(e,a,c);a=v[d+40>>2];f=d+8|0;bg(f,3,Ee(e),a);v[23516]=0;R(221,d+24|0,f|0);e=v[23516];v[23516]=0;if((e|0)!=1){e=b;b=d+24|0;yc(e,b);wb(b);Qc(d+40|0);hb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Qc(d+40|0);S(a|0);L()}function iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;e=d+40|0;Mf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,2,Ee(e),a);v[23516]=0;R(221,d+24|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){a=d+24|0;wl(b,a);wb(a);Qc(d+40|0);hb=d- -64|0;break a}a=P()|0;O()|0;Qc(d+40|0);S(a|0);L()}}function baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;e=d+40|0;Mf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,1,Ee(e),a);v[23516]=0;R(221,d+24|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){a=d+24|0;xe(b,a);wb(a);Qc(d+40|0);hb=d- -64|0;break a}a=P()|0;O()|0;Qc(d+40|0);S(a|0);L()}}function Y8(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{d=v[a+20>>2];c=v[d+4>>2];if((ad(c,v[d+8>>2])|0)!=8){break b}if(Qb(c,9585,4)){break b}b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);v[a+4260>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[a+4264>>2]=b;break a}Hx(a,b)}Fs(a)}function Wh(a){var b=C(0),c=0,d=0;c=(p(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return C(a*C(0))}a=(c|0)>=0?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){a=C(C(a+b)+C(-1));break a}a=C(a+b);if(!(b<=C(-.5))){break a}a=C(a+C(1))}a=(c|0)>=0?a:C(-a)}return a}function H9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;c=nf(a,c);ke(d,v[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!zb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}e=v[c+16>>2]}f=v[a+36>>2];c:{if(!((e|0)!=4&(e|0)!=-1)){kk(f,b);break c}MG(f,b,e)}f=c}Ve(a,f);hb=d+16|0}function xP(a,b){var c=0,d=0,e=0,f=0;c=hb-96|0;hb=c;zR(b,c,c+96|0);b=0;while(1){if((b|0)==12){v[a+104>>2]=0;v[a+96>>2]=!(v[a+88>>2]|v[a+92>>2]);v[a+100>>2]=0;hb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d&65535;b=b+1|0;continue}break}v[a+112>>2]=0}function WU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;e=d+40|0;Mf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,2,Ee(e),a);v[23516]=0;R(221,d+24|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){a=d+24|0;Ac(b,a);wb(a);Qc(d+40|0);hb=d- -64|0;break a}a=P()|0;O()|0;Qc(d+40|0);S(a|0);L()}}function Mq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;v[f+12>>2]=c;c=f+12|0;uc(c,256);uc(c,65535);h=x[f+12>>1];tg(a,h);c=0;while(1){if((c|0)==(h|0)){hb=f+16|0}else{g=w[b+c|0];i=yl(v[a>>2],v[a+4>>2],c),j=(d|0)==(g|0)?-1:(e|0)==(g|0)?-2:g,u[i>>1]=j;c=c+1|0;continue}break}}function sJ(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=v[a>>2];d=Og(e);b:{c:{if((Fb(c)|0)==(d|0)){v[23516]=0;d=W(368,c|0,e|0,d|0)|0;e=v[23516];v[23516]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}V(0)|0;O()|0;Tb();L()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function lS(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;v[e+12>>2]=a;a:{if(!(!c|b)){a=Oe(+(B(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){uc(e+12|0,10);a=B(w[v[e+12>>2]+26976|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Oe(733.8401379310345/f*1e4);break a}a=Oe(f/.264*1e4)}hb=e+16|0;return a}function at(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;Be(d+8|0,b);b=v[d+8>>2];e=v[d+12>>2];c=hb-16|0;hb=c;f=Fb(a);v[c+12>>2]=f;v[c+8>>2]=e;g=Hb(c+12|0,c+8|0);a=Ip(Ic(a),b,v[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}hb=c+16|0;hb=d+16|0;return a>>>31|0}function TC(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=v[a+1068>>2]+Hd(x[v[a+1060>>2]+34>>1])|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function af(a){var b=0,c=0;b=hb-32|0;hb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;BC(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];hb=b+32|0}function aba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=hb+-64|0;hb=c;d=c+40|0;Mf(d,a,32);a=v[c+40>>2];e=c+8|0;bg(e,1,Ee(d),a);v[23516]=0;R(221,c+24|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){a=c+24|0;Ac(b,a);wb(a);Qc(c+40|0);hb=c- -64|0;break a}a=P()|0;O()|0;Qc(c+40|0);S(a|0);L()}}function Aba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;b=OP(d,a+8|0,b);a=v[b>>2];a:{while(1){if(v[b+4>>2]==(a|0)){break a}v[23516]=0;R(772,a|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){a=v[b>>2]+32|0;v[b>>2]=a;continue}break}a=P()|0;O()|0;Kd(b);S(a|0);L()}Kd(b);hb=d+16|0}function qba(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{d:{if(Fe(a)){c=Al(a)-1|0;d=v[a+4>>2];if((c|0)==(d|0)){break d}break b}c=1;d=w[a+11|0];if((d|0)!=1){break c}}MF(a,c,1,c,c);d=c;if(Fe(a)){break b}}Xd(a,d+1|0);break a}c=v[a>>2];xd(a,d+1|0);a=c}a=(d<<2)+a|0;td(a,b);td(a+4|0,0)}function XB(a,b,c){var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;Mf(e,a,c);a=v[d+40>>2];f=d+8|0;bg(f,3,Ee(e),a);v[23516]=0;R(221,d+24|0,f|0);e=v[23516];v[23516]=0;if((e|0)!=1){e=b;b=d+24|0;Ac(e,b);wb(b);Qc(d+40|0);hb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Qc(d+40|0);S(a|0);L()}function Tv(a,b,c,d,e){var f=0,g=0;a:{f=hb+-64|0;hb=f;g=f+40|0;Mf(g,a,e);a=v[f+40>>2];e=f+8|0;bg(e,d,Ee(g),a);v[23516]=0;R(221,f+24|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){fc(f,b,c);a=f+24|0;Cl(f,a);wb(a);Qc(f+40|0);hb=f- -64|0;break a}a=P()|0;O()|0;Qc(f+40|0);S(a|0);L()}}function OK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=v[v[a+16>>2]+1074404>>2];v[23516]=0;v[c+12>>2]=0;U(923,a+4208|0,B(b,254)|0,c+12|0);b=v[23516];v[23516]=0;a:{if((b|0)==1){b=V(92664)|0;if((O()|0)!=(ea(92664)|0)){break a}_(b|0)|0;$()}v[a+4220>>2]=0;hb=c+16|0;return}S(b|0);L()}function CR(a){var b=0;a:{if(Qb(a,15609,4)|((w[a+8|0]|w[a+9|0]<<8)-768&65535)>>>0<65280|(((w[a+112|0]|w[a+113|0]<<8)-65&65535)>>>0<65472|(w[a+106|0]|w[a+107|0]<<8)>>>0>256)){break a}if((w[a+122|0]|w[a+123|0]<<8)>>>0>255){break a}b=(w[a+124|0]|w[a+125|0]<<8)>>>0<4e3}return b}function yha(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;v[c+8>>2]=b;a:{if(sc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!vd(b)){break a}v[23516]=0;R(496,a|0,c+8|0);a=v[23516];v[23516]=0;d=b;if((a|0)!=1){break a}a=P()|0;O()|0;qg(c+8|0);S(a|0);L()}qg(c+8|0);hb=c+16|0;return d|0}function kga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;b=cE(c,a,b);a=v[b+4>>2];d=v[b+8>>2];a:{while(1){if((a|0)==(d|0)){break a}v[23516]=0;Y(588,a|0);e=v[23516];v[23516]=0;if((e|0)!=1){a=a+24|0;v[b+4>>2]=a;continue}break}a=P()|0;O()|0;ic(b);S(a|0);L()}ic(b);hb=c+16|0}function aV(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;v[d+12>>2]=b;c=hb-16|0;hb=c;v[c+12>>2]=153391689;v[c+8>>2]=2147483647;e=Hb(c+12|0,c+8|0);hb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=yB(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Vc(d+8|0,d+12|0)>>2]}hb=d+16|0;return b}rd();L()}function mV(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function mC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;b=Su(c,a,b);a=v[b+4>>2];d=v[b+8>>2];a:{while(1){if((a|0)==(d|0)){break a}v[23516]=0;Y(230,a|0);e=v[23516];v[23516]=0;if((e|0)!=1){a=a+20|0;v[b+4>>2]=a;continue}break}a=P()|0;O()|0;ic(b);S(a|0);L()}ic(b);hb=c+16|0}function gS(a,b){var c=0,d=0;a:{c=v[b>>2];d=v[b+20>>2];if(!Vd(c,d)){break a}if(v[a+20>>2]==(d|0)){v[a+20>>2]=0;c=v[b>>2]}uc(a,c);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!Jg(a)){break a}pc(v[a+20>>2],v[b+20>>2],Fj(v[a>>2],x[a+34>>1]))}}function LD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;g=v[b+8>>2];f=v[b>>2];Vg(e+16|0,c,d);c=v[v[f>>2]+28>>2];d=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=d;lb[c|0](e+24|0,f,g,e+8|0);Vg(a,v[e+24>>2],v[e+28>>2]);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];hb=e+32|0}function FU(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;v[d+12>>2]=b;c=hb-16|0;hb=c;v[c+12>>2]=89478485;v[c+8>>2]=2147483647;e=Hb(c+12|0,c+8|0);hb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=BU(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Vc(d+8|0,d+12|0)>>2]}hb=d+16|0;return b}rd();L()}function tn(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=uka(a,b,10,0);f=kb;e=rka(d,f,246,0)+a|0;c=c-1|0;t[c|0]=e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=B(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function l3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;yn(c,a);if(v[b>>2]){Gc(b);a=v[b>>2];qr(b);Jb(a);d=Db(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=Db(c);d=Db(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Vf(c);hb=c+16|0}function X$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function Ih(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;b=hb-16|0;hb=b;v[b+4>>2]=1;f=b,g=tc(16),v[f+8>>2]=g;c=Oo(v[b+8>>2]);v[c>>2]=42904;f=Wm(zc(c)),g=43036,v[f>>2]=g;c=d+8|0;e=Qo(b);Po(c,zc(e),e);Xm(b);hb=b+16|0;Bg(a,c);je(c);hb=d+16|0;v[a+8>>2]=0;ce(a+12|0);return a}function se(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function F2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;v[d+24>>2]=c;a:{while(1){if((a|0)==(b|0)){break a}c=Fc(d+8|0,v[a>>2]);v[23516]=0;Q(1096,d+24|0,c|0)|0;e=v[23516];v[23516]=0;if((e|0)!=1){wb(c);a=a+4|0;continue}break}a=P()|0;O()|0;wb(c);S(a|0);L()}hb=d+32|0}function v8(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;v[b+12>>2]=a;v[b+8>>2]=4104;a=0;d=v[b+8>>2];a:{if(d>>>0<4096){break a}c=v[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}v[b+12>>2]=e;v[b+8>>2]=d-c;a=e}if(!a){aa(6056,9043,88,7360);L()}hb=b+16|0;return a|0}function kP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-16|0;hb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Ic(d);Th(b,a,Fb(d)+a|0);break c}jP(e,c,d);v[23516]=0;U(42,a|0,b|0,e|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}Yc(e)}hb=e+16|0;break a}a=P()|0;O()|0;Yc(e);S(a|0);L()}}function gn(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(!b){b=0;break a}d=b;b=E(b);Hf(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+v[c+8>>2]|0;e=e+(v[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=v[c>>2];b=v[c+4>>2]}v[a>>2]=d;v[a+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=e;hb=c+16|0}function gV(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;f=Ib(a,31),g=0,t[f|0]=g;t[b+15|0]=0;c=yi(a,Wn(a),b+15|0);t[b+14|0]=0;c=vh(a,c);gm(c+a|0,Wn(a),b+14|0);while(1){if((c|0)!=(d|0)){e=Ib(a,d);if((w[e|0]-127&255)>>>0<=160){t[e|0]=32}d=d+1|0;continue}break}hb=b+16|0}function Cs(a){var b=0,c=0,d=C(0);b=a+4232|0;c=w[b|0];if(c>>>0>=5){t[b|0]=0;c=0}if(t[a+4233|0]<0){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<0){t[a+4234|0]=127;b=127}a:{if((c|0)==3){d=C(C(1)-qe(C(2),C(-C((b&255)+1|0))));break a}d=qe(C(2),C(-C((b&255)>>>0)))}z[a+4224>>2]=d}function eX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+12>>2]=c;v[d+8>>2]=b;c=hb-16|0;hb=c;v[c+4>>2]=1;e=c,f=tc(24),v[e+8>>2]=f;b=Oo(v[c+8>>2]);v[b>>2]=62388;GD(zc(b),v[d+8>>2],v[d+12>>2]);b=Qo(c);Po(d,zc(b),b);Xm(c);hb=c+16|0;Bg(a,d);je(d);hb=d+16|0}function MD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=hb-16|0;hb=d;b:{c:{if(!b){b=a;a=qd(c);Th(b,a,wd(v[c+4>>2],w[c+11|0])+a|0);break c}qN(d,c);v[23516]=0;U(42,a|0,b|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}Yc(d)}hb=d+16|0;break a}a=P()|0;O()|0;Yc(d);S(a|0);L()}}function BQ(a){var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;b=Cb(v[a>>2]);v[c+8>>2]=b;e=Cb(v[a+4>>2]);while(1){a:{d=Nb(b,e);if(!d){break a}a=x[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){u[b>>1]=65535;break b}if(a>>>0>63){break a}}b=v[Qe(c+8|0)>>2];continue}break}hb=c+16|0;return d^1}function zj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Cb(v[b>>2]);f=Cb(v[b+4>>2]);e=hb-16|0;hb=e;v[e+8>>2]=d;while(1){a:{if(!Nb(d,f)){break a}if(IU(c,v[d>>2],v[d+4>>2])){break a}d=v[Em(e+8|0)>>2];continue}break}hb=e+16|0;if(nc(d,Cb(v[b+4>>2]))){Ih(a);return}so(a,d)}function oz(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;b=Az(d,a,b);a=v[b+4>>2];e=v[b+8>>2];a:{while(1){if((a|0)==(e|0)){break a}v[23516]=0;R(772,a|0,c|0);f=v[23516];v[23516]=0;if((f|0)!=1){a=a+32|0;v[b+4>>2]=a;continue}break}a=P()|0;O()|0;ic(b);S(a|0);L()}ic(b);hb=d+16|0}function jh(a,b){var c=0,d=0,e=0;a:{if(!(b?1:t[a+480180|0]&1)){break a}e=v[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function h0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Kf(t[b|0]),e=v[v[a>>2]+52>>2],lb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=rk(b,1,c,v[a+32>>2])}return c|0}function gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-160|0;hb=b;e=-1;c=hb-16|0;hb=c;f=b+8|0;XQ(c+8|0,f);d=v[c+12>>2];id(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(g|0);if(!a){WQ(f)}if(a){e=YQ(b+8|0)}hb=b+160|0;return e|0}function bp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function _ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-624|0;hb=b;e=-1;c=hb-16|0;hb=c;f=b+8|0;YU(c+8|0,f);d=v[c+12>>2];id(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(g|0);if(!a){XU(f)}if(a){e=ZU(b+8|0)}hb=b+624|0;return e|0}function RC(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;bd(d,a);v[23516]=0;a=T(19,d|0)|0;d=v[23516];v[23516]=0;a:{if((d|0)==1){break a}v[23516]=0;a=Q(20,a|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break a}Zb(c+8|0);hb=c+16|0;return a}a=P()|0;O()|0;Zb(c+8|0);S(a|0);L()}function PC(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=v[a>>2];break a}a=v[a>>2];v[a+((f>>>0<33?0:g>>>5|0)<<2)>>2]=0}Go(d+8|0,a,e);dv(v[d+8>>2],v[d+12>>2],b,c);hb=d+16|0}function NU(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[ef(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[ef(d+13|0,d+12|0)|0]}hb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function EE(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;v[e+12>>2]=c;c=e+12|0;uc(c,d);uc(c,65535);f=x[e+12>>1];tg(a,f);c=0;while(1){if((c|0)==(f|0)){hb=e+16|0}else{d=w[b+c|0];g=yl(v[a>>2],v[a+4>>2],c),h=(d|0)==255?-1:(d|0)==254?-2:d,u[g>>1]=h;c=c+1|0;continue}break}}function o8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=zx(a+8|0,d);v[23516]=0;Q(933,a+20|0,c|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;Ub(b);S(a|0);L()}function vja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-32|0;hb=b;e=-1;c=hb-16|0;hb=c;f=b+8|0;iu(c+8|0,f);d=v[c+12>>2];id(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(g|0);if(!a){mU(f)}if(a){e=nU(b+8|0)}hb=b+32|0;return e|0}function rJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Kb(a);d=Og(b);e=Fb(c);v[23516]=0;X(1082,a|0,b|0,d|0,d+e|0);b=v[23516];v[23516]=0;a:{if((b|0)!=1){b=Ic(c);v[23516]=0;W(1083,a|0,b|0,e|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;wb(a);S(b|0);L()}}function qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;e=-1;c=hb-16|0;hb=c;f=b+8|0;xo(c+8|0,f);d=v[c+12>>2];id(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(g|0);if(!a){ES(f)}if(a){e=FS(b+8|0)}hb=b+16|0;return e|0}function Nr(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=v[b+76>>2]>=0;b:{c=v[b+4>>2];c:{if(!c){Pw(b);c=v[b+4>>2];if(!c){break c}}if(v[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;d=a&255}return d}function E0(a){a=a|0;var b=0,c=0,d=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}d=-1;a:{if(!(w[a+48|0]&8)){break a}b=v[a+16>>2];if(b>>>0<c>>>0){qn(a,v[a+8>>2],v[a+12>>2],c);b=v[a+16>>2]}a=v[a+12>>2];if(a>>>0>=b>>>0){break a}d=Kf(t[a|0])}return d|0}function xE(a,b,c,d){var e=0,f=0;a:{e=hb+-64|0;hb=e;f=e+40|0;Mf(f,a,d);a=v[e+40>>2];d=e+8|0;bg(d,c,Ee(f),a);v[23516]=0;R(221,e+24|0,d|0);a=v[23516];v[23516]=0;if((a|0)!=1){a=e+24|0;xe(b,a);wb(a);Qc(e+40|0);hb=e- -64|0;break a}a=P()|0;O()|0;Qc(e+40|0);S(a|0);L()}}function k7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ui(a,b,c,d);v[a>>2]=46688;b=a+4208|0;e=Bb(b,0),f=1017370378,v[e>>2]=f;e=Bb(b,1),f=0,v[e>>2]=f;v[23516]=0;R(917,a+44|0,2);b=v[23516];v[23516]=0;if((b|0)!=1){ti(a);return a|0}b=P()|0;O()|0;Ff(a);S(b|0);L()}function tG(a,b,c){var d=0,e=0,f=0,g=0;d=a;a:{e=Qd(b,c);if(e>>>0<1073741808){b:{if(e>>>0<=1){Xd(d,e);break b}f=Tl(e)+1|0;g=Ai(f);td(d,g);bf(d,f);xd(d,e);d=g}while(1){if((b|0)!=(c|0)){td(d,v[b>>2]);d=d+4|0;b=b+4|0;continue}break}td(d,0);break a}df();L()}return a}function mT(a){var b=0,c=0,d=0,e=0;d=w[a+32|0]|w[a+33|0]<<8;e=w[a+38|0]|w[a+39|0]<<8;c=w[a+34|0]|w[a+35|0]<<8;b=c+(w[a+36|0]|w[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;kb=a;return b}function hV(a,b,c){var d=0,e=0;d=hb+-64|0;hb=d;_f(b);e=d+40|0;Mf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,2,Ee(e),a);v[23516]=0;R(221,d+24|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){a=d+24|0;yc(b,a);wb(a);Qc(d+40|0);hb=d- -64|0;return}a=P()|0;O()|0;Qc(d+40|0);S(a|0);L()}function Cl(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;d=Ic(b);e=c,f=Fb(b),v[e+12>>2]=f;v[c+8>>2]=v[a+4>>2]-1;lh(d,d+v[Hb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];e=c,f=Fb(b),v[e+12>>2]=f;a=v[a+4>>2];v[c+8>>2]=a-1;gm(d+v[Hb(c+12|0,c+8|0)>>2]|0,a+d|0,62620);hb=c+16|0}function A2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=hb-16|0;hb=c;v[c+4>>2]=1;e=c,f=tc(52),v[e+8>>2]=f;d=v[c+8>>2];v[23516]=0;Q(1103,d|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){b=a;a=Qo(c);Po(b,zc(a),a);Xm(c);hb=c+16|0;break a}a=P()|0;O()|0;Xm(c);S(a|0);L()}}function fea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;v[c+12>>2]=4925421;v[c+8>>2]=2147483647;d=Hb(c+12|0,c+8|0);hb=c+16|0;if(y[d>>2]<b>>>0){rd();L()}if(b>>>0>=4925422){Zf(11191);L()}c=B(b,872);b=tc(c);v[a>>2]=b;v[a+4>>2]=b;e=Db(a),f=b+c|0,v[e>>2]=f}function Uk(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=ds(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Oj(a,b){var c=0,d=0,e=0,f=0,g=0;g=v[a+8>>2];while(1){if((b|0)!=(e|0)){d=v[a>>2];if(d){c=v[a+4>>2]}else{v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=8;c=w[c|0]}v[a>>2]=d-1;v[a+4>>2]=c>>>1;f=c&1|f<<1;e=e+1|0;continue}break}return f}function kf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=hb-16|0;hb=e;a:{if(b>>>0<4294967280){b:{if(b>>>0<=10){Xd(d,b);break b}f=ih(b)+1|0;g=tc(f);td(d,g);bf(d,f);xd(d,b);d=g}c=vB(d,b,c);t[e+15|0]=0;$d(b+c|0,e+15|0);hb=e+16|0;break a}df();L()}return a|0}function g2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Lb(a);a:{if(!c){break a}v[23516]=0;R(1104,a|0,c|0);d=v[23516];v[23516]=0;if((d|0)!=1){v[23516]=0;X(1105,a|0,b|0,Jd(b,c)|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;Me(a);S(b|0);L()}return a|0}function Tb(){var a=0;a=v[23513];v[23516]=0;Z(a|0);a=v[23516];v[23516]=0;a:{if((a|0)!=1){v[23516]=0;Z(1229);a=v[23516];v[23516]=0;if((a|0)!=1){break a}}a=V(0)|0;O()|0;_(a|0)|0;v[23516]=0;Z(1229);a=v[23516];v[23516]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Tb()}L()}function nP(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=94072;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function W8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0),f=0,g=C(0);d=hb-16|0;hb=d;f=d,g=C(C(lb[v[v[a>>2]+48>>2]](a,b))+c),z[f+12>>2]=g;c=C(0);e=z[d+12>>2];a:{if(!(e<C(0))){c=C(1);if(!(e>C(1))){break a}}z[d+12>>2]=c}lb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);hb=d+16|0}function $y(a,b,c,d){var e=0,f=0,g=0;e=Pd(a);a:{if(e){f=gc(a);while(1){a=e;e=x[a+16>>1];g=v[a+20>>2];if(el(c,d,e,g)){f=a;e=v[a>>2];if(e){continue}break a}if(!el(e,g,c,d)){break a}f=a+4|0;e=v[a+4>>2];if(e){continue}break}break a}a=gc(a);f=a}v[b>>2]=a;return f}function cX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;f=v[b+8>>2];a:{if(f>>>0<=c>>>0){c=v[d>>2];b=0;break a}v[e+12>>2]=f-c;v[e+8>>2]=v[d+4>>2];c=v[b+4>>2]+c|0;f=c;b=v[Hb(e+12|0,e+8|0)>>2];g=c+b|0;c=v[d>>2];Mi(f,g,c)}ec(a,c,b);hb=e+16|0}function Wk(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;v[e+8>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=hb-16|0;hb=c;d=qc(c+8|0,v[a>>2]);f=v[d>>2];g=v[d+4>>2];d=v[e+8>>2];d=Mc(f,g,v[d>>2],v[d+4>>2]);hb=c+16|0;if(!d){break a}b=a}hb=e+16|0;return b}a=a+8|0;continue}}function Ay(a,b,c,d){var e=0,f=0,g=0;e=Pd(a);a:{if(e){f=gc(a);while(1){a=e;e=w[a+16|0];g=v[a+20>>2];if(Gn(c,d,e,g)){f=a;e=v[a>>2];if(e){continue}break a}if(!Gn(e,g,c,d)){break a}f=a+4|0;e=v[a+4>>2];if(e){continue}break}break a}a=gc(a);f=a}v[b>>2]=a;return f}function uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;_f(b);t[c+15|0]=0;a:{if(!Oh(a,c+15|0)){break a}f=w[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}t[c+14|0]=0;if(Oh(a,c+14|0)){Wp(b,t[c+14|0]);e=e+1|0;continue}break}d=0}hb=c+16|0;return d|0}function v9(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Kb(c+16|0);v[23516]=0;v[c>>2]=v[c>>2]&-1332|1058;v[c+4>>2]=1;U(99,a|0,b|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){Lj(c);hb=c+32|0;return}a=P()|0;O()|0;Lj(c);S(a|0);L()}function ZB(a,b,c){var d=0,e=0;d=hb+-64|0;hb=d;e=d+40|0;Mf(e,a,c);a=v[d+40>>2];c=d+8|0;bg(c,3,Ee(e),a);v[23516]=0;R(221,d+24|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){a=d+24|0;wl(b,a);wb(a);Qc(d+40|0);hb=d- -64|0;return}a=P()|0;O()|0;Qc(d+40|0);S(a|0);L()}function U$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function X_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;v[g+8>>2]=b;bd(g,d);v[23516]=0;b=T(1153,g|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){Zb(g);YF(a,f+24|0,g+8|0,c,e,b);hb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Zb(g);S(a|0);L()}function W_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;v[g+8>>2]=b;bd(g,d);v[23516]=0;b=T(1153,g|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){Zb(g);XF(a,f+16|0,g+8|0,c,e,b);hb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Zb(g);S(a|0);L()}function Gba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=b;d=hb-16|0;hb=d;b=nf(a,c);ke(d,v[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!zb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}c=v[b+16>>2]}lz(v[a+36>>2],e,c);f=1;g=b}Ve(a,g);hb=d+16|0;return f|0}function Pw(a){var b=0,c=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;if(v[a+20>>2]!=v[a+28>>2]){lb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function i8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b:{e=v[a+20>>2];c=v[e+4>>2];if((ad(c,v[e+8>>2])|0)!=7){break b}if(Qb(c,9585,4)){break b}b=Cb(c);c=Cb(v[v[a+20>>2]+8>>2]);yo(d+8|0,a+4228|0);lh(b,c,v[d+8>>2]);break a}Hx(a,b)}Cs(a);hb=d+16|0}function b$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;v[g+8>>2]=b;bd(g,d);v[23516]=0;b=T(19,g|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){Zb(g);$F(a,f+24|0,g+8|0,c,e,b);hb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Zb(g);S(a|0);L()}function a$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;v[g+8>>2]=b;bd(g,d);v[23516]=0;b=T(19,g|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){Zb(g);_F(a,f+16|0,g+8|0,c,e,b);hb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Zb(g);S(a|0);L()}function PU(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[ef(d+15|0,d+14|0)|0]}a=e;hb=d+16|0;return a&255}function qA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;qS(a,b);Zc(a,_b(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))+504|0);pS(a,d);a:{b=_b(w[b+32|0]|w[b+33|0]<<8|(w[b+34|0]<<16|w[b+35|0]<<24));if(!b){break a}if(!Zc(a,b)){break a}sA(a,c);return}Rb(c,0,80)}function Oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{if((b|0)!=437){if((b|0)==1252){break b}d=0;if((b|0)==65001){break a}c:{if((b|0)!=28591){if((b|0)==28605){break c}if((b|0)!=20127){break b}d=1;break a}d=2;break a}d=3;break a}d=5;break a}d=8}_C(a,d,c)}function l2(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;if(!w[a+8|0]){Oi(a+12|0,v[a+4>>2]);oe(b+24|0,v[a+12>>2],v[a+16>>2]);c=v[v[a>>2]+40>>2];d=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=d;lb[c|0](b+16|0,a,0,b+8|0);t[a+8|0]=1}hb=b+32|0;return v[a+12>>2]}function cja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-160|0;hb=b;e=-1;c=hb-16|0;hb=c;YT(c+8|0,b);d=v[c+12>>2];id(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(f|0);if(!a){XT(b)}if(a){e=ZT(b)}hb=b+160|0;return e|0}function bA(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-1024|0;hb=e;d=hb-16|0;hb=d;_z(d+8|0,e);f=v[d+12>>2];jc(d,v[a>>2],v[a+8>>2],v[d+8>>2],f);g=v[d+4>>2];if((g|0)==(f|0)){Yb(a,v[d+12>>2])}hb=d+16|0;if((f|0)==(g|0)){h=$z(e,c)>>>0<=b>>>0}hb=e+1024|0;return h}function _2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=v[b>>2];e=v[b+8>>2];f=v[b+4>>2];a=0;a:while(1){if((a|0)!=(f|0)){g=(a<<2)+d|0;b=0;while(1)if((b|0)==(e|0)){a=a+1|0;continue a}else{c=v[g>>2]+(b<<3)|0;v[c>>2]=0;v[c+4>>2]=0;b=b+1|0;continue}}break}}function Xv(a,b,c,d,e,f){var g=0;g=hb-16|0;hb=g;v[g+12>>2]=e;v[g+8>>2]=d;d=Bg(g,g+8|0);e=v[d+4>>2];d=v[d>>2];v[23516]=0;a=ga(f|0,a|0,b|0,c|0,d|0,e|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){je(g+8|0);hb=g+16|0;return a}a=P()|0;O()|0;je(g+8|0);S(a|0);L()}function Qea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-208|0;hb=b;e=-1;c=hb-16|0;hb=c;wQ(c+8|0,b);d=v[c+12>>2];id(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(f|0);if(!a){vQ(b)}if(a){e=xQ(b)}hb=b+208|0;return e|0}function aG(a,b,c){var d=0,e=0,f=0;d=a;a:{if(b>>>0<1073741808){b:{if(b>>>0<=1){Xd(d,1);break b}e=Tl(b)+1|0;f=Ai(e);td(d,f);bf(d,e);xd(d,b);d=f}e=b;f=d;while(1){v[f>>2]=c;f=f+4|0;e=e-1|0;if(e){continue}break}td((b<<2)+d|0,0);break a}df();L()}return a}function vr(a,b,c,d){var e=0;e=hb-32|0;hb=e;v[e+8>>2]=-1;v[e+12>>2]=0;v[e>>2]=0;Kb(e+16|0);v[e+4>>2]=d;v[23516]=0;v[e>>2]=v[e>>2]&-1332|1058;U(c|0,a|0,b|0,e|0);a=v[23516];v[23516]=0;if((a|0)!=1){bm(e);hb=e+32|0;return}a=P()|0;O()|0;bm(e);S(a|0);L()}function OE(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;v[b>>2]=0;t[c+15|0]=0;Oh(a,c+15|0);d=w[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){v[b>>2]=e;if((d|0)==(f|0)){hb=c+16|0}else{t[c+15|0]=0;Oh(a,c+15|0);d=d+1|0;e=v[b>>2]|w[c+15|0]<<(d<<3)-2;continue}break}}function xQ(a){var b=0;a:{if(Qb(a,15103,4)){break a}if(Eb(w[a+4|0]|w[a+5|0]<<8)>>>0>2|w[a+6|0]>128){break a}if(Eb(w[a+200|0]|w[a+201|0]<<8)>>>0>3999){break a}if(!Eb(w[a+140|0]|w[a+141|0]<<8)){break a}b=(Eb(w[a+148|0]|w[a+149|0]<<8)|0)==50}return b}function iW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-48|0;hb=b;e=-1;c=hb-16|0;hb=c;tC(c+8|0,b);d=v[c+12>>2];id(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(f|0);if(!a){sC(b)}if(a){e=uC(b)}hb=b+48|0;return e|0}function zr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;d=_c(a);e=Fb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=wc(a);Ce(d+e|0,b,c);b=c+e|0;th(a,b);t[f+15|0]=0;$d(b+d|0,f+15|0);break a}cp(a,d,(c+e|0)-d|0,e,e,0,c,b)}hb=f+16|0;return a|0}function zH(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=zH(a*0x10000000000000000,b);c=v[b>>2]+-64|0}v[b>>2]=c;return a}v[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function Ml(a,b,c,d,e,f){var g=0;g=hb-32|0;hb=g;v[g+8>>2]=-1;v[g+12>>2]=0;v[g>>2]=0;Kb(g+16|0);v[g+4>>2]=f;v[23516]=0;v[g>>2]=v[g>>2]&e|d;U(c|0,a|0,b|0,g|0);a=v[23516];v[23516]=0;if((a|0)!=1){Lj(g);hb=g+32|0;return}a=P()|0;O()|0;Lj(g);S(a|0);L()}function gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;Bq(e,c);_i(d+8|0,e);v[23516]=0;X(299,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23516];v[23516]=0;if((a|0)!=1){Ub(d+16|0);hb=d+32|0;break a}a=P()|0;O()|0;Ub(d+16|0);S(a|0);L()}}function _ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;AA(e,c);_i(d+8|0,e);v[23516]=0;X(112,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23516];v[23516]=0;if((a|0)!=1){ac(d+16|0);hb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);S(a|0);L()}}function Yr(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=ba(16)|0;nF();a=fc(c+8|0,a,94048);c=v[a+4>>2];a=v[a>>2];v[23516]=0;a=fa(1117,d|0,a|0,c|0,b|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){ia(a|0,92016,1118);L()}a=P()|0;O()|0;ca(d|0);S(a|0);L()}function Wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;Uo(e,c);_i(d+8|0,e);v[23516]=0;X(112,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23516];v[23516]=0;if((a|0)!=1){ac(d+16|0);hb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);S(a|0);L()}}function Vfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;wp(e,c);_i(d+8|0,e);v[23516]=0;X(299,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23516];v[23516]=0;if((a|0)!=1){Ub(d+16|0);hb=d+32|0;break a}a=P()|0;O()|0;Ub(d+16|0);S(a|0);L()}}function V_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=hb-16|0;hb=a;v[a+8>>2]=b;bd(a,d);v[23516]=0;b=T(1153,a|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){Zb(a);WF(f+20|0,a+8|0,c,e,b);hb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Zb(a);S(b|0);L()}function UO(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;aq(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){Ki(v[d>>2],x[c>>1]);v[d>>2]=v[d>>2]+2;c=c+2|0;continue}break}oc(a,e);oc(a+4|0,d);oc(Db(a),zc(b));v[b>>2]=v[b+4>>2];return f}function Oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;wT(e,c);_i(d+8|0,e);v[23516]=0;X(112,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23516];v[23516]=0;if((a|0)!=1){ac(d+16|0);hb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);S(a|0);L()}}function EA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Lb(a+8|0);v[23516]=0;d=T(200,b|0)|0;e=v[23516];v[23516]=0;b:{if((e|0)==1){break b}v[23516]=0;U(246,a|0,b|0,d|0);a=v[23516];v[23516]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;dc(c);S(a|0);L()}}function qC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;Ou(e,c);_i(d+8|0,e);v[23516]=0;X(112,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23516];v[23516]=0;if((a|0)!=1){ac(d+16|0);hb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);S(a|0);L()}}function pU(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;aq(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){nd(v[d>>2],w[c|0]);v[d>>2]=v[d>>2]+1;c=c+1|0;continue}break}oc(a,e);oc(a+4|0,d);oc(Db(a),zc(b));v[b>>2]=v[b+4>>2];return f}function SU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;LB(e,c);_i(d+8|0,e);v[23516]=0;X(112,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23516];v[23516]=0;if((a|0)!=1){ac(d+16|0);hb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);S(a|0);L()}}function RD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;bn(e,c);_i(d+8|0,e);v[23516]=0;X(112,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23516];v[23516]=0;if((a|0)!=1){ac(d+16|0);hb=d+32|0;break a}a=P()|0;O()|0;ac(d+16|0);S(a|0);L()}}function Pv(a,b,c,d,e){var f=0;f=hb-32|0;hb=f;v[f+8>>2]=-1;v[f+12>>2]=0;v[f>>2]=0;v[f+4>>2]=0;Kb(f+16|0);v[23516]=0;v[f>>2]=v[f>>2]&e|d;U(c|0,a|0,b|0,f|0);a=v[23516];v[23516]=0;if((a|0)!=1){Lj(f);hb=f+32|0;return}a=P()|0;O()|0;Lj(f);S(a|0);L()}function J9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;c=nf(a,c);ke(e,v[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);f=-1;if(!zb(v[v[e>>2]>>2],v[e+4>>2])){break b}break a}f=v[c+16>>2]}lb[d|0](v[a+36>>2],b,f);g=c}Ve(a,g);hb=e+16|0}function tO(a){var b=0,c=0,d=0,e=0,f=0;b=hb-16|0;hb=b;c=a;d=v[a>>2];f=ik(d,v[a+4>>2]);a=Cb(d);v[b+8>>2]=a;e=+(f>>>0);c=Cb(v[c+4>>2]);while(1){if(Nb(a,c)){A[a>>3]=A[a>>3]/e;A[a+8>>3]=A[a+8>>3]/e;a=v[$p(b+8|0)>>2];continue}else{hb=b+16|0}break}}function qD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function ap(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function SB(a){var b=0,c=0,d=0,e=0;b=w[a+2|0];c=b+(w[a+5|0]|w[a+6|0]<<8)|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;a=w[a+3|0]|w[a+4|0]<<8;d=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;kb=a;return b}function $_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=hb-16|0;hb=a;v[a+8>>2]=b;bd(a,d);v[23516]=0;b=T(19,a|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){Zb(a);ZF(f+20|0,a+8|0,c,e,b);hb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Zb(a);S(b|0);L()}function pd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;g=v[b+8>>2];f=v[b>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[f>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;lb[c|0](a,f,g,e);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];hb=e+16|0}function aA(a,b,c){var d=0;d=hb-16|0;hb=d;u[d+12>>1]=c;u[d+14>>1]=b;b=Cb(v[a>>2]);c=Cb(v[a+4>>2]);a=hb-16|0;hb=a;v[a+8>>2]=b;while(1){if(Nb(b,c)){if(x[b>>1]==x[d+14>>1]){u[b>>1]=x[d+12>>1]}b=v[Qe(a+8|0)>>2];continue}break}hb=a+16|0;hb=d+16|0}function IY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;if(d>>>0<4294967280){a:{if(d>>>0<=10){Xd(a,c);break a}f=ih(d)+1|0;d=tc(f);td(a,d);bf(a,f);xd(a,c);a=d}a=Ce(a,b,c);t[e+15|0]=0;$d(a+c|0,e+15|0);hb=e+16|0;return}df();L()}function DN(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=v[a+104>>2];a:{if(!c){break a}c=v[c>>2];if(!c){break a}v[a+76>>2]=c;v[a+88>>2]=v[a+88>>2]&-131|128;v[d+12>>2]=b<<8;v[d+8>>2]=c-1;b=c+(v[Hb(d+12|0,d+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}hb=d+16|0}function aD(a){var b=0,c=0;a:{if(Qb(a,14264,4)){break a}if(Qb(a+8|0,14185,4)){break a}b=_b(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24));if(!b){break a}c=(_b(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function BK(a,b,c){var d=0,e=0;if(C(D(a))<C(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return C((e?b^-1|e:b)|0)}function yE(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;v[e+12>>2]=c;c=e+12|0;uc(c,d);uc(c,65535);d=x[e+12>>1];tg(a,d);c=0;while(1){if((c|0)==(d|0)){hb=e+16|0}else{f=w[b+c|0];g=yl(v[a>>2],v[a+4>>2],c),h=f,u[g>>1]=h;c=c+1|0;continue}break}}function r3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-32|0;hb=d;Zk(d,c);c=d+16|0;v[c>>2]=b;Xc(c+4|0,d);v[23516]=0;R(1076,a+4|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){qs(d+16|0);wb(d);hb=d+32|0;return}a=P()|0;O()|0;qs(d+16|0);wb(d);S(a|0);L()}function nia(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;t[b+30|0]=0;u[b+28>>1]=0;c=fc(b+8|0,b+28|0,3);jc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=3){break a}if(Qb(b+28|0,14836,3)){break a}Yb(a,3);d=1}hb=b+32|0;return d|0}function jea(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;u[b+28>>1]=0;v[b+24>>2]=0;c=fc(b+8|0,b+24|0,6);jc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=6){break a}if(Qb(b+24|0,3856,6)){break a}Yb(a,6);d=1}hb=b+32|0;return d|0}function fe(a,b){var c=0,d=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if(v[a+8>>2]>=(d|0)){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=w[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function TN(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function Mf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lb(a+8|0);v[23516]=0;U(246,a|0,b|0,c|0);c=v[23516];v[23516]=0;a:{if((c|0)!=1){a=v[a>>2];v[23516]=0;Q(186,b|0,a|0)|0;a=v[23516];v[23516]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;dc(d);S(a|0);L()}}function LM(a,b){a=IM(a);IM(a+368680|0);if(b){HM(a,1);return}if(!w[462936]){LM(94232,1);t[462936]=1}Qn(225344,290880,a+131112|0);Qn(290880,356416,a+196648|0);Qn(356416,421952,a+262184|0);Qn(94256,225344,a+24|0);pc(a+327720|0,421952,40960)}function EQ(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if((b|0)!=26&(b|0)!=2|w[a+30|0]!=2){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=CQ(a+20|0)}return c}function Sv(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;u[b>>1]=0;t[c+15|0]=0;Oh(a,c+15|0);d=w[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){u[b>>1]=e;if(d>>>0>=f>>>0){hb=c+16|0}else{t[c+15|0]=0;Oh(a,c+15|0);e=x[b>>1]|w[c+15|0]<<7;d=1;continue}break}}function Jja(a,b){a=a|0;b=b|0;var c=0;b=hb-32|0;hb=b;c=-1;a:{if(!mB(a,b+16|0)){break a}c=0;if(!yU(b+16|0)){break a}if(!Qb(b+16|0,14250,4)){c=-1;if(!dd(a,4)){break a}}c=-1;if(!Nj(a,b+8|0)){break a}c=!Qb(b+8|0,14226,4)}hb=b+32|0;return c|0}function Ef(a,b,c){var d=0;a:{if(y[b+8>>2]<c>>>0){v[23516]=0;X(1095,17479,9139,393,6384);a=v[23516];v[23516]=0;if((a|0)==1){break a}L()}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c;return}V(0)|0;O()|0;Tb();L()}function jN(a,b){var c=0,d=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}c=v[c>>2];b:{if(c){d=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[d+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[b>>2]=a}}function Ega(a,b){a=a|0;b=b|0;var c=0;a=Lb(a);a:{if(!b){break a}v[23516]=0;R(584,a|0,b|0);c=v[23516];v[23516]=0;if((c|0)!=1){v[23516]=0;R(585,a|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;gA(a);S(b|0);L()}return a|0}function li(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;e=v[a+4>>2];d=v[a+44>>2]-e|0;v[a+120>>2]=d;v[a+124>>2]=d>>31;d=a;a=v[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}v[d+104>>2]=a}function dW(a,b){a=a|0;b=b|0;var c=0;a=Lb(a);a:{if(!b){break a}v[23516]=0;R(228,a|0,b|0);c=v[23516];v[23516]=0;if((c|0)!=1){v[23516]=0;R(229,a|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;Nc(a);S(b|0);L()}return a|0}function UT(a){var b=0,c=0,d=0,e=0;b=w[a+3|0];c=rka(b>>>0<3?48:64,0,Eb(w[a+196|0]|w[a+197|0]<<8),0);d=kb;e=c;c=rka(rka(Eb(w[a+198|0]|w[a+199|0]<<8),0,b>>>0<4?4:5,0),kb,Eb(w[a+200|0]|w[a+201|0]<<8),0);b=e+c|0;b=b+512|0;a=b;kb=0;return a}function BN(a,b){var c=0,d=0;a:{if(!(t[a+851|0]&1)){break a}c=v[a+104>>2];if(!c){break a}d=v[c>>2];if(!d){break a}v[a+76>>2]=d;v[a>>2]=0;v[a+4>>2]=d-1;c=v[a+88>>2];v[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}v[a+84>>2]=d;v[a+80>>2]=0}}function q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=b;d=hb-16|0;hb=d;b=nf(a,c);ke(d,v[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!zb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}c=v[b+16>>2]}lz(v[a+36>>2],e,c);f=b}Ve(a,f);hb=d+16|0}function wN(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;Ab(d+8|0,a+1074312|0,80);if(!(!e|!zb(v[v[d+8>>2]>>2],v[d+12>>2]))){t[b+824|0]=w[b+824|0]<<2}hb=d+16|0}function Aha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;while(1){a:{d=v[a>>2];if(sc(d,v[a+4>>2])>>>0>e>>>0){Jl(c,v[Bb(d,e)>>2]+40|0);d=hq(c,b);xb(c);if(!d){break a}f=v[Bb(v[a>>2],e)>>2]}hb=c+16|0;return f|0}e=e+1|0;continue}}function e8(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Qb(b,9585,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4228>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4232>>2]=c;Cs(a)}}function Vi(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function Q8(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Qb(b,9585,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4264>>2]=c;Fs(a)}}function k0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((lb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=rk(b,4,c,v[a+32>>2])}return c|0}function aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=vf(v[b>>2],v[b+4>>2]);c=JP(d+8|0,c);v[23516]=0;X(745,a|0,b|0,e-1&65535,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){Ue(c);hb=d+32|0;return}a=P()|0;O()|0;Ue(c);S(a|0);L()}function VP(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,872);a=v[c+4>>2];b=v[c+8>>2];while(1){if((a|0)==(b|0)){ic(c);hb=c+16|0}else{UP(Rb(a,0,872));a=a+872|0;v[c+4>>2]=a;continue}break}}function hM(a){var b=0,c=0,d=0;c=hb-544|0;hb=c;a:{if(!(w[a+480210|0]&128)|!v[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=Ez(c,v[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}pc(b+112|0,a,538);b=b+872|0;continue}}hb=c+544|0}function G9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;c=nf(a,c);ke(d,v[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!zb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}e=v[c+16>>2]}fT(v[a+36>>2],b,e);f=c}Ve(a,f);hb=d+16|0}function Ez(a,b){var c=0,d=0,e=0,f=0;u[a+24>>1]=0;v[a+20>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[a+16>>2]=b;v[a>>2]=0;v[a+4>>2]=0;e=a,f=dQ(c-+(b<<2)),v[e+8>>2]=f;v[a+12>>2]=kb;return a}function By(a,b,c){var d=0,e=0;d=Pd(a);a:{if(d){e=gc(a);while(1){a=d;d=w[a+16|0];if(Hn(c,d)){e=a;d=v[a>>2];if(d){continue}break a}if(!Hn(d,c)){break a}e=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=gc(a);e=a}v[b>>2]=a;return e}function tfa(a,b){a=a|0;b=b|0;var c=0;b=hb-32|0;hb=b;c=-1;a:{if(!mB(a,b+16|0)){break a}c=0;if(!fR(b+16|0)){break a}c=-1;if(!Nj(a,b+8|0)){break a}c=0;if(!v[b+12>>2]){break a}a=v[b+8>>2];c=(a&2139062143)==(a|0)}hb=b+32|0;return c|0}function TD(){var a=0,b=0,c=0;b=hb-16|0;hb=b;a=Fc(b,14901);a:{if(!Fb(a)){break a}c=1;if((Cg(a,14732)|0)!=-1){break a}if((Cg(a,16896)|0)!=-1){break a}if((Cg(a,13794)|0)!=-1){break a}c=(Cg(a,13837)|0)!=-1}wb(a);hb=b+16|0;return c|0}function OD(a){var b=0;if(!(Qb(a,13386,8)|(w[a+8|0]|w[a+9|0]<<8)!=14|(!(w[a+12|0]|w[a+13|0]<<8)|(w[a+14|0]|w[a+15|0]<<8|(w[a+16|0]<<16|w[a+17|0]<<24))<=0))){b=(w[a+18|0]|w[a+19|0]<<8|(w[a+20|0]<<16|w[a+21|0]<<24))>>>0>23}return b}function C9(a,b){a=a|0;b=b|0;var c=0,d=0;a=Lb(a);a:{b:{c=sc(v[b>>2],v[b+4>>2]);if(c){v[23516]=0;R(227,a|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break b}lA(a,v[b>>2],v[b+4>>2],c)}break a}b=P()|0;O()|0;lc(a);S(b|0);L()}return a|0}function sja(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Ob(v[a>>2],v[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){zo((a<<1)+b|0);a=a+1|0;continue}break}break a}su(c+8|0,b);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0;return d|0}function ig(a,b){var c=0,d=0,e=0,f=0;d=x[a+22>>1];e=d+x[a+20>>1]|0;c=x[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-B(v[Bb(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;continue}break}return a}function hS(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){e=v[a+4>>2];f=e>>>8|0;d=v[a>>2];e=(e&255)<<24|d>>>8;d=(((d^w[b|0])&255)<<3)+21824|0;g=v[d>>2];d=v[d+4>>2]^f;v[a>>2]=e^g;v[a+4>>2]=d;b=b+1|0;continue}break}return a}function a3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=v[b>>2];d=v[b+8>>2];e=v[b+4>>2];a=0;a:while(1){if((a|0)!=(e|0)){f=(a<<2)+c|0;b=0;while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{v[v[f>>2]+(b<<2)>>2]=0;b=b+1|0;continue}}break}}function EV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Ob(v[a>>2],v[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){Ch(a+b|0);a=a+1|0;continue}break}break a}ec(c+8|0,b,120);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0;return d|0}function Iea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;v[c+12>>2]=477218588;v[c+8>>2]=2147483647;d=Hb(c+12|0,c+8|0);hb=c+16|0;if(y[d>>2]<b>>>0){rd();L()}c=B(b,9);b=tc(c);v[a>>2]=b;v[a+4>>2]=b;e=Db(a),f=b+c|0,v[e>>2]=f}function vi(a){var b=0,c=0,d=0,e=0;e=Je(a);c=e&63;a:{if(!(e&64)){break a}b=6;while(1){d=Je(a);c=(d&127)<<b|c;if(!(d&128)){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}a=e>>>7|0;b=a?-2147483648:c;return a?(c|0)>=0?0-c|0:b:b}function qB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=v[a>>2];f=sk(e,v[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=ag(e,c);if(!Nb(v[c>>2],v[c+4>>2])){break a}d=d+1|0;continue}break}return(kh(a,d&65535,b)?d:-1)&65535}function aga(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;u[b+30>>1]=0;c=fc(b+8|0,b+30|0,2);jc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=2){break a}if(Qb(b+30|0,13702,2)){break a}Yb(a,2);d=1}hb=b+32|0;return d|0}function XL(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Dc(ska(rka(d,d>>31,g,h),kb,256,0),kb);v[a+4>>2]=f-d;v[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function Sja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;mv(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function uu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;if(b){e=_c(a);d=Fb(a);g=d+b|0;if(e-d>>>0<b>>>0){im(a,e,g-e|0,d,d,0,0)}e=d;d=wc(a);vB(e+d|0,b,c);th(a,g);t[f+15|0]=0;$d(d+g|0,f+15|0)}hb=f+16|0;return a|0}function ska(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=uka(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;kb=(g^kb)-((a>>>0<f>>>0)+g|0)|0;return b}function IN(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(!c){break a}v[b+40>>2]=c;if(!c|v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Vc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=Nz(c&255),v[e+44>>2]=f}hb=d+16|0}function pA(a,b){var c=0,d=0,e=0,f=0;c=a<<8;d=c&16711680;c=e;e=a<<24|d;f=c;d=b<<24|a>>>8;c=b<<8|a>>>24;a=f|(((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24));kb=e|(d&65280|c&255);return a}function jia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;yA(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,4896)}return a|0}function Ps(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=43996;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=43848;break a;case 2:c=43844;break a;case 1:break b;case 0:break c}}c=43840;break a}c=43836}v[a>>2]=v[c>>2]}function Nd(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+22>>1];g=d+x[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0<2048){break a}u[a+20>>1]=c-d}return}c=c+1|0;continue}}function oia(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;v[a+480180>>2]=b;oq(c,pq(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;Ps(a+8|0,pq(a));hb=c+16|0}function Tp(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(A[b-8>>3]-A[a>>3]);b=0;while(1){if((b|0)!=2048){d=-se(f*A[_e(a,b)>>3]);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Bb(c,b),h=e,v[g>>2]=h;b=b+1|0;continue}break}}function fW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;Ru(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,65)}return a|0}
function dha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;vA(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,33)}return a|0}function UA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=rl(a);e=wd(v[a+4>>2],w[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=qd(a);Ce(d+e|0,b,c);b=c+e|0;io(a,b);nd(b+d|0,0);return a|0}mq(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Ob(v[a>>2],v[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){Ch(a+b|0);a=a+1|0;continue}break}break a}eB(c+8|0,b);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0;return d|0}function DE(a,b,c,d,e){var f=0;f=hb-32|0;hb=f;v[f+24>>2]=a;v[f+28>>2]=b;v[f+16>>2]=d;v[f+20>>2]=e;v[f+8>>2]=c;v[f+12>>2]=0;a=MB(f+24|0,f+8|0);b=f+16|0;a=pr(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?a:b;hb=f+32|0;return v[a>>2]}function AN(a,b,c,d){var e=0;a=$c(Ln(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=bl(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=$c(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function gL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;og(a+12|0,d);if(b){if(b>>>0>=2097152){Zf(11191);L()}d=tc(b<<11)}else{d=0}v[a>>2]=d;c=d+(c<<11)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<11)|0,v[e>>2]=f;return a|0}function Dt(a,b){var c=0,d=0,e=0;if(v[a>>2]){fV(a);c=v[a>>2];yB(a);Jb(c);d=Db(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Db(b);d=Db(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function ds(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!ax(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Ye(a)}return b}aa(15810,13226,1578,5432);L()}function dN(a,b){var c=0,d=0,e=0,f=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];d=Db(a);c=gc(a);a:{if(!v[d>>2]){v[a>>2]=c;break a}v[v[c>>2]+8>>2]=c;c=gc(b);v[b>>2]=c;v[c>>2]=0;e=Db(b),f=0,v[e>>2]=f}return a}function Mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;a:{if(a){lb[v[v[a>>2]+8>>2]](a,b,c);break a}if(!tT(d+8|0,b)){break a}v[d+24>>2]=0;a=wM(d+24|0);e=d+8|0;vM(e,9182,10860,140,42);hE(a,e,b,13282,c)}hb=d+32|0}function MZ(a){a=a|0;if(w[468144]){return v[117035]}if(!w[469304]){a=469280;while(1){a=Kb(a)+12|0;if((a|0)!=469304){continue}break}t[469304]=1}ld(469280,89520);ld(469292,89532);t[468144]=1;v[117035]=469280;return 469280}function GQ(a,b,c){var d=0;d=hb-16|0;hb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){t[d+14|0]=(x[(b<<1)+32798>>1]-x[(c<<1)+32798>>1]|0)/5;a=w[Vb(d+15|0,d+14|0)|0]}hb=d+16|0;return a&255}function FZ(a){a=a|0;if(w[468136]){return v[117033]}if(!w[469272]){a=469248;while(1){a=Kb(a)+12|0;if((a|0)!=469272){continue}break}t[469272]=1}kd(469248,13944);kd(469260,13923);t[468136]=1;v[117033]=469248;return 469248}function rha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=-1;a:{if(!Nj(a,d+8|0)){break a}e=v[d+12>>2];c=0;if(!(v[d+8>>2]==(Lm(9007)|0)&e>>>0>255&e>>>0<260)){break a}c=we(a,b,e>>>0<259?80:76,0)}hb=d+16|0;return c|0}function ms(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;d=v[b>>2];b=sc(d,v[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){hb=c+16|0}else{v[c+8>>2]=0;e=wh(c+8|0);f=Bb(d,a),g=v[e>>2],v[f>>2]=g;a=a+1|0;continue}break}}function ku(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;if(c>>>0<4294967280){a:{if(c>>>0<=10){Xd(a,c);break a}e=ih(c)+1|0;f=tc(e);td(a,f);bf(a,e);xd(a,c);a=f}a=Ce(a,b,c);t[d+15|0]=0;$d(a+c|0,d+15|0);hb=d+16|0;return}df();L()}function _7(a){a=a|0;var b=0;lb[v[v[a>>2]+132>>2]](a);yx(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=lb[v[v[a>>2]+196>>2]](a)|0;v[a+4328>>2]=0;v[a+4312>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4324>>2]=b;v[a+4320>>2]=b}function XM(a,b,c,d){var e=0,f=0;e=v[(B(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=x[(B(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=w[((b<<5)+a|0)+480288|0]}return f}function Oz(a,b){a=a|0;b=b|0;var c=0,d=0;a=Lb(a);a:{c=ad(v[b>>2],v[b+4>>2]);if(c){v[23516]=0;R(322,a|0,c|0);d=v[23516];v[23516]=0;if((d|0)==1){break a}Wt(a,v[b>>2],v[b+4>>2],c)}return a|0}b=P()|0;O()|0;dc(a);S(b|0);L()}function AS(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Yp(a,b,c){var d=0;d=hb-16|0;hb=d;Ab(d+8|0,c+1074312|0,102);a:{if(!zb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;hb=d+16|0}function Xx(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;a:{if(!c){a=Gd(v[a>>2],b);A[a+8>>3]=e;A[a>>3]=d;break a}g=c>>>1|0;Xx(a,b,g,d,e);h=Gd(v[a>>2],c);wi(f,d,e,A[h>>3],A[h+8>>3]);Xx(a,b|c,g,A[f>>3],A[f+8>>3])}hb=f+16|0}function HO(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function Fq(a){var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;b=hb-16|0;hb=b;Pq(b+8|0,c+15|0);d=v[b+12>>2];id(b,a,v[b+8>>2],d);e=v[b+4>>2];if((e|0)==(d|0)){dd(a,v[b+12>>2])}hb=b+16|0;hb=c+16|0;return((d|0)==(e|0)?w[c+15|0]:0)&255}function yba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;AO(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){ez(b)}return a|0}function rka(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;kb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function nT(a){var b=0;a:{b:{if(Qb(a,13921,4)){if(Qb(a,16377,4)){break a}if((w[a+34|0]|w[a+35|0]<<8)>>>0<=255){break b}break a}if((w[a+34|0]|w[a+35|0]<<8)>>>0>255){break a}}b=(w[a+36|0]|w[a+37|0]<<8)>>>0<4e3}return b}function lz(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:LO(a,b);return;default:break a}}d=hb-32|0;hb=d;v[d+28>>2]=c;u[d+24>>1]=0;v[d+12>>2]=2;kw(d+16|0,a,d+24|0,v[Hb(d+28|0,d+12|0)>>2]);u[b>>1]=x[d+24>>1];hb=d+32|0}function rC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;tC(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){sC(b)}return a|0}function nq(a,b,c){var d=0,e=0;e=x[a+480192>>1];a:{if(e){if(!Wc(b)|c>>>0>e>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[$b(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function _w(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!cs(a)){break a}if(!(t[a+1375|0]&1)){continue}break}bc(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function Mu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;bC(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){aC(b)}return a|0}function Et(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;gR(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){hR(b)}return a|0}function EH(a,b){var c=0,d=0,e=0;c=hb-256|0;hb=c;if((b|0)>=2){v[(b<<2)+a>>2]=c;pc(c,v[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;pc(v[e>>2],v[(d<<2)+a>>2],4);v[e>>2]=v[e>>2]+4;if((b|0)!=(d|0)){continue}break}}hb=c+256|0}function pO(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=e*A[a+16>>3]+(A[a>>3]*b+c*A[a+8>>3])-d*A[a+24>>3]-f*A[a+32>>3];A[a+56>>3]=b;return b}function un(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return C(b?-1/a:a)}function hm(a,b){var c=C(0),d=0,e=0;c=C(1);d=u[a+28>>1];a:{if((d|0)>(b|0)){break a}e=v[a+4>>2];if((sc(e,v[a+8>>2])+d<<16)-65536>>16<(b|0)){break a}c=z[Bb(e,b-d|0)>>2];c=c<=C(1.0000000036274937e-15)?C(1):c}return c}function gP(a){var b=0;b=u[a+784>>1];if(b){v[a+692>>2]=(b&32767)-1;if((b|0)<0){v[a+88>>2]=v[a+88>>2]|256}u[a+784>>1]=0}b=w[a+795|0];if(b){t[a+795|0]=0;t[a+838|0]=b-1}b=w[a+796|0];if(b){t[a+796|0]=0;t[a+837|0]=b-1}}function Mp(a,b){a=pc(a,b,88);v[a+88>>2]=v[b+88>>2];pc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];pc(a+672|0,b+672|0,52);Ey(a+724|0,b+724|0);Ey(a+732|0,b+732|0);Ey(a+740|0,b+740|0);pc(a+748|0,b+748|0,123);return a}function E_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ep(a);e=Fb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=wc(a);mi(d+(e<<2)|0,b,c);b=c+e|0;th(a,b);td(d+(b<<2)|0,0);return a|0}oF(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function Iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;c=nf(a,c);ke(e,v[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(zb(v[v[e>>2]>>2],v[e+4>>2])){break a}}bT(v[a+36>>2],b,d,0);f=c}Ve(a,f);hb=e+16|0}function rba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Lb(a);d=Xf(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[23516]=0;R(785,a|0,1);b=v[23516];v[23516]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;jO(d);iO(a);S(b|0);L()}function TS(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,6)+e;a=v[d>>2];while(1){if(v[d+4>>2]!=(a|0)){Ut(a,c);a=v[d>>2]+6|0;v[d>>2]=a;continue}break}Kd(d);hb=d+16|0}function wk(a){uc(a+16|0,v[a>>2]);uc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function YO(a,b,c,d){var e=0;e=hb-16|0;hb=e;a=$h(e,a,d);d=hb-16|0;hb=d;v[d+8>>2]=b;while(1){if(Nb(b,c)){Ki(v[a+4>>2],x[b>>1]);b=Qe(d+8|0);v[a+4>>2]=v[a+4>>2]+2;b=v[b>>2];continue}break}hb=d+16|0;ic(a);hb=e+16|0}function KC(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Ob(v[a>>2],v[a+8>>2],1)){break b}t[c+15|0]=0;xg(a,c+15|0);d=t[c+15|0]}hb=c+16|0;a=d;break a}aa(11259,9108,136,14288);L()}return a}function t9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;c=nf(a,c);ke(e,v[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(zb(v[v[e>>2]>>2],v[e+4>>2])){break a}}nL(d,v[a+36>>2],b);f=c}Ve(a,f);hb=e+16|0}function hy(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;bM(a+24648|0);hM(a)}function ei(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;ec(d+8|0,b,c);e=v[d+12>>2];jc(d,v[a>>2],v[a+8>>2],v[d+8>>2],e);f=v[d+4>>2];if((f|0)==(e|0)){Yb(a,v[d+12>>2])}hb=d+16|0;a=(e|0)==(f|0);if(!a){Rb(b,0,c)}return a}function aaa(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;a:{if(!Nj(a,b+8|0)){break a}c=0;if(!NL(v[b+8>>2],v[b+12>>2])){break a}a=IQ(a,b);if(!a){Fm(b)}c=-1;if(!a){break a}c=ML(v[b>>2])}a=c;hb=b+16|0;return a|0}function YG(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=lb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!sn(b)){break a}v[a>>2]=0}return a|0}function or(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;Wo(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Db(a),zc(b));v[b>>2]=v[b+4>>2]}function mD(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-36|0;qv(v[d>>2]-36|0,c);v[d>>2]=v[d>>2]-36;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Db(a),zc(b));v[b>>2]=v[b+4>>2]}function bw(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function aB(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-20|0;dB(v[d>>2]-20|0,c);v[d>>2]=v[d>>2]-20;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Db(a),zc(b));v[b>>2]=v[b+4>>2]}function _m(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;a:{if(c){Fc(d,c);break a}Kb(d)}v[23516]=0;U(11,a|0,b|0,d|0);a=v[23516];v[23516]=0;if((a|0)!=1){wb(d);hb=d+16|0;return}a=P()|0;O()|0;wb(d);S(a|0);L()}function MO(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-32|0;nz(v[d>>2]-32|0,c);v[d>>2]=v[d>>2]-32;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Db(a),zc(b));v[b>>2]=v[b+4>>2]}function F8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;a=gj(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=lb[e|0](a,c)|0}else{a=1}hb=c+16|0;return a|0}function Dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{a=Lb(a);b:{d=b+c|0;c=vh(b,d);if(c){v[23516]=0;R(344,a|0,c|0);e=v[23516];v[23516]=0;if((e|0)==1){break b}Wt(a,b,d,c)}break a}b=P()|0;O()|0;dc(a);S(b|0);L()}}function jy(a,b){var c=0;c=v[b+24>>2];v[a+24628>>2]=c?c>>>0<512?c:512:1;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}pc(a+24604|0,b,40);cM(a,c)}function dQ(a){a=a*4294967296;if(D(a)<0x8000000000000000){kb=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}kb=-2147483648;return 0}function Baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;v[a>>2]=v[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){ly(d,v[c+4>>2],v[c+8>>2])}pc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function BW(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;d=-1;a:{if(!bD(a,c+8|0)){break a}d=0;if(!aD(c+8|0)){break a}if(b){a=v[b>>2];if(!v[b+4>>2]&a>>>0<_b(v[c+12>>2])-8>>>0){break a}}d=1}hb=c+48|0;return d|0}function $z(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=CD(a);a:while(1){if((a|0)!=(e|0)){f=sd(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((w[Ib(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function dA(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;f=v[b+12>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[b>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;lb[c|0](a,b,f,e);v[b+12>>2]=v[b+12>>2]+v[a+4>>2];hb=e+16|0}function UM(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function Ns(a){var b=0;v[23516]=0;a=T(832,a|0)|0;b=v[23516];v[23516]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23516]=0;Z(18);b=v[23516];v[23516]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Tb();L()}function Fu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Ad(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Ob(v[a>>2],v[a+8>>2],1)){break b}t[c+15|0]=0;xg(a,c+15|0);d=w[c+15|0]}hb=c+16|0;break a}aa(11259,9108,136,14288);L()}return d}function h1(a,b){a=a|0;b=b|0;var c=0;a=us(a);v[a>>2]=77696;c=Kb(a+32|0);v[a+44>>2]=0;v[a+48>>2]=8;v[23516]=0;R(90,a|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;wb(c);Bn(a);S(b|0);L()}function xba(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],27)){a=0;while(1){if((a|0)!=27){Ch(a+b|0);a=a+1|0;continue}break}break a}AO(c+8|0,b);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function p3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;DJ(d,c);a=v[a+1298464>>2];v[23516]=0;U(384,a|0,b|0,d|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(d);hb=d+16|0;return}a=P()|0;O()|0;xb(d);S(a|0);L()}function kz(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=v[c>>2];if(d){Un(d);IO(v[c>>2])}b=b+1|0;continue}break}}function bea(a){a=a|0;var b=0;b=hb-16|0;hb=b;a:{if(qq(a,10284)){rJ(b,17670,a);a=Ic(b);v[23516]=0;R(39,44,a|0);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;wb(b);S(a|0);L()}hb=b+16|0;return}L()}function Xja(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],64)){a=0;while(1){if((a|0)!=64){Ch(a+b|0);a=a+1|0;continue}break}break a}su(c+8|0,b);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function Sk(a){a=a|0;var b=0;v[a>>2]=78892;v[23516]=0;R(68,a|0,0);b=v[23516];v[23516]=0;if((b|0)!=1){Zb(a+28|0);Jb(v[a+32>>2]);Jb(v[a+36>>2]);Jb(v[a+48>>2]);Jb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Tb();L()}function Dea(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;sm(a,b);b=Cb(v[a>>2]);v[c+8>>2]=b;a=Cb(v[a+4>>2]);while(1){if(Nb(b,a)){d=w[b|0]+(d&255)|0;t[b|0]=d;b=v[He(c+8|0)>>2];continue}else{hb=c+16|0}break}}function wR(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],32)){a=0;while(1){if((a|0)!=32){Ch(a+b|0);a=a+1|0;continue}break}break a}uR(c+8|0,b);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function Df(a,b,c,d,e){var f=0;f=hb-256|0;hb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Rb(f,b&255,d?c:256);if(!d){while(1){of(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}of(a,f,c)}hb=f+256|0}function p7(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=v[b+52>>2];if(c&16){d=v[b+48>>2];c=v[b+28>>2];if(d>>>0<c>>>0){v[b+48>>2]=c;d=c}Th(a,v[b+24>>2],d);break a}if(c&8){Th(a,v[b+12>>2],v[b+20>>2]);break a}Kb(a)}}function ee(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Md(b)}return c}function d7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;b=Dc(ska(rka(d,d>>31,b,0),kb,1e3,0),kb);v[a+16>>2]=0;v[a+12>>2]=b+c;rK(a,e);b=v[a+12>>2];v[f+12>>2]=0;qL(a,b,f+12|0);hb=f+16|0}function Zda(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;if((b|0)>=0){d=2147483647;a=nt(a);if(a>>>0<=1073741822){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Vc(c+12|0,c+8|0)>>2]}hb=c+16|0;return d|0}Bz();L()}function ZT(a){var b=0;a:{if(Qb(a,3873,4)|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(Qb(a+71|0,13782,4)|w[a+75|0]!=1|w[a+76|0]){break a}b=((w[a+116|0]|w[a+117|0]<<8)-1&65535)>>>0<9}return b}function t3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a=qt(e,a,d);v[23516]=0;U(1075,b|0,c|0,a+4|0);b=v[23516];v[23516]=0;if((b|0)!=1){ic(a);hb=e+16|0;return}b=P()|0;O()|0;ic(a);S(b|0);L()}function rL(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=_c(a);a:{if(d>>>0>=c>>>0){b=Xh(wc(a),b,c);t[e+15|0]=0;$d(b+c|0,e+15|0);th(a,c);break a}f=d;g=c-d|0;d=Fb(a);cp(a,f,g,d,0,d,c,b)}hb=e+16|0;return a}function qS(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;sS(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){rS(b)}return a}function lV(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],8)){a=0;while(1){if((a|0)!=8){Ch(a+b|0);a=a+1|0;continue}break}break a}Tm(c+8|0,b);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function e2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a=At(e,a,d);v[23516]=0;U(1106,b|0,c|0,a+4|0);b=v[23516];v[23516]=0;if((b|0)!=1){ic(a);hb=e+16|0;return}b=P()|0;O()|0;ic(a);S(b|0);L()}function Yg(a){var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;c=2;if(a>>>0>=2){v[b+12>>2]=a>>>1;v[b+8>>2]=a^-1;d=b,e=v[Hb(b+12|0,b+8|0)>>2]+a|0,v[d+12>>2]=e;v[b+8>>2]=-1;c=v[Hb(b+12|0,b+8|0)>>2]}hb=b+16|0;return c}function VF(a,b,c,d,e,f){var g=0,h=0,i=0;g=hb-16|0;hb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){Bh(g+13|0,g+14|0)}h=c,i=(ab(b|0,ad(b,v[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,v[h>>2]=i;hb=g+16|0}function $A(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;cU(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){dU(b)}return a}function xR(a,b){a=a|0;b=b|0;var c=0,d=0;d=v[a>>2];c=65535;a:{if(!te(d,v[a+4>>2],b)){break a}d=qB(a,v[ag(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=v[a>>2];a=ag(c,b);DL(ag(c,d),a);c=d}return c|0}function Zg(a,b){var c=0,d=0,e=0;c=Fb(a);a:{if((c|0)!=(Fb(b)|0)){break a}d=Ic(a);b=Ic(b);if(!Fe(a)){while(1){e=!c;if(!c|w[d|0]!=w[b|0]){break a}b=b+1|0;d=d+1|0;c=c-1|0;continue}}e=!Ip(d,b,c)}return e}function VX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;f=v[v[b>>2]+20>>2];e=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=e;e=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=e;lb[f|0](a,b,d,8);hb=d+16|0}function fK(a){var b=0,c=0,d=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(D(c)<2147483648){a=~~c;break a}a=-2147483648}d=C(ni(b-+(a|0)))}else{d=C(0)}return d}function QQ(a){var b=0,c=0,d=0;d=w[a+32|0]|w[a+33|0]<<8;b=w[a+34|0]|w[a+35|0]<<8;a=b+(w[a+36|0]|w[a+37|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<1|a>>>31;b=b<<1;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;kb=a;return c}function JX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;v[e+12>>2]=d;d=wd(v[b+4>>2],w[b+11|0]);if(d>>>0<c>>>0){pk();L()}b=qd(b);v[e+8>>2]=d-c;FD(a,b+c|0,v[Hb(e+12|0,e+8|0)>>2]);hb=e+16|0}function GB(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],512)){a=0;while(1){if((a|0)!=128){Fm((a<<2)+b|0);a=a+1|0;continue}break}break a}yu(c+8|0,b);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function AP(a){var b=0,c=0,d=0;d=w[a+64|0]|w[a+65|0]<<8;b=w[a+70|0]|w[a+71|0]<<8;a=b+(w[a+72|0]|w[a+73|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<2|a>>>30;b=b<<2;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;kb=a;return c}function Uu(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],256)){a=0;while(1){if((a|0)!=256){Ch(a+b|0);a=a+1|0;continue}break}break a}ec(c+8|0,b,256);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function zJ(){var a=0,b=0,c=0,d=0;a=hb-16|0;hb=a;b=tc(1298472);v[23516]=0;c=T(1080,b|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){b=v[If(a+8|0,c)>>2];hb=a+16|0;return b|0}a=P()|0;O()|0;Jb(b);S(a|0);L()}function rO(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function fi(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;ec(d+8|0,b,c);e=v[d+12>>2];jc(d,v[a>>2],v[a+8>>2],v[d+8>>2],e);f=v[d+4>>2];if((f|0)==(e|0)){Yb(a,v[d+12>>2])}hb=d+16|0;if((e|0)!=(f|0)){Rb(b,0,c)}}function bU(a){var b=0,c=0,d=0;a:{if(Qb(a,21740,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|w[a+16|0]>3|w[a+17|0]>3){break a}d=a;a=a+19|0;if(w[d+18|0]<16){continue}break}}return b}function Od(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function tr(a,b,c,d){var e=0,f=0,g=0;e=b+4|0;g=c;f=v[a>>2];c=v[a+4>>2]-f|0;d=v[e>>2]+B(g,(c|0)/(d|0)|0)|0;v[e>>2]=d;if((c|0)>0){pc(d,f,c)}oc(a,e);oc(a+4|0,b+8|0);oc(Db(a),zc(b));v[b>>2]=v[b+4>>2]}function cj(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Yo(a,b,c,d,e,f){var g=0,h=0;og(a+12|0,d);if(b){if(b>>>0>=f>>>0){Zf(11191);L()}d=tc(B(b,e))}else{d=0}v[a>>2]=d;c=d+B(c,e)|0;v[a+8>>2]=c;v[a+4>>2]=c;g=zc(a),h=d+B(b,e)|0,v[g>>2]=h;return a}function wH(a){var b=0,c=0,d=0;d=v[a>>2];while(1){c=t[d|0];if(Zj(c)){d=d+1|0;v[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=B(b,10);b=(c|0)>(2147483647-b|0)?-1:c+b|0}else{b=-1}continue}break}return b}function ou(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function kM(a){var b=0,c=0;a=a+906300|0;c=ck(a);while(1){if((a|0)!=(c|0)){b=v[a>>2];a:{if(!b){break a}if(!(lb[v[v[b>>2]+120>>2]](b)|0)){break a}lb[v[v[b>>2]+100>>2]](b)}a=a+160|0;continue}break}}function C3(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;DJ(c,b);a=v[a+1298464>>2];v[23516]=0;U(384,a|0,1,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){xb(c);hb=c+16|0;return}a=P()|0;O()|0;xb(c);S(a|0);L()}function wS(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;eB(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)|0}function oB(a,b){var c=0;c=hb-16|0;hb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Wb(128/(B(v[Ne(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[ef(c+7|0,c+6|0)|0];hb=c+16|0;return a|b<<4&240}function TO(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;t[a+16|0]=0;c=rz(b,v[a+12>>2]);v[23516]=0;R(771,a|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){hl(c);hb=b+32|0;return}a=P()|0;O()|0;hl(c);S(a|0);L()}function Hl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=er(b);d=rl(a);a:{if(c>>>0<=d>>>0){nd(Xh(qd(a),b,c)+c|0,0);io(a,c);break a}e=d;f=c-d|0;d=wd(v[a+4>>2],w[a+11|0]);mq(a,e,f,d,0,d,c,b)}return a|0}function Hh(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;Tm(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)|0}function Bu(a,b,c){var d=0;a=(a&65535)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function iR(a){var b=0,c=0,d=0,e=0;kb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+94|0]|w[a+95|0]<<8;b=c+w[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function fT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;Wf(a,d+14|0);e=x[d+14>>1];sM(b,e);c=0;while(1){if((c|0)==(e|0)){my(b);hb=d+16|0}else{kk(a,Bb(v[b>>2],c));c=c+1|0;continue}break}}function eK(a,b){var c=0,d=0,e=0,f=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);c=+a;e=32768/(1-c);f=c;c=Ze(31415.926535897932/+b);d=pl(e*(1-(f*c+K(+C(a+a)*(1-c)-+C(a*a)*(1-c*c)))))}return d}function ZH(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=z[e>>2];c=c+h|0;g=z[c>>2];z[e>>2]=f+g;z[c>>2]=f-g;d=d+1|0;continue}break}}function ET(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;b=eh(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){ic(b);hb=d+16|0}else{xm(a,x[c>>1]|x[c+2>>1]<<16);a=a+4|0;v[b+4>>2]=a;continue}break}}function Dh(a,b){var c=0;c=v[a>>2];a=Zd(b);b=v[c+8>>2];if(sc(b,v[c+12>>2])>>>0>a>>>0){c=v[Bb(b,a)>>2]!=0}else{c=0}if(!c){a=cm(ba(4)|0);v[a>>2]=93108;ia(a|0,93244,1127);L()}return v[Bb(b,a)>>2]}function vg(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb+-64|0;hb=c;d=Sx(c+8|0,a);v[23516]=0;U(199,a|0,b|0,d|0);a=v[23516];v[23516]=0;if((a|0)!=1){$k(d);hb=c- -64|0;return}a=P()|0;O()|0;$k(d);S(a|0);L()}function ky(a,b){var c=0;a=kQ(a,b);t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function pg(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(1073741823);if(d>>>0<=b>>>0){a=Vh(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function pF(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=84248;d=a+8|0;while(1){b=v[a+8>>2];if(sc(b,v[a+12>>2])>>>0>c>>>0){b=v[Bb(b,c)>>2];if(b){Ym(b)}c=c+1|0;continue}break}wb(a+152|0);jw(d);return a|0}function nj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=gl(a,b);if((d|0)==255){break a}fk(a,b);Vp(a,b,0,0);if(!c){break a}e=$b(a+26|0,d),f=65535,u[e>>1]=f;a=Ib(a+62|0,b);t[a|0]=w[a|0]|128}}function m0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(d>>>0<4294967280){a:{if(d>>>0<=10){Xd(a,c);break a}e=ih(d)+1|0;d=tc(e);td(a,d);bf(a,e);xd(a,c);a=d}nd(Ce(a,b,c)+c|0,0);return}df();L()}function Kj(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(2147483647);if(d>>>0<=b>>>0){a=Om(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function wn(a){var b=0,c=0;b=hb-16|0;hb=b;a:{if(!mJ(w[a+20|0])){v[23516]=0;R(1085,b+8|0,a|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}}t[a+20|0]=255;hb=b+16|0;return}V(0)|0;O()|0;Tb();L()}function qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(sc(v[a+4>>2],v[a+8>>2])+e|0)-1|0,u[f+10>>1]=g;a=uL(a,b,c,d+8|0);hb=d+16|0;return a|0}function oD(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(119304647);if(d>>>0<=b>>>0){a=pv(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function gE(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(178956970);if(d>>>0<=b>>>0){a=qr(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function en(a,b){var c=0,d=0,e=0;a:{c=yG(b);if(c>>>0<1073741808){b:{if(c>>>0<=1){Xd(a,c);break b}d=Tl(c)+1|0;e=Ai(d);td(a,e);bf(a,d);xd(a,c);a=e}mi(a,b,c);td((c<<2)+a|0,0);break a}df();L()}}function dr(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(536870911);if(d>>>0<=b>>>0){a=Zm(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function cB(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(214748364);if(d>>>0<=b>>>0){a=lC(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function _p(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(134217727);if(d>>>0<=b>>>0){a=$n(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function TA(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=(xp(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),A[d+8>>3]=e;PN(c+8|0,127);a=nk(A[c+8>>3]);hb=c+16|0;return a}function SP(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(268435455);if(d>>>0<=b>>>0){a=rt(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function BA(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(715827882);if(d>>>0<=b>>>0){a=nu(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function $m(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(357913941);if(d>>>0<=b>>>0){a=Sj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function zL(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(82595524);if(d>>>0<=b>>>0){a=Qs(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function wt(a){var b=0;a:{if(Qb(a,13630,4)|w[a+4|0]){break a}if(Eb(w[a+6|0]|w[a+7|0]<<8)>>>0>1){break a}if(Eb(w[a+12|0]|w[a+13|0]<<8)){break a}b=(Eb(w[a+16|0]|w[a+17|0]<<8)|0)==20}return b}function mh(a,b,c){a:{if(b>>>0<=c>>>0){a=ba(8)|0;v[23516]=0;b=T(191,a|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return w[a+c|0]}ia(b|0,26232,166);L()}function WM(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;b=ar(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){ic(b);hb=d+16|0}else{VM(a,v[c>>2],v[c+4>>2]);a=a+8|0;v[b+4>>2]=a;continue}break}}function LR(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;RR(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){SR(b)}}function EG(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function DC(a){var b=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;b=v[a>>2];if(b&8){v[a>>2]=b|32;return-1}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];return 0}function jA(a,b){var c=0,d=0;d=hb-32|0;hb=d;c=Db(a);c=Tf(d+8|0,pg(a,sc(v[a>>2],v[a+4>>2])+1|0),sc(v[a>>2],v[a+4>>2]),c);dq(v[c+8>>2],v[b>>2]);v[c+8>>2]=v[c+8>>2]+4;Cd(a,c);Sf(c);hb=d+32|0}function Px(a,b,c,d,e,f,g,h,i){var j=0;j=hb-16|0;hb=j;Dg(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;hb=j+16|0}function Iw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function rP(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function fG(a,b,c,d){var e=0;e=hb-16|0;hb=e;dG(e+8|0,b);Mk(v[e+12>>2],c,d);b=hb-16|0;hb=b;v[b+12>>2]=v[v[e+12>>2]+4>>2];v[b+8>>2]=0;d=v[Ne(b+8|0,b+12|0)>>2];hb=b+16|0;ec(a,c,d);hb=e+16|0}function HF(a,b){var c=0,d=0;d=hb-32|0;hb=d;c=Db(a);c=Ql(d+8|0,Ol(a,ad(v[a>>2],v[a+4>>2])+1|0),ad(v[a>>2],v[a+4>>2]),c);nd(v[c+8>>2],w[b|0]);v[c+8>>2]=v[c+8>>2]+1;Cd(a,c);Pl(c);hb=d+32|0}function xi(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function mB(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;vq(c+8|0,b);d=v[c+12>>2];id(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){xU(b)}return a}function kR(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;gR(c+8|0,b);d=v[c+12>>2];id(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){hR(b)}return a}function bD(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;Xq(c+8|0,b);d=v[c+12>>2];id(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Yq(b)}return a}function Z$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=Js(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;pc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function VU(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;ru(c+8|0,b);d=v[c+12>>2];id(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){uB(b)}return a}function VS(a,b,c,d){var e=0;e=hb-16|0;hb=e;v[e+12>>2]=b;v[e+8>>2]=d;a=Ip(a,c,v[Hb(e+12|0,e+8|0)>>2]);a:{if(a){break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}hb=e+16|0;return a}function UR(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;RR(c+8|0,b);d=v[c+12>>2];id(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){SR(b)}return a}function PD(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;ND(c+8|0,b);d=v[c+12>>2];id(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Cv(b)}return a}function Nj(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;Tm(c+8|0,b);d=v[c+12>>2];id(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Qj(b)}return a}function FQ(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;cU(c+8|0,b);d=v[c+12>>2];id(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){dU(b)}return a}function p6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=XJ(f,b,c,d,0,0,0,0,e);hb=f+16|0;return a|0}function d$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-16|0;hb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=Xj(h,b,c,d,e,f,g+8|0,a);hb=a;return b|0}function Dx(a){var b=0,c=0,d=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=In(d)|b<<15;continue}break}A[c+4280>>3]=C(C(b|0)*C(-4.656612873077393e-10))}function js(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=v[a+4>>2];d=((b<<2)+(bv(v[a>>2],1)^270549120)|0)+2019860093|0;v[a>>2]=d;b=b+B(bv(d,16),5)|0;v[a+4>>2]=b;continue}break}return b}function gia(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Ob(v[a>>2],v[a+8>>2],12);a:{if(!d){t[c|0]=0;ci(b,12,c);break a}vq(c+8|0,b);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0;return d|0}function f3(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=v[14511];v[c+8>>2]=v[14510];v[c+12>>2]=d;d=v[14509];v[c>>2]=v[14508];v[c+4>>2]=d;lb[v[qp(c,_j(w[b+20|0]))>>2]](a,b);hb=c+16|0}function Wfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Lb(a);a:{if(b){v[23516]=0;R(630,a|0,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break a}Ao(a,b,c)}return a|0}b=P()|0;O()|0;gd(a);S(b|0);L()}function jT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Lb(a);a:{if(b){v[23516]=0;R(457,a|0,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break a}FA(a,b,c)}return a|0}b=P()|0;O()|0;Ah(a);S(b|0);L()}function eW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Lb(a);a:{if(b){v[23516]=0;R(227,a|0,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break a}nC(a,b,c)}return a|0}b=P()|0;O()|0;lc(a);S(b|0);L()}function Sh(a){var b=0;a=Wh(a);b=2147483647;a:{if(a>=C(2147483648)){break a}b=-2147483648;if(a<=C(-2147483648)){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function Ol(a,b){var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=b;d=b;b=Kh(-1);if(d>>>0<=b>>>0){a=dp(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Vc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}rd();L()}function vs(a){var b=0;b=v[a+24>>2];v[23516]=0;Y(833,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){Me(a+68|0);Vf(a+36|0);os(a+32|0);fj(a+24|0);ej(a+4|0);return ze(a)}V(0)|0;O()|0;Tb();L()}function lia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;IS(b,c);c=Ob(v[a>>2],v[a+8>>2],c<<2);if(c){HS(d+8|0,v[b>>2],v[b+4>>2]);pd(d,a,v[d+8>>2],v[d+12>>2])}hb=d+16|0;return c|0}function iea(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Ob(v[a>>2],v[a+8>>2],4);a:{if(!d){t[c|0]=0;hD(b,4,c);break a}Jh(c+8|0,b);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0;return d|0}function cK(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=bK(f,b,c,d,e,0,0,0,0);hb=f+16|0;return+c}function Tf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;og(a+12|0,d);if(b){d=Ai(b)}else{d=0}v[a>>2]=d;c=d+(c<<2)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<2)|0,v[e>>2]=f;return a|0}function Rl(a,b){v[a+28>>2]=0;u[a+24>>1]=65535;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;t[a|0]=0;v[a+32>>2]=11;v[a+36>>2]=b;Lb(a+40|0);Lb(a+52|0);Rb(a- -64|0,0,48);return a}function rM(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;nM(c,b+80|0);v[23516]=0;U(11,a|0,0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){wb(c);hb=c+16|0;return}a=P()|0;O()|0;wb(c);S(a|0);L()}function jX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;wD(b,c);c=Ob(v[a>>2],v[a+8>>2],c<<3);if(c){tD(d+8|0,v[b>>2],v[b+4>>2]);pd(d,a,v[d+8>>2],v[d+12>>2])}hb=d+16|0;return c|0}function az(a){var b=0,c=0;b=v[a>>2];c=v[b>>2];a:{if(!c){while(1){c=zh(b);b=v[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=v[b+4>>2];if(c){continue}break}}v[a>>2]=b;return a}function _W(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;v[d+12>>2]=c;c=0;a=lb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Hb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function Fv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;v[e+12>>2]=d;d=Fb(b);if(d>>>0<c>>>0){pk();L()}b=Ic(b);v[e+8>>2]=d-c;ku(a,b+c|0,v[Hb(e+12|0,e+8|0)>>2]);hb=e+16|0}function zu(a,b){var c=0,d=0;c=hb-16|0;hb=c;yo(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function xg(a,b){var c=0,d=0;c=hb-16|0;hb=c;Pq(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function wr(a,b,c){var d=0;d=hb-16|0;hb=d;ec(d+8|0,b,c);b=v[d+12>>2];jc(d,v[a>>2],v[a+8>>2],v[d+8>>2],b);c=v[d+4>>2];if((b|0)==(c|0)){Yb(a,v[d+12>>2])}hb=d+16|0;return(b|0)==(c|0)}function vU(a,b){var c=0,d=0;c=hb-16|0;hb=c;su(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function uU(a,b){var c=0,d=0;c=hb-16|0;hb=c;vq(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function oR(a,b){var c=0,d=0;c=hb-16|0;hb=c;mA(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;jQ(b,c);if(Ob(v[a>>2],v[a+8>>2],c<<8)){c=v[b>>2];ec(d+8|0,c,xh(c,v[b+4>>2])<<8);pd(d,a,v[d+8>>2],v[d+12>>2])}hb=d+16|0}function kD(a,b){var c=0,d=0;c=hb-16|0;hb=c;ND(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function iX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(ad(v[c>>2],v[c+4>>2])>>>0>=a>>>0){break a}Oi(c,a)}return!d|0}function cD(a,b){var c=0,d=0;c=hb-16|0;hb=c;Xq(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function WB(a,b){var c=0,d=0;c=hb-16|0;hb=c;VB(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function NS(a,b){var c=0,d=0;c=hb-16|0;hb=c;MS(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function Mo(a,b){var c=0,d=0;c=hb-16|0;hb=c;Jh(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function LU(a,b){var c=0,d=0;c=hb-16|0;hb=c;Pu(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function KR(a,b){var c=0,d=0;c=hb-16|0;hb=c;JR(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function Jo(a,b){var c=0,d=0;c=hb-16|0;hb=c;Nm(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function FN(a,b,c,d){a:{if((a|0)!=67108864){break a}a=B(d,872)+c|0;v[a+704>>2]=v[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=B(a,872)+c|0;v[a+704>>2]=v[a+704>>2]&-129}}function Au(a,b){var c=0,d=0;c=hb-16|0;hb=c;xo(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function AU(a,b){var c=0,d=0;c=hb-16|0;hb=c;ru(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function re(a,b){var c=0;a:{c=Og(b);if((c|0)==(Fb(a)|0)){v[23516]=0;a=W(368,a|0,b|0,c|0)|0;b=v[23516];v[23516]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Tb();L()}function nC(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;b=eh(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){ic(b);hb=d+16|0}else{dq(a,v[c>>2]);a=a+4|0;v[b+4>>2]=a;continue}break}}function Ut(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function Qx(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;b=eh(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){ic(b);hb=d+16|0}else{bk(a,z[c>>2]);a=a+4|0;v[b+4>>2]=a;continue}break}}function Ao(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;b=$h(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){ic(b);hb=d+16|0}else{Ki(a,x[c>>1]);a=a+2|0;v[b+4>>2]=a;continue}break}}function yc(a,b){var c=0,d=0;c=hb-16|0;hb=c;if(Fe(a)){Jb(v[a>>2])}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];Xd(b,0);t[c+15|0]=0;$d(b,c+15|0);hb=c+16|0;return a}function uC(a){var b=0,c=0;a:{if(Qb(a,14260,3)){break a}b=w[a+3|0];b:{if(b>>>0<=7){if((b|0)==1){break b}break a}if(b>>>0>14){break a}}c=(w[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function bZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=x[(a<<1)+80208>>1]}else{a=0}u[d>>1]=a;d=d+2|0;b=b+4|0;continue}break}return c|0}function Zha(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;eT(b,c);dT(a,c);hb=c+32|0}function Ho(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;b=Gk(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){ic(b);hb=d+16|0}else{nd(a,w[c|0]);a=a+1|0;v[b+4>>2]=a;continue}break}}function $ha(){var a=0,b=0,c=0;a=hb-16|0;hb=a;b=tc(1);v[23516]=0;Z(30);c=v[23516];v[23516]=0;if((c|0)!=1){b=v[If(a+8|0,b)>>2];hb=a+16|0;return b|0}a=P()|0;O()|0;Jb(b);S(a|0);L()}function ks(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;v[b+12>>2]=12;while(1){v[b+8>>2]=32;if(y[Hb(b+12|0,b+8|0)>>2]<=c>>>0){hb=b+16|0}else{c=c+15|0;d=In(a)&4095;continue}break}return d}function cO(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;while(1){if(c){f=el(x[c+16>>1],v[c+20>>2],a,b);d=f?d:c;c=v[(f?c+4|0:c)>>2];continue}break}a=v[cc(e+8|0,d)>>2];hb=e+16|0;return a}function YD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=rl(a);d=wd(v[a+4>>2],w[a+11|0]);e=d+1|0;if((c|0)==(d|0)){Py(a,c,e-c|0,c,c,0)}c=qd(a);fI(c+d|0,1,b);io(a,e);nd(c+e|0,0);return a|0}function Y6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);if(b>>>0<=12){c=Td(c,C(0));d=a+4208|0;if((b|0)==12){c=C(Wh(C(c*C(3)))/C(3));b=12}e=Bb(d,b),f=c,z[e>>2]=f;t[a+5046|0]=1}}function VD(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function O9(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-32|0;hb=d;c=-1;a:{if(!PD(a,d+8|0)){break a}c=0;if(!IL(d+8|0)|(v[d+16>>2]!=v[b>>2]|v[b+4>>2]?b:0)){break a}c=1}hb=d+32|0;return c|0}function KX(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;MD(b,0,a);v[23516]=0;a=T(123,b|0)|0;c=v[23516];v[23516]=0;if((c|0)!=1){wb(b);hb=b+16|0;return a|0}a=P()|0;O()|0;wb(b);S(a|0);L()}function t2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;v[d+12>>2]=c;ix(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Hb(d+8|0,d+12|0)>>2]}hb=d+16|0;return c|0}function rja(a,b){a=a|0;b=b|0;if(!uU(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function bF(a,b,c){var d=0;a:{if(!a){a=ba(8)|0;v[23516]=0;c=T(c|0,a|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ia(c|0,b|0,970);L()}function Zv(a,b,c,d,e){var f=0;a:{f=Ns(4332);if(f){v[23516]=0;ga(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break a}}return f}a=P()|0;O()|0;Jb(f);S(a|0);L()}function uD(a,b,c){var d=0,e=0;a:{b:{if(c>>>0<=10){Xd(a,c);break b}if(c>>>0>=4294967280){break a}d=ih(c)+1|0;e=tc(d);td(a,e);bf(a,d);xd(a,c);a=e}Ce(a,b,c+1|0);return}df();L()}function id(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;f=v[b+12>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[b>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;lb[c|0](a,b,f,e);hb=e+16|0}function ZL(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;while(1){v[b+12>>2]=7;v[b+8>>2]=32;if(y[Hb(b+12|0,b+8|0)>>2]<=c>>>0){hb=b+16|0}else{c=c+15|0;d=In(a)&127;continue}break}return d}function Kaa(a,b){a=a|0;b=b|0;var c=0;a=Xf(a);c=Ei(v[b>>2]);b=tf(b);v[23516]=0;U(827,a|0,c|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;gN(a);S(b|0);L()}function Gea(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;b=-1;a:{if(!Nj(a,c+8|0)){break a}b=0;if(!lQ(c+8|0)){break a}b=-1;if(!eg(a,4)){break a}b=JQ(a)>>>31|0}hb=c+16|0;return b|0}function GY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;lb[v[v[a>>2]+12>>2]](d+8|0,a,b);a=v[d+8>>2];b=v[c>>2];a=nc(v[d+12>>2],v[c+4>>2])&(a|0)==(b|0);hb=d+16|0;return a|0}function zq(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];d=v[a+4>>2];if(Oc(c,d)>>>0>b>>>0){a=v[a+24>>2];b=yl(c,d,b);a=te(v[a+484344>>2],v[a+484348>>2],x[b>>1])}else{a=0}return a|0}function lp(a){var b=0,c=0;b=v[23435];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(Sw()>>>0<a>>>0){if(!(xa(a|0)|0)){break a}}v[23435]=a;return b}v[115992]=48;return-1}function Qda(a,b){a=a|0;b=b|0;var c=0;a=Lb(a);a:{if(b){v[23516]=0;R(227,a|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}wP(a,b)}return a|0}b=P()|0;O()|0;lc(a);S(b|0);L()}function Hga(a,b){a=a|0;b=b|0;var c=0;a=Lb(a);a:{if(b){v[23516]=0;R(583,a|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}xA(a,b)}return a|0}b=P()|0;O()|0;lc(a);S(b|0);L()}function yg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=mh(v[d>>2],v[d+4>>2],a);return((mh(v[d>>2],v[d+4>>2],a+1|0)<<8|e<<16|mh(v[d>>2],v[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function nU(a){var b=0;a:{if(Qb(a,16814,4)){break a}if(_b(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Eb(w[a+8|0]|w[a+9|0]<<8)}return b}function mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;v[d+8>>2]=b;while(1){if(Nb(b,c)){v[d+4>>2]=v[b>>2];wA(a,d+4|0);b=v[Ie(d+8|0)>>2];continue}else{hb=d+16|0}break}}function Lu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;Oi(b,c);if(Ob(v[a>>2],v[a+8>>2],c)){c=v[b>>2];ec(d+8|0,c,ad(c,v[b+4>>2]));pd(d,a,v[d+8>>2],v[d+12>>2])}hb=d+16|0}function FA(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;b=yq(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){ic(b);hb=d+16|0}else{Ut(a,c);a=a+6|0;v[b+4>>2]=a;continue}break}}function k9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;f=v[c>>2];if(f>>>0<ad(a,b)>>>0){a=Fk(e,Ib(a,f),x[c+20>>1]);g=_v(d,a);Ub(a)}hb=e+16|0;return g|0}function Ql(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;og(a+12|0,d);if(b){d=tc(b)}else{d=0}v[a>>2]=d;c=c+d|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=b+d|0,v[e>>2]=f;return a|0}function Oh(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;t[c+24|0]=0;_i(c+8|0,c+24|0);nn(c+16|0,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];t[b|0]=w[c+24|0];hb=c+32|0;return(a|0)==1|0}function cf(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+8>>2]=c;v[d+4>>2]=31;e=d,f=eV(b,c),v[e+12>>2]=f;c=b;b=zB(d+4|0);lh(c,c+b|0,a);e=Ib(a,b),f=0,t[e|0]=f;gV(a);hb=d+16|0}function $Y(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=v[c>>2];if(!(a>>>0>127|!(x[(a<<1)+80208>>1]&b))){c=c+4|0;continue}break}d=c}return d|0}function tha(){var a=0,b=0,c=0;a=hb-16|0;hb=a;b=Fc(a,10284);v[23516]=0;Y(34,b|0);c=v[23516];v[23516]=0;if((c|0)!=1){wb(b);hb=a+16|0;return}a=P()|0;O()|0;wb(b);S(a|0);L()}function _l(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Ob(v[a>>2],v[a+8>>2],16);a:{if(!d){fC(b);break a}Pu(c+8|0,b);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0;return d|0}function $W(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=lb[v[v[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function xA(a,b){var c=0,d=0;c=hb-16|0;hb=c;b=eh(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){ic(b);hb=c+16|0}else{Fm(a);a=a+4|0;v[b+4>>2]=a;continue}break}}function wP(a,b){var c=0,d=0;c=hb-16|0;hb=c;b=eh(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){ic(b);hb=c+16|0}else{uP(a);a=a+4|0;v[b+4>>2]=a;continue}break}}function jE(a,b){var c=0,d=0;c=hb-16|0;hb=c;b=Gk(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){ic(b);hb=c+16|0}else{iE(a);a=a+1|0;v[b+4>>2]=a;continue}break}}function iC(a,b){var c=0,d=0;c=hb-16|0;hb=c;b=$h(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){ic(b);hb=c+16|0}else{hC(a);a=a+2|0;v[b+4>>2]=a;continue}break}}function aZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=v[c>>2];if(a>>>0>127|!(x[(a<<1)+80208>>1]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function GF(a,b){var c=0,d=0;c=hb-16|0;hb=c;b=eh(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){ic(b);hb=c+16|0}else{DF(a);a=a+4|0;v[b+4>>2]=a;continue}break}}function FD(a,b,c){var d=0,e=0;if(c>>>0<4294967280){a:{if(c>>>0<=10){Xd(a,c);break a}d=ih(c)+1|0;e=tc(d);td(a,e);bf(a,d);xd(a,c);a=e}nd(Ce(a,b,c)+c|0,0);return}df();L()}function eo(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Ob(v[a>>2],v[a+8>>2],4);a:{if(!d){KS(b);break a}Jh(c+8|0,b);pd(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0;return d|0}function _H(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function Ft(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=w[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function Uea(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;d=-1;a:{if(!FQ(a,c)){break a}d=0;if(!EQ(c)){break a}d=we(a,b,DQ(w[c+31|0],w[c+33|0]),kb)}hb=c+48|0;return d|0}function Rfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;wD(b,c);if(Ob(v[a>>2],v[a+8>>2],c<<3)){tD(d+8|0,v[b>>2],v[b+4>>2]);pd(d,a,v[d+8>>2],v[d+12>>2])}hb=d+16|0}function Qb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function AC(a,b,c){var d=0;d=hb-16|0;hb=d;b=Io(d,a+8|0,b);a=v[b>>2];while(1){if((a|0)!=v[b+4>>2]){Ki(a,x[c>>1]);a=v[b>>2]+2|0;v[b>>2]=a;continue}break}Kd(b);hb=d+16|0}function zba(a,b){a=a|0;b=b|0;a=yf(a);t[a+534|0]=0;v[a+4>>2]=0;v[23516]=0;R(776,a|0,b|0);b=v[23516];v[23516]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;co(a);S(b|0);L()}function vga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Lb(a+8|0);v[23516]=0;U(246,a|0,b|0,c|0);a=v[23516];v[23516]=0;if((a|0)!=1){break a}a=P()|0;O()|0;dc(d);S(a|0);L()}}function rA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;IS(b,c);if(Ob(v[a>>2],v[a+8>>2],c<<2)){HS(d+8|0,v[b>>2],v[b+4>>2]);pd(d,a,v[d+8>>2],v[d+12>>2])}hb=d+16|0}function fk(a,b){var c=0,d=0,e=0;a:{c=gl(a,b);if((c|0)==255){break a}if(gk(v[a>>2])){break a}d=Ib(a+8|0,c);e=w[d|0]&223;t[d|0]=e;ah(v[a>>2],v[a+4>>2],b,jt(c)|176,e)}}function U6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=sp(d,a);UJ(a,c);v[23516]=0;R(68,b|0,1);a=v[23516];v[23516]=0;if((a|0)==1){a=P()|0;O()|0;Zb(d);S(a|0);L()}}function PS(a,b,c){var d=0;d=hb-16|0;hb=d;b=Mv(d,a+8|0,b);a=v[b>>2];while(1){if((a|0)!=v[b+4>>2]){nd(a,w[c|0]);a=v[b>>2]+1|0;v[b>>2]=a;continue}break}Kd(b);hb=d+16|0}function OW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Hb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function wA(a,b){a=a|0;b=b|0;var c=0;if(y[a+4>>2]<y[Db(a)>>2]){c=hb-16|0;hb=c;a=eh(c,a,1);dq(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;ic(a);hb=c+16|0;return}jA(a,b)}function u2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;ix(a,b,c);a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function pP(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function e1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a=Vw(Ra(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);hb=e+16|0;kb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function aX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Hb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function ZS(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;b=gc(b);a=gh(a,tc(32),hh(d+8|0,b));b=v[a>>2]+16|0;u[b>>1]=x[v[c>>2]>>1];Kb(b+4|0);e=gc(a),f=1,t[e+4|0]=f;hb=d+16|0}function Y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=lb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=wc(a);return Wj(g,h,c,d,e,f,b,b+(Fb(a)<<2)|0)|0}function Ria(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],12)){u[c>>1]=0;vT(a,6,c);break a}vq(c+8|0,a);pd(c,b,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function eH(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Kf(b),d=v[v[a>>2]+52>>2],lb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Kf(b)}function IQ(a,b){var c=0,d=0;c=hb-16|0;hb=c;Jh(c+8|0,b);b=v[c+12>>2];id(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){dd(a,v[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function Cfa(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],8)){u[c>>1]=0;vT(a,4,c);break a}Tm(c+8|0,a);pd(c,b,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function ufa(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],5)){t[c|0]=0;ci(a,5,c);break a}xo(c+8|0,a);pd(c,b,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function nja(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],6)){t[c|0]=0;ci(a,6,c);break a}eB(c+8|0,a);pd(c,b,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function iJ(a,b){var c=0,d=0;c=hb-16|0;hb=c;b=Gk(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){ic(b);hb=c+16|0}else{a=a+1|0;v[b+4>>2]=a;continue}break}}function Xe(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(c){a=v[gc(a)>>2];v[23516]=0;Y(a|0,c|0);a=v[23516];v[23516]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Tb();L()}function UP(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;Ez(a+112|0,48e3);v[a+668>>2]=0;Dz(a+724|0);Dz(a+732|0);Dz(a+740|0);sg(a+788|0);return a}function zB(a){var b=0,c=0;a:{c=Bb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=ho(v[b>>2],v[a>>2])?b:a;continue}}return v[a>>2]}function yD(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;v[f+12>>2]=e;v[f+8>>2]=d;v[f+4>>2]=c;v[f>>2]=b;a=Bg(a,f);v[a+8>>2]=0;b=a+12|0;a=f+8|0;Bg(b,a);je(a);je(f);hb=f+16|0}function lY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;v[d+12>>2]=v[c>>2];a=lb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}hb=d+16|0;return a|0}function Zp(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function Tja(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Tm(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);if((b|0)==v[c+4>>2]){Yb(a,v[c+12>>2])}hb=c+16|0}function Mba(a,b){a=a|0;b=b|0;a=Lb(a);t[a+16|0]=0;v[a+12>>2]=b;v[23516]=0;Y(770,a|0);b=v[23516];v[23516]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;SO(a);S(b|0);L()}function Km(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],4)){t[c|0]=0;ci(a,4,c);break a}Jh(c+8|0,a);pd(c,b,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function Jl(a,b){a=a|0;b=b|0;var c=0;if(!zf(w[b+11|0])){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return a|0}uD(a,v[b>>2],v[b+4>>2]);return a|0}function yM(a){var b=0,c=0,d=0;b=v[a+112>>2];if((b|0)>=11){c=378;while(1){if(c|d){xM(a);b=c;c=b-1|0;d=d-!b|0;continue}break}b=0}v[a+112>>2]=b+1;a=xM(a);return a}function tP(a,b){var c=0;c=v[a+4>>2];a:{if((b|0)>=0){b=b+c|0;c=v[a>>2]+(b>>>3&536870908)|0;break a}b=b+c|0;c=v[a>>2]+((b-31|0)/32<<2)|0}v[a>>2]=c;v[a+4>>2]=b&31}function paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=Di(b),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[Gj(c+12|0,c+8|0,44e3)>>2],v[d+36>>2]=e;zp(a);hb=c+16|0}function lq(a){var b=0,c=0,d=0,e=0;b=v[a+4>>2];c=v[b>>2];v[a+4>>2]=c;if(c){dm(c,a)}v[b+8>>2]=v[a+8>>2];d=v[a+8>>2]+(zh(a)?0:4)|0,e=b,v[d>>2]=e;v[b>>2]=a;dm(a,b)}function kq(a){var b=0,c=0,d=0,e=0;b=v[a>>2];c=v[b+4>>2];v[a>>2]=c;if(c){dm(c,a)}v[b+8>>2]=v[a+8>>2];d=v[a+8>>2]+(zh(a)?0:4)|0,e=b,v[d>>2]=e;v[b+4>>2]=a;dm(a,b)}function kk(a,b){var c=0;c=hb-32|0;hb=c;v[c+24>>2]=0;Kv(c+8|0,c+24|0);nn(c+16|0,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];v[b>>2]=v[c+24>>2];hb=c+32|0;return(a|0)==4}function WA(a){var b=0,c=0;b=hb-16|0;hb=b;u[b+14>>1]=a;Bf(b+14|0,4095);a=x[b+14>>1];c=QT(ni(+((a&255)>>>0)*.00390625)*32768);hb=b+16|0;return c>>>15-(a>>>8|0)|0}function Pi(a,b,c,d,e){a:{e=Ns(e);if(e){v[23516]=0;fa(d|0,e|0,a|0,b|0,c|0)|0;a=v[23516];v[23516]=0;if((a|0)==1){break a}}return e}a=P()|0;O()|0;Jb(e);S(a|0);L()}function Mfa(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-80|0;hb=d;c=-1;a:{if(!VU(a,d+8|0)){break a}c=0;if(!tR(d+8|0)){break a}c=we(a,b,sR(d+8|0),kb)}hb=d+80|0;return c|0}function jc(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;v[f+12>>2]=e;v[f+8>>2]=d;d=v[v[b>>2]+28>>2];e=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=e;lb[d|0](a,b,c,f);hb=f+16|0}function cs(a){var b=0;a:{if((Ye(a)|0)!=79){break a}if((Ye(a)|0)!=103){break a}if((Ye(a)|0)!=103){break a}b=(Ye(a)|0)==83}if(!b){bc(a,30);return 0}return TH(a)}function c$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=lb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=Ic(a);return Xj(g,h,c,d,e,f,b,Fb(a)+b|0)|0}function Tu(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],2)){t[c|0]=0;gC(a,c);break a}Nm(c+8|0,a);pd(c,b,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function KI(a,b){var c=0,d=0;d=a+4|0;c=ad(v[d>>2],v[a+8>>2]);a=v[a+16>>2]+b|0;if(c>>>0<a>>>0){a:{if(c){b=Yg(c);if(a>>>0<=b>>>0){break a}}b=LI(a,65536)}Oi(d,b)}}function ym(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(D(a)<2147483648){return~~a}b=-2147483648}return b}function tU(a){var b=0;if(!(Qb(a,17945,8)|w[a+8|0]>1|((w[a+9|0]-1&255)>>>0>7|(w[a+10|0]|w[a+11|0]<<8)>>>0>4096))){b=(w[a+12|0]|w[a+13|0]<<8)>>>0<4097}return b}function sT(a,b){var c=0;c=rka(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+kb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;kb=a;return b}function Td(a,b){var c=0,d=0,e=C(0);c=hb-16|0;hb=c;v[c+8>>2]=1065353216;z[c+12>>2]=b;d=c,e=Gf(a),z[d+4>>2]=e;a=z[St(c+4|0,c+12|0,c+8|0)>>2];hb=c+16|0;return a}function OV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=-1;if(xg(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=XB(a,b,v[Hb(c+4|0,c+12|0)>>2])}hb=c+16|0;return d|0}function J8(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;XK(b+8|0,a,0);c=v[b+12>>2];if(c){a=v[a+20>>2];v[a+148>>2]=-1;d=a+4|0;a=v[b+8>>2];ly(d,a,Ib(a,c))}hb=b+16|0}function BL(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(Fe(a)){d=v[a>>2];t[c+15|0]=0;$d(b+d|0,c+15|0);xd(a,b);break a}t[c+14|0]=0;$d(a+b|0,c+14|0);Xd(a,b)}hb=c+16|0}function BJ(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function $B(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;v[c+12>>2]=-1;if(xg(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=UB(a,b,v[Hb(c+4|0,c+12|0)>>2])}hb=c+16|0;return d|0}function lK(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function jD(a){var b=0;if(!(Qb(a,15624,4)|(w[a+4|0]-16&255)>>>0<249|((w[a+5|0]-16&255)>>>0<249|(w[a+6|0]-16&255)>>>0<249))){b=(w[a+7|0]-9&255)>>>0<7}return b}function bB(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=jC(b)}else{d=0}v[a>>2]=d;c=d+B(c,20)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+B(b,20)|0,v[e>>2]=f;return a}function S$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function Iz(a){var b=0;a=se(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function Bk(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=WD(b)}else{d=0}v[a>>2]=d;c=d+B(c,12)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+B(b,12)|0,v[e>>2]=f;return a}function s3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((a|0)!=(b|0)){d=v[c>>2];v[d>>2]=v[a>>2];yh(d+4|0,a+4|0);v[c>>2]=v[c>>2]+16;a=a+16|0;continue}break}}function eea(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-48|0;hb=d;c=-1;a:{if(!FQ(a,d)){break a}c=0;if(!LP(d)){break a}c=we(a,b,KP(w[d+47|0]),kb)}hb=d+48|0;return c|0}function Yb(a,b){a=a|0;b=b|0;var c=0;c=Ob(v[a>>2],v[a+8>>2],b);a:{if(c){b=v[a+8>>2]+b|0;break a}b=v[a>>2];b=lb[v[v[b>>2]+24>>2]](b)|0}v[a+8>>2]=b;return c|0}function Wv(a,b,c,d){var e=0;e=ba(8)|0;v[23516]=0;a=Q(d|0,e|0,a|0)|0;d=v[23516];v[23516]=0;if((d|0)!=1){ia(a|0,c|0,b|0);L()}a=P()|0;O()|0;ca(e|0);S(a|0);L()}function V$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function TR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;while(1){if((b|0)==(c|0)){hb=d+16|0}else{v[d+12>>2]=v[b>>2];wA(a,d+12|0);b=b+4|0;continue}break}}function BE(a,b,c,d){a=Lb(a);a:{if(b){v[23516]=0;R(d|0,a|0,b|0);d=v[23516];v[23516]=0;if((d|0)==1){break a}Ho(a,b,c)}return a}b=P()|0;O()|0;dc(a);S(b|0);L()}function tc(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Md(a);if(b){break a}b=v[117449];if(b){lb[b|0]();continue}break}ia(An(ba(4)|0)|0,92664,26);L()}return b|0}function pt(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=MP(b)}else{d=0}v[a>>2]=d;c=d+(c<<5)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<5)|0,v[e>>2]=f;return a}function cr(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=sD(b)}else{d=0}v[a>>2]=d;c=d+(c<<3)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<3)|0,v[e>>2]=f;return a}function Xz(a,b,c){var d=0;d=hb-16|0;hb=d;v[d+8>>2]=a;c=c&65535;while(1){if(!(!Nb(a,b)|(c|0)==x[a>>1])){a=v[Qe(d+8|0)>>2];continue}break}hb=d+16|0;return a}function US(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=QS(b)}else{d=0}v[a>>2]=d;c=d+B(c,6)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+B(b,6)|0,v[e>>2]=f;return a}function Ss(a,b){var c=0,d=0,e=C(0);c=hb-16|0;hb=c;z[c+12>>2]=b;v[c+8>>2]=0;v[c+4>>2]=1065353216;d=a,e=z[St(c+12|0,c+8|0,c+4|0)>>2],z[d+144>>2]=e;hb=c+16|0}function RP(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=QP(b)}else{d=0}v[a>>2]=d;c=d+(c<<4)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<4)|0,v[e>>2]=f;return a}function Jj(a,b,c,d){var e=0,f=0;og(a+12|0,d);if(b){d=SC(b)}else{d=0}v[a>>2]=d;c=d+(c<<1)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<1)|0,v[e>>2]=f;return a}function FM(){var a=0,b=0,c=0,d=0;a=hb-16|0;hb=a;b=a+8|0;while(1){if(c>>>0<32){c=c+48|0;d=py(94104);continue}break}v[b>>2]=d;In(b);hb=a+16|0;return v[b>>2]}function tp(a,b){var c=0,d=0;a:{if(!a){break a}c=rka(a,0,b,0);d=kb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Md(c);if(!(!a|!(w[a-4|0]&3))){Rb(a,0,c)}return a}function pba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;if(Zm(a)>>>0<b>>>0){d=Db(a);e=a;a=cr(c+8|0,b,Qg(v[a>>2],v[a+4>>2]),d);Cd(e,a);br(a)}hb=c+32|0}function jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;if(Sj(a)>>>0<b>>>0){d=Db(a);e=a;a=Bk(c+8|0,b,ud(v[a>>2],v[a+4>>2]),d);or(e,a);QN(a)}hb=c+32|0}function jV(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function ij(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;A[a>>3]=A[a>>3]-c;A[a+8>>3]=A[a+8>>3]-d}function iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;if(Xy(a)>>>0<b>>>0){d=Db(a);e=a;a=XN(c+8|0,b,Yy(v[a>>2],v[a+4>>2]),d);WN(e,a);VN(a)}hb=c+32|0}function iD(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=(lb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0;a=v[b>>2];fc(c,d,(lb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function hi(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function haa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;if(Vh(a)>>>0<b>>>0){d=Db(a);e=a;a=Tf(c+8|0,b,sc(v[a>>2],v[a+4>>2]),d);Cd(e,a);Sf(a)}hb=c+32|0}function Y1(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=yh(a,b);v[23516]=0;Q(52,a+12|0,c|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){break a}b=P()|0;O()|0;wb(a);S(b|0);L()}}function PW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Lea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;if(Sj(a)>>>0<b>>>0){d=Db(a);e=a;a=Bk(c+8|0,b,ud(v[a>>2],v[a+4>>2]),d);tQ(e,a);sQ(a)}hb=c+32|0}function yh(a,b){a=a|0;b=b|0;var c=0;if(!Fe(b)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return a|0}uD(a,v[b>>2],v[b+4>>2]);return a|0}function nl(a,b){var c=0,d=0,e=0;a=Lb(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Db(b);d=Db(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function mS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;if(Om(a)>>>0<b>>>0){d=Db(a);e=a;a=Jj(c+8|0,b,Oc(v[a>>2],v[a+4>>2]),d);Cd(e,a);Li(a)}hb=c+32|0}function hn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;if(dp(a)>>>0<b>>>0){d=Db(a);e=a;a=Ql(c+8|0,b,ad(v[a>>2],v[a+4>>2]),d);Cd(e,a);Pl(a)}hb=c+32|0}function dx(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(a*C(z[((c&3)<<2)+66064>>2]*C(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function bX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function MG(a,b,c){var d=0;d=hb-32|0;hb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;kw(d+16|0,a,d+24|0,v[Hb(d+28|0,d+12|0)>>2]);v[b>>2]=v[d+24>>2];hb=d+32|0}function wE(a,b,c){a=Lb(a);a:{if(b){v[23516]=0;R(c|0,a|0,b|0);c=v[23516];v[23516]=0;if((c|0)==1){break a}jE(a,b)}return a}b=P()|0;O()|0;dc(a);S(b|0);L()}function vn(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Md(b)}return c}function N6(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=Uy(C(C(C(C(y[v[a+16>>2]+24620>>2])/C(3))+C(-80))/C(15920)),C(0),C(1)),z[b+4272>>2]=c;mK(a);lK(a)}function Ig(a){var b=0,c=0;b=v[a>>2];c=v[b+4>>2];a:{if(!c){while(1){if(!zh(b)){b=v[b+8>>2];continue}break}b=v[b+8>>2];break a}b=zT(c)}v[a>>2]=b;return a}function rs(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;qs(b);continue}break}v[a+4>>2]=c;b=v[a>>2];rt(a);Jb(b)}}function m9(a){a=a|0;var b=0;b=hb-16|0;hb=b;Pc(b,a+32|0,4);if(!zb(v[v[b>>2]>>2],v[b+4>>2])){Ov(a)}a=v[cc(b+8|0,Cb(v[a+52>>2]))>>2];hb=b+16|0;return a|0}function lD(a){a=a|0;var b=0;a=Kb(a);v[23516]=0;T(172,a+12|0)|0;b=v[23516];v[23516]=0;if((b|0)!=1){yf(a+32|0);return a|0}b=P()|0;O()|0;xb(a);S(b|0);L()}function l9(a){a=a|0;var b=0;b=hb-16|0;hb=b;Pc(b,a+32|0,4);if(!zb(v[v[b>>2]>>2],v[b+4>>2])){Ov(a)}a=v[cc(b+8|0,Cb(v[a+56>>2]))>>2];hb=b+16|0;return a|0}function kQ(a,b){var c=0,d=0,e=0;$t(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Db(b);d=Db(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function gA(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-24|0;yb(b);continue}break}v[a+4>>2]=c;b=v[a>>2];qr(a);Jb(b)}}function f0(a,b){a=a|0;b=b|0;var c=0,d=0;b=yw(b);v[a+36>>2]=b;c=a,d=nh(b),v[c+44>>2]=d;c=a,d=pn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Mr(5566);L()}}function cR(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-56|0;Ct(b);continue}break}v[a+4>>2]=c;b=v[a>>2];bR(a);Jb(b)}}function b0(a,b){a=a|0;b=b|0;var c=0,d=0;b=Dw(b);v[a+36>>2]=b;c=a,d=nh(b),v[c+44>>2]=d;c=a,d=pn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Mr(5566);L()}}function Zc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(lb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function UY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function Me(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;Ub(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Sj(a);Jb(b)}}function Il(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;ac(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Sj(a);Jb(b)}}function Bm(a,b){var c=0,d=0,e=0;iB(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Db(b);d=Db(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function zn(a,b){v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Rb(a+32|0,0,40);lH(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function n4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-32|0;hb=h;i=h+8|0;GI(i,b,c,d,e,f,g);Xc(a,h+20|0);nm(i);hb=h+32|0}function aU(a,b){var c=0;c=rka(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+kb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;a=b>>>0<11?a+1|0:a;kb=a;return b}function XS(a,b,c){var d=0;d=hb-32|0;hb=d;v[d+28>>2]=c;t[d+24|0]=0;v[d+12>>2]=1;kw(d+16|0,a,d+24|0,v[Hb(d+28|0,d+12|0)>>2]);t[b|0]=w[d+24|0];hb=d+32|0}function Kp(a,b,c){var d=0;a:{if(b&134218752){break a}if(!lj(c)){break a}b=w[c+34|0];if((b+5&255)>>>0<6){break a}d=v[Id(a+906300|0,b-1|0)>>2]}return d}function yN(a,b,c){var d=0,e=0;v[b+56>>2]=0;d=b,e=Ln(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(w[a+480180|0]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function nv(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],3)){t[c|0]=0;ci(a,3,c);break a}mv(c+8|0,a);pd(c,b,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function bE(a){v[a>>2]=0;v[a+4>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;u[a+20>>1]=0;v[a+16>>2]=-1;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0}function yfa(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-96|0;hb=d;c=-1;a:{if(!kR(a,d)){break a}c=0;if(!jR(d)){break a}c=we(a,b,iR(d),kb)}hb=d+96|0;return c|0}function lga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(178956970)>>>0<b>>>0){rd();L()}c=B(b,24);b=tc(c);v[a>>2]=b;v[a+4>>2]=b;d=Db(a),e=b+c|0,v[d>>2]=e}function iv(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function hea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(119304647)>>>0<b>>>0){rd();L()}c=B(b,36);b=tc(c);v[a>>2]=b;v[a+4>>2]=b;d=Db(a),e=b+c|0,v[d>>2]=e}function _f(a){var b=0,c=0;b=hb-16|0;hb=b;a:{if(Fe(a)){c=v[a>>2];t[b+15|0]=0;$d(c,b+15|0);xd(a,0);break a}t[b+14|0]=0;$d(a,b+14|0);Xd(a,0)}hb=b+16|0}function MY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=t[b|0];t[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function $ea(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-96|0;hb=d;c=-1;a:{if(!kR(a,d)){break a}c=0;if(!RQ(d)){break a}c=we(a,b,QQ(d),kb)}hb=d+96|0;return c|0}function xL(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;v[a+8>>2]=b;$k(b);continue}break}c=v[a>>2];if(c){zc(a);Jb(c)}}function vY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Tg(a,v[b+8>>2],f)){dw(b,c,d,e);return}a=v[a+8>>2];lb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function sK(a){var b=0;b=y[v[a+16>>2]+24620>>2]/(tj(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;uc(a+4224|0,b)}function rv(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;v[a+8>>2]=b;_q(b);continue}break}c=v[a>>2];if(c){zc(a);Jb(c)}}function mz(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;hl(b);continue}break}c=v[a>>2];if(c){Vo(a);Jb(c)}}function mM(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]/1e4}return+y[a+24620>>2]/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))*60}function fu(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;v[a+8>>2]=b;yb(b);continue}break}c=v[a>>2];if(c){zc(a);Jb(c)}}function aR(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;v[a+8>>2]=b;Ct(b);continue}break}c=v[a>>2];if(c){zc(a);Jb(c)}}function aK(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;c=EJ(tc(12));v[c+8>>2]=b;v[c+4>>2]=a;v[c>>2]=49196;a=v[If(d+8|0,c)>>2];hb=d+16|0;return a|0}function _U(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;v[a+8>>2]=b;yd(b);continue}break}c=v[a>>2];if(c){zc(a);Jb(c)}}function QN(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;Ub(b);continue}break}c=v[a>>2];if(c){Vo(a);Jb(c)}}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(715827882)>>>0<b>>>0){rd();L()}c=B(b,6);b=tc(c);v[a>>2]=b;v[a+4>>2]=b;d=Db(a),e=b+c|0,v[d>>2]=e}function Hv(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;ac(b);continue}break}c=v[a>>2];if(c){Vo(a);Jb(c)}}function xU(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function tka(a,b,c){var d=0;d=b>>31;a=a^d;pka(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);kb=jb;a=d^ib;b=a-d|0;kb=(d^kb)-((a>>>0<d>>>0)+d|0)|0;return b}function o0(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;lb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);continue}break}}function iz(a,b,c){var d=0,e=0,f=0;d=gl(a,b);if((d|0)!=255){e=$b(a+26|0,d),f=c,u[e>>1]=f;a=a+62|0;e=Ib(a,b),f=255,t[e|0]=f;e=Ib(a,c),f=d,t[e|0]=f}}function hF(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function Via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(2147483647)>>>0<b>>>0){rd();L()}c=b<<1;b=tc(c);v[a>>2]=b;v[a+4>>2]=b;d=Db(a),e=b+c|0,v[d>>2]=e}function Ve(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!b){Pc(c+8|0,a+32|0,5);if(zb(v[v[c+8>>2]>>2],v[c+12>>2])){break a}}v[a+28>>2]=v[a+28>>2]+1}hb=c+16|0}function Tx(a,b,c,d){var e=0;e=hb-16|0;hb=e;a=yq(e,a,d);c=c-b|0;if((c|0)>0){pc(v[a+4>>2],b,c);v[a+4>>2]=v[a+4>>2]+B((c>>>0)/6|0,6)}ic(a);hb=e+16|0}function CO(a){var b=0,c=0,d=0;d=w[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=w[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function m5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-32|0;hb=h;i=h+8|0;GI(i,b,c,d,e,f,g);Xc(a,i);nm(i);hb=h+32|0}function i7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);if(b>>>0<=1){c=Td(c,C(0));if((b|0)==1){d=1;c=Wh(c)}e=Bb(a+4208|0,d),f=c,z[e>>2]=f;sK(a)}}function aC(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function x9(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;u[c+24>>1]=b;b=c+24|0;Nm(c+16|0,b);d=v[c+16>>2];Nm(c+8|0,b);Fk(a,d,v[c+12>>2]);hb=c+32|0}function p8(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;if(Vh(a)>>>0<=12){c=Db(a);d=a;a=Tf(b+8|0,13,sc(v[a>>2],v[a+4>>2]),c);Cd(d,a);Sf(a)}hb=b+32|0}function op(a,b){var c=0;a:{if(!_H(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function oL(a){var b=0;b=hb-16|0;hb=b;z[b+12>>2]=D(a);v[b+8>>2]=646978941;v[b+4>>2]=1259902592;a=z[St(b+12|0,b+8|0,b+4|0)>>2];hb=b+16|0;return a}function nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(1073741823)>>>0<b>>>0){rd();L()}c=OC(b);v[a>>2]=c;v[a+4>>2]=c;d=Db(a),e=(b<<2)+c|0,v[d>>2]=e}function lH(a){var b=0,c=0;v[23516]=0;c=ha(1119)|0;b=v[23516];v[23516]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;Um(a);return}V(0)|0;O()|0;Tb();L()}function Wf(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;u[c+24>>1]=0;Tj(c+8|0,c+24|0);nn(c+16|0,a,v[c+8>>2],v[c+12>>2]);u[b>>1]=x[c+24>>1];hb=c+32|0}function Cba(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;t[c+24|0]=b;b=c+24|0;Pq(c+16|0,b);d=v[c+16>>2];Pq(c+8|0,b);Fk(a,d,v[c+12>>2]);hb=c+32|0}function Bw(a){var b=0,c=0;b=hb-16|0;hb=b;c=-1;a:{if(Pw(a)){break a}if((lb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}hb=b+16|0;return c}function rk(a,b,c,d){var e=0;e=B(b,c);a:{if(v[d+76>>2]<0){a=Nu(a,e,d);break a}a=Nu(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function rN(a,b){t[a+840|0]=b;t[a+812|0]=b;t[a+811|0]=b;t[a+809|0]=b;t[a+807|0]=b;t[a+806|0]=b;t[a+833|0]=b;t[a+826|0]=b>>>4;t[a+827|0]=b<<2&60}function f2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(357913941)>>>0<b>>>0){rd();L()}c=WD(b);v[a>>2]=c;v[a+4>>2]=c;d=Db(a),e=B(b,12)+c|0,v[d>>2]=e}function dj(a,b,c){if(a>>>0<b>>>0){pc(a,b,c);return}if(c){a=a+c|0;b=b+c|0;while(1){a=a-1|0;b=b-1|0;t[a|0]=w[b|0];c=c-1|0;if(c){continue}break}}}function YV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(214748364)>>>0<b>>>0){rd();L()}c=jC(b);v[a>>2]=c;v[a+4>>2]=c;d=Db(a),e=B(b,20)+c|0,v[d>>2]=e}function Tz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(2147483647)>>>0<b>>>0){rd();L()}c=SC(b);v[a>>2]=c;v[a+4>>2]=c;d=Db(a),e=(b<<1)+c|0,v[d>>2]=e}function Im(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(1073741823)>>>0<b>>>0){rd();L()}c=Ai(b);v[a>>2]=c;v[a+4>>2]=c;d=Db(a),e=(b<<2)+c|0,v[d>>2]=e}function t6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){rx(a,0,0,0,0,0,0,c,d);return}rx(a,v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2],v[b+24>>2],b,c,d)}function qO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(536870911)>>>0<b>>>0){rd();L()}c=sD(b);v[a>>2]=c;v[a+4>>2]=c;d=Db(a),e=(b<<3)+c|0,v[d>>2]=e}function oO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(268435455)>>>0<b>>>0){rd();L()}c=QP(b);v[a>>2]=c;v[a+4>>2]=c;d=Db(a),e=(b<<4)+c|0,v[d>>2]=e}function kka(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;v[c+12>>2]=-1;if(xg(a,c+8|0)){v[c+4>>2]=w[c+8|0];hV(a,b,v[Hb(c+4|0,c+12|0)>>2])}hb=c+16|0}function jj(a){var b=0,c=0;b=hb-16|0;hb=b;Ab(b+8|0,a+1074312|0,7);if(zb(v[v[b+8>>2]>>2],v[b+12>>2])){c=Am(v[a+480180>>2])^1}hb=b+16|0;return c}function iS(a){var b=0;if(!(Qb(a,15122,3)|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))-2147483647>>>0<2147484072)){b=w[a+3|0]<6}return b}function cT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(715827882)>>>0<b>>>0){rd();L()}c=QS(b);v[a>>2]=c;v[a+4>>2]=c;d=Db(a),e=B(b,6)+c|0,v[d>>2]=e}function _y(a){var b=0,c=0;b=hb-16|0;hb=b;v[b+8>>2]=a;c=b+8|0;a=1;while(1){if((a|0)>0){Ig(c);a=a-1|0;continue}break}hb=b+16|0;return v[b+8>>2]}function Ufa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=zg(b);zg(b);break a}a=Ng(b);Ng(b)}while(1){if(a){if(a&1){Yb(b,260)}a=a>>>1|0;continue}break}}function NQ(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}Uc(a,8,1,0,10);return}b=16;if(e){break a}}b=8}Uc(a,b,c&2|1,0,d^1)}function Ll(a,b){var c=0,d=0;d=v[a+4>>2];c=v[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;v[a+8>>2]=c;continue}break}b=v[a>>2];if(b){zc(a);Jb(b)}}function JH(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function sQ(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){Vo(a);Jb(b)}}function gi(a){var b=0;a=a*a;b=a*a;return C(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function ft(a,b){var c=0,d=0;d=vf(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!te(a,b,d&65535)){continue}}break}return c&65535}function TV(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;v[c+12>>2]=-1;if(xg(a,c+8|0)){v[c+4>>2]=w[c+8|0];ZB(a,b,v[Hb(c+4|0,c+12|0)>>2])}hb=c+16|0}function Sm(a,b){var c=0;a=Wm(a);v[a>>2]=62524;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function PP(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){Vo(a);Jb(b)}}function sB(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;u[c+14>>1]=1;d=c,e=ul(a,b),u[d+12>>1]=e;a=x[ie(c+14|0,c+12|0)>>1];hb=c+16|0;return a-1&65535}function l4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=g+8|0;HI(h,b,c,d,e,f);Xc(a,g+20|0);nm(h);hb=g+32|0}function fz(a,b,c){var d=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];v[a>>2]=d<<8^v[((w[b|0]^d>>>24)<<2)+29372>>2];b=b+1|0;continue}break}return a}function Maa(a,b){a=a|0;b=b|0;a=Dy(a);v[23516]=0;R(824,a|0,b|0);b=v[23516];v[23516]=0;if((b|0)==1){b=P()|0;O()|0;Op(a);S(b|0);L()}return a|0}function wja(a){a=a|0;var b=0,c=0,d=0;if(Kh(1073741823)>>>0<=8191){rd();L()}b=tc(32768);v[a>>2]=b;v[a+4>>2]=b;c=Db(a),d=b+32768|0,v[c>>2]=d}function Zu(a,b){var c=0;a:{if(!b){break a}if(!Ob(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=1){c=IC(a,1);break a}c=Ng(a);Yb(a,b-2|0)}return c}function OT(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;c=b,d=_b(a),v[c+12>>2]=d;v[b+8>>2]=236;a=v[Vc(b+12|0,b+8|0)>>2];hb=b+16|0;kb=0;return a-216|0}function Mb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;if(b>>>0>=118){Bo(12178);L()}e=d+8|0;Ab(e,a,b);We(e,c);hb=d+16|0;return a|0}function Le(a,b,c){t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a}function Gb(a,b){var c=0;if(zf(w[a+11|0])){Jb(v[a>>2])}c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];Xd(b,0);nd(b,0);return a}function Do(a,b){var c=0;a:{if(!b){break a}if(!Ob(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=3){c=JC(a,b);break a}c=zg(a);Yb(a,b-4|0)}return c}function lF(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=aw(v[d>>2],c)}lb[v[v[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function dZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Hb(a+12|0,a+8|0);hb=a+16|0;return v[b>>2]}function bl(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;c=v[a+24>>2];d=v[a+40>>2];v[b+12>>2]=1;a=v[Vc(a+20|0,b+12|0)>>2];hb=b+16|0;return B(a,c+d|0)}function eba(a){a=a|0;var b=0;b=v[a>>2];if(lb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=lb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function QZ(a){a=a|0;var b=0,c=0,d=0;if(Kh(1073741823)>>>0<=29){rd();L()}b=CF(iw(a),30);v[a>>2]=b;v[a+4>>2]=b;c=Db(a),d=b+120|0,v[c>>2]=d}function Pz(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=Db(b),d=0,v[c>>2]=d;return a}function Nz(a){a=50-(B(w[(a>>>4|0)+31712|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Dc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function Ij(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Vb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;hb=d+16|0}function Hj(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Vb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;hb=d+16|0}function $c(a){var b=0;b=hb-16|0;hb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[b+4>>2]=32767;a=u[Ne(b+8|0,od(b+12|0,b+4|0))>>1];hb=b+16|0;return a}function rU(a){var b=0,c=0,d=0;c=hb-16|0;hb=c;b=c+8|0;nv(b,a);a=w[Ib(b,0)|0];d=w[Ib(b,1)|0];b=w[Ib(b,2)|0];hb=c+16|0;return a|d<<8|b<<16}function Qw(a,b){var c=0;if(b>>>0<=99){return sH(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Zr(qH(c,a),B(a,-100)+b|0)}return $i(a,b)}function IE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a>>2];if(d>>>0<=127){d=v[(d<<2)+c>>2]}v[a>>2]=d;a=a+4|0;continue}break}return b}function I8(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=v[a+20>>2];oe(b,v[c+4>>2],v[c+8>>2]);WK(a,fc(b+8|0,v[b>>2],v[b+4>>2]),0);hb=b+16|0}function k5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=g+8|0;HI(h,b,c,d,e,f);Xc(a,h);nm(h);hb=g+32|0}function eA(a){var b=0;b=Eb(w[a+26|0]|w[a+27|0]<<8);return((w[a+24|0]>15)+(w[a+25|0]>64)|0)+(Eb(w[a+22|0]|w[a+23|0]<<8)<<1>>>0<b>>>0)|0}function dd(a,b){var c=0,d=0,e=0;c=eg(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=lb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function a1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=Mw(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function Rq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((b|0)<0){Bz();L()}b=(b-1>>>5|0)+1|0;c=OC(b);v[a+4>>2]=0;v[a>>2]=c;d=Db(a),e=b,v[d>>2]=e}function OM(a,b,c,d){var e=0;e=a+1074376|0;Ky(a,e,b,c,d);e=0-w[(B(b,872)+e|0)+1428|0]|0;if(d){c=0}else{c=Ts(v[a+480180>>2])}Fn(a,b,e,c)}function bs(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function Pl(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;v[a+8>>2]=b;continue}break}a=v[a>>2];if(a){Jb(a)}}function W1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=sx(v[a+32>>2],b,c,d,2);if(a>>>0<=15){a=w[a+43904|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function SD(a){a=a|0;var b=0;a=Kb(a);v[23516]=0;Q(134,a|0,13740)|0;b=v[23516];v[23516]=0;if((b|0)==1){b=P()|0;O()|0;xb(a);S(b|0);L()}}function CE(a,b,c,d){a=Lb(a);v[23516]=0;U(d|0,a|0,b|0,c|0);b=v[23516];v[23516]=0;if((b|0)!=1){return a}b=P()|0;O()|0;lc(a);S(b|0);L()}function A8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Wc(c&255))){YK(a,8,C(0))}a=gj(a);if(a){lb[v[v[a>>2]+96>>2]](a,b,c,d,e)}}function hba(a,b){a=a|0;b=b|0;a=zu(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function Zh(a,b,c){t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;t[a+4|0]=c;t[a+5|0]=c>>>8;t[a+6|0]=c>>>16;t[a+7|0]=c>>>24}function ZR(a){var b=0;b=hb-16|0;hb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[b+4>>2]=127;a=t[Ne(b+8|0,od(b+12|0,b+4|0))|0];hb=b+16|0;return a}function Ri(a,b){var c=0;if(Fe(a)){c=v[a>>2];Al(a);Jb(c)}c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];Xd(b,0);td(b,0)}function HE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=t[a|0];if((d|0)>=0){d=v[(d<<2)+c>>2]}t[a|0]=d;a=a+1|0;continue}break}return b}function z7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;if(b>>>0<=4){c=Td(c,C(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=Wh(c)}z[d>>2]=c;vK(a)}}function gj(a){var b=0,c=0;b=Pm(v[v[a+20>>2]+28>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[Id(v[a+16>>2]+906300|0,b)>>2]}return c}function Rh(a,b){var c=0,d=0;c=v[a>>2];d=v[a+4>>2];b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Lc(c,d,(b>>31&a)+b|0)>>2]}function PM(a,b,c,d){var e=0;e=a+1074376|0;Ly(a,e,b,c,d);e=w[(B(b,872)+e|0)+1427|0];if(d){c=0}else{c=Ts(v[a+480180>>2])}Fn(a,b,e,c)}function Lf(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;if(b>>>0>=118){Bo(12143);L()}d=c+8|0;Ab(d,a,b);We(d,0);hb=c+16|0;return a|0}function Jw(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return lb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Kf(t[b|0])|0}function $r(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function W0(a){a=a|0;var b=0;if((lb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+1;a=Kf(t[a|0])}else{a=-1}return a|0}function Paa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;if(b>>>0>=250){Bo(12178);L()}d=c+8|0;Ab(d,a,b);fo(d);hb=c+16|0;return a|0}function IH(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}aa(14312,13226,1180,5737);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function El(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kh(-1)>>>0<b>>>0){rd();L()}c=tc(b);v[a>>2]=c;v[a+4>>2]=c;d=Db(a),e=b+c|0,v[d>>2]=e}function rg(a){var b=0;b=hb-16|0;hb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[b+4>>2]=255;a=w[Ne(b+8|0,od(b+12|0,b+4|0))|0];hb=b+16|0;return a}function GC(a,b){var c=0;c=rka(b&255,0,1536,0);b=kb;a=rka(a&255,0,25,0);c=a+c|0;b=kb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;kb=b;return a}function xN(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(w[a+480180|0]&2){break a}}v[b+56>>2]=0;d=Ln(a,x[b+70>>1],v[b+48>>2],c,0)}return d}function je(a){var b=0;a=v[a+4>>2];if(a){if(Ym(a)){a:{b=a+8|0;if(v[b>>2]){if((uv(b)|0)!=-1){break a}}lb[v[v[a>>2]+16>>2]](a)}}}}function hq(a,b){var c=0;c=wd(v[a+4>>2],w[a+11|0]);if((c|0)==(wd(v[b+4>>2],w[b+11|0])|0)){a=Gv(qd(a),qd(b),c)}else{a=1}return!a}function hW(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;b=v[v[b>>2]-12>>2]+b|0;if(Mh(b)){b=v[b+72>>2];if(b){ev(b)}t[a|0]=1}return a|0}function bz(a,b){var c=0;c=v[a+484360>>2];b=b&255;if(pj(c,v[a+484364>>2])>>>0<=b>>>0){return Sb(c,w[a+484376|0])}return wj(c,b)}function _F(a,b,c,d,e,f){a=lb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Jr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function XF(a,b,c,d,e,f){a=lb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Hr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function WY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function S0(a){a=a|0;var b=0;if((lb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+4;a=v[a>>2]}else{a=-1}return a|0}function FE(a,b,c){var d=0;d=hb-16|0;hb=d;v[d+8>>2]=a;v[d+12>>2]=b;v[d>>2]=c;v[d+4>>2]=0;a=Qq(d+8|0,d);hb=d+16|0;return v[a>>2]}function $w(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}pc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function yJ(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=fJ(tc(8));v[c+4>>2]=a;v[c>>2]=58056;a=v[If(b+8|0,c)>>2];hb=b+16|0;return a|0}function sq(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function oE(a,b,c){a=Wh(a);a:{if(a>=b){break a}c=0;if(a<=C(0)){break a}if(a<C(4294967296)&a>=C(0)){c=~~a>>>0;break a}}return c}function gZ(a){a=a|0;var b=0;b=hb-16|0;hb=b;ii(ji(b+8|0,v[a+8>>2]));hb=b+16|0;a=v[a+8>>2];if(!a){return 1}return(uF(a)|0)==1|0}function _B(a,b){var c=0;c=v[b+4>>2];if(c){ec(a,c,v[b>>2]);return}c=v[b+8>>2];b=v[b+12>>2];if(!nc(c,b)){oe(a,c,b);return}ce(a)}function UD(){var a=0,b=0,c=0;a=hb-16|0;hb=a;b=Fc(a,14901);if(Fb(b)){c=(Cg(b,13945)|0)!=-1}else{c=0}wb(b);hb=a+16|0;return c|0}function OY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function KO(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){xd(b,a)}if(c){xd(c,a)}if(d){xd(d,a)}if(e){xd(e,a)}}function Ds(a){var b=0;b=A[a+4248>>3]/+y[v[a+16>>2]+24620>>2];A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*(A[a+4288>>3]/60)}}function zS(a,b){var c=0;c=hb-16|0;hb=c;a=eh(c,a,1);xm(v[a+4>>2],x[b>>1]|x[b+2>>1]<<16);v[a+4>>2]=v[a+4>>2]+4;ic(a);hb=c+16|0}function tY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Tg(a,v[b+8>>2],0)){bw(b,c,d);return}a=v[a+8>>2];lb[v[v[a>>2]+28>>2]](a,b,c,d)}function ol(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(lb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function ew(a,b){var c=0,d=0,e=0,f=0;c=Og(b);d=tc(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=pc(zc(d),b,c+1|0),v[e>>2]=f}function Jq(a,b){return ho(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24),w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))?b:a}function nS(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;u[c+14>>1]=b;if((ul(v[a>>2],v[a+4>>2])|0)!=65535){PB(a,c+14|0)}hb=c+16|0}function jg(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return Sn(a,d)}function jU(a){var b=0;a:{if(Qb(a,3863,4)){break a}if(Qb(a+44|0,17937,3)){break a}b=(w[a+47|0]|w[a+48|0]<<8)>>>0>97}return b}function _k(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;Wx(a,c,d)}function YF(a,b,c,d,e,f){a=lb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Hr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function Tc(a,b,c){var d=0;d=a;a=c&31;if((c&63)>>>0>=32){c=b>>31;a=b>>a}else{c=b>>a;a=((1<<a)-1&b)<<32-a|d>>>a}kb=c;return a}function NN(a){Oy(a);v[a>>2]=0;v[a+4>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;a=Xf(a);Xf(a+12|0);t[a+24|0]=1}function $F(a,b,c,d,e,f){a=lb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Jr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function rc(a,b){var c=0;a=cm(a);v[a+4>>2]=0;v[a>>2]=49296;c=Md(Fb(b)+1|0);v[a+4>>2]=c;if(c){pc(c,Ic(b),Fb(b)+1|0)}return a}function qK(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=lc(b-24|0);if((c|0)!=(b|0)){continue}break}return Ff(a)|0}function HQ(a,b){var c=0;c=hb-16|0;hb=c;nR(c+8|0,a);Be(c,b);a=Mc(v[c+8>>2],v[c+12>>2],v[c>>2],v[c+4>>2]);hb=c+16|0;return a}function qE(a,b){v[a>>2]=b;lH(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function l8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=dh(C(Td(c,C(0))*C(127))),t[d|0]=e;Cs(a)}}function cu(a,b,c){c=c&255;while(1){a:{if(!b){a=0;break a}if(nc(w[a|0],c)){break a}b=b-1|0;a=a+1|0;continue}break}return a}function Sz(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function SL(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function CQ(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((w[a+b|0]-127&255)>>>0>160){continue}}break}return(b|0)==8}function $8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=dh(C(Td(c,C(0))*C(255))),t[d|0]=e;Fs(a)}}function me(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function Ko(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function d2(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((a|0)!=(b|0)){QK(v[c>>2],a);v[c>>2]=v[c>>2]+12;a=a+12|0;continue}break}}function bH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return lb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function aQ(a){var b=0;if(!(w[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){v[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function aP(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){ZO(a,1);ZO(a,0)}}function XR(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!eg(a,4)){KS(b);break a}Jh(c+8|0,b);dA(c,a,v[c+8>>2],v[c+12>>2])}hb=c+16|0}function Ug(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;v[f+12>>2]=e;c=ji(f+8|0,c);a=Kr(a,b,d,v[f+12>>2]);ii(c);hb=f+16|0;return a}function AY(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((c|0)>=257){nF();b=94048;break a}if(!w[469792]){t[469792]=1}b=94044}fc(a,c,b)}function $O(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){_O(a,1);_O(a,0)}}function yi(a,b,c){c=w[c|0];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=w[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function vT(a,b,c){var d=0;while(1){if(b){d=w[c|0]|w[c+1|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}}function tR(a){var b=0;if(!(Qb(a,13897,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64))){b=(w[a+33|0]-1&255)>>>0<32}return b}function mN(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Wb(v[a>>2]+((B((d^-1|-256)+b|0,c<<24>>24)|0)/2|0)|0,0,256),v[e>>2]=f}}function ht(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function ZX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return lb[a|0](h|b,c,d,e,b|f,g)|0}function Ye(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function tE(a,b,c){a=se(a);a:{if(a>=b){break a}c=0;if(a<=0){break a}if(a<4294967296&a>=0){c=~~a>>>0;break a}}return c}function eG(a,b,c){var d=0;d=hb-16|0;hb=d;v[d+12>>2]=c;b=ji(d+8|0,b);a=DG(a,9291,v[d+12>>2]);ii(b);hb=d+16|0;return a}function Hi(a){var b=0;while(1){a:{if((b|0)!=46){if(w[b+43936|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function hP(a){v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function fV(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;yd(b);continue}break}v[a+4>>2]=c}function Ro(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;_q(b);continue}break}v[a+4>>2]=c}function Q6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=2){c=Td(c,C(0));d=Bb(a+4208|0,b),e=c,z[d>>2]=e;mK(a)}}function P$(a){a=a|0;var b=0,c=0;c=v[a+4>>2];b=v[a>>2];a=v[a+8>>2];b=b+(a>>1)|0;if(a&1){c=v[c+v[b>>2]>>2]}lb[c|0](b)}function O7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=5){c=Td(c,C(0));d=Bb(a+4208|0,b),e=c,z[d>>2]=e;CK(a)}}function Jg(a){var b=0;um(a);b=vt(v[a>>2],yk(x[a+34>>1]));v[a+20>>2]=b;if(!b){return 0}return Fj(v[a>>2],x[a+34>>1])}function I6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=3){c=Td(c,C(0));d=Bb(a+4208|0,b),e=c,z[d>>2]=e;kK(a)}}function H7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=4){c=Td(c,C(0));d=Bb(a+4208|0,b),e=c,z[d>>2]=e;xK(a)}}function tu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;Km(d+8|0,b);v[d+4>>2]=v[d+8>>2];gu(a,d+4|0,c);hb=d+16|0}function dO(a){var b=0,c=0,d=0;if(v[a>>2]){Gc(a);b=v[a>>2];Zm(a);Jb(b);c=Db(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function XO(a){var b=0,c=0,d=0;if(v[a>>2]){Gc(a);b=v[a>>2];Om(a);Jb(b);c=Db(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function Kh(a){var b=0;b=hb-16|0;hb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=Hb(b+12|0,b+8|0);hb=b+16|0;return v[a>>2]}function IG(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function EL(a){var b=0,c=0,d=0;if(v[a>>2]){Gc(a);b=v[a>>2];nu(a);Jb(b);c=Db(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function Di(a){var b=0;b=hb-16|0;hb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=v[Hb(b+12|0,b+8|0)>>2];hb=b+16|0;return a}function $t(a){var b=0,c=0,d=0;if(v[a>>2]){Gc(a);b=v[a>>2];Vh(a);Jb(b);c=Db(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function pc(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function iV(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function RQ(a){var b=0;if(!(Qb(a+44|0,13906,4)|w[a+29|0]!=16)){b=((w[a+42|0]|w[a+43|0]<<8)-1&65535)>>>0<2}return b}function GH(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+((c+c)*d+(c*c-e))}function Cd(a,b){var c=0;c=b+4|0;aq(v[a>>2],v[a+4>>2],c);oc(a,c);oc(a+4|0,b+8|0);oc(Db(a),zc(b));v[b>>2]=v[b+4>>2]}function wK(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function vN(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function al(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function ZG(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!nc(eH(c,b),-1)){break a}v[a>>2]=0}return a|0}function Sl(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}Bh(a,b);a=a+1|0;continue}}}function Ir(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}oc(a,b);a=a+4|0;continue}}}function lQ(a){if(Qb(a,13879,4)){a=0}else{a=(_b(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))|0)==1}return a}function gQ(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;v[a+8>>2]=b;continue}break}}function B3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=lb[v[v[b>>2]+8>>2]](b)|0;d=c,e=fg(a?a:21751),v[d>>2]=e}}function nw(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(v[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function mm(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function l0(a,b){a=a|0;b=b|0;var c=0,d=0;lb[v[v[a>>2]+24>>2]](a)|0;b=yw(b);v[a+36>>2]=b;c=a,d=pn(b),t[c+44|0]=d}function i0(a,b){a=a|0;b=b|0;var c=0,d=0;lb[v[v[a>>2]+24>>2]](a)|0;b=Dw(b);v[a+36>>2]=b;c=a,d=pn(b),t[c+44|0]=d}function Zi(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function Lm(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function vL(a){var b=0;b=hb-16|0;hb=b;v[b+12>>2]=a;v[b+8>>2]=32767;a=u[Hb(b+12|0,b+8|0)>>1];hb=b+16|0;return a}function tl(a){var b=0;b=hb-16|0;hb=b;v[b+12>>2]=a;v[b+8>>2]=65535;a=x[Hb(b+12|0,b+8|0)>>1];hb=b+16|0;return a}function pu(a,b){var c=0;c=hb-16|0;hb=c;v[c+12>>2]=(B(a,b)>>>0)/255;me(c+12|0,0,15);hb=c+16|0;return w[c+12|0]}function We(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function Tg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!xi(v[a+4>>2],v[b+4>>2])}function IF(a,b){var c=0;c=hb-16|0;hb=c;a=Gk(c,a,1);nd(v[a+4>>2],w[b|0]);v[a+4>>2]=v[a+4>>2]+1;ic(a);hb=c+16|0}function GE(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=Bb(c,a);a=a+1|0;v[d>>2]=a<<b;continue}break}}function DQ(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;b=a>>>0>c>>>0?b+1|0:b;kb=b;return c}function yp(a,b){var c=0;c=hb-32|0;hb=c;Jh(c+16|0,b);nn(c+24|0,a,v[c+16>>2],v[c+20>>2]);Jh(c+8|0,b);hb=c+32|0}function oM(a,b){var c=0;c=hb-16|0;hb=c;a=yz(c,a);dq(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;ic(a);hb=c+16|0}function ju(a){var b=0;b=hb-16|0;hb=b;u[b+14>>1]=a;u[b+12>>1]=255;a=w[Rc(b+14|0,b+12|0)|0];hb=b+16|0;return a}function cl(a,b,c,d){var e=0;e=hb-16|0;hb=e;v[e+12>>2]=d;v[e+8>>2]=c;fc(a,b,v[Hb(e+12|0,e+8|0)>>2]);hb=e+16|0}function YL(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function $v(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=aw(v[e>>2],h)}lb[v[v[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function ti(a){var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function ida(){var a=0;a=hb-16|0;hb=a;if($a(a+12|0,4)|0){Yr(v[115992],12678);L()}hb=a+16|0;return v[a+12>>2]}function gH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return lb[v[v[a>>2]+36>>2]](a)|0}return Kf(t[b|0])}function ZF(a,b,c,d,e){b=Ti(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function WF(a,b,c,d,e){b=Si(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function Rw(a,b){var c=0;if(b>>>0<=9999){return Qw(a,b)}c=a;a=(b>>>0)/1e4|0;return $i(Qw(c,a),B(a,-1e4)+b|0)}function IO(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+20>>1]>>>6|x[b+22>>1]<<4)&65535)+29232|0]>>>x[a+68>>1]}function qm(a,b){var c=0;c=hb-16|0;hb=c;v[c+8>>2]=a;a=c+8|0;v[a>>2]=v[a>>2]+(b<<2);hb=c+16|0;return v[a>>2]}function Xga(a,b){a=a|0;b=b|0;if(!wS(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}function WH(a,b,c,d){z[d+4>>2]=a+c;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=b+a}function Sx(a,b){a=Lb(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Lb(a+24|0);Kb(a+36|0);v[a+48>>2]=b;return a}function MR(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(b>=0){A[a+8>>3]=b;v[a+16>>2]=3}return a}function Bl(a){var b=0;b=hb-16|0;hb=b;v[b+12>>2]=a;v[b+8>>2]=255;a=w[Hb(b+12|0,b+8|0)|0];hb=b+16|0;return a}function ov(a){var b=0;b=hb-16|0;hb=b;a=v[cc(b+8|0,qd(a)+wd(v[a+4>>2],w[a+11|0])|0)>>2];hb=b+16|0;return a}function jR(a){var b=0;if(!(Qb(a,17932,4)|w[a+5|0]!=16|(w[a+54|0]-33&255)>>>0<224)){b=w[a+4|0]>95}return b}function i4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return WE(a,b,c,d,e,f,g,12945,1047)|0}function Zs(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=In(a);continue}break}return a}function Yu(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function Vja(a,b){a=a|0;b=b|0;var c=0;b=hb-80|0;hb=b;c=-1;if(VU(a,b+8|0)){c=UU(b+8|0)}hb=b+80|0;return c|0}function V3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return WE(a,b,c,d,e,f,g,13013,1054)|0}function Pga(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(Nj(a,b+8|0)){c=iS(b+8|0)}hb=b+16|0;return c|0}function yr(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=aw(v[d>>2],g)}lb[v[v[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function wV(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(Nj(a,b+8|0)){c=DB(b+8|0)}hb=b+16|0;return c|0}function tF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function mO(a,b){var c=0;c=v[a+484344>>2];if(te(c,v[a+484348>>2],b)){a=v[Xb(c,b)+12>>2]}else{a=1}return a}function Qk(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return lb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function zM(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;$k(c);continue}break}v[a+4>>2]=b}function qQ(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;pQ(c);continue}break}v[a+4>>2]=b}function kC(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;yb(c);continue}break}v[a+4>>2]=b}function he(a,b){a=Gl(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];Gl(a+12|0,v[b+12>>2],v[b+16>>2]);return a}function gO(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;Ue(c);continue}break}v[a+4>>2]=b}function QO(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;hl(c);continue}break}v[a+4>>2]=b}function Pb(a,b,c){var d=0;c=v[a+4>>2]+c|0;d=b;b=v[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;v[a>>2]=b;v[a+4>>2]=c}function yU(a){a:{if(Qb(a,14269,4)){break a}if(Qb(a+8|0,14250,4)){break a}return 1}return!Qb(a,14250,4)}function PN(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}A[a>>3]=d}}function KY(){if(w[468028]){return v[117006]}sp(468020,AK());t[468028]=1;v[117006]=468020;return 468020}function uF(a){var b=0,c=0;b=hb-16|0;hb=b;a=ji(b+8|0,a);c=v[v[116018]>>2];ii(a);hb=b+16|0;return c?4:1}function el(a,b,c,d){a=a&65535;c=c&65535;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function wT(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=Eb(b&65535),u[d+14>>1]=e;KJ(a,c+14|0);hb=c+16|0}function nX(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;c=-1;if(PD(a,b+8|0)){c=OD(b+8|0)}hb=b+32|0;return c|0}function kB(a,b){if(b>>>0<=126){af(((b<<5)+a|0)+480280|0);Vn((B(b,872)+a|0)+1074992|0,a,b,134217728)}}function iB(a){var b=0,c=0;if(v[a>>2]){Gc(a);Jb(v[a>>2]);b=Db(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function VA(a){a=a|0;var b=0;u[a+34>>1]=0;b=a+43|0;gm(b,b+22|0,62620);v[a+20>>2]=0;jd(a,0);return a|0}function Rb(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function Iq(a,b,c){var d=0;d=hb-16|0;hb=d;if(b){t[d+15|0]=0;qM(a+36|0,b,yi(b,b+c|0,d+15|0))}hb=d+16|0}function IW(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=-1;if(Nj(a,b+8|0)){c=jD(b+8|0)}hb=b+16|0;return c|0}function BP(a){if(((w[a+68|0]|w[a+69|0]<<8)-128&65535)>>>0>=65409){a=Qb(a,17780,17)}else{a=1}return!a}function uo(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Mo(a,b+8|0)){c=_b(v[b+8>>2])}hb=b+16|0;return c|0}function tW(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Mm(c+8|0,b);Tq(a,v[c+8>>2],v[c+12>>2]);hb=c+16|0}function sW(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;vj(a+8|0,0);Rq(a,127);PC(a,127,w[b|0]);return a|0}function _1(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;YB(c+8|0,b);Tq(a,v[c+8>>2],v[c+12>>2]);hb=c+16|0}function WR(a){u[a+10>>1]=0;u[a+12>>1]=0;u[a+8>>1]=1084;v[a>>2]=0;v[a+4>>2]=40;u[a+14>>1]=0;return a}function Qj(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function IM(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3;return a}function Eu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function Ej(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Jo(a,b+8|0)){c=Eb(x[b+8>>1])}hb=b+16|0;return c|0}function EP(a){Ud(a+140|0);yb(a+120|0);yb(a+100|0);yb(a+80|0);yb(a+60|0);yb(a+40|0);yb(a+20|0);yb(a)}function $S(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){_S(c+52|0);xb(c+40|0);lc(c+16|0);lc(c+4|0);Jb(c)}}function iM(a,b){if(b>>>0<=255){a=v[((b<<2)+a|0)+900380>>2];a=a?a+492|0:21751}else{a=21751}return a}function Xc(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];kE(b);return a}function V1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=zz(sx(v[a+32>>2],b,c,d,3));return(a>>>0<5?a+1|0:0)|0}function RS(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]+B((b|0)/-6|0,6)|0;v[d>>2]=c;if((b|0)>0){pc(c,a,b)}}function C8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=gj(a);if(a){lb[v[v[a>>2]+88>>2]](a,b,c,d,e)}}function y8(a,b,c){a=a|0;b=b|0;c=c|0;a=gj(a);if(!a){return 0}return lb[v[v[a>>2]+104>>2]](a,b,c)|0}function x3(a,b){a=a|0;b=b|0;var c=0;b=Ic(b);c=v[a+4>>2];if(c){lb[c|0](b,v[a+8>>2]);return}zs(b,a)}function vF(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;e=ji(f+8|0,e);a=Lr(a,b,c,d);ii(e);hb=f+16|0;return a}function lg(a,b,c){var d=0;d=c;c=v[a>>2];d=v[a+4>>2]-(d+(c>>>0<b>>>0)|0)|0;v[a>>2]=c-b;v[a+4>>2]=d}function kO(a,b,c){var d=0;d=hb-16|0;hb=d;a=v[cc(d+8|0,cO(b,c,Pd(a),gc(a)))>>2];hb=d+16|0;return a}function cga(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(mB(a,b)){c=DR(b)}hb=b+16|0;return c|0}function _u(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=xg(a,b+15|0);hb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function Gn(a,b,c,d){a=a&255;c=c&255;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function Cga(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Jo(a,b+8|0);hb=b+16|0;return(a?x[b+8>>1]:0)<<16>>16}function gx(a,b,c){b=(B(B(ex(a),fx(a,b)),125)>>>0)/(cI(a,b)>>>0)|0;a=(a&6)==6?b&-4:b;return a?a:c}function M6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;lb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;sp(d,a);UJ(a,c)}function o4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return aF(a,b,c,d,e,f,10638,1044)|0}function nn(a,b,c,d){var e=0;e=hb-16|0;hb=e;Vg(e+8|0,c,d);fG(a,b,v[e+8>>2],v[e+12>>2]);hb=e+16|0}function n5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return aF(a,b,c,d,e,f,10683,1018)|0}function mi(a,b,c){if(c){while(1){v[a>>2]=v[b>>2];a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}}function kw(a,b,c,d){var e=0;e=hb-16|0;hb=e;ec(e+8|0,c,d);fG(a,b,v[e+8>>2],v[e+12>>2]);hb=e+16|0}function Uz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){v[a>>2]=v[c>>2];b=b-1|0;a=a+4|0;continue}break}}function SE(a,b,c){var d=0;d=hb-16|0;hb=d;c=Fc(d,c);a=rc(a,c);wb(c);v[a>>2]=b;hb=d+16|0;return a}function O0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function N0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function M0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function L0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function K0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function J0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function Bp(a,b){var c=0;c=hb-16|0;hb=c;v[c+8>>2]=v[a>>2];a=v[fB(c+8|0,b)>>2];hb=c+16|0;return a}function y0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function vR(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}v[a>>2]=b}}function sha(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Mo(a,b+8|0);hb=b+16|0;return C(a?z[b+8>>2]:C(0))}function mt(a,b){b=rka(a,a>>31,b,b>>31)+5e5|0;a=kb;return Dc(ska(b,b>>>0<5e5?a+1|0:a,1e6,0),kb)}function mY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Tg(a,v[b+8>>2],f)){dw(b,c,d,e)}}function jv(a,b){a=dD(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];dD(a+12|0,v[b+12>>2],v[b+16>>2])}function iaa(a,b){a=a|0;b=b|0;vi(a);vi(a);a:{if(b>>>0>=60){Yb(a,4);break a}vi(a)}return vi(a)|0}function g3(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=v[If(b+8|0,nl(tc(12),a))>>2];hb=b+16|0;return a|0}function ZV(a){a=a|0;var b=0;b=v[a+76>>2];if(nc(-1,b)){b=RC(a,32);v[a+76>>2]=b}return b<<24>>24}function OB(a,b){a=a|0;b=b|0;if(!Au(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0}}function CV(a,b){a=a|0;b=b|0;if(!Au(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function xG(a){var b=0;b=v[116018];if(a){v[116018]=(a|0)==-1?467812:a}return(b|0)==467812?-1:b}function ZU(a){var b=0;if(!(Qb(a,26500,20)|(w[a+25|0]-9&255)>>>0<248)){b=t[a+47|0]>=0}return b}function ZA(a,b){var c=0;c=hb-16|0;hb=c;v[c+8>>2]=a;a=v[_T(c+8|0,0-b|0)>>2];hb=c+16|0;return a}function Vv(a,b,c,d){var e=0;v[a>>2]=v[b>>2];e=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<d)+e;return a}function OU(a,b){return(Wb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Wb((B(a&15,b)>>>0)/15|0,1,15))&255}function KH(a){var b=0;b=+((a&2097151)>>>0);return C(Vj(+C((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function yC(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;kb=a;return b}function vu(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=a;a=Fc(c,b);Xc(d,a);wb(a);hb=c+16|0}function nQ(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function gm(a,b,c){b=b-a|0;while(1){if((b|0)>0){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function Qf(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=a;a=vc(c,b);Xc(d,a);xb(a);hb=c+16|0}function Lk(a){var b=0;b=hb-16|0;hb=b;a=v[cc(b+8|0,wc(a)+(Fb(a)<<2)|0)>>2];hb=b+16|0;return a}function $X(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=lb[a|0](b,c,d,e)|0;ra(kb|0);return a|0}function yG(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function qW(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=xg(a,b+8|0);hb=b+16|0;return(a?w[b+8|0]:0)&255}function qF(a){a=a|0;var b=0;v[a>>2]=84268;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Jb(b)}return a|0}function jga(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;c=a;a=Ih(b+8|0);fS(c,a,0,0);yb(a);hb=b+32|0}function XA(a){var b=0,c=0;b=hb-16|0;hb=b;if(Jo(a,b+8|0)){c=ne(u[b+8>>1])}hb=b+16|0;return c}function JQ(a){var b=0,c=0;b=hb-16|0;hb=b;if(IQ(a,b+8|0)){c=_b(v[b+8>>2])}hb=b+16|0;return c}function F0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return lb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function fx(a,b){a=a&255;return w[(B(a>>>1&3,15)+B(a>>>3&1,45)+((b&240)>>>4)|0)+64961|0]<<1}function fR(a){a:{if(Qb(a,17725,4)){break a}if(Qb(a+8|0,14307,4)){break a}return 1}return 0}function Ofa(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Hh(a,b+8|0);hb=b+16|0;return+(a?A[b+8>>3]:0)}function Ny(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function NC(a,b){if((a&4088)>>>0>=520){b=bv(0-vka(b^1230262859,25)|0,4)^1247037516}return b}function CJ(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=VK(d);b=b+1|0}eJ(a,b,c,d,e)}function $f(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){kB(a,c);b=b+1|0;continue}break}}function rK(a,b){var c=0;c=v[a+12>>2];if((c|0)>0){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function ih(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function fw(a,b,c){var d=0;d=hb-16|0;hb=d;c=ji(d+8|0,c);a=Tw(a,b);ii(c);hb=d+16|0;return a}function fH(a){var b=0;b=v[a>>2];if(b){if(!nc(gH(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function eO(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[gc(a)+4|0]){fO(b+16|0)}if(b){Jb(b)}}}function dD(a,b,c){var d=0;d=hb-16|0;hb=d;b=Gl(d+8|0,b,c);ID(b,a);je(b);hb=d+16|0;return a}function YS(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[gc(a)+4|0]){Xt(b+16|0)}if(b){Jb(b)}}}function TL(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[gc(a)+4|0]){ac(b+16|0)}if(b){Jb(b)}}}function Pf(a,b){var c=0;c=hb-16|0;hb=c;v[c+8>>2]=a;a=v[fB(c+8|0,b)>>2];hb=c+16|0;return a}function Nl(a,b,c){var d=C(0);if(b>>>0<=c>>>0){d=z[Bb(a+4208|0,b)>>2]}else{d=C(0)}return d}function Lv(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+21800>>2]}else{b=9761}vc(a,b)}function KP(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;kb=a;return b}function D6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;rx(a,b,c,d,e,0,0,f,g)}function xw(a,b,c,d){var e=0;e=hb-16|0;hb=e;v[e+12>>2]=d;a=Kr(a,b,c,d);hb=e+16|0;return a}function vka(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function er(a){var b=0;while(1){if(!nc(w[a|0],0)){a=a+1|0;b=b+1|0;continue}break}return b}function _X(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;lb[a|0](b,c,d,e,f,g)}function Ng(a){var b=0;b=hb-16|0;hb=b;a=Jo(a,b+8|0);hb=b+16|0;return(a?x[b+8>>1]:0)&65535}function IU(a,b,c){var d=0;d=hb-16|0;hb=d;Zh(d+8|0,b,c);hb=d+16|0;return v[d+8>>2]==(a|0)}function GJ(a){a=a|0;var b=0;v[a>>2]=49296;b=v[a+4>>2];if(b){Jb(b);v[a+4>>2]=0}return a|0}function Fp(a,b,c){a=a+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function E8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=gj(a);if(a){lb[v[v[a>>2]+76>>2]](a,b,c,d)}}function D8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=gj(a);if(a){lb[v[v[a>>2]+84>>2]](a,b,c,d)}}function B8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=gj(a);if(a){lb[v[v[a>>2]+92>>2]](a,b,c,d)}}function $K(a,b){a=a|0;b=b|0;var c=0;c=Fb(a);if(c>>>0<b>>>0){uu(a,b-c|0,0);return}BL(a,b)}function uh(a){var b=0;b=hb-16|0;hb=b;a=v[cc(b+8|0,wc(a)+Fb(a)|0)>>2];hb=b+16|0;return a}function r0(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){Cw(a,c);return}Fc(a,7914)}function nz(a,b){a=nl(a,b);Xc(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function ns(a){if(mJ(a)){a=ba(4)|0;v[a>>2]=0;a=cm(a);v[a>>2]=92232;ia(a|0,92268,26);L()}}function nR(a,b){var c=0;c=hb-16|0;hb=c;Mm(c+8|0,b);WS(a,v[c+8>>2],v[c+12>>2]);hb=c+16|0}function dt(a){var b=0;b=hb-16|0;hb=b;a=v[cc(b+8|0,Ic(a)+Fb(a)|0)>>2];hb=b+16|0;return a}function bN(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|64;v[a+852>>2]=v[a+852>>2]+b}}function Ms(a,b){var c=0;c=Ic(a);if(c>>>0<=b>>>0){a=Fb(a)+c>>>0>=b>>>0}else{a=0}return a}function KM(a){a=Kb(a);Kb(a+12|0);Kb(a+24|0);Kb(a+36|0);Kb(a+48|0);v[a+60>>2]=0;return a}function Je(a){var b=0;b=hb-16|0;hb=b;a=xg(a,b+15|0);hb=b+16|0;return(a?w[b+15|0]:0)&255}function JM(a){var b=0;b=a+4e4|0;while(1){b=qy(b-160|0);if((b|0)!=(a|0)){continue}break}}function Av(){var a=0,b=0;a=hb-16|0;hb=a;b=If(a+8|0,Lb(tc(12)));hb=a+16|0;return v[b>>2]}function sg(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function cH(a){var b=0;b=v[a>>2];if(b){if(!sn(Qk(b))){return!v[a>>2]}v[a>>2]=0}return 1}function Ym(a){var b=0;b=uv(a+4|0);if((b|0)==-1){lb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function St(a,b,c){var d=C(0);d=z[a>>2];if(!Rt(d,z[b>>2])){b=Rt(z[c>>2],d)?c:a}return b}function SW(a){a=a|0;var b=0;b=v[a+4>>2];return(lb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function Mv(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function Lp(a,b,c){a=bl(a)-v[a+16>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function LA(a){var b=0;b=xz(a);while(1){if((a|0)!=(b|0)){gV(a);a=a+32|0;continue}break}}function Jx(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=VK(d);b=b+1|0}Cx(a,b,c,d)}function G8(a,b){a=a|0;b=b|0;a=gj(a);if(!a){return 1}return lb[v[v[a>>2]+68>>2]](a,b)|0}function FL(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){dj(c,a,d)}return B((d|0)/6|0,6)+c|0}function CG(a,b){var c=0;c=hb-16|0;hb=c;v[c+12>>2]=b;a=DG(a,11144,b);hb=c+16|0;return a}function yX(){var a=0;a:{if(VD(19988497)){break a}if(UD()){break a}a=TD()^1}return a|0}function m4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return $E(a,b,c,d,e,12401,1045)|0}function l5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return $E(a,b,c,d,e,12501,1019)|0}function cI(a,b){a=a&255;return v[(b&12)+64964>>2]>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function ZP(a){var b=0;b=a+36|0;while(1){b=wb(b-12|0);if((b|0)!=(a|0)){continue}break}}function YR(a){var b=0;b=a+24|0;while(1){b=wb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Ou(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;t[c+15|0]=b;OJ(a,c+15|0);hb=c+16|0}function JD(a,b){var c=0;c=hb-16|0;hb=c;b=Bg(c+8|0,b);ID(b,a);je(b);hb=c+16|0;return a}function FB(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+26448|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function DO(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function Ac(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;Mm(d,a);Cl(d,b);hb=c+16|0;return a}function zs(a,b){a=a|0;b=b|0;b=hb-16|0;hb=b;v[b>>2]=a;YJ(17954,b);xs(93592);hb=b+16|0}function yl(a,b,c){a=a|0;b=b|0;c=c|0;if(Oc(a,b)>>>0<=c>>>0){Vu();L()}return(c<<1)+a|0}function u$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return LE(b,c,d,e,f,1)|0}function s$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return LE(b,c,d,e,f,0)|0}function lA(a,b,c,d){var e=0;e=hb-16|0;hb=e;a=eh(e,a,d);Vt(b,c,a+4|0);ic(a);hb=e+16|0}function kE(a){var b=0;while(1){if((b|0)!=3){v[(b<<2)+a>>2]=0;b=b+1|0;continue}break}}function k$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return JE(b,c,d,e,f,1)|0}function j1(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function i1(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function i$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return JE(b,c,d,e,f,0)|0}function g4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return VE(a,b,c,d,e,9645,1048)|0}function aq(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>0){pc(c,a,b)}}function Xs(a,b){if(!(t[b+851|0]&1&v[a+480180>>2]==8)){fy(a,b,0);fy(a,b,1);fy(a,b,2)}}function Wt(a,b,c,d){var e=0;e=hb-16|0;hb=e;a=Gk(e,a,d);Vt(b,c,a+4|0);ic(a);hb=e+16|0}function Tl(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function T3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return VE(a,b,c,d,e,9717,1055)|0}function SY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+82768>>2]}return b<<24>>24}function QY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+81232>>2]}return b<<24>>24}function Pt(a,b){var c=0;c=hb-16|0;hb=c;u[c+14>>1]=b;Lt(a+236|0,128,c+14|0);hb=c+16|0}function PF(a,b){var c=0,d=0;Xe(a,_d(b));b=gc(b);c=gc(a),d=v[b>>2],v[c>>2]=d;return a}function NO(a,b,c,d){var e=0;e=hb-16|0;hb=e;a=$h(e,a,d);Vt(b,c,a+4|0);ic(a);hb=e+16|0}function Bt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function te(a,b,c){if(Hm(a,b,c)){a=ag(a,c);a=Nb(v[a>>2],v[a+4>>2])}else{a=0}return a}function XP(a,b,c,d,e,f){a=cc(a,b);cc(a+4|0,c);cc(a+8|0,d);cc(a+12|0,e);cc(a+16|0,f)}function Uv(a,b){var c=0;while(1){if((b|0)!=(c|0)){Ch(a+c|0);c=c+1|0;continue}break}}function Lz(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function In(a){var b=0;b=a;a=v[a>>2];v[b>>2]=B(a,214013)+2531011;return a>>>16&32767}function Gj(a,b,c){var d=0;d=v[a>>2];if(!fp(d,v[b>>2])){b=fp(v[c>>2],d)?c:a}return b}function Eg(a,b,c){var d=0;d=A[a>>3];if(!DP(d,A[b>>3])){b=DP(A[c>>3],d)?c:a}return b}function Cj(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;sg(a)}function CF(a,b){a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=Ai(b)}return a}function $e(a){a=a|0;var b=0;b=v[a>>2];return(lb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function xF(a){a=a|0;v[a>>2]=84320;if(v[a+8>>2]!=(Dd()|0)){zG(v[a+8>>2])}return a|0}function up(a){a=a|0;v[a+56>>2]=78232;v[a>>2]=78212;ys(a+4|0);Sk(a+56|0);return a|0}function sl(a,b){var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=Oe(ni(b)*+(c>>>0)),v[d+24>>2]=e}function q0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=UG(a,c,d,b);v[a>>2]=78572;return a|0}function pf(a){a=a|0;v[a+60>>2]=78396;v[a>>2]=78376;ys(a+8|0);Sk(a+60|0);return a|0}function m6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return WJ(a,b,c,d,0,0,0,0,e)|0}function k8(a,b){a=a|0;b=b|0;return C(b>>>0<=2?C(C(w[(a+b|0)+4232|0])/C(127)):C(0))}function _8(a,b){a=a|0;b=b|0;return C(b>>>0<=3?C(C(w[(a+b|0)+4264|0])/C(255)):C(0))}function Rd(a){var b=0;b=hb-16|0;hb=b;v[b+12>>2]=49464;Yn(a,49360,b+12|0);hb=b+16|0}function Bg(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function AG(a){return(a|0)!=0&(a|0)!=89728&(a|0)!=89752&(a|0)!=467728&(a|0)!=467752}function zg(a){var b=0;b=hb-16|0;hb=b;a=Mo(a,b+8|0);hb=b+16|0;return a?v[b+8>>2]:0}function v7(a){a=a|0;t[a+4202|0]=1;v[a+4256>>2]=v[v[a+16>>2]+24620>>2];vK(a);uK(a)}function uN(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function py(a){var b=0;b=hb-16|0;hb=b;cc(b+8|0,a+116|0);a=yM(a);hb=b+16|0;return a}function _o(a,b,c,d){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<d);return a}function Xo(a,b,c,d){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,d);return a}function S8(a){a=a|0;t[a+4202|0]=1;v[a+4232>>2]=v[v[a+16>>2]+24620>>2];Fs(a);_K(a)}function NH(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function pL(a,b,c){while(1){if(b){z[a>>2]=z[c>>2];b=b-1|0;a=a+4|0;continue}break}}function _n(a,b){a=pc(a,b,34);u[a+34>>1]=x[b+34>>1];pc(a+36|0,b+36|0,68);return a}function Lt(a,b,c){while(1){if(b){u[a>>1]=x[c>>1];b=b-1|0;a=a+2|0;continue}break}}function LP(a){if((w[a+14|0]-53&255)>>>0>=252){a=Qb(a,15671,14)}else{a=1}return!a}function tf(a){var b=0;b=hb-16|0;hb=b;a=v[cc(b+8|0,Yf(a))>>2];hb=b+16|0;return a}function qk(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;hc(a+8|0,b+8|0)}function ge(a){var b=0;b=hb-16|0;hb=b;a=v[cc(b+8|0,wc(a))>>2];hb=b+16|0;return a}function et(a){var b=0;b=hb-16|0;hb=b;a=v[cc(b+8|0,Ic(a))>>2];hb=b+16|0;return a}function Yf(a){var b=0;b=hb-16|0;hb=b;a=v[cc(b+8|0,gc(a))>>2];hb=b+16|0;return a}function YJ(a,b){var c=0;c=hb-16|0;hb=c;v[c+12>>2]=b;yH(93592,a,b,0,0);hb=c+16|0}function Pj(a){var b=0;b=hb-16|0;hb=b;a=v[cc(b+8|0,qd(a))>>2];hb=b+16|0;return a}function Mga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Xv(a,b,c,d,e,580)|0}function Ei(a){var b=0;b=hb-16|0;hb=b;a=v[cc(b+8|0,Cb(a))>>2];hb=b+16|0;return a}function sU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Xv(a,b,c,d,e,338)|0}function o_(){var a=0,b=0,c=0;a=Yd(469360);v[a>>2]=84320;b=a,c=Dd(),v[b+8>>2]=c}function hD(a,b,c){while(1){if(b){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function fr(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Xv(a,b,c,d,e,167)|0}function cZ(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<1)+80208>>1]&b)!=0&c>>>0<=127}function ai(a){return(Mj(v[a>>2],v[a+4>>2])|0)!=(0-Mj(v[a+12>>2],v[a+16>>2])|0)}function Xf(a){var b=0,c=0;wh(a+4|0);vj(a+8|0,0);b=a,c=gc(a),v[b>>2]=c;return a}function Nv(a,b){b=a+b|0;while(1){b=xb(b-12|0);if((b|0)!=(a|0)){continue}break}}function xaa(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[Db(a)>>2]){oM(a,b);return}jA(a,b)}function oU(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[Db(a)>>2]){IF(a,b);return}HF(a,b)}function _x(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[Db(a)>>2]){oM(a,b);return}jA(a,b)}function Zn(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function XX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return lb[a|0](b,c,d,e)|0}function WX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb[v[v[b>>2]+16>>2]](a,b,c,d,1,8)}function LZ(a){a=a|0;if(!w[468240]){en(468228,84556);t[468240]=1}return 468228}function Ku(a,b){return Oe(ni((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function KZ(a){a=a|0;if(!w[468272]){en(468260,84640);t[468272]=1}return 468260}function JZ(a){a=a|0;if(!w[468176]){en(468164,84484);t[468176]=1}return 468164}function IZ(a){a=a|0;if(!w[468208]){en(468196,84520);t[468208]=1}return 468196}function EZ(a){a=a|0;if(!w[468224]){Fc(468212,13526);t[468224]=1}return 468212}function C1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return mI(a-88|0,b,c,d,e)|0}function BZ(a){a=a|0;if(!w[468192]){Fc(468180,13787);t[468192]=1}return 468180}function xe(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;cv(d,a);Cl(d,b);hb=c+16|0}function wl(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;YB(d,a);Cl(d,b);hb=c+16|0}function sY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Tg(a,v[b+8>>2],0)){bw(b,c,d)}}function fA(a){if(zf(w[a+11|0])){nd(v[a>>2],0);xd(a,0);return}nd(a,0);Xd(a,0)}function aj(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Jb(b)}function ZN(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function Ty(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function Nx(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function JY(a,b){a=a|0;b=b|0;a=cm(a);v[a>>2]=92704;ew(a+4|0,Ic(b));return a|0}function JP(a,b){a=$Q(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function Dn(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function DZ(a){a=a|0;if(!w[468256]){Fc(468244,9282);t[468256]=1}return 468244}function DY(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Fc(a,7950);return}Cw(a,c)}function CZ(a){a=a|0;if(!w[468160]){Fc(468148,5268);t[468160]=1}return 468148}function BY(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Fc(a,7880);return}Cw(a,c)}function $i(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Zr(Zr(c,a),B(a,-100)+b|0)}function xj(a){var b=0;b=hb-16|0;hb=b;a=v[If(b+8|0,a)>>2];hb=b+16|0;return a}function x7(a,b){a=a|0;b=b|0;return C(b>>>0<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function iG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function e4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cn(a,b,c,d,12902,1049)|0}function cG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function a4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cn(a,b,c,d,12976,1051)|0}function YM(a,b,c){var d=0;return!b|!(w[a+35|0]&4?!a|(c|0)!=1:1)?d:w[b+34|0]}function Wd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];Yb(b,c);xv(a,b,d,c)}function KF(a){var b=0;b=hb-16|0;hb=b;v[b+8>>2]=a;hb=b+16|0;return v[b+8>>2]}function Ee(a){var b=0;b=hb-16|0;hb=b;Gu(b+8|0,a);hb=b+16|0;return v[b+8>>2]}function Cb(a){var b=0;b=hb-16|0;hb=b;a=v[cc(b+8|0,a)>>2];hb=b+16|0;return a}function zT(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function yO(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);rO(a,b,0,0,b+-1,0)}function w$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ME(b,c,d,e,1)|0}function t$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ME(b,c,d,e,0)|0}function m$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return KE(b,c,d,e,1)|0}function ln(a,b,c){var d=0,e=0;v[a>>2]=b;d=a,e=vh(b,c),v[d+4>>2]=e;return a}function k4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cn(a,b,c,d,9449,1046)|0}function j$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return KE(b,c,d,e,0)|0}function c4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cn(a,b,c,d,9600,1050)|0}function _Y(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+82768>>2]}return b|0}function Z3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cn(a,b,c,d,9678,1052)|0}function YY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+81232>>2]}return b|0}function XG(a,b,c,d,e,f,g,h){return lb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function X3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cn(a,b,c,d,9480,1053)|0}function Pr(a,b,c,d,e,f,g,h){return lb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function MK(a){a=a|0;v[a>>2]=46460;lc(a+4276|0);lc(a+4264|0);return Ff(a)|0}function Kz(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function Gk(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function wg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function tv(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){dj(c,a,d)}return c+d|0}function hk(a){var b=0;b=x[a+172>>1];a=x[a+156>>1];return(FP(a)?b:a)&65535}function Zr(a,b){b=x[(b<<1)+77360>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function Sg(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function FY(a,b,c){a=a|0;b=b|0;c=c|0;return nc(a,v[b+4>>2])&v[b>>2]==(c|0)}function zD(a,b){a=Bg(a,b);v[a+8>>2]=v[b+8>>2];Bg(a+12|0,b+12|0);return a}function s8(a,b){a=a|0;b=b|0;a=v[a+20>>2];t[a+24|0]=w[a+24|0]&253|(b?2:0)}function qd(a){var b=0,c=0,d=0;return b=v[a>>2],c=a,d=zf(w[a+11|0]),d?b:c}function ot(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function dG(a,b){var c=0,d=0;c=cc(a,v[v[b>>2]-12>>2]+b|0),d=b,v[c+4>>2]=d}function cd(a,b){a=JD(a,b);v[a+8>>2]=v[b+8>>2];JD(a+12|0,b+12|0);return a}function Vt(a,b,c){b=b-a|0;if((b|0)>0){pc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function Uc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function Rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Do(a,b),v[d>>2]=e}function Qha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Zu(a,b),u[d>>1]=e}function Pk(a,b,c){a=a|0;b=b|0;c=c|0;return lb[v[v[a>>2]+12>>2]](a,b,c)|0}function Ob(a,b,c){a=a|0;b=b|0;c=c|0;return lb[v[v[a>>2]+32>>2]](a,b,c)|0}function NR(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function Gm(a,b,c){a=a|0;b=b|0;c=c|0;return lb[v[v[a>>2]+48>>2]](a,b,c)|0}function AD(a,b){a=a|0;b=b|0;a=cm(a);v[a>>2]=92704;ew(a+4|0,b);return a|0}function zw(a,b){var c=0;c=OG(a+4|0);v[a>>2]=79392;v[c>>2]=79412;zn(c,b)}function vP(a,b){t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function tia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;sE(a,b,c,d,e,111)}
function oH(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Sg(a,-1,-1)}function Aw(a,b){var c=0;c=As(a+4|0);v[a>>2]=79224;v[c>>2]=79244;zn(c,b)}function vI(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function rl(a){if(zf(w[a+11|0])){a=jB(v[a+8>>2])-1|0}else{a=10}return a}function rQ(a){var b=0;if(v[a>>2]){qQ(a,v[a>>2]);b=v[a>>2];Sj(a);Jb(b)}}function qc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=Og(b),v[c+4>>2]=d;return a}function pB(a,b,c){var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function lc(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];Vh(a);Jb(b)}return a}function gw(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function Yw(a){return((rh(a)+(rh(a)<<8)|0)+(rh(a)<<16)|0)+(rh(a)<<24)|0}function Yea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;sE(a,b,c,d,e,137)}function Vf(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];qr(a);Jb(b)}return a}function Nc(a){var b=0;if(v[a>>2]){kC(a,v[a>>2]);b=v[a>>2];lC(a);Jb(b)}}function KU(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function JO(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function HK(a){a=a|0;return C(C(C(z[Bb(a+4208|0,5)>>2]*C(198))+C(-99)))}function EO(a){if(a>>>0<=8){return w[a+29360|0]}return w[a+29351|0]|256}function rz(a,b){a=Lb(a);Kb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function gl(a,b){a=w[Ib(a+62|0,b)|0];return(a<<24>>24>=0?a&127:-1)&255}function cw(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function Zx(a,b){if(b){Zx(a,v[b>>2]);Zx(a,v[b+4>>2]);ac(b+16|0);Jb(b)}}function Zq(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function Wy(a,b){if(b){Wy(a,v[b>>2]);Wy(a,v[b+4>>2]);nm(b+16|0);Jb(b)}}function Sp(a,b){if(b){Sp(a,v[b>>2]);Sp(a,v[b+4>>2]);fO(b+16|0);Jb(b)}}function LV(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){va();L()}}function Kk(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function Ey(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function DR(a){if(Qb(a,13901,4)){a=1}else{a=Qb(a+8|0,13954,4)}return!a}function DA(a,b){if(b){DA(a,v[b>>2]);DA(a,v[b+4>>2]);Xt(b+16|0);Jb(b)}}function CA(a,b){if(b){CA(a,v[b>>2]);CA(a,v[b+4>>2]);Xt(b+16|0);Jb(b)}}function wJ(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){wn(c+120|0);Jb(c)}}function vM(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function kY(a){a=a|0;if(!a){return 0}return(Cy(a,92316,92460)|0)!=0|0}function hw(a){a=a|0;if(v[a+8>>2]!=(Dd()|0)){zG(v[a+8>>2])}return a|0}function aY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;lb[a|0](b,c,d,e)}function YP(a,b,c,d,e){a=cc(a,b);cc(a+4|0,c);cc(a+8|0,d);cc(a+12|0,e)}function WL(a,b,c,d){if((b|0)==(d|0)){a=ZM(a,b,c,d)}else{a=1}return!a}function Mc(a,b,c,d){if((b|0)==(d|0)){a=VS(a,b,c,d)}else{a=1}return!a}function wu(a,b){var c=0;c=hb-16|0;hb=c;MC(c,a,64);QC(c,b);hb=c+16|0}function v_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;yh(a,f)}function vS(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];hc(a+8|0,b+8|0)}function mk(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){gc(a);if(b){Jb(b)}}}function jC(a){if(a>>>0>=214748365){Zf(11191);L()}return tc(B(a,20))}function YX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return lb[a|0](b,c,d)|0}function WD(a){if(a>>>0>=357913942){Zf(11191);L()}return tc(B(a,12))}function Vl(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function Q$(a){a=a|0;var b=0;b=v[117008]+1|0;v[117008]=b;v[a+4>>2]=b}function HP(a,b){a=Pz(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function BB(a,b){var c=0;c=hb-16|0;hb=c;MC(c,a,32);QC(c,b);hb=c+16|0}function yL(a){if(a>>>0>=82595525){Zf(11191);L()}return tc(B(a,52))}function nM(a,b){var c=0;c=hb-16|0;hb=c;Vz(c,1,b);Cc(a,c);hb=c+16|0}function d4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return UE(a,b,c,d,4)|0}function b4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return UE(a,b,c,d,2)|0}function aN(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|64}function aE(a,b){return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function Y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return TE(a,b,c,d,2)|0}function Qq(a,b){return av(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function QS(a){if(a>>>0>=715827883){Zf(11191);L()}return tc(B(a,6))}function MB(a,b){return pr(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function Lc(a,b,c){if(sc(a,b)>>>0<=c>>>0){Vu();L()}return(c<<2)+a|0}function ES(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function $3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return TE(a,b,c,d,4)|0}function gF(a,b,c,d){b=Qa(975,a|0,b|0,c|0,d|0)|0;kb=O()|0;return b}function bP(a,b){var c=0,d=0;c=cc(a,v[b>>2]),d=w[b+4|0],t[c+4|0]=d}function VY(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function Haa(a,b){a=a|0;b=b|0;if(!v[23516]){v[23517]=b;v[23516]=a}}function FF(a,b,c){a:{if((a|0)==(b|0)){t[b+120|0]=0;break a}Jb(b)}}function CL(a,b){if((a|0)!=(b|0)){jS(a,v[b>>2],v[b+4>>2])}return a}function Ai(a){if(a>>>0>=1073741824){Zf(11191);L()}return tc(a<<2)}function tI(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function sD(a){if(a>>>0>=536870912){Zf(11191);L()}return tc(a<<3)}function pJ(a,b,c){a=a|0;b=b|0;c=c|0;return lJ(a,b,Ic(c),Fb(c))|0}function ir(a,b){a=a|0;b=b|0;return lb[v[v[a>>2]+32>>2]](a,0,b)|0}function gh(a,b,c){a=cc(a,b);BT(a+4|0,v[c>>2],v[c+4>>2]);return a}function fn(a,b){if(y[a+4>>2]<y[Db(a)>>2]){IF(a,b);return}HF(a,b)}function fS(a,b,c,d){a=he(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function UW(a){a=a|0;a=v[a+4>>2];return lb[v[v[a>>2]+12>>2]](a)|0}function TW(a){a=a|0;a=v[a+4>>2];return lb[v[v[a>>2]+16>>2]](a)|0}function QP(a){if(a>>>0>=268435456){Zf(11191);L()}return tc(a<<4)}function MP(a){if(a>>>0>=134217728){Zf(11191);L()}return tc(a<<5)}function L6(a,b,c){a=a|0;b=b|0;c=c|0;return Pi(a,b,c,945,86224)|0}function Jm(a,b){v[a>>2]=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];return a}function Ic(a){var b=0,c=0,d=0;return b=v[a>>2],c=a,d=Fe(a),d?b:c}function FH(a,b){a=DH(a-1|0);if(!a){a=DH(b);a=a?a+32|0:0}return a}function Dj(a,b){if(Uf(v[a>>2],v[a+4>>2])>>>0>b>>>0){t[a+16|0]=b}}function uy(a){xb(a+48|0);xb(a+36|0);xb(a+24|0);xb(a+12|0);xb(a)}function pr(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function nK(a){return C(C(z[Bb(a+4208|0,11)>>2]*C(19980))+C(20))}function n8(a,b,c){a=a|0;b=b|0;c=c|0;return Pi(a,b,c,934,4236)|0}function l7(a,b,c){a=a|0;b=b|0;c=c|0;return Pi(a,b,c,941,4228)|0}function fd(a){a=(a|0)<32767?a:32767;return(a|0)>-32768?a:-32768}function eq(a,b,c){a=Eb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function d9(a,b,c){a=a|0;b=b|0;c=c|0;return Pi(a,b,c,916,4268)|0}function c7(a,b,c){a=a|0;b=b|0;c=c|0;return Pi(a,b,c,942,5048)|0}function VW(a){a=a|0;a=v[a+4>>2];return lb[v[v[a>>2]+8>>2]](a)|0}function U7(a,b,c){a=a|0;b=b|0;c=c|0;return Pi(a,b,c,937,4280)|0}function T6(a,b,c){a=a|0;b=b|0;c=c|0;return Pi(a,b,c,944,4276)|0}function P8(a,b,c){a=a|0;b=b|0;c=c|0;return Pi(a,b,c,924,4304)|0}function Mja(a,b){a=a|0;b=b|0;a=mu(a,b);v[a>>2]=92860;return a|0}function K7(a,b,c){a=a|0;b=b|0;c=c|0;return Pi(a,b,c,938,4276)|0}function GD(a,b,c){a=Wm(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=62524}function C7(a,b,c){a=a|0;b=b|0;c=c|0;return Pi(a,b,c,939,4268)|0}function zl(a,b){a=a|0;b=b|0;return lb[v[v[a>>2]+28>>2]](a,b)|0}function ze(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){FJ(b)}return a}function yt(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];Cz(a);Jb(b)}}function xr(a){var b=0;b=hb-16|0;A[b+8>>3]=a;return A[b+8>>3]*a}function rw(a,b){a=a|0;b=b|0;return lb[v[v[a>>2]+12>>2]](a,b)|0}function pQ(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];Sj(a);Jb(b)}}function pM(a){var b=0;if(v[a>>2]){Ro(a);b=v[a>>2];pv(a);Jb(b)}}function oK(a){return C(C(z[Bb(a+4208|0,0)>>2]*C(1e4))+C(-1e4))}function lW(a,b){a=a|0;b=b|0;a=mu(a,b);v[a>>2]=92912;return a|0}function kl(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];rt(a);Jb(b)}}function jba(a,b){a=a|0;b=b|0;a=BS(a,b);if(!a){AS(b)}return a|0}function iO(a){var b=0;if(v[a>>2]){hO(a);b=v[a>>2];Sj(a);Jb(b)}}function gd(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];Om(a);Jb(b)}}function eZ(a){a=a|0;a=v[a+8>>2];if(!a){return 1}return uF(a)|0}function bq(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];Db(a);Jb(b)}}function be(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];Zm(a);Jb(b)}}function av(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function ao(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];yS(a);Jb(b)}}function Yc(a){var b=0;if(Fe(a)){b=v[a>>2];Al(a);Jb(b)}return a}function Ud(a){var b=0;if(v[a>>2]){fV(a);b=v[a>>2];yB(a);Jb(b)}}function UN(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];Xy(a);Jb(b)}}function SO(a){var b=0;if(v[a>>2]){RO(a);b=v[a>>2];$n(a);Jb(b)}}function PO(a,b){a=a|0;b=b|0;a=mu(a,b);v[a>>2]=92724;return a|0}function Or(a,b){a=a|0;b=b|0;return lb[v[v[a>>2]+44>>2]](a,b)|0}function Lia(a,b){a=a|0;b=b|0;a=yT(a,b);if(!a){xT(b)}return a|0}function Hz(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];pv(a);Jb(b)}}function DM(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];BU(a);Jb(b)}}function Ci(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];$n(a);Jb(b)}}function Bx(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];Kx(a);Jb(b)}}function BH(a){var b=0;b=hb-16|0;z[b+12>>2]=a;return z[b+12>>2]}function B6(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function Ap(a,b,c){if(!b){return 0}return Js(a,Kf(c<<24>>24),b)}function Ah(a){var b=0;if(v[a>>2]){Gc(a);b=v[a>>2];nu(a);Jb(b)}}function AM(a){var b=0;if(v[a>>2]){Rs(a);b=v[a>>2];Qs(a);Jb(b)}}function yv(a,b){a=a|0;b=b|0;a=rD(a,b);if(!a){qD(b)}return a|0}function qv(a,b){a=Xc(a,b);hc(a+12|0,b+12|0);dg(a+32|0,b+32|0)}function oA(a,b){a=a|0;b=b|0;a=Mo(a,b);if(!a){Fm(b)}return a|0}function o3(a,b,c){a=a|0;b=b|0;c=c|0;kP(a,0,v[b+1298404>>2],c)}function mo(a,b){a=a|0;b=b|0;a=uU(a,b);if(!a){xU(b)}return a|0}function lv(a,b){a=a|0;b=b|0;a=cD(a,b);if(!a){Yq(b)}return a|0}function jr(a,b){a=a|0;b=b|0;a=kD(a,b);if(!a){Cv(b)}return a|0}function eg(a,b){return lb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function eV(a,b){if(!b){return-1}b=Ap(a,b,0);return b?b-a|0:-1}function di(a,b){a=a|0;b=b|0;a=Hh(a,b);if(!a){Qj(b)}return a|0}function dM(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function _b(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function Vq(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function Tq(a,b,c){a=a|0;b=b|0;c=c|0;Th(a,b,yi(b,b+c|0,62620))}function SN(a,b){a=a|0;b=b|0;a=LU(a,b);if(!a){ou(b)}return a|0}function RB(a,b){a=a|0;b=b|0;a=zu(a,b);if(!a){Eu(b)}return a|0}function O_(a,b){a=a|0;b=b|0;_M(a,Jw(v[b>>2])<<24>>24,v[b>>2])}function OQ(a){return w[a+15|0]<<12|w[a+14|0]<<4|w[a+13|0]<<20}function KA(a,b){a=a|0;b=b|0;a=NS(a,b);if(!a){zA(b)}return a|0}function It(a,b){a=a|0;b=b|0;a=vU(a,b);if(!a){lu(b)}return a|0}function FK(a){a=a|0;return tj(C(z[Bb(a+4208|0,4)>>2]*C(4)))|0}function u7(a,b,c){a=a|0;b=b|0;c=c|0;return Zv(a,b,c,0,940)|0}function qh(a,b,c){return(x[((c&255)<<1)+a>>1]&b)!=0&(c|0)>=0}function m7(a,b,c){a=a|0;b=b|0;c=c|0;return Zv(a,b,c,1,940)|0}function lja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;vE(a,b,c,d,362)}function jM(a,b){return b>>>0<4e3?((b<<5)+a|0)+946304|0:21751}function eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;zE(a,b,c,d,111)}function d8(a,b,c){a=a|0;b=b|0;c=c|0;return Zv(a,b,c,0,936)|0}function cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;vE(a,b,c,d,471)}function Yja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;zE(a,b,c,d,137)}function LI(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function KD(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Jb(dc(c))}}function Gl(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){Um(c)}return a}function BM(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Jb(co(c))}}function z8(a){a=a|0;a=gj(a);if(a){lb[v[v[a>>2]+100>>2]](a)}}function ys(a){a=a|0;v[a>>2]=77696;wb(a+32|0);return Bn(a)|0}function xI(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function oc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function dy(a,b){var c=0;c=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=c}function V7(a){a=a|0;return C(C(z[Bb(a+4208|0,6)>>2]*C(20)))}function Pg(a,b,c,d){kb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function MW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ec(a,v[d>>2],0)}function GM(a){v[a>>2]=0;Lb(a+4|0);Rb(a+16|0,0,144);return a}function GK(a){a=a|0;return C(C(z[Bb(a+4208|0,2)>>2]*C(10)))}function Fx(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function Daa(a){a=a|0;a=mu(a,21751);v[a>>2]=92804;return a|0}function yW(a){a=a|0;a=BD(a,13363);v[a>>2]=26252;return a|0}function wq(a){return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function uv(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function sH(a,b){if(b>>>0<=9){return qH(a,b)}return Zr(a,b)}function qu(a,b,c){a=a|0;b=b|0;c=c|0;return BE(a,b,c,322)|0}function nA(a,b){if(b){nA(a,v[b>>2]);nA(a,v[b+4>>2]);Jb(b)}}function n7(a){a=a|0;return C(C(z[Bb(a+4208|0,6)>>2]*C(4)))}function mx(a,b,c,d,e,f){return RE(a,b,c,d,e,f,58116,58912)}function mu(a,b){a=cm(a);v[a>>2]=92684;ew(a+4|0,b);return a}function lx(a,b,c,d,e,f){return RE(a,b,c,d,e,f,58992,59756)}function ji(a,b){var c=0,d=0;c=a,d=xG(b),v[c>>2]=d;return a}function hN(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Jb(Fy(b))}}function hJ(a,b){a=a|0;b=b|0;return vh(v[b>>2],v[b+4>>2])|0}function gJ(a,b){a=a|0;b=b|0;return Qd(v[b>>2],v[b+4>>2])|0}function fha(a,b,c){a=a|0;b=b|0;c=c|0;return CE(a,b,c,35)|0}function f5(a,b){a=a|0;b=b|0;return C(ZE(a,b,6232,1075834))}function dS(a){var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b}function dI(a,b){a=a|0;b=+b;PE(a,b,1e4,1074420,9392,512,32)}function d5(a,b){a=a|0;b=b|0;return C(YE(a,b,6275,1075834))}function b5(a,b){a=a|0;b=b|0;return C(YE(a,b,6177,1075835))}function a5(a,b){a=a|0;b=b|0;return C(ZE(a,b,6133,1075835))}function ZY(a,b,c){a=a|0;b=b|0;c=c|0;return IE(b,c,82768)|0}function XY(a,b,c){a=a|0;b=b|0;c=c|0;return IE(b,c,81232)|0}function Ws(a,b){if(b){Ws(a,v[b>>2]);Ws(a,v[b+4>>2]);Jb(b)}}function Vs(a,b){if(b){Vs(a,v[b>>2]);Vs(a,v[b+4>>2]);Jb(b)}}function Vk(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Jb(Vf(b))}}function UU(a){return!Qb(a,14255,4)&(w[a+4|0]-1&255)>>>0<10}function SA(a,b){if(b){SA(a,v[b>>2]);SA(a,v[b+4>>2]);Jb(b)}}function RY(a,b,c){a=a|0;b=b|0;c=c|0;return HE(b,c,82768)|0}function RA(a,b){if(b){RA(a,v[b>>2]);RA(a,v[b+4>>2]);Jb(b)}}function PY(a,b,c){a=a|0;b=b|0;c=c|0;return HE(b,c,81232)|0}function KB(a,b,c){a=a|0;b=b|0;c=c|0;return BE(a,b,c,262)|0}function Gz(a,b){if(b){Gz(a,v[b>>2]);Gz(a,v[b+4>>2]);Jb(b)}}function Fz(a,b){if(b){Fz(a,v[b>>2]);Fz(a,v[b+4>>2]);Jb(b)}}function DH(a){return t[(B(0-a&a,124511785)>>>27|0)+74e3|0]}function DD(a,b){return UA(a,qd(b),wd(v[b+4>>2],w[b+11|0]))}function Cn(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function v3(a,b,c){a=a|0;b=b|0;c=c|0;Xc(a,lJ(c,0,b,Og(b)))}function tq(a,b,c){if((a|0)!=(b|0)){b=b-a|0;dj(c-b|0,a,b)}}function qn(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function qR(a){var b=0;a=a+8|0;b=a>>>0<8?1:b;kb=b;return a}function n3(a){a=a|0;IJ(a,2,100);Dj(v[a+24>>2]+484360|0,0)}function n0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb=0;return 0}function fo(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function fX(a){a=a|0;a=BD(a,8733);v[a>>2]=30676;return a|0}function Wx(a,b,c){A[a>>3]=A[a>>3]+b;A[a+8>>3]=A[a+8>>3]+c}function NY(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function NX(a){a=a|0;a=PO(a,7985);v[a>>2]=42008;return a|0}function Fb(a){if(Fe(a)){return v[a+4>>2]}return w[a+11|0]}function vJ(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){FJ(c)}}function uI(a,b){a=a|0;b=+b;PE(a,b,256,1074456,11788,1,0)}function uE(a,b,c){a=a|0;b=b|0;c=c|0;ku(a,b,c);return a|0}function jw(a){if(v[a>>2]){Gc(a);FF(iw(a),v[a>>2],Vh(a))}}function io(a,b){if(zf(w[a+11|0])){xd(a,b);return}Xd(a,b)}function cV(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0];return a}function bx(a,b){return v[((a>>>24^b)<<2)+462944>>2]^a<<8}function Yt(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Jb(c)}}function Xn(a){v[a>>2]=0;v[a+4>>2]=0;vj(a+8|0,0);return a}function Sf(a){var b=0;gQ(a);b=v[a>>2];if(b){Jz(a);Jb(b)}}function SH(a){while(1){if((ds(a)|0)!=-1){continue}break}}function Oo(a){a=HD(a);v[a+8>>2]=0;v[a>>2]=89652;return a}function Np(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function Nha(a,b,c){a=a|0;b=b|0;c=c|0;Th(a,b,ad(b,c)+b|0)}function II(a){a=a|0;v[a>>2]=61868;dc(a+12|0);return a|0}
function Fw(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function Dc(a,b){return DE(a,b,2147483647,-2147483648,-1)}function zF(a){a=a|0;v[a>>2]=84408;wb(a+16|0);return a|0}function yF(a){a=a|0;v[a>>2]=84368;wb(a+12|0);return a|0}function xt(a,b){oc(a,b);oc(a+4|0,b+4|0);oc(Db(a),Db(b))}function t4(a,b){a=a|0;b=b|0;return dn(a,b,11979,1040)|0}function q4(a,b){a=a|0;b=b|0;return dn(a,b,11947,1041)|0}function ph(a,b,c){t[a|0]=w[a|0]|b;v[a+4>>2]=v[a+4>>2]|c}function nH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Sg(a,-1,-1)}function n1(a,b,c){a=a|0;b=b|0;c=c|0;return Md(B(b,c))|0}function maa(a,b,c){a=a|0;b=b|0;c=c|0;return rL(a,b,c)|0}function j5(a,b){a=a|0;b=b|0;return dn(a,b,11915,1020)|0}function hX(a,b,c){a=a|0;b=b|0;c=c|0;xv(a,b,v[b+8>>2],c)}function gB(a,b){t[v[a>>2]]=w[b|0];t[v[a+4>>2]]=w[b+1|0]}function eN(a,b){a=dN(a,b);dN(a+12|0,b+12|0);t[a+24|0]=1}function cz(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function bj(a){return Ye(a)|Ye(a)<<8|Ye(a)<<16|Ye(a)<<24}function UJ(a,b){Um(v[b>>2]);Ym(v[a>>2]);v[a>>2]=v[b>>2]}function SC(a){if((a|0)<0){Zf(11191);L()}return tc(a<<1)}function R4(a,b){a=a|0;b=b|0;return dn(a,b,11818,1027)|0}function P4(a,b){a=a|0;b=b|0;return cF(a,b,13335,1028)|0}function Ot(a){lc(a+88|0);lc(a+68|0);lc(a+48|0);return a}function Fm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function E4(a,b){a=a|0;b=b|0;return dn(a,b,11853,1035)|0}function Bh(a,b){var c=0;c=w[a|0];t[a|0]=w[b|0];t[b|0]=c}function B4(a,b){a=a|0;b=b|0;return dn(a,b,11883,1037)|0}function xD(a){a=a|0;v[a>>2]=43280;je(a+4|0);return a|0}function wv(a){a=a|0;v[a>>2]=92704;kF(a+4|0);return a|0}function qG(a,b,c){a=cc(a,b);cc(a+4|0,v[c>>2]);return a}function q7(a){a=a|0;return z[Bb(a+4208|0,1)>>2]<C(1)|0}function ls(a){a=a|0;v[a>>2]=49508;rs(a+4|0);return a|0}function kF(a){a=hx(v[a>>2]);if((uv(a+8|0)|0)<0){Jb(a)}}function fF(a,b,c,d,e){return Ja(a|0,b|0,c|0,d|0,e|0)|0}function f7(a){a=a|0;sK(a);t[a+4202|0]=1;v[a+4224>>2]=0}function cba(a,b,c){a=a|0;b=b|0;c=c|0;lE(a,b,c,816,815)}function bI(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function _c(a){if(Fe(a)){a=Al(a)-1|0}else{a=10}return a}function Yn(a,b,c){v[a>>2]=b;v[a+4>>2]=v[c>>2];return a}function YA(a){a=a&255;return Wc(a)^1|(a-49&255)>>>0<36}function X7(a){a=a|0;return z[Bb(a+4208|0,3)>>2]<C(1)|0}function Vr(a){a=a|0;v[a>>2]=77632;Zb(a+4|0);return a|0}function Qo(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function NI(a){a=a|0;v[a>>2]=62332;dc(a+4|0);return a|0}function ML(a){return(a|0)==1179012417|(a|0)==538987841}function Lb(a){v[a>>2]=0;v[a+4>>2]=0;wh(a+8|0);return a}function JU(a){a=a|0;v[a>>2]=92684;kF(a+4|0);return a|0}function EF(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Ym(b)}}function Bn(a){a=a|0;v[a>>2]=77568;Zb(a+4|0);return a|0}function Bd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function x0(a){a=a|0;return up(v[v[a>>2]-12>>2]+a|0)|0}function u0(a){a=a|0;return pf(v[v[a>>2]-12>>2]+a|0)|0}function sia(a,b){a=a|0;b=b|0;Ml(a,b,413,1042,-1332,2)}function rh(a){var b=0;b=ds(a);v[a+1396>>2]=0;return b}function np(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function k6(a,b){a=a|0;b=b|0;return cF(a,b,6435,968)|0}function jH(a){a=a|0;return Ur(v[v[a>>2]-12>>2]+a|0)|0}function ex(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function ep(a){if(Fe(a)){a=Al(a)-1|0}else{a=1}return a}function bfa(a,b){a=a|0;b=b|0;Ml(a,b,261,1042,-1332,2)}function bY(a){a=a|0;a=lb[a|0]()|0;ra(kb|0);return a|0}function aH(a){a=a|0;return Sr(v[v[a>>2]-12>>2]+a|0)|0}function Z9(a,b,c){a=a|0;b=b|0;c=c|0;lE(a,b,c,887,886)}function Wl(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function Wg(a,b){a=a|0;b=b|0;lb[v[v[b>>2]+20>>2]](a,b)}function Wb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function W$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Th(a,c,d)}function T$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;tG(a,c,d)}function Qh(a,b){a=a|0;b=b|0;lb[v[v[b>>2]+24>>2]](a,b)}function QL(a,b){return B(b&65535,a&65535)+7>>>3&65535}function Ph(a,b){a=a|0;b=b|0;lb[v[v[b>>2]+28>>2]](a,b)}function Oda(a,b){a=a|0;b=b|0;if(!oR(a,b)){Rb(b,0,40)}}function Mha(a,b){a=a|0;b=b|0;return Fc(a,b?b:21751)|0}function H_(a,b){a=a|0;b=b|0;fc(a,bH(v[b>>2]),v[b>>2])}function HL(a,b){return(b>>>0<=15?t[a+b|0]:63)<<24>>24}function GL(a,b){return(b>>>0<=45?t[a+b|0]:63)<<24>>24}function xb(a){if(zf(w[a+11|0])){Jb(v[a>>2])}return a}function vc(a,b){a=a|0;b=b|0;FD(a,b,er(b));return a|0}function uG(a,b,c){a=vG(a,b,c,0,-2147483648);return a}function sv(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){Um(c)}}function nh(a){a=a|0;return lb[v[v[a>>2]+24>>2]](a)|0}function nB(a,b){a=he(a,b);Rb(a+20|0,0,1040);return a}function lf(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function kn(a,b){return lb[v[v[a>>2]+36>>2]](a,b,0)|0}function jn(a,b){return lb[v[v[a>>2]+52>>2]](a,b,0)|0}function gr(a,b){a=hc(a,b);Rb(a+20|0,0,1040);return a}function f8(a,b,c){a=a|0;b=b|0;c=c|0;fc(a,b+4228|0,7)}function dc(a){if(v[a>>2]){Gc(a);Jb(v[a>>2])}return a}function Yi(a){a=a|0;return lb[v[v[a>>2]+16>>2]](a)|0}function Xi(a){a=a|0;return lb[v[v[a>>2]+12>>2]](a)|0}function Vha(a,b){a=a|0;b=b|0;Ml(a,b,99,1042,-1332,2)}function Vga(a,b,c){a=a|0;b=b|0;c=c|0;jS(a,b,Bb(b,c))}function TK(a){lc(a+36|0);lc(a+24|0);Bx(a+12|0);Bx(a)}function R8(a,b,c){a=a|0;b=b|0;c=c|0;fc(a,b+4260|0,8)}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;Xc(a,pJ(c,0,b))}function Of(a,b,c,d){b=b+d|0;kb=a+c>>>0<c>>>0?b+1|0:b}function Fy(a){Op(a+223860|0);dc(a+223848|0);return a}function Fc(a,b){a=a|0;b=b|0;ku(a,b,Og(b));return a|0}function FV(a,b){a=a|0;b=b|0;Ml(a,b,261,1025,-1284,2)}function E2(a,b){a=a|0;b=b|0;RN(v[a>>2],b);return a|0}function x8(a){a=a|0;t[a+4202|0]=1;Ds(a);Dx(a);UK(a)}function vD(a){return CH(a,C(2.524354896707238e-29))}function uz(a){a=Lb(a);v[a+12>>2]=0;u[a+16>>1]=65280}function uq(a,b,c,d,e){fc(a,b+d|0,(e|0)==-1?c-d|0:e)}function qka(a){if(a){return 31-E(a-1^a)|0}return 32}function nD(a,b,c,d){return Yo(a,b,c,d,36,119304648)}function kv(a){a=a|0;return lb[v[v[a>>2]+8>>2]](a)|0}function fE(a,b,c,d){return Yo(a,b,c,d,24,178956971)}function ae(a,b,c){t[a|0]=b;t[a+1|0]=w[c|0];return a}function aL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function YC(a,b){return(w[b+34|0]&8)>>>3&(a&2050)==2}function TX(a,b){a=a|0;b=b|0;Ml(a,b,12,1058,-1332,2)}function QD(a){return CH(a,C(1.5845632502852868e29))}function Ls(a){a=a|0;a=Ih(a);v[a+20>>2]=0;return a|0}function I0(a,b){a=a|0;b=b|0;Ml(a,b,99,1025,-1284,4)}function B0(a,b){a=a|0;b=b|0;Ml(a,b,99,1025,-1284,2)}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;rE(a,b,c,14,2)}function $U(a,b,c,d){return Yo(a,b,c,d,28,153391690)}function wO(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function wM(a){v[a>>2]=49616;v[a>>2]=49588;return a}function w3(a){a=a|0;a=v[a+4>>2];return(a?a:5014)|0}function uj(a){if(!a){return 0}return v[a+44>>2]!=0}function sp(a,b){b=v[b>>2];v[a>>2]=b;Um(b);return a}function sga(a,b,c){a=a|0;b=b|0;c=c|0;rE(a,b,c,5,3)}function o7(a){a=a|0;return C(z[Bb(a+4208|0,3)>>2])}function lj(a){if(!a){return 0}return sj(w[a+31|0])}function kd(a,b){a=a|0;b=b|0;return rL(a,b,Og(b))|0}function cea(a,b,c){a=a|0;b=b|0;c=c|0;Xc(a,Ev(b,c))}function _d(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function Xr(a,b){v[a>>2]=b;v[a+4>>2]=b>>31;return a}function XN(a,b,c,d){return Yo(a,b,c,d,7,613566757)}function WZ(){Yd(469576);BF(469584);v[117394]=87024}function W7(a){a=a|0;return C(z[Bb(a+4208|0,1)>>2])}function Vw(a){if(!a){return 0}v[115992]=a;return-1}function Ue(a){var b=0;b=v[a>>2];if(b){Db(a);Jb(b)}}function UZ(){Yd(469592);BF(469600);v[117398]=87180}function Tga(a,b,c){a=a|0;b=b|0;c=c|0;yE(a,b,c,256)}function Pfa(a,b){a=a|0;b=b|0;return ei(a,b,1030)|0}function No(a){a=a|0;a=zc(a);lb[v[v[a>>2]>>2]](a)|0}function MC(a,b,c){t[a+8|0]=1;v[a+4>>2]=c;v[a>>2]=b}function Ip(a,b,c){if(!c){return 0}return Qb(a,b,c)}function IK(a){a=a|0;return C(z[Bb(a+4208|0,0)>>2])}function Go(a,b,c){fc(a,(c>>>3&536870908)+b|0,c&31)}function Gfa(a,b){a=a|0;b=b|0;return wr(a,b,1100)|0}function G1(a,b,c){a=a|0;b=b|0;c=c|0;qI(a-88|0,b,c)}function Ev(a,b){a=a|0;b=b|0;return UA(a,b,er(b))|0}function EU(a,b,c,d){return Yo(a,b,c,d,48,89478486)}function E1(a,b,c){a=a|0;b=b|0;c=c|0;oI(a-88|0,b,c)}function Dz(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function Ab(a,b,c){fc(a,(c>>>3&536870908)+b|0,1<<c)}function xk(a,b){return(a&65535)>>>0<(b&65535)>>>0}function xja(a,b){a=a|0;b=b|0;return wE(a,b,344)|0}function v1(a,b,c){a=a|0;b=b|0;c=+c;iI(a-92|0,b,c)}function t1(a,b,c){a=a|0;b=b|0;c=+c;gI(a-92|0,b,c)}function sV(a,b){a=a|0;b=b|0;Pv(a,b,261,274,-1332)}function ria(a,b,c){a=a|0;b=b|0;c=c|0;sr(a,b,c,83)}function pga(a,b,c){a=a|0;b=b|0;c=c|0;ur(a,b,c,77)}function oga(a,b,c){a=a|0;b=b|0;c=c|0;ur(a,b,c,76)}function km(a){kj(a+724|0);kj(a+732|0);kj(a+740|0)}function kS(a,b,c){a=a|0;b=b|0;c=c|0;Xc(a,sF(b,c))}function k1(a,b){a=a|0;b=b|0;return Zo(a,b,1122)|0}function h3(a,b){a=a|0;b=b|0;return Zo(a,b,1121)|0}function dka(a,b,c){a=a|0;b=b|0;c=c|0;ur(a,b,c,78)}function ZD(a,b,c){a=a|0;b=b|0;c=c|0;Xc(a,DD(b,c))}function Yfa(a,b){a=a|0;b=b|0;if(!zu(a,b)){Eu(b)}}
function Y0(a,b){a=a|0;b=b|0;return Zo(a,b,1126)|0}function V0(a,b){a=a|0;b=b|0;return Zo(a,b,1124)|0}function Qn(a,b,c){if((a|0)!=(b|0)){dj(c,a,b-a|0)}}function Q0(a,b){a=a|0;b=b|0;return Zo(a,b,1125)|0}function Lga(a,b){a=a|0;b=b|0;return ei(a,b,422)|0}function Jia(a,b){a=a|0;b=b|0;return ei(a,b,308)|0}function I1(a,b,c){a=a|0;b=b|0;c=+c;sI(a-88|0,b,c)}function Gga(a,b){a=a|0;b=b|0;return ei(a,b,826)|0}function F1(a,b){a=a|0;b=b|0;return pI(a-88|0,b)|0}function D1(a,b){a=a|0;b=b|0;return nI(a-88|0,b)|0}function Cm(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function zC(a){return!Qb(a,26336,25)&w[a+34|0]<65}function yS(a){return(v[Db(a)>>2]-v[a>>2]|0)/33|0}function yB(a){return(v[Db(a)>>2]-v[a>>2]|0)/28|0}function xX(a,b){a=a|0;b=b|0;Pv(a,b,12,257,-1284)}function xW(a,b,c){a=a|0;b=b|0;c=c|0;sr(a,b,c,85)}function wfa(a,b){a=a|0;b=b|0;return ei(a,b,71)|0}function th(a,b){if(Fe(a)){xd(a,b);return}Xd(a,b)}function s2(a,b,c){a=a|0;b=b|0;c=c|0;pE(a,b,c,70)}function qr(a){return(v[Db(a)>>2]-v[a>>2]|0)/24|0}function pv(a){return(v[Db(a)>>2]-v[a>>2]|0)/36|0}function pm(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function pT(a){if(!(a&255)){return 1}return Wc(a)}function p1(a,b,c){a=a|0;b=b|0;c=c|0;mE(a,b,c,70)}function p0(a,b,c){a=a|0;b=b|0;c=c|0;sr(a,b,c,84)}function om(a,b,c){v[a+4>>2]=c;u[a>>1]=b;return a}function mha(a,b){a=a|0;b=b|0;return ei(a,b,91)|0}function lC(a){return(v[Db(a)>>2]-v[a>>2]|0)/20|0}function kT(a,b){a=a|0;b=b|0;return wE(a,b,322)|0}function iF(a){return(a<<1)+16777216>>>0<16777217}function hha(a,b){a=a|0;b=b|0;if(!BS(a,b)){AS(b)}}function fc(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function caa(a,b){a=a|0;b=b|0;if(!kD(a,b)){Cv(b)}}function bR(a){return(v[Db(a)>>2]-v[a>>2]|0)/56|0}function Z1(a,b,c){a=a|0;b=b|0;c=c|0;ur(a,b,c,72)}function Xl(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function X6(a,b){a=a|0;b=b|0;return C(Nl(a,b,12))}function W9(a,b){a=a|0;b=b|0;return ei(a,b,225)|0}function W4(a){a=a|0;return Yv(a,12833,1074416)|0}function UX(a,b){a=a|0;b=b|0;Pv(a,b,12,290,-1332)}function T9(a,b){a=a|0;b=b|0;return ei(a,b,326)|0}function Sj(a){return(v[Db(a)>>2]-v[a>>2]|0)/12|0}function R2(a,b,c){a=a|0;b=b|0;c=c|0;nE(a,b,c,59)}function Qs(a){return(v[Db(a)>>2]-v[a>>2]|0)/52|0}function Qp(a,b){v[a+4>>2]=256;v[a>>2]=b;return a}function Qia(a,b){a=a|0;b=b|0;if(!yT(a,b)){xT(b)}}function Pja(a,b){a=a|0;b=b|0;if(!LU(a,b)){ou(b)}}function Pia(a,b){a=a|0;b=b|0;return ei(a,b,78)|0}function NL(a,b){return(a|0)==1179011410&b>>>0>80}function M2(a,b,c){a=a|0;b=b|0;c=c|0;mE(a,b,c,59)}function JG(a){return(Zj(a)|0)!=0|(a|32)-97>>>0<6}function HD(a){v[a+4>>2]=0;v[a>>2]=92212;return a}function BU(a){return(v[Db(a)>>2]-v[a>>2]|0)/48|0}function BD(a,b){a=AD(a,b);v[a>>2]=92964;return a}function AV(a,b,c){a=a|0;b=b|0;c=c|0;sr(a,b,c,79)}function A1(a,b,c){a=a|0;b=b|0;c=c|0;nE(a,b,c,70)}function $2(a,b,c){a=a|0;b=b|0;c=c|0;pE(a,b,c,59)}function wU(a,b){a=a|0;b=b|0;if(!vU(a,b)){lu(b)}}function u1(a,b){a=a|0;b=b|0;return+hI(a-92|0,b)}function sA(a,b){a=a|0;b=b|0;if(!NS(a,b)){zA(b)}}function s1(a,b){a=a|0;b=b|0;return+eI(a-92|0,b)}function ql(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function px(a,b){v[a>>2]=v[b>>2];Xc(a+4|0,b+4|0)}function oo(a,b){a=a|0;b=b|0;if(!Hh(a,b)){Qj(b)}}function nu(a){return(v[Db(a)>>2]-v[a>>2]|0)/6|0}function jz(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function h7(a,b){a=a|0;b=b|0;return C(Nl(a,b,1))}function ed(a,b,c,d){return Ed(a,B(Lg(b),c)+d|0)}function aka(a,b){a=a|0;b=b|0;return uu(a,1,b)|0}function a8(a,b){a=a|0;b=b|0;return C(Nl(a,b,6))}function _T(a,b){v[a>>2]=v[a>>2]+B(b,6);return a}function _M(a,b,c){v[a+4>>2]=c;t[a|0]=b;return a}function _I(a,b){a=a|0;b=b|0;Dk(a,b,58952,58960)}function _4(a){a=a|0;return XE(a,8825,1074448)|0}function ZK(a){a=a|0;dc(a+4208|0);return Ff(a)|0}function ZI(a,b){a=a|0;b=b|0;Dk(a,b,58968,58976)}function Y9(a,b){a=a|0;b=b|0;return ei(a,b,73)|0}function Xy(a){return(v[Db(a)>>2]-v[a>>2]|0)/7|0}function X4(a){a=a|0;return Yv(a,5322,1074424)|0}function WS(a,b,c){fc(a,b,yi(b,b+c|0,62620)-b|0)}function WO(a,b){v[a>>2]=v[a>>2]+(b<<1);return a}function WI(a,b){a=a|0;b=b|0;Dk(a,b,59772,59780)}function VI(a,b){a=a|0;b=b|0;Dk(a,b,59788,59796)}function UI(a,b){a=a|0;b=b|0;Dk(a,b,60600,60608)}function TU(a,b){a=AU(a,b);if(!a){uB(b)}return a}function TI(a,b){a=a|0;b=b|0;Dk(a,b,60616,60624)}function R9(a,b){a=a|0;b=b|0;return ei(a,b,60)|0}function QI(a,b){a=a|0;b=b|0;Dk(a,b,61428,61436)}function QB(a,b){a=a|0;b=b|0;if(!rD(a,b)){qD(b)}}function Po(a,b,c){a=ce(a);v[a+4>>2]=c;v[a>>2]=b}function PI(a,b){a=a|0;b=b|0;Dk(a,b,61444,61452)}function P6(a,b){a=a|0;b=b|0;return C(Nl(a,b,2))}function NV(a,b){a=a|0;b=b|0;if(!WB(a,b)){Fu(b)}}function N7(a,b){a=a|0;b=b|0;return C(Nl(a,b,5))}function Ju(a,b){a=a|0;b=b|0;if(!Jo(a,b)){zo(b)}}function Hs(a){a=a|0;lc(a+4208|0);return Ff(a)|0}function HT(a,b){a=a|0;b=b|0;if(!cD(a,b)){Yq(b)}}function H6(a,b){a=a|0;b=b|0;return C(Nl(a,b,3))}function H1(a,b){a=a|0;b=b|0;return+rI(a-88|0,b)}function F7(a,b){a=a|0;b=b|0;return C(Nl(a,b,4))}function DK(a){a=a|0;lc(a+4256|0);return Ff(a)|0}function vB(a,b,c){if(b){Rb(a,Kf(c),b)}return a}function uH(a,b){if(!a){return 0}return Tw(a,b)}function u4(a){a=a|0;return Yv(a,5819,480272)|0}function tja(a,b){a=a|0;b=b|0;$o(a,b,361,360,8)}function qfa(a,b){a=a|0;b=b|0;$o(a,b,668,667,8)}function pn(a){return lb[v[v[a>>2]+28>>2]](a)|0}function pW(a,b){a=a|0;b=b|0;Wp(a,b);return a|0}function pH(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function oha(a,b){a=a|0;b=b|0;$o(a,b,514,513,6)}function od(a,b){return fp(v[b>>2],v[a>>2])?b:a}function ie(a,b){return xk(x[a>>1],x[b>>1])?b:a}function em(a,b){return Rt(z[b>>2],z[a>>2])?b:a}function aS(a){var b=0;b=v[a>>2];He(a);return b}function Y4(a){a=a|0;return XE(a,7113,480214)|0}function Vc(a,b){return ho(v[a>>2],v[b>>2])?b:a}function Tt(a,b){a=a|0;b=b|0;return Ob(a,b,1)^1}function TB(a,b){return(b&255)==2&(a&255)>>>0<3}function Rc(a,b){return xk(x[b>>1],x[a>>1])?b:a}function Oy(a){if(w[a+24|0]){iN(a);t[a+24|0]=0}}function Ne(a,b){return fp(v[a>>2],v[b>>2])?b:a}function Lh(a,b,c){return Ka(980,a|0,b|0,c|0)|0}function Ii(a,b){a=a|0;b=b|0;EB(a,v[a+16>>2]|b)}function Ifa(a,b){a=a|0;b=b|0;$o(a,b,636,635,8)}function Hk(a){return lb[v[v[a>>2]+36>>2]](a)|0}function Hb(a,b){return ho(v[b>>2],v[a>>2])?b:a}function FS(a){return!Qb(a,13959,4)&w[a+4|0]<32}function BF(a){var b=0,c=0;b=a,c=Dd(),v[b>>2]=c}function Ax(a,b){return Rt(z[a>>2],z[b>>2])?b:a}function A3(a){a=a|0;return SE(a,49256,12557)|0}function zz(a){return a>>>0<=45?w[a+43856|0]:0}function y3(a){a=a|0;return SE(a,49276,8220)|0}function xu(a,b,c){a=a|0;b=b|0;c=c|0;hV(a,b,c)}function uV(a,b){a=a|0;b=b|0;$o(a,b,298,297,8)}function qP(a){v[a>>2]=0;v[a+4>>2]=-1;return a}function of(a,b,c){if(!(w[a|0]&32)){Nu(b,c,a)}}function kg(a,b,c){a=ska(a,b,c,c>>31);return a}function jt(a){return(a>>>0<9?a:a-9|256)&65535}function i3(a,b){a=a|0;b=b|0;Xc(a,HJ(b,17740))}function hh(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function V6(a){a=a|0;pK(a);wx(a);t[a+4202|0]=1}function RU(a,b,c){a=a|0;b=b|0;c=c|0;XB(a,b,c)}function L7(a){a=a|0;t[a+4202|0]=1;zK(a);CK(a)}function Hfa(a,b){a=a|0;b=b|0;return oR(a,b)|0}function HY(a,b,c){a=a|0;b=b|0;c=c|0;fc(a,c,b)}function GA(a,b,c){a=a|0;b=b|0;c=c|0;UB(a,b,c)}function Fi(a,b){return(B(b,104)+a|0)+484380|0}function Dr(a,b){return(a&255)>>>0<(b&255)>>>0}function DB(a){return!Qb(a,15575,4)&w[a+4|0]<4}function D7(a){a=a|0;t[a+4202|0]=1;xK(a);wK(a)}function BO(a){ez(a);Rb(a+27|0,0,255);return a}function zx(a,b){a=a|0;b=b|0;return yh(a,b)|0}function wb(a){if(Fe(a)){Jb(v[a>>2])}return a}function w0(a){a=a|0;WG(v[v[a>>2]-12>>2]+a|0)}function vw(a,b,c){a=vG(a,b,c,-1,-1);return a}function uka(a,b,c,d){a=pka(a,b,c,d);return a}function uc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function uQ(a){return Oe(443250/+(a>>>0)*1e4)}function t0(a){a=a|0;VG(v[v[a>>2]-12>>2]+a|0)}function p2(a){a=a|0;v[a>>2]=61968;return a|0}function ll(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function jp(a,b){a=a|0;b=b|0;return hH(a,b)^1}function ija(a,b){a=a|0;b=b|0;AE(a,b,365,364)}function iU(a){kb=0;a=(a&65535)-98|0;return a}function iH(a){a=a|0;Kw(v[v[a>>2]-12>>2]+a|0)}function i2(a){a=a|0;v[a>>2]=61468;return a|0}function h5(a){a=a|0;return _E(a,7057,1024)|0}function ef(a,b){return Dr(w[a|0],w[b|0])?b:a}function dV(a,b){a=a|0;b=b|0;return sF(a,b)|0}function ce(a){v[a>>2]=0;v[a+4>>2]=0;return a}function bi(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function _G(a,b){a=a|0;b=b|0;return DD(a,b)|0}function ZW(a){a=a|0;v[a>>2]=62388;return a|0}function ZJ(a,b){a=a|0;b=b|0;return HJ(a,b)|0}function Yj(a,b){a=a|0;b=b|0;return hH(a,b)|0}function Yd(a){a=HD(a);v[a>>2]=84696;return a}function Vb(a,b){return Dr(w[b|0],w[a|0])?b:a}function UQ(a){a=rka(a&65535,0,80,0);return a}function Tr(a,b){a=a|0;b=b|0;return dH(a,b)^1}function QU(a){t[a+12|0]=w[a+12|0]|2;return a}function Pm(a){return(a>>>0>127?a^128:-1)&255}function Ok(a,b){a=a|0;b=b|0;return dH(a,b)|0}function OX(a,b){a=a|0;b=b|0;return YD(a,b)|0}function OG(a){a=QJ(a);v[a>>2]=79088;return a}function NW(a){a=a|0;v[a>>2]=43144;return a|0}function N4(a){a=a|0;return _E(a,6594,1032)|0}function Lo(a,b,c,d){a=ska(a,b,c,d);return a}
function LW(a){a=a|0;v[a>>2]=42904;return a|0}function Kx(a){return v[Db(a)>>2]-v[a>>2]>>11}function JF(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function GS(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function Fia(a,b){a=a|0;b=b|0;Tv(a,b,17,3,16)}function F9(a,b){a=a|0;b=b|0;my(CL(a+24|0,b))}function EJ(a){a=a|0;v[a>>2]=49340;return a|0}function Bf(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function As(a){a=QJ(a);v[a>>2]=78864;return a}function An(a){a=cm(a);v[a>>2]=92624;return a}function AX(a,b){a=a|0;b=b|0;return Ev(a,b)|0}function $ja(a,b){a=a|0;b=b|0;AE(a,b,304,303)}function $G(a){a=a|0;Gw(v[v[a>>2]-12>>2]+a|0)}function zh(a){return v[v[a+8>>2]>>2]==(a|0)}function xx(a){return C(C(a*C(7900))+C(100))}function wd(a,b){if(!zf(b)){a=Kf(b)}return a}function w2(a){a=a|0;MI(a);return v[a+16>>2]}function tj(a){return oE(a,C(4294967296),-1)}function t_(a){a=a|0;de(a,469312,Zd(467840))}function tT(a,b){a=a|0;b=b|0;return(b|0)<6|0}function sw(){ia(An(ba(4)|0)|0,92664,26);L()}function s_(a){a=a|0;de(a,469320,Zd(467848))}function rt(a){return v[Db(a)>>2]-v[a>>2]>>4}function r_(a){a=a|0;de(a,469328,Zd(468044))}function rV(a,b){a=a|0;b=b|0;Tv(a,b,44,2,44)}function q_(a){a=a|0;de(a,469344,Zd(468036))}function p_(a){a=a|0;de(a,469352,Zd(468052))}function n_(a){a=a|0;de(a,469360,Zd(468060))}function m_(a){a=a|0;de(a,469376,Zd(468068))}function l_(a){a=a|0;de(a,469384,Zd(468076))}function k_(a){a=a|0;de(a,469392,Zd(468084))}function j_(a){a=a|0;de(a,469416,Zd(468092))}function i_(a){a=a|0;de(a,469448,Zd(467856))}function h_(a){a=a|0;de(a,469456,Zd(467864))}function g_(a){a=a|0;de(a,469464,Zd(467872))}function g1(a){a=a|0;return gb(v[a+60>>2])|0}function f_(a){a=a|0;de(a,469472,Zd(467880))}function e_(a){a=a|0;de(a,469480,Zd(467920))}function eF(a){a=Ia(a|0)|0;kb=O()|0;return a}function d_(a){a=a|0;de(a,469488,Zd(467928))}function c_(a){a=a|0;de(a,469496,Zd(467936))}function cS(a){if(a){VH(a);ye(v[a+80>>2],a)}}function b_(a){a=a|0;de(a,469504,Zd(467944))}function a_(a){a=a|0;de(a,469512,Zd(467952))}function _j(a){a=a&255;return(a|0)==255?-1:a}function _Z(a){a=a|0;de(a,469528,Zd(467968))}function Zm(a){return v[Db(a)>>2]-v[a>>2]>>3}function ZZ(a){a=a|0;de(a,469536,Zd(467976))}function YZ(a){a=a|0;de(a,469544,Zd(467888))}function XZ(a){a=a|0;de(a,469560,Zd(467896))}function Vh(a){return v[Db(a)>>2]-v[a>>2]>>2}function VZ(a){a=a|0;de(a,469576,Zd(467904))}function TZ(a){a=a|0;de(a,469592,Zd(467912))}function SZ(a){a=a|0;de(a,469608,Zd(467984))}function RZ(a){a=a|0;de(a,469616,Zd(467992))}function Om(a){return v[Db(a)>>2]-v[a>>2]>>1}function Jz(a){return v[zc(a)>>2]-v[a>>2]>>2}function Gx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function FJ(a){if(a){lb[v[v[a>>2]+4>>2]](a)}}function Dy(a){t[a+24|0]=0;t[a|0]=0;return a}function Cz(a){return v[Db(a)>>2]-v[a>>2]>>8}function $n(a){return v[Db(a)>>2]-v[a>>2]>>5}function $Z(a){a=a|0;de(a,469520,Zd(467960))}function xm(a,b){u[a>>1]=b;u[a+2>>1]=b>>>16}function x2(a){a=a|0;MI(a);return v[a+4>>2]}function wc(a){if(Fe(a)){a=v[a>>2]}return a}function sf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function rn(a){a=a|0;bH(v[a>>2]);return a|0}function ri(a,b){a=a|0;b=b|0;return C(C(0))}function jl(a,b){return a<<24>>24<b<<24>>24}function jk(a,b){return a<<16>>16<b<<16>>16}function hka(a,b){a=a|0;b=b|0;vr(a,b,296,2)}function fB(a,b){v[a>>2]=v[a>>2]+b;return a}function dp(a){return v[Db(a)>>2]-v[a>>2]|0}function dL(a){a=a|0;lb[v[v[a>>2]+4>>2]](a)}function dK(a){return Sh(C(fK(a)*C(32768)))}function aJ(a){t[a+4|0]=0;t[a|0]=0;return a}function Yl(a){a=a|0;Jw(v[a>>2]);return a|0}function Xh(a,b,c){if(c){dj(a,b,c)}return a}function LF(a,b,c){return tv(KF(a),KF(b),c)}function Hm(a,b,c){return vf(a,b)>>>0>c>>>0}function Hda(a,b){a=a|0;b=b|0;vr(a,b,581,3)}function Ce(a,b,c){if(c){pc(a,b,c)}return a}function yw(a){a=a|0;return Dh(a,468060)|0}function um(a){sz(v[a+20>>2]);v[a+20>>2]=0}function uM(a){v[a>>2]=v[a>>2]+52;return a}function tw(a){a=a|0;return Dh(a,468084)|0}function raa(a,b){a=a|0;b=b|0;To(a+40|0,b)}function r8(a,b,c){a=a|0;b=b|0;c=c|0;ce(a)}function pz(a){v[a>>2]=v[a>>2]+32;return a}function ow(a){a=a|0;return Dh(a,468092)|0}function nka(a,b){a=a|0;b=b|0;To(a+12|0,b)}function mf(a,b,c){a=rka(c,0,a,b);return a}function kA(a,b){a=a|0;b=b|0;vr(a,b,581,2)}function jka(a,b){a=a|0;b=b|0;Eq(a+36|0,b)}function iK(a){return C(C(a*C(96))+C(-96))}function gs(a){return(a|0)<=65535&(a|0)>=0}function gq(a){v[a>>2]=v[a>>2]+12;return a}function fQ(a,b,c,d){fc(a,b,(d|0)==-1?c:d)}function dX(a){a=a|0;return v[a+4>>2]!=0|0}function _q(a){hr(a+32|0);yb(a+12|0);xb(a)}function Xu(a){a=a|0;return Dh(a,468044)|0}function V8(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function P0(a){a=a|0;return Dh(a,467856)|0}function Nea(a,b){a=a|0;b=b|0;xE(a,b,2,31)}function Kt(a,b){a=a|0;b=b|0;vr(a,b,582,2)}function Jk(a,b){lb[v[v[b>>2]+44>>2]](a,b)}function Jf(a){v[a>>2]=v[a>>2]+20;return a}function Ik(a,b){lb[v[v[b>>2]+32>>2]](a,b)}function Hw(a){a=a|0;return Dh(a,468036)|0}function G0(a){a=a|0;return Dh(a,467872)|0}function Em(a){v[a>>2]=v[a>>2]+28;return a}function Dw(a){a=a|0;return Dh(a,468052)|0}function Ct(a){Ue(a+24|0);dc(a+12|0);dc(a)}function CH(a,b){return C(BH(a?C(-b):b)*b)}function Ar(a,b){lb[v[v[b>>2]+40>>2]](a,b)}function Al(a){return v[a+8>>2]&2147483647}function $p(a){v[a>>2]=v[a>>2]+16;return a}function $k(a){wb(a+36|0);lc(a+24|0);Ah(a)}function $M(a,b){return FE(a,b,2147483647)}function zZ(a,b){a=a|0;b=b|0;yh(a,b+16|0)}function y9(a,b){a=a|0;b=b|0;yh(a,b+36|0)}function x1(a,b){a=a|0;b=b|0;kI(a-92|0,b)}function w1(a,b){a=a|0;b=b|0;jI(a-92|0,b)}function vk(a){v[a>>2]=v[a>>2]+6;return a}function uf(a){a=a|0;Ih(a+8|0);return a|0}function tZ(a,b){a=a|0;b=b|0;yh(a,b+12|0)}function sF(a,b){return zr(a,Ic(b),Fb(b))}function qH(a,b){t[a|0]=b+48;return a+1|0}function pp(a){a=a|0;vs(a+8|0);return a|0}function ne(a){return Eb(a&65535)<<16>>16}function nF(){if(!w[469793]){t[469793]=1}}function lt(a){gm(a,Wn(a),62620);return a}function kI(a,b){a=a|0;b=b|0;NE(a,b,2048)}function jK(a){a=a|0;Rb(a+4296|0,0,81928)}function jI(a,b){a=a|0;b=b|0;NE(a,b,4096)}function hj(a,b){v[a>>2]=v[b>>2];return a}function gt(a){v[a>>2]=v[a>>2]+8;return a}function fka(a,b){a=a|0;b=b|0;fi(a,b,136)}function Xfa(a,b){a=a|0;b=b|0;fi(a,b,274)}function VO(a){v[a>>2]=v[a>>2]-2;return a}function Ur(a){a=a|0;Sk(a+8|0);return a|0}function Sr(a){a=a|0;Sk(a+4|0);return a|0}function Sfa(a,b){a=a|0;b=b|0;fi(a,b,106)}function Rk(a){a=a|0;return gH(a)<<24>>24}function R1(a,b){a=a|0;b=b|0;AI(a-88|0,b)}function Qe(a){v[a>>2]=v[a>>2]+2;return a}function Q1(a,b){a=a|0;b=b|0;zI(a-88|0,b)}function ON(a,b){if(z[a>>2]>b){z[a>>2]=b}}function Nja(a,b){a=a|0;b=b|0;xE(a,b,3,8)}function Mr(a){a=a|0;Wv(a,166,93012,1021)}function Ie(a){v[a>>2]=v[a>>2]+4;return a}function He(a){v[a>>2]=v[a>>2]+1;return a}function En(a,b){return v[a>>2]-v[b>>2]|0}function Dia(a,b){a=a|0;b=b|0;fi(a,b,282)}function B1(a,b){a=a|0;b=b|0;lI(a-88|0,b)}function $1(a,b){a=a|0;b=b|0;Jl(a,b+12|0)}function z1(a){a=a|0;return pp(a-92|0)|0}function yk(a){return B(Qm(a),Hd(a))&255}function yZ(a,b){a=a|0;b=b|0;en(a,84440)}function xZ(a,b){a=a|0;b=b|0;en(a,84460)}function tJ(a){return(wc(a)+Fb(a)|0)-1|0}function sZ(a,b){a=a|0;b=b|0;Fc(a,11316)}function rZ(a,b){a=a|0;b=b|0;Fc(a,11433)}function r1(a){a=a|0;return pp(a-96|0)|0}function qo(a,b){t[a|0]=b;t[a+1|0]=b>>>8}function pS(a,b){a=a|0;b=b|0;fi(a,b,284)}function oja(a,b){a=a|0;b=b|0;fi(a,b,34)}function o1(a,b){a=a|0;b=+b;dI(a-96|0,b)}function mj(a,b){return v[a>>2]!=v[b>>2]}function kj(a){u[a+4>>1]=65535;v[a>>2]=0}function ic(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function g8(a){a=a|0;t[a+4202|0]=1;OK(a)}function dF(a,b,c){Ha(105,a|0,b|0,c|0,0)}function bf(a,b){v[a+8>>2]=b|-2147483648}function _6(a){a=a|0;return v[a+4260>>2]}function Vd(a,b){return(b|0)!=0&(a|0)!=0}function T1(a){a=a|0;return pp(a-88|0)|0}function Sga(a,b){a=a|0;b=b|0;fi(a,b,42)}function Rr(a,b){v[a+24>>2]=v[a+24>>2]+b}function Rf(a,b){a=ska(0,a,b,0);return a}function Qfa(a,b){a=a|0;b=b|0;fi(a,b,72)}function P1(a,b){a=a|0;b=+b;yI(a-88|0,b)}function Nk(a){return(a|0)==32|a-9>>>0<5}function N1(a,b){a=a|0;b=+b;wI(a-88|0,b)}function K1(a,b){a=a|0;b=+b;uI(a-88|0,b)}function ID(a,b){oc(a,b);oc(a+4|0,b+4|0)}function Eia(a,b){a=a|0;b=b|0;Iq(a,b,17)}function BT(a,b,c){v[a>>2]=b;v[a+4>>2]=c}function z6(a){a=a|0;return(a|0)==277|0}function rF(a,b){a=a|0;b=b|0;return b|0}function oV(a,b){a=a|0;b=b|0;fi(a,b,50)}function gha(a,b){a=a|0;b=b|0;ZB(a,b,8)}function ek(a,b){return My(a&255,b&255)}function du(a,b,c){return a<b?b:a>c?c:a}function dT(a,b){a=a|0;b=b|0;Iq(a,b,32)}function cW(a,b){a=a|0;b=b|0;fi(a,b,59)}function aI(a){v[a+4>>2]=v[a+4>>2]|8192}function ZQ(a,b,c,d){return ll(c,d,a,b)}function Yh(a){return(a&65535)>>>0<3999}function Xm(a){a=v[a+8>>2];if(a){Jb(a)}}function Ww(a){return(p(a),j(2))>>>20|0}function Uy(a,b,c){return a<b?b:a>c?c:a}function UF(a,b){a=a|0;b=b|0;kf(a,1,45)}function U8(a){a=a|0;return w[a+4201|0]}function TM(a,b){return(gl(a,b)|0)!=255}function TF(a,b){a=a|0;b=b|0;aG(a,1,45)}function T8(a){a=a|0;return w[a+4202|0]}function RV(a,b){a=a|0;b=b|0;Iq(a,b,11)}function QT(a){return tE(a,65535,65535)}function Gg(a,b,c){t[a+4|0]=c;v[a>>2]=b}function Eb(a){return(a<<8|a>>>8)&65535}function zP(a,b,c){return CE(a,b,c,40)}function qJ(a){return a?(a|0)==2?3:2:1}function oj(a,b){return wc(a)+(b<<2)|0}function oe(a,b,c){ln(a,b,ad(b,c)+b|0)}function dh(a){return oE(a,C(255),255)}function cL(a){a=a|0;return 1869112133}function cE(a,b,c){return Xo(a,b,c,24)}function _i(a,b){v[a+4>>2]=1;v[a>>2]=b}function Vy(a,b){return DE(a,b,-1,0,0)}function Tj(a,b){v[a+4>>2]=2;v[a>>2]=b}function Su(a,b,c){return Xo(a,b,c,20)}function RW(a){a=a|0;return v[a+16>>2]}function O1(a){a=a|0;return+xI(a-88|0)}function M1(a){a=a|0;return+vI(a-88|0)}function Kv(a,b){v[a+4>>2]=4;v[a>>2]=b}function Kd(a){v[v[a+8>>2]>>2]=v[a>>2]}function J6(a){a=a|0;return-2013527448}function J1(a){a=a|0;return+tI(a-88|0)}function IV(a){a=a|0;return v[a+12>>2]}function HU(a,b,c){return Xo(a,b,c,48)}function Gda(a){a=a|0;PQ(a);return a|0}function Dv(a,b){v[a+4>>2]=3;v[a>>2]=b}function Br(a){a=a|0;return 2147483647}function At(a,b,c){return Xo(a,b,c,12)}function AT(a,b,c){ql(a,b&65535,c&255)}function yq(a,b,c){return Xo(a,b,c,6)}function xf(a,b,c){return ed(a,b,c,0)}function vf(a,b){return sk(a,b)&65535}function tD(a,b,c){ec(a,b,Qg(b,c)<<3)}function sj(a){return(a-1&255)>>>0<17}function s7(a){a=a|0;return-271958638}function r2(a){a=a|0;return w[a+40|0]}function qt(a,b,c){return _o(a,b,c,4)}function oi(a,b,c){Xc(Xc(a,b)+12|0,c)}function no(a,b){u[a+8>>1]=b;return a}function j7(a){a=a|0;return-620920304}function ii(a){a=v[a>>2];if(a){xG(a)}}function hH(a,b){return fH(a)^fH(b)^1}function fJ(a){v[a>>2]=49672;return a}function eh(a,b,c){return _o(a,b,c,2)}function e0(a){a=a|0;return LG(a,0)|0}function dH(a,b){return cH(a)^cH(b)^1}function d0(a){a=a|0;return LG(a,1)|0}function cm(a){v[a>>2]=93264;return a}function c8(a){a=a|0;return-270114148}function bka(a,b){a=a|0;b=b|0;kt(a,b)}function ar(a,b,c){return _o(a,b,c,3)}function a0(a){a=a|0;return KG(a,0)|0}function _t(a,b){a=a|0;b=b|0;return 1}function _J(a,b){a=a|0;b=b|0;return 0}function Wr(a,b){a=a|0;b=b|0;return-1}function Wm(a){v[a>>2]=61920;return a}function Vaa(a,b){a=a|0;b=b|0;LN(a,b)}function Se(a,b){v[a+4>>2]=b;return a}function R6(a){a=a|0;return 302837129}function QJ(a){v[a>>2]=78892;return a}function Q7(a){a=a|0;return-285139079}function OP(a,b,c){return Vv(a,b,c,5)}function Nq(a){a=a|0;return v[a+4>>2]}function M8(a){a=a|0;return 542066252}function LL(a,b){Uc(a,b&4?16:8,1,0,0)}function LJ(a){a=C(a-a);return C(a/a)}function Io(a,b,c){return Vv(a,b,c,1)}function I7(a){a=a|0;return-284078960}function HS(a,b,c){ec(a,b,sc(b,c)<<2)}function HN(a,b){return(0-b|0)!=(a|0)}function HJ(a,b){return zr(a,b,Og(b))}function Fe(a){return w[a+11|0]>>>7|0}function FP(a){return(a&65535)==65534}function EI(a){v[a>>2]=63232;return a}function ED(a){a=a|0;return v[a+8>>2]}function Dl(a,b,c){return Vv(a,b,c,2)}function DI(a){v[a>>2]=63256;return a}function CI(a){v[a>>2]=63336;return a}function C6(a,b){a=a|0;b=b|0;return 3}function BI(a){v[a>>2]=63376;return a}function Az(a,b,c){return _o(a,b,c,5)}function Am(a){return(a&740327453)!=0}function A7(a){a=a|0;return-281111764}function A6(a,b){a=a|0;b=b|0;return 2}function $h(a,b,c){return _o(a,b,c,1)}function $I(a){v[a>>2]=58936;return a}function $6(a){a=a|0;return-275227023}function $$(a){a=a|0;return KG(a,1)|0}function zX(a,b){a=a|0;b=b|0;$D(a,b)}function yP(a,b,c,d){tP(fc(a,b,c),d)}function vx(a){a=a|0;bF(a,49176,971)}function vZ(a){a=a|0;return t[a+8|0]}function uZ(a){a=a|0;return t[a+9|0]}function ts(a){return x[a+480192>>1]}function ss(a){return x[a+480190>>1]}function rp(a,b){a=a|0;b=b|0;Jl(a,b)}function pi(a,b){a=a|0;b=b|0;yh(a,b)}function oN(a){return(a+5&255)>>>0<2}function nt(a){return v[Db(a)>>2]<<5}function m2(a){a=a|0;return w[a+8|0]}function laa(a){a=a|0;return vi(a)|0}function lX(a){a=a|0;UC(Ic(a),Fb(a))}function jL(a,b){a=a|0;b=b|0;pi(a,b)}function hB(a,b,c){cc(cc(a,b)+4|0,c)}function gK(a){v[a>>2]=0;v[a+4>>2]=0}function fh(a){Vf(a+52|0);dc(a+40|0)}function eu(a,b){return w[a+b|0]!=63}function eQ(a,b){return B(b,872)+a|0}function bn(a,b){a=a|0;b=b|0;NJ(a,b)}function bL(a,b,c){a=a|0;b=b|0;c=c|0}function Zia(a){a=a|0;return XA(a)|0}function Waa(a){a=a|0;return nh(a)|0}function VJ(a){a=a|0;bF(a,49120,969)}function Um(a){v[a+4>>2]=v[a+4>>2]+1}function QR(a,b){if(!KR(a,b)){Zz(b)}}function QK(a,b){a=a|0;b=b|0;zx(a,b)}function PX(a,b){a=a|0;b=b|0;CN(a,b)}function Oq(a,b){a=a|0;b=b|0;nv(a,b)}function NJ(a,b){a=a|0;b=b|0;rp(a,b)}function MQ(a){return(a|0)<120?a:120}function Lg(a){return x[a+480188>>1]}function KQ(a){return(a&255)>>>0<129}function Id(a,b){return B(b,160)+a|0}function Hea(a){a=a|0;return Ai(a)|0}function Ex(a,b){a=a|0;b=b|0;$K(a,b)}function Dja(a){a=a|0;return rU(a)|0}function Bq(a,b){a=a|0;b=b|0;jL(a,b)}function AA(a,b){a=a|0;b=b|0;KJ(a,b)}function zt(a,b){return B(b,36)+a|0}function xq(a,b){return(b-a|0)/48|0}function wf(a,b){return(b-a|0)/20|0}function ul(a,b){return tl(Oc(a,b))}function ud(a,b){return(b-a|0)/12|0}function sk(a,b){return(b-a|0)/52|0}function pj(a,b){return Uf(a,b)&255}function pe(a,b,c){return qG(a,b,c)}function pV(a){a=a|0;return kv(a)|0}function nk(a){return tE(a,255,255)}function ng(a){return C(D(a))==C(N)}function nc(a,b){return(a|0)==(b|0)}function kX(a){a=a|0;return zg(a)|0}function iq(a){return(a&255)==1?1:2}function ho(a,b){return a>>>0<b>>>0}function fv(a){t[a+2|0]=0;u[a>>1]=0}function ff(a,b){return B(b,24)+a|0}function e7(a){a=a|0;v[a+4224>>2]=0}function dg(a,b){return vj(a,_d(b))}function cq(a,b){return(b-a|0)/56|0}function cc(a,b){v[a>>2]=b;return a}function bS(a,b){return Pf(a,0-b|0)}function ag(a,b){return B(b,52)+a|0}function Zw(a){return!Qb(a,93580,6)}function WC(a){a=a|0;return Ng(a)|0}function Vx(a,b){return B(b,28)+a|0}function Ts(a){return!(a&204473357)}function TG(a){a=a|0;return wv(a)|0}function Sb(a,b){return ue(a,b&255)}function Qz(a,b){return B(b,56)+a|0}function Qt(a,b){return(b-a|0)/33|0}function Op(a){if(w[a+24|0]){iN(a)}}function Ni(a,b){return(b-a|0)/24|0}function Mi(a,b,c){return tv(a,b,c)}function MA(a,b,c){return Js(a,b,c)}function Kg(a,b){return B(b,20)+a|0}function KW(a){a=a|0;lD(Rb(a,0,36))}function Jd(a,b){return B(b,12)+a|0}function JW(a){a=a|0;return Ih(a)|0}function Hq(a){a=a|0;return Je(a)|0}function H0(a){a=a|0;return Qk(a)|0}function Gv(a,b,c){return Qb(a,b,c)}function Gp(a){return KU(a,251,255)}function Fk(a,b,c){return uE(a,b,c)}function DS(a,b){return B(b,33)+a|0}function Cq(a,b){return(b-a|0)/28|0}function AB(a){a=a|0;return tc(a)|0}function $q(a,b){return(b-a|0)/36|0}function $J(a){a=a|0;return Sk(a)|0}function zo(a){t[a|0]=0;t[a+1|0]=0}function zf(a){return(a&128)>>>7|0}function yT(a,b){return wr(a,b,56)}function xn(a,b){v[a+1298464>>2]=b}function tx(a,b,c,d){Rv(a,b,c,d,4)}function rD(a,b){return wr(a,b,20)}function qi(a){a=a|0;t[a+4202|0]=0}function pN(a){be(a+8|0);hN(a+4|0)}function pD(a,b){return Gk(a,b,36)}function mJ(a){return(_j(a)|0)==-1}function m1(a,b){a=a|0;b=b|0;Jb(b)}function lk(a,b){return(b-a|0)/6|0}function kJ(a,b){a=a|0;b=b|0;dc(b)}function jJ(a,b){a=a|0;b=b|0;wm(b)}function jB(a){return a&2147483647}function fp(a,b){return(a|0)<(b|0)}function fm(a){return C(D(a))<C(N)}function bV(a,b){return Gk(a,b,28)}function Yy(a,b){return(b-a|0)/7|0}function Xk(a,b){return(a+b|0)-1|0}function Wq(a,b){return(b<<11)+a|0}function WT(a){return w[a+1|0]!=63}function Sn(a,b){return(b<<13)+a|0}function RF(a){return Dh(a,467928)}function Qv(a,b){return!(b>>>31|0)}function QF(a){return Dh(a,467920)}function OF(a){return Dh(a,467944)}function Nh(a,b){a=a|0;b=b|0;Kb(a)}function NF(a){return Dh(a,467936)}function MJ(a,b,c,d){Rv(a,b,c,d,2)}function Ks(a,b){return(a-b|0)/6|0}function Iv(a,b){return Gk(a,b,12)}function Gia(a){a=a|0;return+rH(a)}function Fj(a,b){return B(yk(b),a)}function Ew(a){return nc(a,-1)?0:a}function Ek(a){return(a&255)>>>0>1}function Ed(a,b){return B(b,6)+a|0}function EX(a){a=a|0;_m(a,1,13485)}function Cx(a,b,c,d){Rv(a,b,c,d,9)}function Be(a,b){fc(a,Ic(b),Fb(b))}function Bc(a,b){return FE(a,b,-1)}function BS(a,b){return wr(a,b,18)}function A9(a){a=a|0;Iq(a,21751,1)}function yz(a,b){return Gk(a,b,4)}function wh(a){v[a>>2]=0;return a}function waa(a){a=a|0;tg(a,qj(a))}function us(a){return qE(a,77568)}function uk(a){u[a>>1]=0;return a}function ue(a,b){return(b<<5)+a|0}function sz(a){if(a){Jb(a+-64|0)}}function s0(a){a=a|0;return 10425}function rm(a,b){return(b<<8)+a|0}function rG(a,b){return qG(a,0,b)}function qy(a){dc(a+4|0);return a}function qq(a,b){return re(a,b)^1}function qga(a){a=a|0;Qf(a,16916)}function ox(a,b){return SL(a,b)^1}function ofa(a){a=a|0;nS(a,65535)}function le(a,b){return!Qb(a,b,4)}function kH(a){return qE(a,77632)}function iY(a){a=a|0;return 13060}function gg(a,b){return Ic(a)+b|0}function dia(a){a=a|0;Qf(a,16285)}function aw(a,b){return v[a+b>>2]}function _e(a,b){return(b<<3)+a|0}function Zj(a){return a-48>>>0<10}function XC(a){return(a&16)>>>4|0}function Wc(a){return KU(a,1,120)}function Pd(a){return v[gc(a)>>2]}function Nb(a,b){return nc(a,b)^1}function Mx(a){v[a>>2]=v[a>>2]+24}function Jn(a){return a+1074328|0}function Jc(a,b){return wc(a)+b|0}function Gf(a){return a!=a?C(0):a}function Gd(a,b){return(b<<4)+a|0}function Eh(a){v[a>>2]=1;return a}function EY(a){a=a|0;return 13174}function Dm(a){v[a>>2]=2;return a}function CY(a){a=a|0;return 10305}function Bo(a){Wv(a,25,92944,211)}function Bb(a,b){return(b<<2)+a|0}function $b(a,b){return(b<<1)+a|0}function $N(a,b){return Gk(a,b,8)}function zja(a){a=a|0;Qf(a,3892)}function yY(a){a=a|0;return 6869}function tX(a){a=a|0;Qf(a,16943)}function rr(a){t[a|0]=0;return a}function rga(a){a=a|0;Qf(a,3988)}function qX(a){a=a|0;UC(a,Og(a))}function po(a){return Rb(a,0,48)}function og(a,b){cc(wh(a)+4|0,b)}function oS(a,b){pc(a,b+4|0,256)}function jY(a){a=a|0;return 9864}function hY(a){a=a|0;return 5723}function eU(a,b,c){EE(a,b,c,256)}function bv(a,b){return vka(a,b)}function bg(a,b,c,d){lf(a,c,d,b)}function aia(a){a=a|0;Qf(a,4487)}function Zf(a){Wv(a,25,92892,24)}function Zea(a){a=a|0;Qf(a,4168)}function Wu(a,b,c){EE(a,b,c,128)}function Vg(a,b,c){ln(a,b,b+c|0)}function Uha(a){a=a|0;Qf(a,4381)}function RK(a){return(a&8)>>>3|0}function QG(a){v[a+72>>2]=466856}function PG(a){v[a+72>>2]=466940}function Mh(a){return!v[a+16>>2]}function Kga(a){a=a|0;vu(a,3883)}function Iga(a){a=a|0;vu(a,4890)}function BC(a){gm(a,So(a),62620)}function Aq(a,b,c){yE(a,b,c,128)}function zk(a,b){return wd(a,b)}function zi(a,b){return(a|b)!=0}function zb(a,b){return(a&b)!=0}function zG(a){if(AG(a)){Jb(a)}}function yb(a){je(a+12|0);je(a)}function y1(a){a=a|0;fs(a-92|0)}function xl(a,b,c){lf(a,c,22,b)}function xB(a,b){return ro(b,a)}function wj(a,b){return ue(a,b)}function vj(a,b){return cc(a,b)}function vh(a,b){return ad(a,b)}function uX(a){a=a|0;Qf(a,4535)}function tQ(a,b){tr(a,b,12,-12)}function st(a,b){return Oc(a,b)}function sG(a,b){return ud(a,b)}function qp(a,b){return Bb(a,b)}function qU(a,b){return jo(b,a)}function q1(a){a=a|0;fs(a-96|0)}function pl(a){return ym(se(a))}function ok(a,b,c){lf(a,c,12,b)}function oh(a,b){return!wd(a,b)}function nm(a){wb(a+12|0);wb(a)}function mg(a){return Uh(a)?0:a}function kp(a){return a<<24>>24}function jf(a){a=a|0;return a|0}function iy(a){u[a+480214>>1]=0}function iw(a){return Db(a+8|0)}function iN(a){gN(a+12|0);fN(a)}function hl(a){xb(a+12|0);gd(a)}function hf(a,b){return xg(a,b)}function hc(a,b){return zD(a,b)}function eE(a,b){tr(a,b,24,-24)}function dC(a){return(a&255)==1}function co(a){Yt(a,0);return a}function bo(a,b){return xk(a,b)}function _v(a,b){return Zg(a,b)}function _s(a){jO(a+12|0);iO(a)}function _h(a,b,c){lf(a,c,13,b)}function _L(a,b){return YL(a,b)}function Xb(a,b){return ag(a,b)}function XD(a,b){return Xc(a,b)}function Vz(a,b,c){lf(a,c,64,b)}function Sd(a){return(a&255)!=0}function S1(a){a=a|0;fs(a-88|0)}function Qi(a,b){return a>>>b&1}function Qd(a,b){return sc(a,b)}function Pc(a,b,c){fc(a,b,1<<c)}function Oe(a){return sq(se(a))}function Mj(a,b){return b-a>>11}function LT(a,b,c){lf(a,c,24,b)}function LC(a,b){return IC(a,b)}function Ke(a,b,c){lf(a,c,32,b)}function Is(a,b){return jk(a,b)}function If(a,b){return vj(a,b)}function Hn(a,b){return Dr(a,b)}function Gi(a,b,c){lf(a,c,28,b)}function Gh(a,b){return Yu(a,b)}function GV(a){a=a|0;Qf(a,4361)}function Fg(a,b){return Nb(a,b)}function FI(a,b){return Qg(a,b)}function Ec(a,b){return Wq(a,b)}function DU(a,b){tr(a,b,48,-48)}function Cr(a){a=a|0;return 127}function CT(a,b){return ho(a,b)}function CB(a,b,c){lf(a,c,30,b)}function Aj(a,b,c){lf(a,c,20,b)}function Af(a){xb(a+20|0);xb(a)}function $u(a,b){return JC(a,b)}function $g(a){return oN(a&255)}function z0(a){a=a|0;Jb(ys(a))}function ye(a,b){if(!a){Jb(b)}}function y2(a){a=a|0;Jb(NI(a))}function xz(a){return a+4896|0}function xh(a,b){return b-a>>8}function wZ(a){a=a|0;Jb(yF(a))}function sn(a){return(a|0)==-1}function sc(a,b){return b-a>>2}function ro(a,b){return a-b>>1}function qx(a){a=a|0;Jb(GJ(a))}function n2(a){a=a|0;Jb(II(a))}function kZ(a){a=a|0;Jb(xF(a))}function ik(a,b){return b-a>>4}function hQ(a){return a+4096|0}function fs(a){a=a|0;Jb(pp(a))}function dR(a,b){Tv(a,b,5,3,4)}function bc(a,b){v[a+100>>2]=b}function b3(a){a=a|0;Jb(ls(a))}function an(a){a=a|0;Jb(JU(a))}function a7(a){a=a|0;Jb(qK(a))}function Z6(a){a=a|0;return 13}function WW(a){a=a|0;Jb(xD(a))}function WG(a){a=a|0;Jb(up(a))}function Vm(a){a=a|0;Jb(wv(a))}function VG(a){a=a|0;Jb(pf(a))}function Uf(a,b){return b-a>>5}function TY(a){a=a|0;Jb(qF(a))}function R7(a){a=a|0;Jb(DK(a))}function Qg(a,b){return b-a>>3}function Ow(a){a=a|0;Jb(Sk(a))}function Oc(a,b){return b-a>>1}function OS(a,b){ln(a,b,sd(b))}function OC(a){return tc(a<<2)}function Nw(a){a=a|0;Jb(Bn(a))}function Nt(a,b){return a-b>>2}function N8(a){a=a|0;Jb(ZK(a))}function My(a,b){return a<<8|b}function Lw(a){a=a|0;Jb(Vr(a))}function LY(a){a=a|0;Jb(pF(a))}function LK(a){a=a|0;Jb(MK(a))}function Kw(a){a=a|0;Jb(Ur(a))}function Ix(a){a=a|0;Jb(Hs(a))}function Hd(a){return a&64?2:1}function Gw(a){a=a|0;Jb(Sr(a))}function Gt(a){return a>>>27^a}function CD(a){return a+1024|0}function Bs(a){a=a|0;Jb(Ff(a))}function AZ(a){a=a|0;Jb(zF(a))}function AF(a){a=a|0;Jb(hw(a))}function $d(a,b){t[a|0]=w[b|0]}function yf(a){return vj(a,0)}function yK(a){a=a|0;return 5}function yA(a,b){ec(a,b,4896)}function x6(){return 19988497}function vd(a){return(a|0)!=0}function rq(a){return a+256|0}function ps(a,b){v[a+32>>2]=b}function pR(a,b){ec(a,b,1108)}function mH(a){a=a|0;return-1}function kc(a){a=a|0;return 0}function jo(a,b){return a-b|0}function gk(a){return vd(a)^1}function gf(a){return D(a)==N}function fU(a,b){lf(a,b,40,2)}function eR(a,b){lf(a,b,33,1)}function ck(a){return a+4e4|0}function bd(a,b){sp(a,b+28|0)}function ad(a,b){return b-a|0}function _z(a,b){ec(a,b,1024)}function Yz(a){return a+128|0}function WN(a,b){tr(a,b,7,-7)}function Uq(a,b){lf(a,b,26,3)}function Tn(a,b){v[a+36>>2]=b}function Tk(a){return(a&5)!=0}function Te(a,b){u[a+28>>1]=b}function Sw(){return mb()<<16}function RL(a,b,c){pm(a,b,-c)}function Qu(a){return!v[a>>2]}function Qm(a){return a&1?2:1}function PK(a){a=a|0;return 3}function P7(a){a=a|0;return 6}function L8(a){a=a|0;return 9}function Kb(a){kE(a);return a}function KK(a){a=a|0;return 7}function JS(a){po(Rb(a,0,48))}function Ib(a,b){return a+b|0}function IB(a,b){ec(a,b,1954)}function Gs(a){a=a|0;return 4}function De(a){a=a|0;return 1}function Co(a){return a>>>0<5}function Ae(a){a=a|0;return 2}function zv(a,b){KD(a,_d(b))}function zc(a){return a+12|0}function yu(a,b){ec(a,b,512)}function xd(a,b){v[a+4>>2]=b}function wQ(a,b){ec(a,b,204)}function tm(a,b,c){Go(a,b,c)}function tA(a,b){Yt(a,_d(b))}function so(a,b){he(a,b+8|0)}function sd(a){return a+16|0}function sP(a,b){ec(a,b,263)}function rT(a,b){ec(a,b,576)}function oT(a,b){ec(a,b,674)}function nO(a){return D(a)<N}function lh(a,b,c){tv(a,b,c)}function iP(a,b,c){fl(a,c,b)}function hx(a){return a-12|0}function hd(a,b){return a>>b}function hO(a){gO(a,v[a>>2])}function go(a){return a+14|0}function gT(a){return a+36|0}function fq(a,b){return a<<b}function fI(a,b,c){Rb(a,c,b)}function ec(a,b,c){fc(a,b,c)}function eM(a){return a-32|0}function dm(a,b){v[a+8>>2]=b}function dP(a,b,c){il(a,c,b)}function ci(a,b,c){hD(a,b,c)}function by(a,b){t[a+34|0]=b}function ay(a,b){t[a+32|0]=b}function _N(a,b,c){Xl(a,b,c)}function _A(a,b){lf(a,b,8,2)}function Zy(a){t[a+6152|0]=0}function YU(a,b){ec(a,b,610)}function YT(a,b){ec(a,b,157)}function Xd(a,b){t[a+11|0]=b}function XQ(a,b){ec(a,b,146)}function Wn(a){return a+32|0}function VM(a,b,c){BT(a,b,c)}function TT(a,b){ec(a,b,206)}function TQ(a,b){ec(a,b,608)}function So(a){return a+20|0}function Rs(a){zM(a,v[a>>2])}function Rj(a){return a-36|0}function RO(a){QO(a,v[a>>2])}function Qr(a,b){sp(a,b+4|0)}function QA(a){return a-28|0}function NT(a,b){ec(a,b,236)}function LS(a,b){ec(a,b,128)}function JT(a){return a+10|0}function JR(a,b){ec(a,b,130)}function HR(a,b){ec(a,b,600)}function Ge(a,b){a=a|0;b=b|0}function Gc(a){xd(a,v[a>>2])}function FT(a,b){ec(a,b,102)}function FC(a,b){ec(a,b,497)}function Ep(a,b){z[a+8>>2]=b}function Dq(a,b){ec(a,b,192)}function Dp(a,b){z[a+4>>2]=b}function Cp(a,b){t[a+33|0]=b}function CP(a){return a+48|0}function BR(a,b){ec(a,b,126)}function $x(a,b){t[a+35|0]=b}function $T(a,b){ec(a,b,218)}function yj(a){return a-4|0}function xC(a,b){ec(a,b,38)}function wo(a){v[a+12>>2]=0}function w6(){return 458752}function vq(a,b){ec(a,b,12)}function vC(a,b){fi(a,b,37)}function vA(a,b){ec(a,b,33)}function uR(a,b){ec(a,b,32)}function tC(a,b){ec(a,b,41)}function su(a,b){ec(a,b,64)}function sS(a,b){ec(a,b,52)}function ry(a){Rb(a,0,4096)}function ru(a,b){ec(a,b,66)}function pk(){Bo(11003);L()}function mA(a,b){ec(a,b,40)}function iu(a,b){ec(a,b,22)}function hU(a,b){ec(a,b,98)}function gc(a){return a+4|0}function gR(a,b){ec(a,b,96)}function eL(a){Rb(a,0,2048)}function df(){Zf(11003);L()}function cv(a,b){fc(a,b,22)}function cg(a,b){t[a+3|0]=b}function cU(a,b){ec(a,b,48)}function bC(a,b){ec(a,b,11)}function YB(a,b){fc(a,b,20)}function Xq(a,b){ec(a,b,36)}function VK(a){return 0-a|0}function VB(a,b){ec(a,b,17)}function Sq(a){return a&127}function Ru(a,b){ec(a,b,65)}function Rt(a,b){return a<b}function Re(a){return a+2|0}function RR(a,b){ec(a,b,30)}function Pu(a,b){ec(a,b,16)}function Pe(a){return!Fb(a)}function ND(a,b){ec(a,b,24)}function Mm(a,b){fc(a,b,32)}function MS(a,b){ec(a,b,80)}function Kf(a){return a&255}function Kc(a){return a+1|0}function KT(a){return a+6|0}function Jp(a){Rb(a,0,8192)}function Ji(a){return a+3|0}function HB(a){Rb(a,0,1954)}function GU(a,b){pc(a,b,48)}function Eo(a,b){t[a+1|0]=b}function Db(a){return a+8|0}function DP(a,b){return a<b}function AO(a,b){ec(a,b,27)}function yo(a,b){ec(a,b,7)}function xo(a,b){ec(a,b,5)}function xc(a){v[a+8>>2]=0}function vQ(a){Rb(a,0,204)}function td(a,b){v[a>>2]=b}function sba(a){a=a|0;hb=a}function qT(a){Rb(a,0,576)}function mv(a,b){ec(a,b,3)}function mr(a){a=a|0;nr(a)}function ml(a,b){Go(a,b,0)}function lT(a){Rb(a,0,192)}function jO(a){Sp(a,Pd(a))}function gN(a){Vs(a,Pd(a))}function gC(a,b){ci(a,2,b)}function fN(a){Ws(a,Pd(a))}function eB(a,b){ec(a,b,6)}function dl(a){Wy(a,Pd(a))}function bu(a){RA(a,Pd(a))}function bk(a,b){z[a>>2]=b}function aT(a){CA(a,Pd(a))}function _S(a){DA(a,Pd(a))}function _P(a){Gz(a,Pd(a))}function Zz(a){Rb(a,0,130)}function Zb(a){Ym(v[a>>2])}function XV(a){a=a|0;Ih(a)}function XU(a){Rb(a,0,610)}function XT(a){Rb(a,0,157)}function WQ(a){Rb(a,0,146)}function Vu(){Bo(7678);L()}function VL(a){Zx(a,Pd(a))}function Uh(a){return a!=a}function Tm(a,b){ec(a,b,8)}function TP(a){Rb(a,0,256)}function ST(a){Rb(a,0,206)}function SQ(a){Rb(a,0,608)}function Pq(a,b){ec(a,b,1)}function Oba(){return hb|0}function Nm(a,b){ec(a,b,2)}function Mt(a){nA(a,Pd(a))}function MT(a){Rb(a,0,236)}function Ki(a,b){u[a>>1]=b}function Jh(a,b){ec(a,b,4)}function JK(a,b){pL(a,3,b)}function Hc(a){a=a|0;Jb(a)}function GR(a){Rb(a,0,600)}function EC(a){Rb(a,0,497)}function DT(a){SA(a,Pd(a))}function Bz(){Zf(7678);L()}function AR(a){Rb(a,0,126)}function $P(a){Fz(a,Pd(a))}function zA(a){Rb(a,0,80)}function xT(a){Rb(a,0,56)}function xS(a){Rb(a,0,33)}function wC(a){Rb(a,0,38)}function uB(a){Rb(a,0,66)}function sC(a){Rb(a,0,41)}function rS(a){Rb(a,0,52)}function nd(a,b){t[a|0]=b}function lu(a){Rb(a,0,64)}function hv(a){return a&1}function hR(a){Rb(a,0,96)}function gU(a){Rb(a,0,98)}function fL(a){Ll(a,2048)}function dU(a){Rb(a,0,48)}function bm(a){wb(a+16|0)}function Yq(a){Rb(a,0,36)}function Lj(a){xb(a+16|0)}function F3(){return 2048}function yd(a){yb(a+8|0)}function wB(a,b){qk(a,b)}function uA(a,b){vS(a,b)}function qs(a){wb(a+4|0)}function mQ(a,b){nl(a,b)}function lR(a,b){he(a,b)}function ki(a,b){Oh(a,b)}function fO(a){be(a+8|0)}function dq(a,b){cc(a,b)}function dB(a,b){hc(a,b)}function bt(a,b){gM(a,b)}function Xt(a){xb(a+4|0)}function Wo(a,b){XD(a,b)}function Qc(a){dc(a+8|0)}function OO(a,b){QO(a,b)}function Lx(a,b){dg(a,b)}function Ld(a,b){xd(a,b)}function LO(a,b){Wf(a,b)}function LB(a,b){OJ(a,b)}function Kl(a,b){EB(a,b)}function Gu(a,b){_B(a,b)}function ER(a){Uv(a,512)}function DF(a){v[a>>2]=0}function Ag(a){a=a|0;L()}function AL(a,b){zM(a,b)}function lr(a){Nv(a,36)}function lo(a){GE(a,16)}function fC(a){Uv(a,16)}function dE(a){Ll(a,24)}function _D(a){Nv(a,48)}function Rg(a){Nv(a,24)}function Pha(){va();L()}function Fo(a){GE(a,11)}function Ch(a){t[a|0]=0}function CU(a){Ll(a,48)}function xY(){mF();L()}function ty(a){CM(a,0)}function sy(a){BM(a,0)}function rd(){Bz();L()}function qg(a){$S(a,0)}function os(a){wJ(a,0)}function mF(){wa();L()}function hr(a){KD(a,0)}function hT(a){Yt(a,0)}function fj(a){xJ(a,0)}function ej(a){vJ(a,0)}function br(a){Ll(a,8)}function bM(a){HM(a,0)}function VN(a){Ll(a,7)}function Sc(a){Xe(a,0)}function SS(a){Ll(a,6)}function Li(a){Ll(a,2)}function KS(a){Uv(a,4)}function wm(a){lc(a)}function uP(a){wh(a)}function qf(a){a=a|0}function oQ(a){Lb(a)}function iQ(a){Ie(a)}function iE(a){rr(a)}function hC(a){uk(a)}function bO(a){Xn(a)}function ac(a){xb(a)}function Wz(a){vk(a)}function Vo(a){zc(a)}function Ub(a){wb(a)}function AJ(a){He(a)}
// EMSCRIPTEN_END_FUNCS
e=w;var lb=c([null,vc,ZD,Jl,GX,_m,xX,qX,MD,lX,gX,_C,xW,hW,ZV,Lq,Ii,LV,$,Xu,zl,ZG,nh,Gm,Mja,JU,jf,$ha,Pha,Lha,tha,wA,fha,bha,bea,mga,TR,$0,_0,Yr,TR,ida,vca,PO,kt,Wp,tba,qba,Vaa,Raa,AB,qM,yh,Fc,uaa,maa,jL,$K,Ex,pi,AK,G7,y7,p7,U6,M6,G0,F0,o0,NJ,c5,CN,_3,H3,z3,pJ,$2,R2,M2,s2,b2,X1,U1,L1,A1,p1,pi,l1,k1,h1,d1,b1,Y0,V0,Q0,I0,_G,B0,v0,p0,m0,UA,Jw,va,Ob,WX,VX,UX,TX,SX,RX,bn,QX,PX,_G,OX,NX,ia,LX,KX,JX,rp,IX,HX,FX,UD,TD,EX,Fv,DX,Uo,AX,mr,To,Hl,Qf,wX,Uo,zX,yX,vX,CX,uX,RD,tX,RD,BX,SD,sX,rX,pX,bn,oX,Zc,Ob,kX,yv,jX,nh,iX,LD,hX,Ak,LD,fr,fX,wv,vv,KW,eX,YW,XW,JW,Oi,EW,DW,kv,lD,CW,jaa,kaa,RN,haa,iaa,_x,Ls,Yb,laa,Wd,iD,zW,yW,WC,vW,uW,WC,qW,_u,pW,B9,$e,vga,Xaa,wW,Hq,Mf,zV,Waa,Kja,L9,A9,lW,qC,pC,fW,eW,oC,dW,ug,cW,bW,Cc,aW,$V,vg,kh,_V,Im,YV,mC,XV,UV,$B,TV,SV,RV,Lu,kP,CC,uJ,QV,PV,OV,NV,MV,Ou,KV,RB,zd,Eq,GV,FV,Du,Cu,EV,DV,CV,QB,BV,PB,Mu,AV,El,Tu,uV,vo,tV,Mb,Lf,Qf,sV,xu,rV,kd,Ej,oka,nka,mka,pV,oV,jd,lka,uo,kka,jka,ika,lV,kV,Oi,vu,hka,gka,Jba,fka,Mg,eka,dka,$ja,Bj,cka,bka,dV,aka,Hh,uf,Yja,Xja,Wja,SU,Tja,Bj,zj,Sja,Rja,zq,Qja,rB,RU,Pja,Oja,Nja,Lja,El,zU,wU,Hja,Eja,hn,Cja,tg,WU,Dja,Lu,sU,Bja,Aja,lB,zja,vv,yja,xja,oU,RT,wja,El,tja,vo,ko,sja,rja,oV,qja,pja,oja,lU,nja,Km,mja,lja,kja,ija,Bj,kU,jja,Hh,uf,qB,dja,aja,qC,Yia,Xia,Wia,Via,Sia,vo,Ria,Qia,oo,lU,Pia,Oia,Qf,Nia,Mia,Lia,Kia,Jia,IT,Iia,Hia,uE,Gia,Fia,Eia,OB,HT,Dia,Cia,Bia,Nba,Aia,GT,zia,GT,Zia,yia,Bj,Hh,uf,Fh,tia,sia,ria,oia,nia,mia,lia,kia,oo,jia,iia,hia,KA,rW,gia,fia,eia,dia,cia,oW,bia,aia,_ha,Zha,kT,jT,Yha,Xha,Qf,Wha,Vha,tB,uia,Uha,Tha,via,Sha,Rha,Qha,HA,HA,GA,Oha,Nha,fT,HA,cT,Mha,rY,Kha,Jha,Iha,Hha,Gha,Fha,Eha,bT,pd,eo,sha,AA,Dha,m9,l9,k9,j9,h9,g9,Cha,Bha,Wf,Aha,zha,yha,xha,ZD,Iba,Gba,x9,J9,K9,wha,vha,uha,taa,e9,rp,Eba,Dba,Cba,Bba,oha,nha,mha,lha,kha,jha,iha,hha,gha,eha,dha,aha,$ga,cha,wS,uf,pS,sA,Yga,rA,Xga,Wga,Vga,Uga,qA,Tga,_u,oC,Sga,nS,mS,Tq,oA,Rga,kf,Qga,kS,oo,Ju,oo,HT,Oq,Qf,SU,oo,hn,Nga,Mga,Lga,Kga,kA,Kt,Jga,Iga,Hga,Gga,Fga,Ega,rC,Dga,Cga,Bga,Aga,zga,yga,xga,wga,EA,uga,tga,sga,Qf,eT,dT,NA,rga,qga,Du,vv,pga,oga,nga,lga,kga,mba,Bq,jga,qu,tu,Th,Uaa,rba,ct,YN,Taa,Saa,JN,$s,EN,Qaa,tN,FO,Paa,gz,nj,di,aga,$fa,It,hga,Tt,Yfa,KB,Xfa,Wfa,xR,eo,Vfa,Ufa,wR,Tfa,Sfa,Rfa,Ht,Qfa,Pfa,Ofa,Nfa,Tz,Ifa,Rz,Hfa,Gfa,Ffa,Bj,Hh,uf,di,Cfa,Bfa,Afa,zfa,rA,wfa,vfa,Ht,ufa,Im,M9,rfa,qfa,zj,mR,Rz,Mu,pfa,ofa,nfa,mfa,Et,lfa,Et,kfa,ir,sW,hfa,Bj,ifa,jfa,Oz,$Q,Hh,uf,It,efa,bfa,sA,afa,Zea,Yea,PQ,wR,KA,Xea,Du,Qf,Oea,Nea,QB,Mea,Lea,Kea,Jea,VA,Iea,uo,Eea,Dea,Cea,Bea,Aea,zea,sm,jQ,yea,xea,wea,vea,uea,tea,sea,rea,qea,pea,oea,nea,mea,rA,lea,kea,jea,Tt,iea,hea,gea,vo,eba,yv,pV,lba,kba,vo,jba,di,yv,iba,hba,gba,fea,VP,cea,aea,$da,_da,Zda,Yda,Rq,Vda,Uda,Tda,Sda,Rda,Qda,Pda,Oda,Nda,Mda,Lda,MX,$D,Kda,Qf,Jda,Ida,yl,nba,Pba,AB,TO,Lba,Kba,Hba,Fba,Aba,GO,yba,xba,zO,wba,vba,uba,qO,oO,Rn,lO,pba,oba,mo,cba,zj,SN,jr,gaa,faa,eaa,Oaa,tW,daa,lv,jr,RB,caa,SN,aba,baa,fba,Bj,Hh,uf,dba,Bj,Hh,uf,bba,Bj,Hh,uf,_aa,dV,Bq,Naa,Maa,Laa,Kaa,Jaa,Iaa,Mba,Gda,GP,Gaa,tc,Eaa,E9,Daa,nX,IW,BW,GW,Baa,Aaa,AW,HW,mX,FW,sM,zaa,yaa,xaa,rM,oy,waa,vaa,zba,saa,raa,qaa,paa,wL,v9,Ev,YD,hE,_x,naa,rp,uu,Kq,Zaa,$aa,_9,Z9,zj,Y9,Rz,X9,W9,V9,It,U9,di,T9,S9,R9,Q9,P9,Bj,Hh,uf,$9,I9,H9,G9,F9,Oh,Ul,D9,C9,z9,t9,s9,r9,q9,p9,uL,w9,zp,tL,Ck,Oh,Wf,n9,f9,o9,u9,c9,b9,v8,a9,ak,gL,Tf,qL,O8,w8,Ql,q8,pi,p8,QK,o8,_x,zx,m8,ly,NK,S7,J7,B7,t7,k7,b7,d7,S6,K6,aK,zs,E6,D6,B2,D2,u6,t6,r6,ZJ,oaa,F2,o6,aK,n6,k3,c3,n3,l6,h2,VJ,vx,j6,A3,GJ,y3,rJ,h6,i9,e6,Y7,f6,T7,c6,uE,v3,a6,i3,TJ,kS,SJ,RJ,PJ,S5,Q5,VJ,vx,N5,M5,L5,K5,J5,I5,H5,G5,F5,E5,D5,C5,B5,A5,z5,y5,x5,w5,v5,u5,t5,s5,r5,q5,p5,m5,k5,i5,AD,_1,o3,g5,S4,g3,Q4,O4,Zk,a2,c2,M4,g2,F4,D4,y9,A4,vx,v4,s4,p4,yn,$1,n4,l4,j4,h4,f4,d4,b4,$3,Y3,W3,U3,S3,JJ,N3,L3,lM,Jt,IJ,I3,G3,E3,D3,C3,B3,wp,Yaa,kr,qN,bh,oO,t3,s3,q3,ch,LN,m3,Faa,j3,IY,zr,h3,f3,Im,El,El,d3,Caa,l3,u3,p3,Lv,aa,E2,zJ,yJ,C2,OI,A2,z2,o2,f2,e2,d2,Z1,Y1,fM,Hda,n1,m1,j1,i1,c1,a1,UG,TG,KY,P0,O0,N0,M0,L0,K0,J0,jf,zY,JY,q0,TG,Dw,yw,Z$,Y$,tw,Qh,Ph,Jr,Jb,sw,jp,Yj,Rk,rw,Yl,Q$,P$,Yi,Wg,iG,Xi,Hw,ow,Qh,Ph,Hr,Tr,Ok,H0,zl,rn,Yi,Wg,cG,Xi,v$,q$,YG,l$,Or,Gm,g$,Er,qf,Q_,Mr,P_,O_,N_,SF,L_,J_,I_,Pk,H_,SF,F_,E_,C_,B_,y_,x_,t_,s_,r_,q_,p_,o_,n_,m_,l_,k_,j_,i_,h_,g_,f_,e_,d_,c_,b_,a_,$Z,_Z,ZZ,YZ,XZ,WZ,VZ,UZ,TZ,SZ,RZ,QZ,PZ,AB,Hea,mF,Vm,Nq,Fda,Eda,Dda,Cda,Bda,Ada,zda,yda,xda,wda,vda,uda,tda,sda,rda,qda,pda,oda,nda,mda,lda,kda,jda,hda,gda,fda,eda,dda,cda,bda,ada,$ca,_ca,Zca,Yca,Xca,Wca,Vca,Uca,Tca,Sca,Rca,Qca,Pca,Oca,Nca,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,yca,xca,wca,uca,tca,sca,rca,qca,pca,oca,nca,mca,lca,kca,jca,ica,hca,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Rba,Qba,Vm,Xda,Wda,qia,pia,$ea,_ea,Uea,Tea,_ga,Zga,Mfa,Lfa,qha,pha,wV,vV,hja,gja,WV,VV,JV,HV,Efa,Dfa,dfa,cfa,eea,dea,Vja,Uja,Jja,Ija,kW,jW,iW,gW,tfa,sfa,gfa,ffa,_fa,Zfa,rha,GS,cja,bja,xia,wia,_ja,Zja,vja,uja,yfa,xfa,aaa,O9,N9,Uia,Tia,$ia,_ia,cga,bga,Gea,Fea,Kfa,Jfa,fja,eja,Wea,Vea,Qea,Pea,Gja,Fja,Sea,Rea,iga,ega,dga,nW,mW,yV,xV,Pga,Oga,gga,fga,an,Nq,LW,Hc,No,_J,Hc,jf,Hc,kc,De,De,kc,kc,MW,$W,_W,NW,Hc,No,Hc,xD,WW,VW,UW,TW,SW,RW,QW,PW,OW,Hs,Ix,dL,cL,kc,qf,kc,kc,kc,Ge,Gs,$8,_8,Z8,Y8,X8,ri,_t,_t,Gx,bL,Gx,aL,Gx,aL,qf,GS,W8,V8,U8,T8,S8,qi,_K,s8,kc,kc,De,Fx,Ae,Ae,De,R8,Q8,Ge,qf,Ge,qf,ZK,N8,M8,kc,qf,kc,kc,kc,Ge,L8,YK,K8,J8,I8,H8,ri,G8,F8,E8,D8,C8,B8,A8,z8,y8,x8,qi,UK,kc,kc,De,Ae,Ae,De,XK,WK,Ff,Ag,xY,u8,Hx,t8,kc,r8,bL,d8,U7,K7,C7,u7,l7,c7,T6,L6,m7,d9,P8,n8,Hs,Ix,cL,kc,qf,kc,kc,kc,Ge,PK,l8,k8,j8,i8,h8,ri,g8,qi,OK,kc,kc,De,Ae,Ae,De,f8,e8,DK,R7,Q7,kc,qf,kc,kc,kc,Ge,P7,O7,N7,M7,ri,L7,qi,zK,kc,kc,De,Ae,Ae,Bs,I7,kc,qf,kc,kc,kc,Ge,yK,H7,F7,E7,ri,D7,qi,wK,kc,kc,De,Ae,Ae,Hs,Ix,A7,kc,qf,kc,kc,kc,Ge,yK,z7,x7,w7,ri,v7,qi,uK,kc,kc,De,Ae,Ae,MK,LK,s7,kc,qf,kc,kc,kc,Ge,KK,r7,a8,$7,ri,_7,qi,Z7,kc,kc,De,Ae,Ae,Ge,qf,IK,q7,o7,HK,n7,GK,FK,LK,c8,KK,b8,IK,X7,W7,HK,V7,GK,FK,Bs,j7,kc,qf,kc,kc,kc,Ge,Ae,i7,h7,g7,ri,f7,qi,e7,kc,kc,De,Ae,Ae,qK,a7,$6,kc,qf,kc,kc,_6,Ge,Z6,Y6,X6,W6,ri,V6,qi,wx,kc,kc,De,Ae,Ae,Ge,qf,Bs,R6,kc,qf,kc,kc,kc,Ge,PK,Q6,P6,O6,ri,N6,qi,lK,kc,kc,De,Ae,Ae,Bs,J6,kc,qf,kc,kc,kc,Ge,Gs,I6,H6,G6,ri,F6,qi,jK,kc,kc,De,Ae,Ae,EJ,Hc,x3,qx,w3,qx,qx,Ag,ls,b3,r3,jf,Hc,tT,_t,Ag,jf,Ag,jf,Hc,a3,_2,Ag,hJ,gJ,hJ,gJ,Ge,ms,Ge,ms,kJ,jJ,kJ,jJ,Hc,e3,jf,Hc,Z2,Y2,Hc,_I,ZI,Ag,V2,XI,U2,XI,X2,YI,W2,YI,Hc,T2,S2,Hc,WI,VI,is,is,is,is,Q2,kx,kx,kx,Hc,P2,O2,Hc,UI,TI,K2,RI,J2,RI,N2,SI,L2,SI,Hc,I2,H2,Hc,QI,PI,hs,hs,hs,hs,G2,jx,jx,jx,i2,Hc,No,Hc,II,n2,De,De,m2,l2,Nq,k2,j2,Ag,Ag,p2,Hc,No,Hc,NI,y2,De,kc,De,x2,w2,v2,u2,t2,r2,q2,Ag,ZW,Hc,No,Hc,Hc,dX,De,De,Nq,ED,cX,bX,aX,Ge,ms,Ge,ms,pp,fs,W1,V1,AI,zI,yI,xI,wI,vI,uI,tI,sI,rI,qI,pI,oI,nI,mI,lI,kI,jI,iI,hI,gI,eI,dI,T1,S1,R1,Q1,P1,O1,N1,M1,K1,J1,I1,H1,G1,F1,E1,D1,C1,B1,z1,y1,x1,w1,v1,u1,t1,s1,r1,q1,o1,jf,Ag,jf,Ag,jf,Ag,jf,Ag,g1,f1,e1,Bn,Nw,Ge,pH,oH,nH,kc,kc,X0,mH,W0,Wr,U0,Wr,Vr,Lw,Ge,pH,oH,nH,kc,kc,T0,mH,S0,Wr,R0,Wr,ys,z0,A0,y0,E0,D0,C0,up,WG,x0,w0,Sr,Gw,aH,$G,pf,VG,u0,t0,Ur,Kw,jH,iH,jf,Hc,s0,HY,GY,FY,r0,Vm,Z0,kc,n0,Nw,b0,a0,$$,_$,$J,Ow,Sk,Ow,Lw,f0,e0,d0,c0,Ur,Kw,jH,iH,$J,Ow,Nw,i0,NG,h0,g0,Lw,l0,NG,k0,j0,Sr,Gw,aH,$G,pF,LY,dL,qF,TY,SY,RY,QY,PY,rF,OY,NY,MY,xF,kZ,jZ,iZ,hZ,gZ,kc,fZ,eZ,yF,wZ,vZ,uZ,tZ,sZ,rZ,zF,AZ,ED,IV,zZ,yZ,xZ,jf,Hc,Hc,cZ,bZ,aZ,$Y,_Y,ZY,YY,XY,rF,WY,VY,UY,Hc,tF,tF,gw,De,De,dZ,De,Hc,nZ,mZ,gw,kc,kc,lZ,Gs,Hc,qZ,pZ,gw,kc,kc,oZ,Gs,jf,Hc,X$,W$,V$,jf,Hc,U$,T$,S$,Hc,R$,O$,N$,M$,mG,mG,L$,K$,J$,I$,H$,Hc,G$,F$,E$,D$,bG,bG,C$,B$,A$,z$,y$,Hc,x$,w$,u$,t$,s$,r$,p$,o$,Hc,n$,m$,k$,j$,i$,h$,f$,e$,jf,Hc,Ae,d$,c$,b$,a$,$_,__,HZ,GZ,FZ,EZ,DZ,CZ,BZ,jf,Hc,Ae,Z_,Y_,X_,W_,V_,U_,OZ,NZ,MZ,LZ,KZ,JZ,IZ,hw,AF,T_,hw,AF,S_,Hc,Cr,Cr,Nh,Nh,Nh,UF,kc,Kk,Kk,Hc,Cr,Cr,Nh,Nh,Nh,UF,kc,Kk,Kk,Hc,Br,Br,Nh,Nh,Nh,TF,kc,Kk,Kk,Hc,Br,Br,Nh,Nh,Nh,TF,kc,Kk,Kk,Hc,R_,M_,Hc,K_,G_,Hc,D_,A_,Hc,z_,w_,Hc,JF,v_,Ge,Hc,JF,u_,Ge,jf,Ag,Hc,EY,DY,Hc,CY,AY,BY,Vm,Ag,Hc,yY,wa,jf,Hc,qf,qf,wY,nY,pY,qY,Hc,iY,an,Vm,an,an,an,an,Vm,Hc,hY,Hc,mY,oY,sY,Hc,vY,uY,tY,Hc,jY]);function mb(){return s.byteLength/65536|0}function rb(sb){sb=sb|0;var nb=mb()|0;var ob=nb+sb|0;if(nb<ob&&ob<65536){var pb=new ArrayBuffer(B(ob,65536));var qb=new Int8Array(pb);qb.set(t);t=new Int8Array(pb);u=new Int16Array(pb);v=new Int32Array(pb);w=new Uint8Array(pb);x=new Uint16Array(pb);y=new Uint32Array(pb);z=new Float32Array(pb);A=new Float64Array(pb);s=pb;r.buffer=s;e=w}return nb}return{"wa":qV,"xa":w6,"ya":x6,"za":Hc,"Aa":Jb,"Ba":v6,"Ca":s6,"Da":q6,"Ea":zs,"Fa":Ge,"Ga":z6,"Ha":y6,"Ia":C6,"Ja":_t,"Ka":A6,"La":_J,"Ma":B6,"Na":jf,"Oa":cK,"Pa":bK,"Qa":cK,"Ra":F3,"Sa":gY,"Ta":fY,"Ua":eY,"Va":p6,"Wa":XJ,"Xa":m6,"Ya":WJ,"Za":Y5,"_a":P3,"$a":Q3,"ab":W5,"bb":V5,"cb":U5,"db":X5,"eb":R3,"fb":r4,"gb":J3,"hb":u4,"ib":T4,"jb":M3,"kb":x4,"lb":O3,"mb":w4,"nb":K3,"ob":X3,"pb":T3,"qb":V3,"rb":k4,"sb":g4,"tb":i4,"ub":Z3,"vb":a4,"wb":c4,"xb":e4,"yb":N4,"zb":P4,"Ab":$4,"Bb":W4,"Cb":V4,"Db":U4,"Eb":_4,"Fb":Z4,"Gb":X4,"Hb":Y4,"Ib":e5,"Jb":f5,"Kb":a5,"Lb":d5,"Mb":b5,"Nb":G4,"Ob":L4,"Pb":J4,"Qb":I4,"Rb":K4,"Sb":H4,"Tb":q4,"Ub":j5,"Vb":E4,"Wb":B4,"Xb":R4,"Yb":t4,"Zb":C4,"_b":z4,"$b":y4,"ac":l5,"bc":m4,"cc":n5,"dc":o4,"ec":h5,"fc":k6,"gc":i6,"hc":dY,"ic":g6,"jc":d6,"kc":b6,"lc":$5,"mc":cY,"nc":_5,"oc":Z5,"pc":T5,"qc":R5,"rc":P5,"sc":o5,"tc":O5,"uc":Md,"vc":lb,"wc":Haa,"xc":Oba,"yc":sba,"zc":lY,"Ac":kY,"Bc":bY,"Cc":aY,"Dc":$X,"Ec":YX,"Fc":_X,"Gc":ZX,"Hc":YX,"Ic":XX,"Jc":XX}}return tb(vb)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


